@@ -10,7 +10,7 @@
 # For more details see the full text of the license in the file        *
 # LICENSE or in <http://www.gnu.org/licenses/>.                        *
 #                                                                      *
-# Copyright (C) 2015-2020, Ignacio Fdez. Galván                        *
+# Copyright (C) 2015-2021, Ignacio Fdez. Galván                        *
 #***********************************************************************
 
 from __future__ import (unicode_literals, division, absolute_import, print_function)
@@ -78,7 +78,6 @@ hcbanner = '''#
 # MOLCAS_Count
 # MOLCAS_EMIL_DEBUG
 # MOLCAS_IN_GEO
-# MOLCAS_ISDEV
 # MOLCAS_LASTMOD
 # MOLCAS_LINK
 # MOLCAS_LOG
@@ -98,7 +97,7 @@ class MolcasException(Exception):
 
 class Molcas_wrapper(object):
 
-  version = 'py2.13'
+  version = 'py2.20'
   rc = 0
 
   def __init__(self, **kwargs):
@@ -567,7 +566,6 @@ class Molcas_wrapper(object):
                     'MOLCAS_TEST',
                     'MOLCAS_LOG',
                     'MOLCAS_ECHO_INPUT',
-                    'MOLCAS_ISDEV',
                     'MOLCAS_SILENT_LIC']
     for key in do_not_print:
       if key in lines:
@@ -952,8 +950,10 @@ class Molcas_wrapper(object):
     return rc
 
   def delete_scratch(self, force=False):
+    if (not self.is_serial):
+      line = '*** WorkDir is not cleaned in parallel environment! ***'
     #TODO: use parnell
-    if (self._ready or force):
+    elif (self._ready or force):
       if (realpath(self.scratch) == realpath(self.currdir)):
         line = '*** WorkDir and CurrDir are the same, not cleaned! ***'
       else:
@@ -968,9 +968,9 @@ class Molcas_wrapper(object):
           else:
             remove(i)
         line = '*** WorkDir at {0} cleaned ***'.format(self.scratch)
-      print('*'*len(line))
-      print(line)
-      print('*'*len(line))
+    print('*'*len(line))
+    print(line)
+    print('*'*len(line))
 
   def in_sbin(self, prog):
     '''Return the path of a program in sbin if it exists'''
@@ -1322,8 +1322,9 @@ class Molcas_module(object):
     else:
       self.parent.run_logue('module.prologue')
       if (isfile(self._exec[0]) and access(self._exec[0], X_OK)):
-        teed_call(command, cwd=self.parent.scratch, stdout=self._output, stderr=self._error, no_tee=no_tee)
-        self._read_rc()
+        self.rc = teed_call(command, cwd=self.parent.scratch, stdout=self._output, stderr=self._error, no_tee=no_tee)
+        if (self.rc == 0):
+          self._read_rc()
       else:
         self.rc = '_RC_NOT_AVAILABLE_'
       self.parent.run_logue('module.epilogue')
