@@ -89,6 +89,13 @@ def first_int(string):
 def blank(string):
   return string.strip() == ''
 
+# Find next non-blank line
+def to_next_non_blank(lines):
+  n = 1
+  while ((n < len(lines)) and blank(lines[n])):
+    n += 1
+  return n
+
 # Check if the current line starts a group
 #  1: group matches, consume one line
 #  0: group doesn't match
@@ -421,11 +428,12 @@ def test_custom(lines, keyword):
 
   elif (module == 'DMRGSCF'):
     if (name == 'SOCCUPY'):
-      ll = 1
+      ll = 0
       while (l+ll < len(lines)):
         try:
-          parts = fortran_split(lines[l+ll])
-          assert all([i in '0ud2' for i in parts])
+          parts = lines[l+ll].split()
+          for part in parts:
+            assert all([i in '0ud2,' for i in part])
           ll += 1
         except:
           break
@@ -642,7 +650,7 @@ def test_custom(lines, keyword):
             elif (parts[0].upper() == 'PROJOP'):
               ll = 1
               n = first_int(lines[l+ll])
-              ll += 1
+              ll += to_next_non_blank(lines[l+ll:])
               for i in range(n+1):
                 n1, n2 = to_int(fortran_split(lines[l+ll])[0:2])
                 ll += test_standard(lines[l+ll:], 'REALS', n2+n1*(1+n2))
@@ -669,6 +677,20 @@ def test_custom(lines, keyword):
             assert (len(parts) > 1)
           elif any([cmp_str(parts[0], i) for i in ['MUON', 'PSEUDO', 'FRAGMENT']]):
             pass
+          elif (cmp_str(parts[0], 'PP')):
+            n1, n2 = to_int(parts[2:4])
+            ll = 0
+            ll += to_next_non_blank(lines[l+ll:])
+            for i in range(n2+1):
+              n1 = first_int(lines[l+ll])
+              ll += to_next_non_blank(lines[l+ll:])
+              for j in range(n1):
+                parts = fortran_split(lines[l+ll])
+                n = fortran_int(parts[0])
+                nums = to_float(parts[1:3])
+                ll += to_next_non_blank(lines[l+ll:])
+            if (ll):
+              l += ll-1
           elif (cmp_str(parts[0], 'SPEC')):
             l += 1
             while (l < len(lines)):
@@ -900,6 +922,145 @@ def test_custom(lines, keyword):
     else:
       return None
 
+  elif (module == 'MULA'):
+    if (name == 'ATOMS'):
+      try:
+        while (first_word(lines[l]).upper() != 'END'):
+          l += to_next_non_blank(lines[l:])
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    elif (name == 'ENERGIES'):
+      try:
+        word = first_word(lines[l])
+        assert (word.upper() == 'FIRST')
+        l += to_next_non_blank(lines[l:])
+        parts = fortran_split(lines[l])
+        n = fortran_float(parts[0])
+        assert (parts[1].upper() in ['EV', 'AU'])
+        l += to_next_non_blank(lines[l:])
+        word = first_word(lines[l])
+        assert (word.upper() == 'SECOND')
+        l += to_next_non_blank(lines[l:])
+        parts = fortran_split(lines[l])
+        n = fortran_float(parts[0])
+        assert (parts[1].upper() in ['EV', 'AU'])
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    elif (name == 'FORCE'):
+      try:
+        word = first_word(lines[l])
+        assert (word.upper() == 'FIRST')
+        l += to_next_non_blank(lines[l:])
+        while (first_word(lines[l]).upper() != 'SECOND'):
+          l += to_next_non_blank(lines[l:])
+        l += to_next_non_blank(lines[l:])
+        while (first_word(lines[l]).upper() != 'END'):
+          l += to_next_non_blank(lines[l:])
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    elif (name == 'GEOMETRY'):
+      try:
+        word = first_word(lines[l]).upper()
+        if (word == 'FILE'):
+          l += to_next_non_blank(lines[l:])
+        elif (word == 'CARTESIAN'):
+          l += to_next_non_blank(lines[l:])
+          word = first_word(lines[l])
+          assert (word.upper() == 'FIRST')
+          l += to_next_non_blank(lines[l:])
+          while (first_word(lines[l]).upper() != 'END'):
+            parts = fortran_split(lines[l])
+            nums = to_float(parts[1:4])
+            l += to_next_non_blank(lines[l:])
+          l += to_next_non_blank(lines[l:])
+          word = first_word(lines[l])
+          assert (word.upper() == 'SECOND')
+          l += to_next_non_blank(lines[l:])
+          while (first_word(lines[l]).upper() != 'END'):
+            parts = fortran_split(lines[l])
+            nums = to_float(parts[1:4])
+            l += to_next_non_blank(lines[l:])
+          l += to_next_non_blank(lines[l:])
+        elif (word == 'INTERNAL'):
+          l += to_next_non_blank(lines[l:])
+          word = first_word(lines[l])
+          assert (word.upper() == 'FIRST')
+          l += to_next_non_blank(lines[l:])
+          while (first_word(lines[l]).upper() != 'END'):
+            parts = fortran_split(lines[l])
+            if (parts[0].upper() == 'BOND'):
+              assert (len(parts) >= 3)
+            elif (parts[0].upper() == 'ANGLE'):
+              assert (len(parts) >= 4)
+            elif (parts[0].upper() == 'TORSION'):
+              assert (len(parts) >= 5)
+            elif (parts[0].upper() == 'OUTOFPL'):
+              assert (len(parts) >= 5)
+            l += to_next_non_blank(lines[l:])
+          l += to_next_non_blank(lines[l:])
+          word = first_word(lines[l])
+          assert (word.upper() == 'SECOND')
+          l += to_next_non_blank(lines[l:])
+          while (first_word(lines[l]).upper() != 'END'):
+            parts = fortran_split(lines[l])
+            if (parts[0].upper() == 'BOND'):
+              assert (len(parts) >= 3)
+            elif (parts[0].upper() == 'ANGLE'):
+              assert (len(parts) >= 4)
+            elif (parts[0].upper() == 'TORSION'):
+              assert (len(parts) >= 5)
+            elif (parts[0].upper() == 'OUTOFPL'):
+              assert (len(parts) >= 5)
+            l += to_next_non_blank(lines[l:])
+          l += to_next_non_blank(lines[l:])
+        else:
+          return None
+      except:
+        return None
+    elif (name == 'INTERNAL'):
+      try:
+        while (first_word(lines[l]).upper() != 'END'):
+          parts = fortran_split(lines[l])
+          if (parts[0].upper() == 'BOND'):
+            assert (len(parts) >= 3)
+          elif (parts[0].upper() == 'ANGLE'):
+            assert (len(parts) >= 4)
+          elif (parts[0].upper() == 'TORSION'):
+            assert (len(parts) >= 5)
+          elif (parts[0].upper() == 'OUTOFPL'):
+            assert (len(parts) >= 5)
+          l += to_next_non_blank(lines[l:])
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    elif (name == 'MODES'):
+      try:
+        while (first_word(lines[l]).upper() != 'END'):
+          nums = to_int(fortran_split(lines[l]))
+          l += to_next_non_blank(lines[l:])
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    elif (name == 'TRANSITIONS'):
+      try:
+        word = first_word(lines[l])
+        assert (word.upper() == 'FIRST')
+        l += to_next_non_blank(lines[l:])
+        nums = to_int(fortran_split(lines[l]))
+        l += to_next_non_blank(lines[l:])
+        word = first_word(lines[l])
+        assert (word.upper() == 'SECOND')
+        l += to_next_non_blank(lines[l:])
+        nums = to_int(fortran_split(lines[l]))
+        l += to_next_non_blank(lines[l:])
+      except:
+        return None
+    else:
+      return None
+
   elif (module == 'POLY_ANISO'):
     if (name in ['PAIR', 'ALIN', 'LIN9']):
       try:
@@ -1135,7 +1296,7 @@ def test_custom(lines, keyword):
         l += ll
       except:
         return None
-    elif (name == 'PROPERTY'):
+    elif (name in ['PROPERTY', 'SOPROPERTY']):
       try:
         parts = fortran_split_quotes(lines[l])
         n = fortran_int(parts.pop(0))
