@@ -49,9 +49,7 @@
 #include "rctfld.fh"
       Character Method*8, Label*80
       Real*8 Grad(nGrad), Temp(nGrad)
-      parameter (lforce=20)
-      real*8 force(lforce)
-      common /finfld/force
+#include "finfld.fh"
       character*30 fldname
       External MltGrd,MltMmG
       Real*8, Allocatable:: Coor(:,:), Fock(:), D_Var(:)
@@ -303,26 +301,26 @@ CAOM>
          iComp = 1
          Do iMltpl = 0, lMax
             Do ix = iMltpl, 0, -1
-               If (Mod(ix,2).eq.0) Then
-                  iSymX=1
-               Else
-                  ixyz=1
-                  iSymX=2**IrrFnc(ixyz)
-               End If
+*              If (Mod(ix,2).eq.0) Then
+*                 iSymX=1
+*              Else
+*                 ixyz=1
+*                 iSymX=2**IrrFnc(ixyz)
+*              End If
                Do iy = iMltpl-ix, 0, -1
-                  If (Mod(iy,2).eq.0) Then
-                     iSymY=1
-                  Else
-                     ixyz=2
-                     iSymY=2**IrrFnc(ixyz)
-                  End If
-                  iz = iMltpl-ix-iy
-                  If (Mod(iz,2).eq.0) Then
-                     iSymZ=1
-                  Else
-                     ixyz=4
-                     iSymZ=2**IrrFnc(ixyz)
-                  End If
+*                 If (Mod(iy,2).eq.0) Then
+*                    iSymY=1
+*                 Else
+*                    ixyz=2
+*                    iSymY=2**IrrFnc(ixyz)
+*                 End If
+*                 iz = iMltpl-ix-iy
+*                 If (Mod(iz,2).eq.0) Then
+*                    iSymZ=1
+*                 Else
+*                    ixyz=4
+*                    iSymZ=2**IrrFnc(ixyz)
+*                 End If
 *                 lOper(iComp) = MltLbl(iSymX,MltLbl(iSymY,iSymZ))
 *-----------------Compute only total symmetric contributions
                   lOper(iComp) = 1
