@@ -17,15 +17,11 @@
 #include "real.fh"
 #include "disp.fh"
       Real*8 Grad(nGrad),C(3)
-      parameter (lforce=20)
-      real*8 Force(lforce)
-      common /finfld/Force
+#include "finfld.fh"
 *
-      logical TstFnc,TF
+      logical, external :: TF
 *
       Ind(ixyz,ix,iz) = (ixyz-ix)*(ixyz-ix+1)/2 + iz + 1
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
 *
       iIrrep=0
       do 800 ixop=0,nOrdOp
