@@ -38,7 +38,7 @@
 
 *     Local variables
       Integer iDCRT(0:7)
-      Logical TstFnc, TF
+      Logical, External :: TF
 #ifdef _PATHSCALE_
       Save Fact
 #endif
@@ -47,14 +47,10 @@
       Logical JfGrad(3,4)
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,
-     &                       dc(mdc)%nStab)
-*
-      iRout = 150
-      iPrint = nPrint(iRout)
 *
 #ifdef _DEBUGPRINT_
+      iRout = 150
+      iPrint = nPrint(iRout)
       If (iPrint.ge.99) Then
          Write (6,*) ' In NAGrd: nArr=',nArr
          nDAO = nElem(la) * nElem(lb)
@@ -123,6 +119,7 @@ C     If (iPrint.ge.99) Call RecPrt('DAO',' ',DAO,nZeta,nDAO)
 *
       kdc = 0
       Do kCnttp = 1, nCnttp
+         If (kCnttp==iCnttp_Dummy) Go To 111
          If (dbsc(kCnttp)%Charge.eq.Zero) Go To 111
          Do kCnt = 1, dbsc(kCnttp)%nCntr
             C(1:3)=dbsc(kCnttp)%Coor(1:3,kCnt)
