@@ -8,17 +8,14 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine Size_SO_block_g(iSD4,nSD,Petite,nSO,No_batch)
+      Subroutine Size_SO_block_g(iSD4,nSD,nSO,No_batch)
       Implicit Real*8 (a-h,o-z)
       Integer iSD4(0:nSD,4)
-      Logical No_batch, Petite
+      Logical No_batch
 *
-      nSO = MemSO2_P(iSD4( 1,1),iSD4( 1,2),iSD4( 1,3),iSD4( 1,4),
-     &               iSD4( 2,1),iSD4( 2,2),iSD4( 2,3),iSD4( 2,4),
-     &               iSD4(11,1),iSD4(11,2),iSD4(11,3),iSD4(11,4))
+      nSO = MemSO2_P(iSD4( 2,1),iSD4( 2,2),iSD4( 2,3),iSD4( 2,4),
+     &               iSD4( 7,1),iSD4( 7,2),iSD4( 7,3),iSD4( 7,4))
       No_batch=nSO.eq.0
 *
       Return
-c Avoid unused argument warnings
-      If (.False.) Call Unused_logical(Petite)
       End
