@@ -12,7 +12,7 @@
 
   IMPLICIT NONE
 
-  Integer, parameter    :: wp=SELECTED_REAL_KIND(p=15,r=307)
+  Integer, parameter        :: wp=kind(0.d0)
   INTEGER, INTENT(in)   :: nH, nTempMagn
   REAL (wp), INTENT(in) :: H(nH), TempMagn(nTempMagn)
   REAL (wp), INTENT(in) :: MHexp(nH,nTempMagn)
@@ -21,36 +21,15 @@
   ! local variables
   REAL (wp) :: hmin, hmax, MHmin_exp, MHmax_exp, MHmin_calc, MHmax_calc, MHmin, MHmax
   REAL (wp) :: gnuplot_version
-  INTEGER           :: file_number, istat, iH, iTempMagn, LuPlt, LuData, file_size, StdOut, iErr
-  LOGICAL           :: file_exist, is_file_open, execute_gnuplot_cmd, dbg
-  CHARACTER(LEN=100):: line1, line2, lineOut, cdummy
-  CHARACTER(LEN=100):: gnuplot_CMD, filedat, fileplt
-  CHARACTER(LEN=7) :: color(111)
-  INTEGER, EXTERNAL:: AixRm
-
-  color(  1)="#ffffff"; color(  2)="#000000"; color(  3)="#a0a0a0"; color(  4)="#ff0000"; color(  5)="#00c000"
-  color(  6)="#0080ff"; color(  7)="#c000ff"; color(  8)="#00eeee"; color(  9)="#c04000"; color( 10)="#c8c800"
-  color( 11)="#4169e1"; color( 12)="#ffc020"; color( 13)="#008040"; color( 14)="#c080ff"; color( 15)="#306080"
-  color( 16)="#8b0000"; color( 17)="#408000"; color( 18)="#ff80ff"; color( 19)="#7fffd4"; color( 20)="#a52a2a"
-  color( 21)="#ffff00"; color( 22)="#40e0d0"; color( 23)="#000000"; color( 24)="#1a1a1a"; color( 25)="#333333"
-  color( 26)="#4d4d4d"; color( 27)="#666666"; color( 28)="#7f7f7f"; color( 29)="#999999"; color( 30)="#b3b3b3"
-  color( 31)="#c0c0c0"; color( 32)="#cccccc"; color( 33)="#e5e5e5"; color( 34)="#ffffff"; color( 35)="#f03232"
-  color( 36)="#90ee90"; color( 37)="#add8e6"; color( 38)="#f055f0"; color( 39)="#e0ffff"; color( 40)="#eedd82"
-  color( 41)="#ffb6c1"; color( 42)="#afeeee"; color( 43)="#ffd700"; color( 44)="#00ff00"; color( 45)="#006400"
-  color( 46)="#00ff7f"; color( 47)="#228b22"; color( 48)="#2e8b57"; color( 49)="#0000ff"; color( 50)="#00008b"
-  color( 51)="#191970"; color( 52)="#000080"; color( 53)="#0000cd"; color( 54)="#87ceeb"; color( 55)="#00ffff"
-  color( 56)="#ff00ff"; color( 57)="#00ced1"; color( 58)="#ff1493"; color( 59)="#ff7f50"; color( 60)="#f08080"
-  color( 61)="#ff4500"; color( 62)="#fa8072"; color( 63)="#e9967a"; color( 64)="#f0e68c"; color( 65)="#bdb76b"
-  color( 66)="#b8860b"; color( 67)="#f5f5dc"; color( 68)="#a08020"; color( 69)="#ffa500"; color( 70)="#ee82ee"
-  color( 71)="#9400d3"; color( 72)="#dda0dd"; color( 73)="#905040"; color( 74)="#556b2f"; color( 75)="#801400"
-  color( 76)="#801414"; color( 77)="#804014"; color( 78)="#804080"; color( 79)="#8060c0"; color( 80)="#8060ff"
-  color( 81)="#808000"; color( 82)="#ff8040"; color( 83)="#ffa040"; color( 84)="#ffa060"; color( 85)="#ffa070"
-  color( 86)="#ffc0c0"; color( 87)="#ffff80"; color( 88)="#ffffc0"; color( 89)="#cdb79e"; color( 90)="#f0fff0"
-  color( 91)="#a0b6cd"; color( 92)="#c1ffc1"; color( 93)="#cdc0b0"; color( 94)="#7cff40"; color( 95)="#a0ff20"
-  color( 96)="#bebebe"; color( 97)="#d3d3d3"; color( 98)="#d3d3d3"; color( 99)="#a0a0a0"; color(100)="#a0b6cd"
-  color(101)="#000000"; color(102)="#1a1a1a"; color(103)="#333333"; color(104)="#4d4d4d"; color(105)="#666666"
-  color(106)="#7f7f7f"; color(107)="#999999"; color(108)="#b3b3b3"; color(109)="#cccccc"; color(110)="#e5e5e5"
-  color(111)="#ffffff"
+  INTEGER   :: file_number, iH, iTempMagn, LuPlt, LuData, file_size, StdOut
+  LOGICAL   :: file_exist, is_file_open, execute_gnuplot_cmd, dbg
+  CHARACTER(LEN=300)  :: line1, line2, cdummy
+  CHARACTER(LEN=300)  :: datafile, plotfile, imagefile, epsfile
+  INTEGER, EXTERNAL   :: AixRm
+  INTEGER             :: Length
+  CHARACTER(LEN=1023) :: realname_plt, realname_dat, realname_png, realname_eps, gnuplot_CMD
+  INTEGER             :: iErr, ifilenumber
+  INTEGER, EXTERNAL   :: IsFreeUnit
 
   dbg=.false.
   iErr=0
@@ -72,7 +51,6 @@
   MHmin=MIN(MHmin_exp,MHmin_calc)-0.08_wp*MAX(MHmax_exp,MHmax_calc)
   MHmax=MAX(MHmax_exp,MHmax_calc)+0.08_wp*MAX(MHmax_exp,MHmax_calc)
 
-
   IF (dbg) WRITE (StdOut,*) 'nH        = ',nH
   IF (dbg) WRITE (StdOut,*) 'hmin      = ',hmin
   IF (dbg) WRITE (StdOut,*) 'hmax      = ',hmax
@@ -90,11 +68,9 @@
   END IF
 
   ! generate the GNUPLOT script in the $WorkDir
-  lineOut=' '
   line1=' '
   line2=' '
   gnuplot_CMD=' '
-  istat=0
   file_exist=.false.
   is_file_open=.false.
   file_size=0
@@ -114,6 +90,7 @@
      ! delete the file
      IF (dbg) WRITE (StdOut,'(A)') 'deleting the file...'
      iErr=AixRm("lineOUT")
+     IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
   ELSE
      IF (dbg) WRITE (StdOut,'(A)') 'file  "lineOUT" does not exist in WorkDir'
   END IF
@@ -122,7 +99,12 @@
   ! find the gnuplot
   IF (dbg) WRITE (StdOut,'(A)') 'inquire which GNUPLOT'
 
+!#ifdef __INTEL_COMPILER
   CALL systemf ( "which gnuplot >> lineOUT", iErr )
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!  CALL execute_command_line ( "which gnuplot >> lineOUT" )
+!#endif
 
   INQUIRE(FILE="lineOUT",EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number,SIZE=file_size)
 
@@ -135,7 +117,7 @@
     IF (file_size>0) then
       IF (dbg) WRITE (StdOut,'(A)') 'new file  "lineOUT"  exists in WorkDir'
 
-      file_number=453
+      file_number=IsFreeUnit(93)
       Call molcas_open(file_number,'lineOUT')
 
       READ (file_number,'(A)') line1
@@ -158,6 +140,7 @@
   END IF
   ! remove file "lineOUT"
   iErr=AixRm("lineOUT")
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
 !--------------------------------------------------------------------------------------------
 
 
@@ -167,8 +150,13 @@
     ! attempt to execute the script
     WRITE (gnuplot_CMD,'(2A)') trim(line2),' --version > lineOUT'
     IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',gnuplot_CMD
+!#ifdef __INTEL_COMPILER
     CALL systemf ( gnuplot_CMD, iErr )
-    file_number=452
+    IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!    CALL execute_command_line ( gnuplot_CMD )
+!#endif
+    file_number=IsFreeUnit(94)
     Call molcas_open(file_number,'lineOUT')
     READ (file_number,*) cdummy, gnuplot_version
     IF (dbg) WRITE (StdOut,'(A,F4.1)') 'gnuplot_version = ', gnuplot_version
@@ -176,43 +164,80 @@
     CLOSE (file_number)
     ! remove file "lineOUT"
     iErr=AixRm("lineOUT")
+    IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
   END IF
+
+
+
+
+  !WRITE(datafile ,'(3A)')  'MH.dat'
+  !WRITE(imagefile,'(3A)')  'MH.png'
+  !WRITE(epsfile  ,'(3A)')  'MH.eps'
+  !WRITE(plotfile ,'(3A)')  'MH.plt'
+  !Call prgmtranslate(datafile ,realname_dat,Length)
+  !Call prgmtranslate(imagefile,realname_png,Length)
+  !Call prgmtranslate(epsfile  ,realname_eps,Length)
+  !Call prgmtranslate(plotfile ,realname_plt,Length)
+  !IF (dbg) THEN
+  !  WRITE(StdOut,'(3A)') 'realname_dat=',trim(realname_dat)
+  !  WRITE(StdOut,'(3A)') 'realname_png=',trim(realname_png)
+  !  WRITE(StdOut,'(3A)') 'realname_eps=',trim(realname_eps)
+  !  WRITE(StdOut,'(3A)') 'realname_plt=',trim(realname_plt)
+  !END IF
 !--------------------------------------------------------------------------------------------
-
-
-
-
   DO iTempMagn=1,nTempMagn
+
      ! generate the file "MH.dat":
-     WRITE(filedat,'(A,I0,A)') 'MH_T_',iTempMagn,'.dat'
-     INQUIRE(FILE=filedat,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
-     IF(file_exist)  iErr=AixRm(trim(filedat))
-     LuData=554+iTempMagn
-     Call molcas_open(LuData,filedat)
-     IF (dbg) WRITE (StdOut,*) 'Opening'//trim(filedat)//' file'
+     WRITE(datafile ,'(A,I0,A)') 'MH_T_',iTempMagn,'.dat'
+     WRITE(imagefile,'(A,I0,A)') 'MH_T_',iTempMagn,'.png'
+     WRITE(epsfile  ,'(A,I0,A)') 'MH_T_',iTempMagn,'.eps'
+     Write(plotfile ,'(A,I0,A)') 'MH_T_',iTempMagn,'.plt'
+     Call prgmtranslate(datafile ,realname_dat,Length)
+     Call prgmtranslate(imagefile,realname_png,Length)
+     Call prgmtranslate(epsfile  ,realname_eps,Length)
+     Call prgmtranslate(plotfile ,realname_plt,Length)
+
+     INQUIRE(FILE=datafile,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+     IF(file_exist)  iErr=AixRm( trim(datafile) )
+     IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+     ifilenumber=0
+     ifilenumber=95+iTempMagn
+     LuData=IsFreeUnit(ifilenumber)
+     Call molcas_open(LuData,datafile)
+     IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(datafile)//'" file. iTempMagn=', iTempMagn
+     IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(realname_dat)//'" file. iTempMagn=',iTempMagn
      DO iH=1,nH
         WRITE (LuData,'(3ES24.14)') H(iH), MHexp(iH,iTempMagn), MHcalc(iH,iTempMagn)
      END DO
-     IF (dbg) WRITE (StdOut,*) 'Writing into the '//trim(filedat)//' file. iTempMagn=',iTempMagn
+     IF (dbg) WRITE (StdOut,*) 'Writing into the "'//trim(datafile)//'" file. iTempMagn=',iTempMagn
+     IF (dbg) WRITE (StdOut,*) 'Writing into the "'//trim(realname_dat)//'" file. iTempMagn=',iTempMagn
      CLOSE (LuData)
-     IF (dbg) WRITE (StdOut,*) 'Closing the '//trim(filedat)//' file. iTempMagn=',iTempMagn
+     IF (dbg) WRITE (StdOut,*) 'Closing the "'//trim(datafile)//'" file. iTempMagn=',iTempMagn
+     IF (dbg) WRITE (StdOut,*) 'Closing the "'//trim(realname_dat)//'" file. iTempMagn=',iTempMagn
      FLUSH (StdOut)
 
 
 
      ! generate the GNUPLOT script in the $WorkDir
-     Write(fileplt,'(A,I0,A)') 'MH_T_',iTempMagn,'.plt'
-     INQUIRE(FILE=fileplt,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
-     IF(file_exist)  iErr=AixRm(trim(fileplt))
-     LuPlt=455+iTempMagn
-     Call molcas_open(LuPlt,fileplt)
-     IF (dbg) WRITE (StdOut,*) 'Opening '//trim(fileplt)//' file'
+
+     INQUIRE(FILE=plotfile,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+     IF(file_exist)  iErr=AixRm( trim(plotfile) )
+     IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+     ifilenumber=0
+     ifilenumber=105+iTempMagn
+     LuPlt=IsFreeUnit(ifilenumber)
+     Call molcas_open(LuPlt,plotfile)
+     IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(plotfile)//'" file'
+     IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(realname_plt)//'" file'
+
+
+     ! EPS or PNG images:
 
 
      IF ( gnuplot_version < 5.0_wp ) Then
      !===  GNUPLOT VERSION 4 and below ==>>  generate EPS
         WRITE (LuPlt,'(A)') 'set terminal postscript eps enhanced color  size 3.0, 2.0 font "arial, 10"'
-        WRITE (LuPlt,'(A,i0,A)') 'set output "MH_T_',iTempMagn,'.eps"'
+        WRITE (LuPlt,'(A)') 'set output "'//trim(realname_eps)//'" '
         WRITE (LuPlt,'(A)') 'set grid'
         WRITE (LuPlt,'(A)')
         WRITE (LuPlt,'(A)') '# Axes'
@@ -237,16 +262,16 @@
         WRITE (LuPlt,'(A)')
         WRITE (LuPlt,'(A)') '# actual plotting'
 
-        WRITE (LuPlt,'(A,F7.3,A)') 'plot "'//trim(filedat)//'" using 1:2 with points  lt 1  lw 3 lc rgb "black"  title "Exp. T=',&
-                                    TempMagn(iTempMagn),' K.", \'
-        WRITE (LuPlt,'(A,F7.3,A)') '     "'//trim(filedat)//'" using 1:3 with lines   lt 1  lw 8 lc rgb "red"    title "Calc.T=',&
-                                    TempMagn(iTempMagn),' K."'
+        WRITE (LuPlt,'(A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:2 with points  lt 1  lw 3 lc rgb "black"'//&
+                                   '  title "Exp. T=',TempMagn(iTempMagn),' K.", \'
+        WRITE (LuPlt,'(A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:3 with lines   lt 1  lw 8 lc rgb "red"  '//&
+                                   '  title "Calc.T=',TempMagn(iTempMagn),' K."'
         WRITE (LuPlt,'(A)')
 
      ELSE IF ( (gnuplot_version >= 5.0_wp) .AND.(gnuplot_version < 6.0_wp) ) Then
      !===  GNUPLOT VERSION 5 and above ==>>  generate PNG
         WRITE (LuPlt,'(A)') 'set terminal pngcairo transparent enhanced font "arial,10" fontscale 4.0 size 1800, 1200'
-        WRITE (LuPlt,'(A,i0,A)') 'set output "MH_T_',iTempMagn,'.png"'
+        WRITE (LuPlt,'(A)') 'set output "'//trim(realname_png)//'" '
         WRITE (LuPlt,'(A)') 'set grid'
         WRITE (LuPlt,'(A)')
         WRITE (LuPlt,'(A)') '# Axes'
@@ -271,10 +296,10 @@
         WRITE (LuPlt,'(A)')
         WRITE (LuPlt,'(A)') '# actual plotting'
 
-        WRITE (LuPlt,'(A,F7.3,A)') 'plot "'//trim(filedat)//'" using 1:2 with circles lt 1  lw 3 lc rgb "black"  title "Exp. T=',&
-                                    TempMagn(iTempMagn),' K.", \'
-        WRITE (LuPlt,'(A,F7.3,A)') '     "'//trim(filedat)//'" using 1:3 with lines   lt 1  lw 8 lc rgb "red"    title "Calc.T=',&
-                                    TempMagn(iTempMagn),' K."'
+        WRITE (LuPlt,'(A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:2 with circles lt 1  lw 3 lc rgb "black"'//&
+                                   '  title "Exp. T=',TempMagn(iTempMagn),' K.", \'
+        WRITE (LuPlt,'(A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:3 with lines   lt 1  lw 8 lc rgb "red"  '//&
+                                   '  title "Calc.T=',TempMagn(iTempMagn),' K."'
         WRITE (LuPlt,'(A)')
      ELSE
        WRITE (StdOut,*) 'GNUPLOT has version: ', gnuplot_version
@@ -285,18 +310,60 @@
 
      IF (execute_gnuplot_cmd) Then
        ! attempt to execute the script
-       WRITE (gnuplot_CMD,'(5A)') trim(line2),'  ',trim(fileplt)
-       IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',gnuplot_CMD
+       IF (dbg) THEN
+         file_exist=.false.
+         WRITE (StdOut,*) trim(realname_plt)
+         INQUIRE(FILE=trim(realname_plt),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+         IF(file_exist) THEN
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_plt)//'" exists.'
+         ELSE
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_plt)//'" does not exist.'
+         END IF
+         file_exist=.false.
+         WRITE (StdOut,*) trim(realname_dat)
+         INQUIRE(FILE=trim(realname_dat),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+         IF(file_exist) THEN
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_dat)//'" exists.'
+         ELSE
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_dat)//'" does not exist.'
+         END IF
+       END IF
+
+       WRITE (gnuplot_CMD,'(5A)') trim(line2),' < ',trim(realname_plt)
+       IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',trim(gnuplot_CMD)
+
+!#ifdef __INTEL_COMPILER
        CALL systemf ( gnuplot_CMD, iErr )
+       IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!       CALL execute_command_line ( gnuplot_CMD )
+!#endif
+
        IF ( gnuplot_version < 5.0_wp ) Then
-         WRITE (StdOut,'(A,i0,A)') 'File "MH_T_',iTempMagn,'.eps" was created in Working directory.'
+         file_exist=.false.
+         INQUIRE(FILE=trim(realname_eps),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+         IF(file_exist) THEN
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_eps)//'" was created in Working directory.'
+         ELSE
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_eps)//'" was NOT created in Working directory.'
+         END IF
        ELSE
-         WRITE (StdOut,'(A,i0,A)') 'File "MH_T_',iTempMagn,'.png" was created in Working directory.'
+         file_exist=.false.
+         INQUIRE(FILE=trim(realname_png),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+         IF(file_exist) THEN
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_png)//'" was created in Working directory.'
+         ELSE
+           WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_png)//'" was NOT created in Working directory.'
+         END IF
        END IF
      END IF
+
   END DO ! iTempMagn
 
   RETURN
+#ifdef _WARNING_WORKAROUND_
+  IF (.FALSE.) CALL UNUSED_CHARACTER(cdummy)
+#endif
   END SUBROUTINE plot_MH_with_Exp
 
 
@@ -307,7 +374,7 @@
 
   IMPLICIT NONE
 
-  Integer, parameter    :: wp=SELECTED_REAL_KIND(p=15,r=307)
+  Integer, parameter        :: wp=kind(0.d0)
   INTEGER, INTENT(in)   :: nH, nTempMagn
   REAL (wp), INTENT(in) :: H(nH), TempMagn(nTempMagn)
   REAL (wp), INTENT(in) :: MHcalc(nH,nTempMagn)
@@ -315,12 +382,16 @@
   ! local variables
   REAL (wp) :: hmin, hmax, MHmin_calc, MHmax_calc, MHmin, MHmax, r
   REAL (wp) :: gnuplot_version
-  INTEGER           :: file_number, istat, iH, iTempMagn, LuPlt, LuData, ik, ic, file_size, StdOut, iErr
-  LOGICAL           :: file_exist, is_file_open, execute_gnuplot_cmd, dbg
-  CHARACTER(LEN=100):: line1, line2, lineOut, fmtline, cdummy
-  CHARACTER(LEN=100):: gnuplot_CMD
-  CHARACTER(LEN=7) :: color(111)
-  INTEGER, EXTERNAL:: AixRm
+  INTEGER   :: file_number, iH, iTempMagn, LuPlt, LuData, ik, ic, file_size, StdOut
+  LOGICAL   :: file_exist, is_file_open, execute_gnuplot_cmd, dbg
+  CHARACTER(LEN=300)    :: line1, line2, fmtline, cdummy
+  CHARACTER(LEN=300)    :: datafile, plotfile, imagefile, epsfile
+  CHARACTER(LEN=7)      :: color(111)
+  INTEGER, EXTERNAL     :: AixRm
+  INTEGER               :: Length
+  CHARACTER(LEN=1023)   :: realname_plt, realname_dat, realname_png, realname_eps, gnuplot_CMD
+  INTEGER               :: iErr
+  INTEGER, EXTERNAL     :: IsFreeUnit
 
   color(  1)="#ffffff"; color(  2)="#000000"; color(  3)="#a0a0a0"; color(  4)="#ff0000"; color(  5)="#00c000"
   color(  6)="#0080ff"; color(  7)="#c000ff"; color(  8)="#00eeee"; color(  9)="#c04000"; color( 10)="#c8c800"
@@ -347,8 +418,8 @@
   color(111)="#ffffff"
 
   dbg=.false.
-  StdOut=6
   iErr=0
+  StdOut=6
   hmin=0.0_wp
   hmax=0.0_wp
   MHmin_calc=0.0_wp
@@ -378,11 +449,9 @@
   END IF
 
   ! generate the GNUPLOT script in the $WorkDir
-  lineOut=' '
   line1=' '
   line2=' '
   gnuplot_CMD=' '
-  istat=0
   file_exist=.false.
   is_file_open=.false.
   file_size=0
@@ -402,6 +471,7 @@
      ! delete the file
      IF (dbg) WRITE (StdOut,'(A)') 'deleting the file...'
      iErr=AixRm("lineOUT")
+     IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
   ELSE
      IF (dbg) WRITE (StdOut,'(A)') 'file  "lineOUT" does not exist in WorkDir'
   END IF
@@ -410,7 +480,13 @@
   ! find the gnuplot
   IF (dbg) WRITE (StdOut,'(A)') 'inquire which GNUPLOT'
 
+!#ifdef __INTEL_COMPILER
   CALL systemf ( "which gnuplot >> lineOUT", iErr )
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!  CALL execute_command_line ( "which gnuplot >> lineOUT" )
+!#endif
+
   INQUIRE(FILE="lineOUT",EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number,SIZE=file_size)
 
   IF (dbg) WRITE (StdOut,*) 'File_number =',file_number
@@ -422,7 +498,7 @@
     IF (file_size>0) then
       IF (dbg) WRITE (StdOut,'(A)') 'new file  "lineOUT"  exists in WorkDir'
 
-      file_number=453
+      file_number=IsFreeUnit(103)
       Call molcas_open(file_number,"lineOUT")
 
       READ (file_number,'(A)') line1
@@ -446,6 +522,7 @@
   END IF
   ! remove file "lineOUT"
   iErr=AixRm("lineOUT")
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
 !--------------------------------------------------------------------------------------------
 
 
@@ -455,8 +532,13 @@
     ! attempt to execute the script
     WRITE (gnuplot_CMD,'(2A)') trim(line2),' --version > lineOUT'
     IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',gnuplot_CMD
+!#ifdef __INTEL_COMPILER
     CALL systemf ( gnuplot_CMD, iErr )
-    file_number=452
+    IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!    CALL execute_command_line ( gnuplot_CMD )
+!#endif
+    file_number=IsFreeUnit(102)
     Call molcas_open(file_number,"lineOUT")
     READ (file_number,*) cdummy, gnuplot_version
     IF (dbg) WRITE (StdOut,'(A,F4.1)') 'gnuplot_version = ', gnuplot_version
@@ -464,37 +546,70 @@
     CLOSE (file_number)
     ! remove file "lineOUT"
     iErr=AixRm("lineOUT")
+    IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
   END IF
 
 
+
+!--------------------------------------------------------------------------------------------
+! get the true real names of the files on disk:
+  WRITE(datafile ,'(3A)')  'MH.dat'
+  WRITE(imagefile,'(3A)')  'MH.png'
+  WRITE(epsfile  ,'(3A)')  'MH.eps'
+  WRITE(plotfile ,'(3A)')  'MH.plt'
+  Call prgmtranslate(datafile ,realname_dat,Length)
+  Call prgmtranslate(imagefile,realname_png,Length)
+  Call prgmtranslate(epsfile  ,realname_eps,Length)
+  Call prgmtranslate(plotfile ,realname_plt,Length)
+  IF (dbg) THEN
+    WRITE(StdOut,'(3A)') 'realname_dat=',trim(realname_dat)
+    WRITE(StdOut,'(3A)') 'realname_png=',trim(realname_png)
+    WRITE(StdOut,'(3A)') 'realname_eps=',trim(realname_eps)
+    WRITE(StdOut,'(3A)') 'realname_plt=',trim(realname_plt)
+  END IF
+
+
+
+
+
 !----------------------------------------------------------------------------------------
 ! create the file "MH.dat"
-  INQUIRE(FILE="MH.dat",EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
-  IF(file_exist)  iErr=AixRm("MH.dat")
-  LuData=454
-  Call molcas_open(LuData,"MH.dat")
-  IF (dbg) WRITE (StdOut,*) 'Opening "MH.dat" file'
+  INQUIRE(FILE=datafile,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+  IF(file_exist)  iErr=AixRm( trim(datafile) )
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+  LuData=IsFreeUnit(104)
+  Call molcas_open(LuData, datafile )
+  IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(datafile)//'" file'
+  IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(realname_dat)//'" file'
   write(fmtline,'(A,i0,A)') '(',nTempMagn+1,'ES24.14)'
   DO iH=1,nH
      WRITE (LuData,fmtline) H(iH), ( MHcalc(iH,iTempMagn), iTempMagn=1,nTempMagn )
   END DO
-  IF (dbg) WRITE (StdOut,*) 'Writing into the "MH.dat" file'
+  IF (dbg) WRITE (StdOut,*) 'Writing into the "'//trim(datafile)//'"file'
+  IF (dbg) WRITE (StdOut,*) 'Writing into the "'//trim(realname_dat)//'"file'
   CLOSE (LuData)
-  IF (dbg) WRITE (StdOut,*) 'Closing the "MH.dat" file'
+  IF (dbg) WRITE (StdOut,*) 'Closing the "'//trim(datafile)//'" file'
+  IF (dbg) WRITE (StdOut,*) 'Closing the "'//trim(realname_dat)//'" file'
   FLUSH (StdOut)
 
+
+
+!----------------------------------------------------------------------------------------
   ! generate the GNUPLOT script in the $WorkDir
-  INQUIRE(FILE="MH.plt",EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
-  IF(file_exist) iErr=AixRm("MH.plt")
-  LuPlt=455
-  Call molcas_open(LuPlt,"MH.plt")
-  IF (dbg) WRITE (StdOut,*) 'Opening "MH.plt" file'
+  INQUIRE(FILE=plotfile,EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+  IF(file_exist) iErr=AixRm( trim(plotfile) )
+  IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+  LuPlt=IsFreeUnit(105)
+  Call molcas_open(LuPlt, plotfile )
+  IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(plotfile)//'" file'
+  IF (dbg) WRITE (StdOut,*) 'Opening "'//trim(realname_plt)//'" file'
+
 
 
   IF ( gnuplot_version < 5.0_wp ) Then
   !===  GNUPLOT VERSION 4 and below ==>>  generate EPS
      WRITE (LuPlt,'(A)') 'set terminal postscript eps enhanced color  size 3.0, 2.0 font "arial, 10"'
-     WRITE (LuPlt,'(A)') 'set output "MH.eps"'
+     WRITE (LuPlt,'(A)') 'set output "'//trim(realname_eps)//'" '
      WRITE (LuPlt,'(A)') 'set grid'
      WRITE (LuPlt,'(A)')
      WRITE (LuPlt,'(A)') '# Axes'
@@ -523,19 +638,19 @@
        Call RANDOM_NUMBER(r)
        ic=INT(111.0_wp*r)
        IF((iTempMagn.eq.1).AND.(nTempMagn.gt.1)) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                          '"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
        ELSE IF ((iTempMagn.eq.1).AND.(nTempMagn.eq.1)) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
        END IF
        IF ( (iTempMagn.lt.nTempMagn).AND.(iTempMagn.ne.1) ) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
        END IF
        IF ( (iTempMagn.eq.nTempMagn).AND.(nTempMagn.gt.1) ) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
        END IF
      END DO
 
@@ -543,7 +658,7 @@
   ELSE IF ( (gnuplot_version >= 5.0_wp) .AND.(gnuplot_version < 6.0_wp) ) Then
   !===  GNUPLOT VERSION 5 and above ==>>  generate PNG
      WRITE (LuPlt,'(A)') 'set terminal pngcairo transparent enhanced font "arial,10" fontscale 4.0 size 1800, 1200'
-     WRITE (LuPlt,'(A)') 'set output "MH.png"'
+     WRITE (LuPlt,'(A)') 'set output "'//trim(realname_png)//'" '
      WRITE (LuPlt,'(A)') 'set grid'
      WRITE (LuPlt,'(A)')
      WRITE (LuPlt,'(A)') '# Axes'
@@ -572,19 +687,19 @@
        Call RANDOM_NUMBER(r)
        ic=INT(110.0_wp*r)
        IF((iTempMagn.eq.1).AND.(nTempMagn.gt.1)) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                          '"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
        ELSE IF ((iTempMagn.eq.1).AND.(nTempMagn.eq.1)) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') 'plot "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
        END IF
        IF ( (iTempMagn.lt.nTempMagn).AND.(iTempMagn.ne.1) ) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K.", \'
        END IF
        IF ( (iTempMagn.eq.nTempMagn).AND.(nTempMagn.gt.1) ) THEN
-         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "MH.dat" using 1:',ik,' with lines lt 1  lw  8 lc rgb "'//color(ic)//&
-                                         '"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
+         WRITE (LuPlt,'(A,i0,A,F7.3,A)') '     "'//trim(realname_dat)//'" using 1:',ik,&
+               ' with lines lt 1  lw  8 lc rgb "'//color(ic)//'"  title "Calc. M at T=',TempMagn(iTempMagn),'K."'
        END IF
      END DO
   ELSE
@@ -596,21 +711,61 @@
   CLOSE (LuPlt)
 
 
-  WRITE (StdOut,'(A)') 'File "MH.png" was created in Working directory.'
-
   IF (execute_gnuplot_cmd) Then
     ! attempt to execute the script
-    WRITE (gnuplot_CMD,'(A,A)') trim(line2),'  MH.plt'
-    IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',gnuplot_CMD
+    IF (dbg) THEN
+      file_exist=.false.
+      WRITE (StdOut,*) trim(realname_plt)
+      INQUIRE(FILE=trim(realname_plt),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+      IF(file_exist) THEN
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_plt)//'" exists.'
+      ELSE
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_plt)//'" does not exist.'
+      END IF
+      file_exist=.false.
+      WRITE (StdOut,*) trim(realname_dat)
+      INQUIRE(FILE=trim(realname_dat),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+      IF(file_exist) THEN
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_dat)//'" exists.'
+      ELSE
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_dat)//'" does not exist.'
+      END IF
+    END IF
+
+    WRITE (gnuplot_CMD,'(5A)') trim(line2),' < ',trim(realname_plt)
+    IF (dbg) WRITE (StdOut,'(A,A)') 'gnuplot_CMD=',trim(gnuplot_CMD)
+
+!#ifdef __INTEL_COMPILER
     CALL systemf ( gnuplot_CMD, iErr )
+    IF(dbg)  WRITE (StdOut,*) 'iErr = ',iErr
+!#else
+!    CALL execute_command_line ( gnuplot_CMD )
+!#endif
+
     IF ( gnuplot_version < 5.0_wp ) Then
-      WRITE (StdOut,'(A,i0,A)') 'File "MH.eps" was created in Working directory.'
+      file_exist=.false.
+      INQUIRE(FILE=trim(realname_eps),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+      IF(file_exist) THEN
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_eps)//'" was created in Working directory.'
+      ELSE
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_eps)//'" was NOT created in Working directory.'
+      END IF
     ELSE
-      WRITE (StdOut,'(A,i0,A)') 'File "MH.png" was created in Working directory.'
+      file_exist=.false.
+      INQUIRE(FILE=trim(realname_png),EXIST=file_exist,OPENED=is_file_open,NUMBER=file_number)
+      IF(file_exist) THEN
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_png)//'" was created in Working directory.'
+      ELSE
+        WRITE (StdOut,'(A,i0,A)') 'File "'//trim(realname_png)//'" was NOT created in Working directory.'
+      END IF
     END IF
   END IF
 
+
   RETURN
+#ifdef _WARNING_WORKAROUND_
+  IF (.FALSE.) CALL UNUSED_CHARACTER(cdummy)
+#endif
   END SUBROUTINE plot_MH_no_Exp
 
 
