@@ -13,8 +13,12 @@
 ************************************************************************
       SUBROUTINE CASPT2(IRETURN)
       USE SUPERINDEX
-      USE INPUTDATA
+      USE INPUTDATA, ONLY: INPUT
       USE PT2WFN
+      use output_caspt2, only:iPrGlb,terse,usual,verbose
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par, King, Set_Do_Parallel
+#endif
       IMPLICIT NONE
       INTEGER IRETURN
 *----------------------------------------------------------------------*
@@ -64,20 +68,15 @@ C     HDF5 SUPPORT BY S. VANCOILLIE (2016)
 C
 ************************************************************************
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "constants.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "pt2_guga.fh"
-#include "WrkSpc.fh"
 #include "intgrl.fh"
 #include "eqsolv.fh"
 #include "chocaspt2.fh"
 #include "stdalloc.fh"
       CHARACTER(LEN=60) STLNE2
-#ifdef _MOLCAS_MPP_
-      LOGICAL KING, Is_Real_Par
-#endif
 * Timers
       REAL*8  CPTF0, CPTF10, CPTF11, CPTF12, CPTF13, CPTF14,
      &       TIOTF0,TIOTF10,TIOTF11,TIOTF12,TIOTF13,TIOTF14,
@@ -112,17 +111,17 @@ C
       Call StatusLine('CASPT2:','Initializing')
       CALL PT2INI
 * Initialize effective Hamiltonian and eigenvectors
-      CALL MMA_ALLOCATE(Heff,Nstate,Nstate)
-      CALL MMA_ALLOCATE(Ueff,Nstate,Nstate)
+      CALL MMA_ALLOCATE(Heff,Nstate,Nstate,Label='Heff')
+      CALL MMA_ALLOCATE(Ueff,Nstate,Nstate,Label='Ueff')
       Heff=0.0D0
       Ueff=0.0D0
 * Initialize zeroth-order Hamiltonian and eigenvectors
-      CALL MMA_ALLOCATE(H0,Nstate,Nstate)
-      CALL MMA_ALLOCATE(U0,Nstate,Nstate)
-      H0=0.0D0
+      CALL MMA_ALLOCATE(H0,Nstate,Nstate,Label='H0')
+      CALL MMA_ALLOCATE(U0,Nstate,Nstate,Label='U0')
+      H0(:,:)=0.0D0
 * U0 is initialized as the identity matrix, in the case of a
 * standard MS-CASPT2 calculation it will not be touched anymore
-      U0=0.0D0
+      U0(:,:)=0.0D0
       call dcopy_(Nstate,[1.0d0],0,U0,Nstate+1)
 *
 *======================================================================*
@@ -144,7 +143,7 @@ C
         DO I=1,NSTATE
           HEFF(I,I) = REFENE(I)
         END DO
-        IF (IPRGLB.GE.DEBUG) THEN
+        IF (IPRGLB.GE.VERBOSE) THEN
           write(6,*)' Heff[1] in the original model space basis:'
           call prettyprint(Heff,Nstate,Nstate)
         END IF
@@ -152,7 +151,7 @@ C
 
 * In case of a XDW-CASPT2 calculation we first rotate the CASSCF
 * states according to the XMS prescription in xdwinit
-      if (IFXMS.and.IFDW) then
+      if ((IFXMS .and. IFDW) .or. (IFRMS)) then
         call xdwinit(Heff,H0,U0)
         if (IFEFOCK) then
           call wgtinit(H0)
@@ -376,37 +375,39 @@ C End of long loop over groups
       IF (IRETURN.NE.0) GOTO 9000
       IF(IPRGLB.GE.TERSE) THEN
        WRITE(6,*)' Total CASPT2 energies:'
-       DO I=1,NSTATE
-        IF ((NLYROOT.NE.0).AND.(I.NE.NLYROOT)) CYCLE
-        CALL PrintResult(6,'(6x,A,I3,5X,A,F16.8)',
+       IF (IFXMS.or.IFRMS) THEN
+        WRITE(6,*)
+        WRITE(6,*)' State-specific CASPT2 energies obtained using'
+        WRITE(6,*)' rotated states do not have a well-defined physical'
+        WRITE(6,*)' meaning, however they can be extracted from the'
+        WRITE(6,*)' diagonal of the effective Hamiltonian.'
+       ELSE
+        DO I=1,NSTATE
+         IF ((NLYROOT.NE.0).AND.(I.NE.NLYROOT)) CYCLE
+         CALL PrintResult(6,'(6x,A,I3,5X,A,F16.8)',
      &    'CASPT2 Root',MSTATE(I),'Total energy:',ENERGY(I),1)
-       END DO
-       WRITE(6,*)
-       IF (IFXMS) THEN
-        WRITE(6,*)' Note that these CASPT2 energies are obtained using'
-        WRITE(6,*)' the XMS Fock operator and thus do not correspond'
-        WRITE(6,*)' to the true single-state CASPT2 ones.'
+        END DO
+        IF(IPRGLB.GE.VERBOSE.AND.(NLYROOT.EQ.0)) THEN
+         WRITE(6,*)
+         WRITE(6,*)' Relative CASPT2 energies:'
+         WRITE(6,'(1X,A4,4X,A12,1X,A10,1X,A10,1X,A10)')
+     &     'Root', '(a.u.)', '(eV)', '(cm^-1)', '(kJ/mol)'
+         ISTATE=1
+         DO I=2,NSTATE
+           IF (ENERGY(I).LT.ENERGY(ISTATE)) ISTATE=I
+         END DO
+         DO I=1,NSTATE
+          RELAU = ENERGY(I)-ENERGY(ISTATE)
+          RELEV = RELAU * CONV_AU_TO_EV_
+          RELCM = RELAU * CONV_AU_TO_CM1_
+          RELKJ = RELAU * CONV_AU_TO_KJ_PER_MOLE_
+          WRITE(6,'(1X,I4,4X,F12.8,1X,F10.2,1X,F10.1,1X,F10.2)')
+     &     MSTATE(I), RELAU, RELEV, RELCM, RELKJ
+         END DO
+        END IF
        END IF
        WRITE(6,*)
       END IF
-      IF(IPRGLB.GE.VERBOSE.AND.(NLYROOT.EQ.0)) THEN
-       WRITE(6,*)' Relative CASPT2 energies:'
-       WRITE(6,'(1X,A4,4X,A12,1X,A10,1X,A10,1X,A10)')
-     &   'Root', '(a.u.)', '(eV)', '(cm^-1)', '(kJ/mol)'
-       ISTATE=1
-       DO I=2,NSTATE
-         IF (ENERGY(I).LT.ENERGY(ISTATE)) ISTATE=I
-       END DO
-       DO I=1,NSTATE
-        RELAU = ENERGY(I)-ENERGY(ISTATE)
-        RELEV = RELAU * CONV_AU_TO_EV_
-        RELCM = RELAU * CONV_AU_TO_CM1_
-        RELKJ = RELAU * CONV_AU_TO_KJ_PER_MOLE_
-        WRITE(6,'(1X,I4,4X,F12.8,1X,F10.2,1X,F10.1,1X,F10.2)')
-     &   MSTATE(I), RELAU, RELEV, RELCM, RELKJ
-       END DO
-       WRITE(6,*)
-      END IF
 
       IF(NLYROOT.NE.0) IFMSCOUP=.FALSE.
       IF(IFMSCOUP) THEN
@@ -447,13 +448,13 @@ C End of long loop over groups
       Call Put_iScalar('NumGradRoot',iRlxRoot)
       Call Store_Energies(NSTATE,ENERGY,iRlxRoot)
 
-      CALL MMA_DEALLOCATE(UEFF)
-      CALL MMA_DEALLOCATE(U0)
 9000  CONTINUE
 
 C Free resources, close files
-      CALL PT2CLS
+      CALL PT2CLS()
 
+      CALL MMA_DEALLOCATE(UEFF)
+      CALL MMA_DEALLOCATE(U0)
       CALL MMA_DEALLOCATE(HEFF)
       CALL MMA_DEALLOCATE(H0)
 
