@@ -11,7 +11,8 @@
 * Copyright (C) 1997, Per Ake Malmqvist                                *
 ************************************************************************
       SUBROUTINE CREIPH_CASPT2(Heff,Ueff,U0)
-      USE REFWFN
+      use output_caspt2, only:iPrGlb,usual
+      USE REFWFN, ONLY: REFWFN_FILENAME, IADR15
       IMPLICIT REAL*8 (A-H,O-Z)
 C Normal operation: A new file, 'JOBMIX', will be created, with the
 C CMO's and CI arrays of the JOBIPH, except that the CI arrays have
@@ -22,7 +23,6 @@ C Also, replace the original CASSCF energies with CASPT2 or MS-CASPT2
 C energies.
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "pt2_guga.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
@@ -94,7 +94,7 @@ C to JOBMIX, we use the same TOC array, IADR15.
 * of uninitialized memory does not get its knickers twisted
       CALL DCOPY_(MXROOT,[0.0D0],0,WEIGHT,1)
       CALL WR_RASSCF_INFO(JOBMIX,1,iAd15,
-     &                    NACTEL,ISPIN,NSYM,LSYM,
+     &                    NACTEL,ISPIN,NSYM,STSYM,
      &                    NFRO,NISH,NASH,NDEL,NBAS,8,
      &                    NAME,LENIN8*MXORB,NCONF,HEADER,144,
      &                    TITLE,4*18*MXTIT,POTNUC,
@@ -148,8 +148,8 @@ CSVC: translates orbital index to levels
 * PAM07: Eliminate unsafe IPOSFILE calls, use instead dummy i/o operations
 * to find disk addresses to CI arrays:
       NIDIST=0
-      DO JSTATE=1,NSTATE
-        JSNUM=MSTATE(JSTATE)
+      DO ISTATE=1,NSTATE
+        JSNUM=MSTATE(ISTATE)
         NIDIST=MAX(NIDIST,JSNUM)
       END DO
       CALL GETMEM('DIST','ALLO','INTE',LIDIST,NIDIST)
@@ -196,18 +196,18 @@ C Write a diagonal Hamiltonian in the JOBMIX:
         END IF
         DO ISTATE=1,NSTATE
           CALL DCOPY_(MXCI,[0.0D0],0,WORK(LCI2),1)
-          DO JSTATE=1,NSTATE
-            JSNUM=MSTATE(JSTATE)
+          DO IISTATE=1,NSTATE
+            JSNUM=MSTATE(IISTATE)
             IDISK=IWORK(LIDIST-1+JSNUM)
             CALL DDAFILE(JOBIPH,2,WORK(LCI1),NCONF,IDISK)
-            X=Ueff(JSTATE,ISTATE)
+            X=Ueff(IISTATE,ISTATE)
             CALL DAXPY_(NCONF,X,WORK(LCI1),1,WORK(LCI2),1)
           END DO
           IF(ISCF.EQ.0) THEN
             IF(IPRGLB.GE.USUAL) THEN
               WRITE(6,'(1x,a,i3)')
      &        ' The CI coefficients for the MIXED state nr. ',ISTATE
-              CALL PRWF_CP2(LSYM,NCONF,WORK(LCI2),CITHR)
+              CALL PRWF_CP2(STSYM,NCONF,WORK(LCI2),CITHR)
             END IF
           END IF
           IDISK=IWORK(LIDIST-1+ISTATE)
@@ -217,18 +217,18 @@ C Write a diagonal Hamiltonian in the JOBMIX:
           CALL CollapseOutput(0,'Mixed CI coefficients:')
           WRITE(6,*)
         END IF
-C In case of XMS/XDW and NOMUL, the CI vectors are replaced by the
+C In case of XMS/XDW/RMS and NOMUL, the CI vectors are replaced by the
 C rotated zeroth-order states (they should have been printed earlier,
 C in grpini)
-      ELSE IF (IFXMS) THEN
+      ELSE IF (IFXMS.or.IFRMS) THEN
         DO ISTATE=1,NSTATE
           ISNUM=MSTATE(ISTATE)
           CALL DCOPY_(MXCI,[0.0D0],0,WORK(LCI2),1)
-          DO JSTATE=1,NSTATE
-            JSNUM=MSTATE(JSTATE)
+          DO IISTATE=1,NSTATE
+            JSNUM=MSTATE(IISTATE)
             IDISK=IWORK(LIDIST-1+JSNUM)
             CALL DDAFILE(JOBIPH,2,WORK(LCI1),NCONF,IDISK)
-            X=U0(JSTATE,ISTATE)
+            X=U0(IISTATE,ISTATE)
             CALL DAXPY_(NCONF,X,WORK(LCI1),1,WORK(LCI2),1)
           END DO
           IDISK=IWORK(LIDIST-1+ISNUM)
