@@ -17,15 +17,16 @@
 * SWEDEN                                     *
 *--------------------------------------------*
       SUBROUTINE DENS(IVEC,DMAT)
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par, King
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 #include "sigma.fh"
-#include "para_info.fh"
       DIMENSION DMAT(*)
 
 C Compute total density matrix as symmetry-blocked array of
