@@ -18,11 +18,10 @@
 * SWEDEN                                     *
 *--------------------------------------------*
       SUBROUTINE MCCTL(HEFF)
+      use output_caspt2, only:iPrGlb,verbose
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
-#include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
 #include "stdalloc.fh"
