@@ -20,11 +20,11 @@
 * contravariant components. 980928, P-A Malmqvist
 *--------------------------------------------
       SUBROUTINE MKRHS(IVEC)
+      use output_caspt2, only:iPrGlb,verbose
       IMPLICIT REAL*8 (A-H,O-Z)
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -71,7 +71,6 @@ C INTEGRAL BUFFERS:
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -143,14 +142,13 @@ C Put W on disk:
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
       DIMENSION ERI(*), SCR(*)
 *#define _KIGEJ_
 *#define _KIGTJ_
-*#include <mig_kig.fh>
+*#include "mig_kig.fh"
 
 C Set up RHS vector of PT2 Linear Equation System, in vector
 C number IVEC of LUSOLV for cases 2 and 3 (VJTI).
@@ -166,11 +164,9 @@ C VJTI CASE:
           NISP=NIGEJ(ISYM)
           NVP=NASP*NISP
           IF(NVP.EQ.0) GOTO 290
-          NSBP=(NASP*(NASP+1))/2
           NASM=NTGTU(ISYM)
           NISM=NIGTJ(ISYM)
           NVM=NASM*NISM
-          NSBM=(NASM*(NASM+1))/2
 C   Allocate WP,WM
           NV=NVP+NVM
           CALL GETMEM('WB','ALLO','REAL',LW,NV)
@@ -275,7 +271,6 @@ C  Put WM on disk
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -370,7 +365,6 @@ C   Put W on disk
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -396,7 +390,6 @@ C   Allocate W; W subdivided into W1,W2.
           NIS=NISUP(ISYM,5)
           NV=NAS*NIS
           IF(NV.EQ.0) GOTO 490
-          NSD=(NAS*(NAS+1))/2
 C Compute W1(tu,ai)=(ai,tu) + FIMO(a,i)*delta(t,u)/NACTEL
 C Compute W2(tu,ai)=(ti,au)
           CALL GETMEM('WD','ALLO','REAL',LW,NV)
@@ -456,7 +449,6 @@ C   Put W on disk.
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -464,7 +456,7 @@ C   Put W on disk.
       DIMENSION ERI1(*),ERI2(*), SCR(*)
 *#define _KIGEJ_
 *#define _KIGTJ_
-*#include <mig_kig.fh>
+*#include "mig_kig.fh"
 
 C Set up RHS vector of PT2 Linear Equation System, in vector
 C number IVEC of LUSOLV, for cases 6 and 7 (VJAI).
@@ -490,11 +482,9 @@ C   Allocate W with parts WP,WM
           NAS=NASH(ISYM)
           NISP=NISUP(ISYM,6)
           NISM=NISUP(ISYM,7)
-          NIS=NISP+NISM
           NVP=NAS*NISP
           IF(NVP.EQ.0) GOTO 590
           NVM=NAS*NISM
-          NSE=(NAS*(NAS+1))/2
           NV=NVP+NVM
           CALL GETMEM('WE','ALLO','REAL',LW,NV)
           LWP=LW
@@ -561,7 +551,6 @@ C   Put WP and WM on disk.
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -585,8 +574,6 @@ C number IVEC of LUSOLV, for cases 8 and 9 (BVAT).
           NVP=NASP*NISP
           IF(NVP.EQ.0)GOTO 690
           NVM=NASM*NISM
-          NSFP=(NASP*(NASP+1))/2
-          NSFM=(NASM*(NASM+1))/2
           CALL GETMEM('WFP','ALLO','REAL',LWP,NVP)
           IF(NVM.GT.0) CALL GETMEM('WFM','ALLO','REAL',LWM,NVM)
 C   Let W(t,u,ab)=(aubt)
@@ -662,7 +649,6 @@ C   Put WM on disk
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
@@ -693,11 +679,9 @@ C   Allocate W with parts WP,WM
           NAS=NASH(ISYM)
           NISP=NISUP(ISYM,10)
           NISM=NISUP(ISYM,11)
-          NIS=NISP+NISM
           NVP=NAS*NISP
           IF(NVP.EQ.0) GOTO 790
           NVM=NAS*NISM
-          NSG=(NAS*(NAS+1))/2
           NV=NVP+NVM
           CALL GETMEM('WG','ALLO','REAL',LW,NV)
           CALL DCOPY_(NV,[0.0D0],0,WORK(LW),1)
@@ -767,14 +751,13 @@ C   Put WP and WM on disk.
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
 #include "SysDef.fh"
       DIMENSION ERI1(*),ERI2(*), SCR(*)
 *#define _KIGEJ_
 *#define _KIGTJ_
-*#include <mig_kig.fh>
+*#include "mig_kig.fh"
 
 C Set up RHS vector of PT2 Linear Equation System, in vector
 C number IVEC of LUSOLV, for cases 12 and 13 (BJAI).
@@ -866,12 +849,14 @@ C With new norm., divide by /SQRT(12)
 CSVC: special routine to save the RHS array. MKRHS works in serial, so
 C in case of a true parallel run we need to put the local array in a
 C global array and then save that to disk in a distributed fashion.
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 
 #include "rasdim.fh"
 #include "WrkSpc.fh"
 #include "caspt2.fh"
-#include "para_info.fh"
 
       NAS=NASUP(ISYM,ICASE)
       NIS=NISUP(ISYM,ICASE)
