@@ -20,7 +20,6 @@
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
 C Transform to orbitals that diagonalize the diagonal
@@ -51,7 +50,7 @@ C     work-array pointers
       INTEGER LXMAT,NXMAT
 #endif
 C     #orbitals per symmetry
-      INTEGER NF,NI,NA,NR1,NR2,NR3,NS,NO,NB
+      INTEGER NI,NA,NR1,NR2,NR3,NS,NO,NB
       INTEGER NSCT,NCMOSCT
 
 
@@ -78,7 +77,6 @@ C     #orbitals per symmetry
 * ICMOSTA,ICMOEND: Section of CMO for each subspace.
       ICMOEND=0
       DO ISYM=1,NSYM
-        NF=NFRO(ISYM)
         NI=NISH(ISYM)
         NA=NASH(ISYM)
         NR1=NRAS1(ISYM)
@@ -249,19 +247,19 @@ C Finally, loop again over symmetries, transforming the CI:
             IF(NA.GT.0) THEN
               IF(NR1.GT.0) THEN
                 ISTART=NAES(ISYM)+1
-                CALL TRACI_RPT2(ISTART,NR1,TORB(ITO),LSYM,
+                CALL TRACI_RPT2(ISTART,NR1,TORB(ITO),STSYM,
      &                                         NCONF,WORK(LCI))
               END IF
               ITO=ITO+NR1**2
               IF(NR2.GT.0) THEN
                 ISTART=NAES(ISYM)+NR1+1
-                CALL TRACI_RPT2(ISTART,NR2,TORB(ITO),LSYM,
+                CALL TRACI_RPT2(ISTART,NR2,TORB(ITO),STSYM,
      &                                         NCONF,WORK(LCI))
               END IF
               ITO=ITO+NR2**2
               IF(NR3.GT.0) THEN
                 ISTART=NAES(ISYM)+NR1+NR2+1
-                CALL TRACI_RPT2(ISTART,NR3,TORB(ITO),LSYM,
+                CALL TRACI_RPT2(ISTART,NR3,TORB(ITO),STSYM,
      &                                         NCONF,WORK(LCI))
               END IF
             END IF
