@@ -19,10 +19,8 @@
       SUBROUTINE MKSEG_CP2(IDRT,IDOWN,LTV,IVR,MVL,MVR,ISGMNT,VSGMNT)
       IMPLICIT REAL*8 (A-H,O-Z)
       CHARACTER(LEN=26) CC1,CC2,CTVPT,CBVPT,CSVC
-      CHARACTER(LEN=20) FRML(7)
 #include "pt2_guga.fh"
-      COMMON /SEGTAB/ IC1(26),IC2(26),ITVPT(26),IBVPT(26),ISVC(26),
-     &                NIVR,LIVR,NSGMNT,LSGMNT
+#include "segtab.fh"
       DIMENSION IVR(NVERT,2),ISGMNT(NVERT,26),VSGMNT(NVERT,26)
       DIMENSION IDRT(NVERT,5),IDOWN(NVERT,0:3),LTV(-1:NLEV)
       DIMENSION MVL(NMIDV,2),MVR(NMIDV,2)
@@ -30,6 +28,7 @@ C     PARAMETER (LTAB=1, NTAB=2, IATAB=3, IBTAB=4, ICTAB=5)
       PARAMETER (IATAB=3, IBTAB=4)
       PARAMETER (ZERO=0.0D0, ONE=1.0D00)
 #ifdef _DEBUGPRINT_
+      CHARACTER(LEN=20) FRML(7)
       CHARACTER(LEN=20) TEXT
 #endif
 
@@ -45,6 +44,7 @@ C    NUMBER OF THE SEGMENT. THE SEGMENT VALUE IS THEN VSGMNT.
       CTVPT='00000000111112222211223333'
       CBVPT='00001122112112212233333333'
       CSVC ='11111615124721732215161111'
+#ifdef _DEBUGPRINT_
       FRML(1)='        1.0         '
       FRML(2)='       -1.0         '
       FRML(3)='        1/(B+1)     '
@@ -52,6 +52,7 @@ C    NUMBER OF THE SEGMENT. THE SEGMENT VALUE IS THEN VSGMNT.
       FRML(5)='  SQRT(   B /(B+1)) '
       FRML(6)='  SQRT((B+2)/(B+1)) '
       FRML(7)='  SQRT(B(B+2))/(B+1)'
+#endif
       READ(CC1,'(26I1)') IC1
       READ(CC2,'(26I1)') IC2
       READ(CTVPT,'(26I1)') ITVPT
