@@ -21,9 +21,7 @@
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
-#include "WrkSpc.fh"
       DIMENSION X1(*),X2(*),Y(*)
       DIMENSION DPT2(*)
       DIMENSION LIST(*)
