@@ -18,12 +18,13 @@
 * 1999: GEMINAL-R12 ENABLED                  *
 *--------------------------------------------*
       SUBROUTINE PCG(ICONV)
-      USE INPUTDATA
+      USE INPUTDATA, ONLY: INPUT
+      use output_caspt2, only: EMP2
+      use output_caspt2, only:iPrGlb,terse,usual
       IMPLICIT NONE
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 
