@@ -12,18 +12,18 @@
 *               2018, Ignacio Fdez. Galvan                             *
 ************************************************************************
       Subroutine Print_CI_Mix(EigVec)
-      Use RefWfn
+      Use RefWfn, Only: refwfn_active, refwfn_is_h5, refwfn_id,
+     &                  refwfn_filename, refwfn_close, iadr15
+#ifdef _HDF5_
+      Use mh5, Only: mh5_open_file_r, mh5_fetch_dset
+#endif
       Implicit None
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
 #include "rasdim.fh"
 #include "caspt2.fh"
 #include "pt2_guga.fh"
-#ifdef _HDF5_
-#include "mh5.fh"
-#endif
       Real*8 :: EigVec(nState,nState)
-      Integer :: iState, jSNum, iDisk
+      Integer :: iState, iiState, jSNum, iDisk
       Real*8, Allocatable, Dimension(:) :: cCI, mCI
       Logical :: Close_refwfn
 
@@ -58,11 +58,11 @@
       Do iState=1,nState
         Call FZero(mCI, nConf)
         iDisk=iAdr15(4)
-        Do jState=1,nState
-          jSNum=mState(jState)
+        Do iiState=1,nState
+          jSNum=mState(iiState)
           If (refwfn_is_h5) Then
 #ifdef _HDF5_
-            Call mh5_fetch_dset_array_real(
+            Call mh5_fetch_dset(
      &           refwfn_id,'CI_VECTORS',cCI,[nConf,1],[0,jSNum-1])
 #else
 * This should never happen
@@ -71,11 +71,11 @@
           Else
             Call dDAFile(refwfn_id,2,cCI,nConf,iDisk)
           End If
-          Call daXpY_(nConf,EigVec(jState,iState),cCI,1,mCI,1)
+          Call daXpY_(nConf,EigVec(iiState,iState),cCI,1,mCI,1)
         End Do
         Write(6,'(1X,A,I3)')
      &     ' The CI coefficients for the MIXED state nr. ',iState
-        Call PrWf_CP2(lSym,nConf,mCI,CITHR)
+        Call PrWf_CP2(stSym,nConf,mCI,CITHR)
       End Do
 
       Call CollapseOutput(0,'Mixed CI coefficients:')
