@@ -9,8 +9,8 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine Set_Print_Level
+      use output_caspt2, only:iPrGlb,silent,usual
       Implicit None
-#include "output.fh"
       Integer, External :: iPrintLevel
       Logical, External :: Reduce_Prt
 * Print levels request from molcas?
