@@ -34,7 +34,6 @@
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "stdalloc.fh"
       CHARACTER(LEN=8) CSNAME(MXCASE)
       DATA CSNAME / 'VJTU    ','VJTIP   ','VJTIM   ',
@@ -58,8 +57,8 @@
       INTEGER NAT,NAU,NAV,NII,NIJ,NSA,NSB
 
 
-      CALL MMA_ALLOCATE(KTUV,NASHT,NASHT,NASHT)
-      CALL MMA_ALLOCATE(MTUV,3,NASHT**3)
+      CALL MMA_ALLOCATE(KTUV,NASHT,NASHT,NASHT,Label='KTUV')
+      CALL MMA_ALLOCATE(MTUV,3,NASHT**3,Label='MTUV')
       ITUV=0
       DO 20 ISYM=1,NSYM
         ICOUNT=0
@@ -96,15 +95,15 @@
         NTUV(ISYM)=NCOUNT
   20  CONTINUE
 
-      CALL MMA_ALLOCATE(KTU,NASHT,NASHT)
-      CALL MMA_ALLOCATE(MTU,3,NASHT**2)
+      CALL MMA_ALLOCATE(KTU,NASHT,NASHT,Label='KTU')
+      CALL MMA_ALLOCATE(MTU,3,NASHT**2,Label='MTU')
 
-      CALL MMA_ALLOCATE(KTGEU,NASHT,NASHT)
-      CALL MMA_ALLOCATE(KTGTU,NASHT,NASHT)
+      CALL MMA_ALLOCATE(KTGEU,NASHT,NASHT,Label='KTGEU')
+      CALL MMA_ALLOCATE(KTGTU,NASHT,NASHT,Label='KTGTU')
       NMTGEU=(NASHT*(NASHT+1))/2
       NMTGTU=(NASHT*(NASHT-1))/2
-      CALL MMA_ALLOCATE(MTGEU,2,NMTGEU)
-      CALL MMA_ALLOCATE(MTGTU,2,NMTGTU)
+      CALL MMA_ALLOCATE(MTGEU,2,NMTGEU,Label='MTGEU')
+      CALL MMA_ALLOCATE(MTGTU,2,NMTGTU,Label='MTGTU')
 
       ITU=0
       ITGEU=0
@@ -167,21 +166,21 @@
 CPAM99 Use allocated workspace instead of MAGEB, MAGTB:
       NMAGEB=(NSSHT*(NSSHT+1))/2
       NMAGTB=(NSSHT*(NSSHT-1))/2
-      CALL MMA_ALLOCATE(MAGEB,2,NMAGEB)
-      CALL MMA_ALLOCATE(MAGTB,2,NMAGTB)
+      CALL MMA_ALLOCATE(MAGEB,2,NMAGEB,Label='MAGEB')
+      CALL MMA_ALLOCATE(MAGTB,2,NMAGTB,Label='MAGTB')
       NMIGEJ=(NISHT*(NISHT+1))/2
       NMIGTJ=(NISHT*(NISHT-1))/2
-      CALL MMA_ALLOCATE(MIGEJ,2,NMIGEJ)
-      CALL MMA_ALLOCATE(MIGTJ,2,NMIGTJ)
+      CALL MMA_ALLOCATE(MIGEJ,2,NMIGEJ,Label='MIGEJ')
+      CALL MMA_ALLOCATE(MIGTJ,2,NMIGTJ,Label='MIGTJ')
 
-      CALL MMA_ALLOCATE(KIGEJ,NISHT,NISHT)
-      CALL MMA_ALLOCATE(KIGTJ,NISHT,NISHT)
-      CALL MMA_ALLOCATE(KAGEB,NSSHT,NSSHT)
-      CALL MMA_ALLOCATE(KAGTB,NSSHT,NSSHT)
+      CALL MMA_ALLOCATE(KIGEJ,NISHT,NISHT,Label='KIGEJ')
+      CALL MMA_ALLOCATE(KIGTJ,NISHT,NISHT,Label='KIGTJ')
+      CALL MMA_ALLOCATE(KAGEB,NSSHT,NSSHT,Label='KAGEB')
+      CALL MMA_ALLOCATE(KAGTB,NSSHT,NSSHT,Label='KAGTB')
 
-      CALL MMA_ALLOCATE(KIA,NISHT,NSSHT)
+      CALL MMA_ALLOCATE(KIA,NISHT,NSSHT,Label='KIA')
       NMIA=NISHT*NSSHT
-      CALL MMA_ALLOCATE(MIA,2,NMIA)
+      CALL MMA_ALLOCATE(MIA,2,NMIA,Label='MIA')
 
 C Construct tables for inactive and secondary pair indices:
       IIGEJ=0
@@ -334,9 +333,9 @@ C Preliminary value for NINDEP: Nr of independent active params:
 CSVC: prepare tables to translate from absolute indices to
 C(index,symmetry) pairs.
 
-      CALL MMA_ALLOCATE(MIREL,2,NISHT)
-      CALL MMA_ALLOCATE(MTREL,2,NASHT)
-      CALL MMA_ALLOCATE(MAREL,2,NSSHT)
+      CALL MMA_ALLOCATE(MIREL,2,NISHT,Label='MIREL')
+      CALL MMA_ALLOCATE(MTREL,2,NASHT,Label='MTREL')
+      CALL MMA_ALLOCATE(MAREL,2,NSSHT,Label='MAREL')
 
       DO ISYM=1,NSYM
         DO II=1,NISH(ISYM)
