@@ -12,27 +12,25 @@
 ************************************************************************
       SUBROUTINE TRACHO3(CMO)
       USE CHOVEC_IO
+      use ChoSwp, only: InfVec
       IMPLICIT NONE
 * ----------------------------------------------------------------
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "caspt2.fh"
 #include "eqsolv.fh"
 #include "chocaspt2.fh"
-#include "choptr.fh"
 #include "choglob.fh"
 #include "WrkSpc.fh"
-#include "output.fh"
 **********************************************************************
 *  Author : P. A. Malmqvist
 **********************************************************************
       REAL*8 CMO(NBSQT)
 
       INTEGER NCES(8),ip_HTVec(8)
-      Integer, External :: Cho_IRange
       INTEGER ISTART(8),NUSE(8)
       INTEGER IC,ICASE,IRC,ILOC
-      INTEGER JSTART,JEND
+      INTEGER JSTART
       INTEGER JRED,JRED1,JRED2,JREDC,JNUM,JV1,JV2
       INTEGER IASTA,IAEND,IISTA,IIEND
       INTEGER NA,NASZ,NI,NISZ,NBUFFY,NPQ
@@ -40,10 +38,8 @@
       INTEGER IP_LFT,IP_LHT
       INTEGER ISYM,JSYM,ISYMA,ISYMB,ISYP,ISYQ
       INTEGER N,N1,N2
-      INTEGER ip_buffy,ip_chspc,ip_ftspc,ip_htspc,ipnt
-      INTEGER NUMV,NV,NVECS_RED,NVTOT,NHTOFF,MUSED
-
-      REAL*8, EXTERNAL :: DDOT_
+      INTEGER ip_buffy,ip_chspc,ip_ftspc,ip_htspc
+      INTEGER NUMV,NVECS_RED,NHTOFF,MUSED
 
 **********************************************************************
 * ======================================================================
@@ -68,9 +64,9 @@
 
       IF(NUMCHO_PT2(JSYM).EQ.0) GOTO 1000
 
-      ipnt=ip_InfVec+MaxVec_PT2*(1+InfVec_N2_PT2*(jSym-1))
-      JRED1=iWork(ipnt)
-      JRED2=iWork(ipnt-1+NumCho_PT2(jSym))
+      JRED1=InfVec(1,2,jSym)
+      JRED2=InfVec(NumCho_PT2(jSym),2,jSym)
+*     write(6,*)'tracho3:  JRED1,JRED2:',JRED1,JRED2
 
 * Loop over JRED
       DO JRED=JRED1,JRED2
@@ -84,7 +80,6 @@
 * the mapping between reduced index and basis set pairs.
 * The reduced set is divided into suitable batches.
 * First vector is JSTART. Nr of vectors in r.s. is NVECS_RED.
-      JEND=JSTART+NVECS_RED-1
 
 * Determine batch length for this reduced set.
 * Make sure to use the same formula as in the creation of disk
@@ -276,11 +271,9 @@ C loop over secondary orbital index c is more efficient.
       IF (RHSDIRECT) THEN
         IP_LFT=IP_FTSPC
         DO JSYM=1,NSYM
-          NVTOT=NVTOT_CHOSYM(JSYM)
           IBSTA=NBTCHES(JSYM)+1
           IBEND=NBTCHES(JSYM)+NBTCH(JSYM)
           DO IB=IBSTA,IBEND
-            NV=NVLOC_CHOBATCH(IB)
             DO ISYQ=1,NSYM
               DO ICASE=1,4
                 NPQ=NPQ_CHOTYPE(ICASE,ISYQ,JSYM)
