@@ -8,11 +8,11 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine cvbmn_cvb(icode)
       implicit real*8 (a-h,o-z)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 
 #include "optze_cvb.fh"
@@ -27,7 +27,6 @@ c  ICODE=2 end of variational calculation (print summary)
       call cvbstart_cvb_lt9(icode)
       call main_cvb()
       call setretvals_cvb(esym,n_iter)
-      call cvbfinish_cvb(icode)
       Call Lucia_Util('CLOSE',iDummy,iDummy,Dummy)
       return
       end
