@@ -8,12 +8,13 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine axexbsol_cvb(ap,rhsp,itdav,maxdav,nfrdim,
      >  solp,solp_res,eig,eig_res)
       implicit real*8 (a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension ap(maxdav,maxdav),rhsp(maxdav)
       dimension solp(maxdav),solp_res(maxdav)
 
@@ -24,7 +25,7 @@
       i5 = mstackr_cvb(itdav)
       call axexbsol2_cvb(ap,rhsp,itdav,maxdav,nfrdim,
      >  solp,solp_res,eig,eig_res,
-     >  w(i1),w(i2),w(i3),w(i4),w(i5))
+     >  work(i1),work(i2),work(i3),work(i4),work(i5))
       call mfreer_cvb(i1)
       return
       end
