@@ -8,11 +8,18 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine date2_cvb(delcpu)
       implicit real*8(a-h,o-z)
       character*120 line
+      interface
+        subroutine datimx(TimeStamp) bind(C,name='datimx_')
+          use, intrinsic :: iso_c_binding, only: c_char
+          character(kind=c_char) :: TimeStamp(*)
+        end subroutine
+      end interface
 
       line=' '
       call datimx(line)
