@@ -8,14 +8,15 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine ddrestart_cvb(c,axc,vec,
      >  hp,solp,
      >  maxdav,n,
      >  nvguess1,nvrestart1)
       implicit real*8 (a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension c(n,maxdav),axc(n,maxdav),vec(n)
       dimension hp(maxdav,maxdav)
       dimension solp(maxdav)
@@ -27,7 +28,7 @@
      >  hp,solp,
      >  maxdav,n,
      >  nvguess1,nvrestart1,
-     >  w(i1),w(i2))
+     >  work(i1),work(i2))
 
       call mfreer_cvb(i1)
       return
