@@ -8,14 +8,16 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine ioopn_cvb(fn,lu)
       implicit real*8(a-h,o-z)
       character*(*) fn
-#include "fio.fh"
+      logical isopen
 
 c  Close first in case file is 'hanging' from previous session:
-      if(isOpen(lu).ne.0)call daclos(lu)
+      inquire(lu,opened=isopen)
+      if(isopen)call daclos(lu)
       call daname_wa(lu,fn)
       end
