@@ -8,11 +8,11 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine setiaprtot_cvb()
       implicit real*8 (a-h,o-z)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 #include "optze_cvb.fh"
 #include "files_cvb.fh"
@@ -20,13 +20,13 @@
 
 
 #include "frag_cvb.fh"
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension dum1(1), dum2(1)
 
       k1=mstackr_cvb(nda*ndb)
-      call dpci2vb_cvb(w(k1),dum1,dum2,0,dum3,4)
-      call setiaprtot2_cvb(w(k1),
-     >  iw(ll(11)),iw(ll(12)),iw(ll(13)),iw(ll(14)),npvb,
+      call dpci2vb_cvb(work(k1),dum1,dum2,0,dum3,4)
+      call setiaprtot2_cvb(work(k1),
+     >  iwork(ll(11)),iwork(ll(12)),iwork(ll(13)),iwork(ll(14)),npvb,
      >  nda,ndb)
       call mfreer_cvb(k1)
       return
