@@ -8,22 +8,23 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine stringen_cvb(norb,nel,locc,lunocc,nstring)
       implicit real*8 (a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension locc(*),lunocc(*)
 
       i_nkmin = mstacki_cvb(norb+1)
       i_nkmax = mstacki_cvb(norb+1)
 c Spin string loop initialization (use xdet as graph storage) :
       do 100 iorb=0,norb
-      iw(iorb+i_nkmin)=max(iorb-norb+nel,0)
-      iw(iorb+i_nkmax)=min(iorb,nel)
+      iwork(iorb+i_nkmin)=max(iorb-norb+nel,0)
+      iwork(iorb+i_nkmax)=min(iorb,nel)
 100   continue
       call mmstringen_cvb(norb,nel,locc,lunocc,nstring,
-     >  iw(i_nkmin),iw(i_nkmax))
+     >  iwork(i_nkmin),iwork(i_nkmax))
       call mfreei_cvb(i_nkmin)
       return
       end
