@@ -8,11 +8,12 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine svd_cvb(a,val,vec,vmat,n1,n2)
       implicit real*8 (a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension a(n1,n2),val(n2),vec(n1,n2),vmat(n2,n2)
 
       n12=max(n1,n2)
@@ -23,7 +24,7 @@
       i5 = mstackr_cvb(n2)
       i6 = mstacki_cvb(n2)
       call svd2_cvb(a,val,vec,vmat,n1,n2,n12,
-     >  w(i1),w(i2),w(i3),w(i4),w(i5),iw(i6))
+     >  work(i1),work(i2),work(i3),work(i4),work(i5),iwork(i6))
       call mfreer_cvb(i1)
       return
       end
