@@ -8,14 +8,14 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine symgen_cvb(nalf1,nbet1,nda1,ndb1,
      >  isymalf,isymbet,iasyind,ibsyind,
      >  ialfsym,ibetsym,irpdet,irpalf,irpbet,
      >  mingrph,maxgrph,nk,locc,lunocc,xalf,xbet,icount)
       implicit real*8 (a-h,o-w,y-z),integer(x)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 #include "optze_cvb.fh"
 #include "files_cvb.fh"
