@@ -8,19 +8,19 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine updvec_cvb(upd,iorb,jorb,niprev,iprev,
      >  orbs,north,corth)
 c  Find update for IORB as projection of JORB on allowed space
       implicit real*8 (a-h,o-z)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 #include "optze_cvb.fh"
 #include "files_cvb.fh"
 #include "print_cvb.fh"
 
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension upd(norb)
       dimension iprev(niprev),orbs(norb,norb)
       dimension north(norb),corth(norb,niorth)
@@ -39,11 +39,11 @@ c  Collect all constraints and find span :
       call span1_cvb(orbs(1,iprev(i)),1,dum,norb,0)
 200   continue
       call span1_cvb(orbs(1,iorb),1,dum,norb,0)
-      call span2_cvb(w(i1),ncon,dum,norb,0)
+      call span2_cvb(work(i1),ncon,dum,norb,0)
 
 c  Orthogonalise update to all remaining constraints
       call fmove_cvb(orbs(1,jorb),upd,norb)
-      call schmidtd_cvb(w(i1),ncon,upd,1,dum,norb,0)
+      call schmidtd_cvb(work(i1),ncon,upd,1,dum,norb,0)
       call mfreer_cvb(i1)
       return
       end
