@@ -55,15 +55,16 @@ c
 #include "reorg.fh"
 
        integer NOIPSB(106)
-       integer idispsb(106)
+c      integer idispsb(106)
 c
 c     help variables
 c
        integer sense
-       integer p,q,r,s,pa,qa,ra,sa
+       integer p,q,r,s,pa,qa,ra
        integer IND,INDT,ISPQRS,NINT,NSLM,idistemp,idishelp
        integer jlow,ilow,iup,jup,kup,lup,iold,jold,kold,lold
        integer norbp,nsi,nsj,nsk,nsl,nsij,nsijk
+       real*8 dum(1)
 
 CFUE   - pick the start addresses of each symmetry allowed integral
 CFUE     block from the tranformed two electron integral file
@@ -177,7 +178,6 @@ c
        pa=p
        qa=q
        ra=r
-       sa=s
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=1
@@ -190,7 +190,6 @@ c
        pa=r
        qa=q
        ra=p
-       sa=s
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=2
@@ -203,7 +202,6 @@ c
        pa=p
        qa=s
        ra=r
-       sa=q
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=1
@@ -216,7 +214,6 @@ c
        pa=r
        qa=s
        ra=p
-       sa=q
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=2
@@ -229,7 +226,6 @@ c
        pa=q
        qa=p
        ra=s
-       sa=r
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=3
@@ -242,7 +238,6 @@ c
        pa=s
        qa=p
        ra=q
-       sa=r
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=4
@@ -255,7 +250,6 @@ c
        pa=q
        qa=r
        ra=s
-       sa=p
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=3
@@ -268,7 +262,6 @@ c
        pa=s
        qa=r
        ra=q
-       sa=p
        typ(pa,qa,ra)=sense
        idis(pa,qa,ra)=idistemp
        np(pa,qa,ra)=4
@@ -277,7 +270,7 @@ c
        ns(pa,qa,ra)=1
 c
 c
-       idispsb(ispqrs)=idistemp
+c      idispsb(ispqrs)=idistemp
        idishelp=0
 C
 C     ******************************************************************
@@ -314,7 +307,8 @@ C
        if (idishelp.gt.INDMAX) then
 CFUE     - all integrals in the reord were processed, hence
 CFUE       update the disk address by a dummy I/O
-         Call dDaFile(LUINTM,0,[0.0d0],INDMAX,idistemp)
+         dum(1)=0.0d0
+         Call dDaFile(LUINTM,0,dum,INDMAX,idistemp)
 CFUE     idistemp=idistemp+idisadd
          idishelp=1
        end if
@@ -329,7 +323,8 @@ C
        if (idishelp.gt.0) then
 CFUE     - all integrals in the reord were processed, hence
 CFUE       update the disk address by a dummy I/O
-         Call dDaFile(LUINTM,0,[0.0d0],INDMAX,idistemp)
+         dum(1)=0.0d0
+         Call dDaFile(LUINTM,0,dum,INDMAX,idistemp)
 CFUE   idistemp=idistemp+idisadd
        end if
 C
