@@ -36,34 +36,37 @@
 *> Requires initialization of the Cholesky information.
 *>
 *> @param[out]    irc     Return code
-*> @param[in]     ipMO    Pointers to each symmetry block of the MO matrix, stored as \p C(k,a)
+*> @param[in]     MO      type DSBA_Type of block of the MO matrix, stored as \p C(k,a)
 *> @param[in]     nOcc    Number of orbitals to be localized in each symmetry
 *> @param[in,out] Rij     \p nOcc &times; \p nOcc symmetry blocked matrix \f$  R_{ij} = (ij|jj) \f$
 *> @param[in]     timings Switch on/off timings printout
 ************************************************************************
-      SUBROUTINE CHO_get_Rij(irc,ipMO,nOcc,Rij,timings)
+      SUBROUTINE CHO_get_Rij(irc,MO,nOcc,Rij,timings)
+      use ChoArr, only: nDimRS
+      use ChoSwp, only: InfVec
+      use Data_Structures, only: DSBA_Type, SBA_Type
+      use Data_Structures, only: Allocate_SBA, Deallocate_SBA
       Implicit Real*8 (a-h,o-z)
-      Logical timings,DoRead
-      Integer nOcc(*),iOcc(8),iOcs(8),ipLib(8),iSkip(8),ipMO(*)
+      Integer irc
+      Type (DSBA_Type) MO
+      Integer nOcc(*)
       Real*8  Rij(*)
+      Logical timings
+
+      Logical, Parameter:: DoRead=.FALSE.
+      Integer iOcc(8),iOcs(8),iSkip(8)
       Real*8  tread(2),tintg(2),tmotr(2)
-      Character*11  SECNAM
-
-      parameter (SECNAM = 'CHO_get_Rij')
-      parameter (zero = 0.0d0, one = 1.0d0, DoRead = .false.)
+      Character(LEN=11), Parameter:: SECNAM = 'CHO_get_Rij'
 
+#include "real.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
 #include "choorb.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 
-      parameter ( N2 = InfVec_N2 )
-
-************************************************************************
-      InfVec(i,j,k) = iWork(ip_InfVec-1+MaxVec*N2*(k-1)+MaxVec*(j-1)+i)
-******
-      nDimRS(i,j) = iWork(ip_nDimRS-1+nSym*(j-1)+i)
-************************************************************************
+      Type (SBA_Type):: Laq(1)
+      Real*8, Allocatable, Target:: Lab(:)
+      Real*8, Pointer:: pLab(:,:,:)=>Null()
+      Real*8, Pointer:: pLjj(:)=>Null()
 
       IREDC = -1
 
@@ -146,7 +149,7 @@ C ---
 
       Mneed = Max(nRS, Mocc**2 + 1) ! mem. for Lab and (Lij + Ljj)
 
-      Call GetMem('MaxM','Max','Real',KDUM,LWORK)
+      Call mma_maxDBLE(LWORK)
 
       nVec  = Min(LWORK/(Maj+Mneed),nVrs)
 
@@ -161,8 +164,9 @@ C ---
 
       LREAD = nRS*nVec
 
-      Call GetMem('rsL','Allo','Real',ipLab,Mneed*nVec)
-      Call GetMem('Ltr','Allo','Real',ipLtr,Maj*nVec)
+      iSwap = 2  ! LiK,b are returned
+      Call Allocate_SBA(Laq(1),nOcc,nBas,nVec,JSYM,nSym,iSwap)
+      Call mma_allocate(Lab,Mneed*nVec,Label='Lab')
 
 C --- BATCH over the vectors in JSYM=1 ----------------------------
 
@@ -181,7 +185,7 @@ C --- BATCH over the vectors in JSYM=1 ----------------------------
 
          CALL CWTIME(TCR1,TWR1)
 
-         CALL CHO_VECRD(Work(ipLab),LREAD,JVEC,IVEC2,JSYM,
+         CALL CHO_VECRD(Lab,LREAD,JVEC,IVEC2,JSYM,
      &                  NUMV,JRED,MUSED)
 
          If (NUMV.le.0 .or. NUMV.ne.JNUM) then
@@ -195,25 +199,15 @@ C --- BATCH over the vectors in JSYM=1 ----------------------------
 
 C --- First half-transformation of the vectors : Lab,J --> LiJ,b
 C --------------------------------------------------------------
-         iSwap = 2  ! LiK,b are returned
 
          kMOs = 1
          nMOs = 1
 
-         lChoT=0
-         Do kSym=1,nSym
-
-            ipLib(kSym) = ipLtr + lChot
-            lChot = lChot + nOcc(kSym)*JNUM*nBas(kSym)
-
-         End Do
-
-
          CALL CWTIME(TCT1,TWT1)
 
-         CALL CHO_X_getVtra(irc,Work(ipLab),LREAD,jVEC,JNUM,
-     &                         JSYM,iSwap,IREDC,nMOs,kMOs,ipMO,nOcc,
-     &                         ipLib,iSkip,DoRead)
+         CALL CHO_X_getVtra(irc,Lab,LREAD,jVEC,JNUM,
+     &                         JSYM,iSwap,IREDC,nMOs,kMOs,MO,
+     &                         Laq(1),DoRead)
 
                if (irc.ne.0) then
                    RETURN
@@ -225,13 +219,17 @@ C --------------------------------------------------------------
          tmotr(2) = tmotr(2) + (TWT2 - TWT1)
 
 
-         ipLij = ipLab  ! re-use mem used for reading from red-sets
-
          Do kSym=1,nSym
 
-            If (iSkip(kSym) .ne. 0) Then
+            n1 = nOcc(kSym)
+            iS = 1
+            iE = n1*JNUM*n1
+            pLab(1:n1,1:JNUM,1:n1) => Lab(iS:iE)
+            iS = iE + 1
+            iE = iE + JNUM
+            pLjj(1:JNUM) => Lab(iS:iE)
 
-               ipLjj = ipLij + nOcc(kSym)**2 * JNUM
+            If (iSkip(kSym) .ne. 0) Then
 
                CALL CWTIME(TCT1,TWT1)
 C ---------------------------------------------------------------------
@@ -239,9 +237,9 @@ C --- Second half-transformation  L(iK,j) = sum_b  L(iK,b) * C(j,b)
 C ---------------------------------------------------------------------
 
               CALL DGEMM_('N','T',nOcc(kSym)*JNUM,nOcc(kSym),nBas(kSym),
-     &                            One,Work(ipLib(kSym)),nOcc(kSym)*JNUM,
-     &                                Work(ipMO(kSym)),nOcc(kSym),
-     &                           Zero,Work(ipLij),nOcc(kSym)*JNUM)
+     &                           One,Laq(1)%SB(kSym)%A3,nOcc(kSym)*JNUM,
+     &                                MO%SB(kSym)%A2,nOcc(kSym),
+     &                           Zero,pLab,nOcc(kSym)*JNUM)
 
 
                CALL CWTIME(TCT2,TWT2)
@@ -255,10 +253,7 @@ C ---------------------------------------------------------------------
 
                   Do jv=1,JNUM
 
-                     jfrom = ipLij + nOcc(kSym)*JNUM*(lj-1)
-     &                     + nOcc(kSym)*(jv-1) + lj - 1
-                     jto = ipLjj + jv - 1
-                     Work(jto) = Work(jfrom)
+                     pLjj(jv) = pLab(lj,jv,lj)
 
                   End Do
 
@@ -267,11 +262,10 @@ C --- Compute   R(i,j) = sum_K  L(i,K)[j] * L(K)[j]
 C --------------------------------------------------------------------
 
                   jpR = iOcs(kSym) + nOcc(kSym)*(lj-1) + 1
-                  ipLik = ipLij + nOcc(kSym)*JNUM*(lj-1)
 
                   CALL DGEMV_('N',nOcc(kSym),JNUM,
-     &                       ONE,Work(ipLik),nOcc(kSym),
-     &                           Work(ipLjj),1,ONE,Rij(jpR),1)
+     &                       ONE,pLab(:,:,lj),nOcc(kSym),
+     &                           pLjj,1,ONE,Rij(jpR),1)
 
 
                End Do
@@ -281,6 +275,8 @@ C --------------------------------------------------------------------
                tintg(2) = tintg(2) + (TWI2 - TWI1)
 
             EndIf
+            pLjj => Null()
+            pLab => Null()
 
          End Do
 
@@ -289,9 +285,8 @@ C --------------------------------------------------------------------
       END DO  !end batch loop
 
 C --- free memory
-      Call GetMem('Ltr','Free','Real',ipLtr,Maj*nVec)
-      Call GetMem('rsL','Free','Real',ipLab,Mneed*nVec)
-
+      Call Deallocate_SBA(Laq(1))
+      Call mma_deallocate(Lab)
 
 999   Continue
 
@@ -326,7 +321,6 @@ C --- sync Rij
 
       endif
 
-
       irc=0
 
       Return
