@@ -8,22 +8,22 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      SUBROUTINE CHO_GETDIAG(ip_DIAG,LCONV)
+      SUBROUTINE CHO_GETDIAG(LCONV)
 C
-C     Purpose: get diagonal in first reduced set. On exit, ip_DIAG
-C              points to the diagonal in work space and flag LCONV tells
+C     Purpose: get diagonal in first reduced set. On exit, DIAG
+C              points to the diagonal and flag LCONV tells
 C              if the diagonal is converged.
 C
+      use ChoArr, only: iSP2F, MySP, n_MySP, iSimRI
+      use ChoSwp, only: IndRSh, IndRSh_Hidden
+      use ChoSwp, only: IndRed, IndRed_Hidden
+      use ChoSwp, only: Diag, Diag_Hidden
 #include "implicit.fh"
       LOGICAL LCONV
 #include "cholesky.fh"
-#include "chovecbuf.fh"
 #include "choprint.fh"
 #include "choorb.fh"
-#include "choptr.fh"
-#include "choptr2.fh"
-#include "chosimri.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 
       CHARACTER*11 SECNAM
       PARAMETER (SECNAM = 'CHO_GETDIAG')
@@ -33,6 +33,8 @@ C
 
       INTEGER ISYLST(8)
 
+      Integer, Allocatable:: KIBUF(:)
+      Real*8, Allocatable:: KBUF(:), KSCR(:), KWRK(:)
 
       IF (RSTDIA) THEN
 
@@ -42,9 +44,11 @@ C        in parallel runs).
 C        -------------------------------------------------------------
 
          N_MYSP = NNSHL
+         l_MySP=0
+         If (Allocated(MYSP)) l_MySP=SIZE(MySP)
          IF (l_MYSP .EQ. NNSHL) THEN
             DO ISP = 1,N_MYSP
-               IWORK(ip_MYSP-1+ISP) = ISP
+               MYSP(ISP) = ISP
             END DO
          ELSE
             CALL CHO_QUIT('MYSP allocation error in '//SECNAM,101)
@@ -59,10 +63,14 @@ C        Allocate mapping arrays between reduced sets.
 C        ---------------------------------------------
 
          MMBSTRT  = NNBSTRT(1)
-         l_INDRED = NNBSTRT(1)*3
-         l_INDRSH = NNBSTRT(1)
-         CALL CHO_MEM('indred','ALLO','INTE',ip_INDRED,l_INDRED)
-         CALL CHO_MEM('indrsh','ALLO','INTE',ip_INDRSH,l_INDRSH)
+
+         Call mma_allocate(IndRed_Hidden,NNBSTRT(1),3,
+     &                     Label='IndRed_Hidden')
+         IndRed => IndRed_Hidden
+
+         Call mma_allocate(IndRSh_Hidden,NNBSTRT(1),
+     &                     Label='IndRSh_Hidden')
+         IndRSh => IndRSh_Hidden
 
 C        Read mapping arrays.
 C        --------------------
@@ -73,7 +81,7 @@ C        Check reduced to full shell pair mapping with the one on disk.
 C        --------------------------------------------------------------
 
          NERR = -1
-         CALL CHO_RSTD_CHKSP2F(IWORK(ip_iSP2F),l_iSP2F,NERR)
+         CALL CHO_RSTD_CHKSP2F(iSP2F,SIZE(iSP2F),NERR)
          IF (NERR .NE. 0) THEN
             WRITE(LUPRI,*) SECNAM,': ',NERR,' errors detected in ',
      &                     'reduced-to-full shell pair mapping!'
@@ -86,88 +94,87 @@ C        ---------------------
          NEEDR = 1
          NEEDI = 4*NEEDR
 
-         CALL CHO_MEM('diarst','ALLO','REAL',KDIAG,NNBSTRT(1))
-         CALL CHO_MEM('buf.2','ALLO','REAL',KBUF,NEEDR)
-         CALL CHO_MEM('ibuf.2','ALLO','INTE',KIBUF,NEEDI)
-
-         KREL = KBUF
+         CALL mma_allocate(Diag_Hidden,NNBSTRT(1),Label='Diag_Hidden')
+         Call mma_allocate(KBUF,NEEDR,Label='KBUF')
+         Call mma_allocate(KIBUF,NEEDI,Label='KIBUF')
 
 C        Read diagonal.
 C        --------------
 
-         CALL CHO_GETDIAG1(WORK(KDIAG),WORK(KBUF),IWORK(KIBUF),NEEDR,
-     &                     NDUMP)
+         CALL CHO_GETDIAG1(Diag_Hidden,KBUF,KIBUF,NEEDR,NDUMP)
 
-         CALL CHO_MEM('buf.2','FLUSH','REAL',KREL,NEEDR)
+         Call mma_deallocate(KIBUF)
+         Call mma_deallocate(KBUF)
 
       ELSE
 
 C        Calculate diagonal and get 1st reduced set.
 C        -------------------------------------------
 
-         CALL CHO_MEM('MAX','GETM','REAL',KDUM,LMAX)
+         Call mma_maxDBLE(LMAX)
          LMAX = LMAX/2 - MX2SH
          IF (LMAX .LT. 5*LBUF) THEN
             LBUF = MAX(LMAX/5,1)
          END IF
 
          LSCR  = MX2SH
-         NEEDR = LBUF + LSCR
+         NEEDR = LBUF
          NEEDI = 4*LBUF
-         CALL CHO_MEM('buf','ALLO','REAL',KREL,NEEDR)
-         CALL CHO_MEM('ibuf','ALLO','INTE',KIBUF,NEEDI)
 
-         KBUF  = KREL
-         KSCR  = KBUF + LBUF
+         Call mma_allocate(KBUF,NEEDR,Label='KBUF')
+         Call mma_allocate(KSCR,LSCR ,Label='KSCR')
+         Call mma_allocate(KIBUF,NEEDI,Label='KIBUF')
 
          NDUMP = 0
 
-         CALL CHO_CALCDIAG(WORK(KBUF),IWORK(KIBUF),LBUF,WORK(KSCR),LSCR,
-     &                     IWORK(ip_IIBSTRSH),IWORK(ip_NNBSTRSH),
-     &                     NSYM,NNSHL,NDUMP)
-         CALL CHO_MEM('buf','FLUSH','REAL',KREL,NEEDR)
+         CALL CHO_CALCDIAG(KBUF,KIBUF,LBUF,KSCR,LSCR,NDUMP)
+
+         Call mma_deallocate(KIBUF)
+         Call mma_deallocate(KBUF)
+         Call mma_deallocate(KSCR)
 
 C        Allocate diagonal and mapping array between reduced sets.
 C        Reallocate buffer.
 C        ---------------------------------------------------------
 
          MMBSTRT  = NNBSTRT(1)
-         l_INDRED = NNBSTRT(1)*3
-         l_INDRSH = NNBSTRT(1)
-         CALL CHO_MEM('indred','ALLO','INTE',ip_INDRED,l_INDRED)
-         CALL CHO_MEM('indrsh','ALLO','INTE',ip_INDRSH,l_INDRSH)
-         CALL CHO_MEM('dia','ALLO','REAL',KDIAG,NNBSTRT(1))
+         Call mma_allocate(IndRed_Hidden,NNBSTRT(1),3,
+     &                     Label='IndRed_Hidden')
+         IndRed => IndRed_Hidden
+         Call mma_allocate(IndRSh_Hidden,NNBSTRT(1),
+     &                     Label='IndRSh_Hidden')
+         IndRSh => IndRSh_Hidden
+         CALL mma_allocate(Diag_Hidden,NNBSTRT(1),Label='Diag_Hidden')
 
          NEEDR = LBUF
          NEEDI = 4*LBUF
-         CALL CHO_MEM('buf.2','ALLO','REAL',KBUF,NEEDR)
-         CALL CHO_MEM('ibuf.2','ALLO','INTE',KIBUF,NEEDI)
-         KREL = KBUF
+         Call mma_allocate(KBUF,NEEDR,Label='KBUF')
+         Call mma_allocate(KIBUF,NEEDI,Label='KIBUF')
 
 C        Get diagonal in first reduced set.
 C        ----------------------------------
 
-         CALL CHO_GETDIAG1(WORK(KDIAG),WORK(KBUF),IWORK(KIBUF),LBUF,
-     &                     NDUMP)
+         CALL CHO_GETDIAG1(Diag_Hidden,KBUF,KIBUF,LBUF,NDUMP)
 
 C        Deallocate back to and including buffer.
 C        ----------------------------------------
 
-         CALL CHO_MEM('buf','FLUSH','REAL',KREL,NEEDR)
+         Call mma_deallocate(KIBUF)
+         Call mma_deallocate(KBUF)
 
       END IF
 
-C     Set local and global info. On exit, KDIAG points to the local
+C     Set local and global info. On exit, Diag points to the local
 C     diagonal.
 C     -------------------------------------------------------------
 
-      CALL CHO_P_SETGL(KDIAG)
+      CALL CHO_P_SETGL()
 
 C     Write local diagonal to disk.
 C     -----------------------------
 
       IOPT = 1
-      CALL CHO_IODIAG(WORK(KDIAG),IOPT)
+      CALL CHO_IODIAG(Diag,IOPT)
 
 C     Allocate memory for iscratch array for reading vectors.
 C     -------------------------------------------------------
@@ -187,9 +194,8 @@ C     THR_SIMRI. Indices of zeroed diagonals are stored in ip_ISIMRI.
 C     ---------------------------------------------------------------
 
       IF (CHO_SIMRI) THEN
-         l_ISIMRI = NNBSTRT(1)
-         CALL CHO_MEM('ISIMRI','ALLO','INTE',ip_ISIMRI,l_ISIMRI)
-         CALL CHO_SIMRI_Z1CDIA(WORK(KDIAG),THR_SIMRI,IWORK(ip_ISIMRI))
+         Call mma_allocate(iSimRI,NNBSTRT(1),Label='iSimRI')
+         CALL CHO_SIMRI_Z1CDIA(Diag,THR_SIMRI,ISIMRI)
       END IF
 
 C     Update diagonal if restart, else just do analysis.
@@ -197,16 +203,17 @@ C     --------------------------------------------------
 
       LCONV = .FALSE.
       IF (RSTCHO) THEN
-         CALL CHO_MEM('Cho.Rs1','MAX ','REAL',KWRK,LWRK)
+         Call mma_maxDBLE(LWRK)
+         Call mma_allocate(KWRK,LWRK,Label='KWRK')
          IF (LOCDBG) THEN
             WRITE(LUPRI,*) SECNAM,': restart diagonal:'
             DO ISYM = 1,NSYM
                ISYLST(ISYM) = ISYM
             END DO
-            CALL CHO_PRTDIA(WORK(KDIAG),ISYLST,NSYM,1)
+            CALL CHO_PRTDIA(Diag,ISYLST,NSYM,1)
          END IF
-         CALL CHO_RESTART(WORK(KDIAG),WORK(KWRK),LWRK,.FALSE.,LCONV)
-         CALL CHO_MEM('Cho.Rs1','FREE','REAL',KWRK,LWRK)
+         CALL CHO_RESTART(Diag,KWRK,LWRK,.FALSE.,LCONV)
+         Call mma_deallocate(KWRK)
          IPRTRED = 2  ! print flag for cho_prtred
       ELSE
          IF (IPRINT .GE. INF_PASS) THEN
@@ -214,7 +221,7 @@ C     --------------------------------------------------
             STEP = 1.0D-1
             NBIN = 18
             SYNC = .FALSE.
-            CALL CHO_P_ANADIA(WORK(KDIAG),SYNC,BIN1,STEP,NBIN,.TRUE.)
+            CALL CHO_P_ANADIA(Diag,SYNC,BIN1,STEP,NBIN,.TRUE.)
          END IF
          IPRTRED = 1  ! print flag for cho_prtred
       END IF
@@ -222,10 +229,4 @@ C     --------------------------------------------------
          CALL CHO_P_PRTRED(IPRTRED)
       END IF
 
-C     Return pointer to (local) diagonal.
-C     -----------------------------------
-
-      ip_DIAG = KDIAG
-
-
       END
