@@ -13,25 +13,19 @@ C
 C     Purpose: copy qualified diagonal elements from global diagonal to
 C              array QD.
 C
+      use ChoSwp, only: iQuAB, IndRed_G, Diag_G
       Implicit None
       Real*8 QD(*)
 #include "cholesky.fh"
-#include "choptr.fh"
 #include "choglob.fh"
-#include "WrkSpc.fh"
 
-      Integer kQD, kD, iSym, iQ, iAB
-      Integer IndRed_G, iQuAB, i, j
-
-      IndRed_G(i,j)=iWork(ip_IndRed_G-1+mmBstRT_G*(j-1)+i)
-      iQuAB(i,j)=iWork(ip_iQuAB-1+MaxQual*(j-1)+i)
+      Integer kQD, iSym, iQ, iAB
 
       kQD = 0
-      kD = ip_Diag_G - 1
       Do iSym = 1,nSym
          Do iQ = 1,nQual(iSym)
             iAB = IndRed_G(iQuAB(iQ,iSym),2)
-            QD(kQD+iQ) = Work(kD+iAB)
+            QD(kQD+iQ) = Diag_G(iAB)
          End Do
          kQD = kQD + nQual(iSym)
       End Do
