@@ -13,10 +13,10 @@ C
 C     Purpose: write reduced set indices to disk and set address for
 C              next write.
 C
+      use ChoArr, only: iSP2F
+      use ChoSwp, only: nnBstRSh, IndRSh, InfRed, IndRed
 #include "implicit.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 
       CHARACTER*10 SECNAM
       PARAMETER (SECNAM = 'CHO_PUTRED')
@@ -27,29 +27,22 @@ C
          WRITE(LUPRI,*) SECNAM,': please increase max. allowed!'
          CALL CHO_QUIT('Too many integral passes in '//SECNAM,104)
       ELSE IF (IPASS .EQ. 1) THEN
-         KOFF1 = ip_NNBSTRSH
-         KOFF2 = ip_INDRED
-         CALL CHO_PUTRED1(IWORK(ip_INFRED),IWORK(KOFF1),IWORK(KOFF2),
-     &                    IWORK(ip_INDRSH),IWORK(ip_iSP2F),
-     &                    MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,1)
+         CALL CHO_PUTRED1(INFRED,nnBstRSh(:,:,1),IndRed(:,1),INDRSH,
+     &                    iSP2F,MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,1)
          IF (MAXRED .GT. 1) THEN
-            IWORK(ip_INFRED+IPASS) = IWORK(ip_INFRED-1+IPASS)
-     &                             + NSYM*NNSHL + 2*NNBSTRT(1) + NNSHL
+            INFRED(IPASS+1) = INFRED(IPASS)
+     &                      + NSYM*NNSHL + 2*NNBSTRT(1) + NNSHL
          END IF
       ELSE IF (IPASS .EQ. MAXRED) THEN
-         KOFF1 = ip_NNBSTRSH + NSYM*NNSHL*(IRED - 1)
-         KOFF2 = ip_INDRED   + MMBSTRT*(IRED - 1)
-         CALL CHO_PUTRED1(IWORK(ip_INFRED),IWORK(KOFF1),IWORK(KOFF2),
-     &                    IWORK(ip_INDRSH),IWORK(ip_iSP2F),
-     &                    MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,IRED)
+         CALL CHO_PUTRED1(INFRED,nnBstRSh(:,:,IRED),IndRed(:,IRED),
+     &                    INDRSH,
+     &                    iSP2F,MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,IRED)
       ELSE
-         KOFF1 = ip_NNBSTRSH + NSYM*NNSHL*(IRED - 1)
-         KOFF2 = ip_INDRED   + MMBSTRT*(IRED - 1)
-         CALL CHO_PUTRED1(IWORK(ip_INFRED),IWORK(KOFF1),IWORK(KOFF2),
-     &                    IWORK(ip_INDRSH),IWORK(ip_iSP2F),
-     &                    MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,IRED)
-         IWORK(ip_INFRED+IPASS) = IWORK(ip_INFRED-1+IPASS)
-     &                          + NSYM*NNSHL + NNBSTRT(IRED)
+         CALL CHO_PUTRED1(INFRED,nnBstRSh(:,:,IRED),IndRed(:,IRED),
+     &                    INDRSH,
+     &                   iSP2F,MAXRED,NSYM,NNSHL,MMBSTRT,IPASS,IRED)
+         INFRED(IPASS+1) = INFRED(IPASS)
+     &                   + NSYM*NNSHL + NNBSTRT(IRED)
       END IF
 
       END
