@@ -30,12 +30,13 @@ C     NOTE: it is assumed that the vectors are stored in their
 C           respective reduced sets (thus, should only be used with
 C           RUN_MODE = RUN_EXTERNAL).
 C
+      use ChoArr, only: nDimRS
+      use ChoSwp, only: InfVec
+      use ChoVecBuf, only: CHVBUF, ip_CHVBUF_SYM, l_CHVBUF_SYM,
+     &                     l_CHVBFI_SYM, nVec_in_Buf
       Implicit Real*8 (a-h,o-z)
       Real*8 Vec(lVec)
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "chovecbuf.fh"
-#include "WrkSpc.fh"
 
       external ddot_
 
@@ -50,10 +51,6 @@ C
       Parameter (LocDbg = .false.)
 #endif
 
-      Parameter (N2 = InfVec_N2)
-      InfVec(i,j,k)=iWork(ip_InfVec-1+MaxVec*N2*(k-1)+MaxVec*(j-1)+i)
-      nDimRS(i,j)=iWork(ip_nDimRS-1+nSym*(j-1)+i)
-
 C     Initialize.
 C     -----------
 
@@ -90,7 +87,7 @@ C     -------------------------------------
       Full = lTot .ge. lVec
       jVec = jVec1 - 1
       iV2  = min(nVec_in_Buf(iSym),iVec2)
-      If (l_nDimRS .lt. 1) Then
+      If (.NOT.Allocated(nDimRS)) Then
          iLoc = 3
          Do While (jVec.lt.iV2 .and. .not.Full)
             jVec = jVec + 1
@@ -134,7 +131,7 @@ C     ----------------------
       If (lTot .gt. 0) Then
          kB = ip_ChVBuf_Sym(iSym)
          If (jVec1 .gt. 1) Then
-            If (l_nDimRS .lt. 1) Then
+            If (.NOT.Allocated(nDimRS)) Then
                iLoc = 3
                Do jVec = 1,jVec1-1
                   jRed = InfVec(jVec,2,iSym)
@@ -157,7 +154,7 @@ C     ----------------------
                End Do
             End If
          End If
-         Call dCopy_(lTot,Work(kB),1,Vec,1)
+         Call dCopy_(lTot,CHVBUF(kB),1,Vec,1)
          ! Check copy operation (may fail if molcas is compiled for
          ! 64 bit but linked to a 32 bit blas library)
          ! Note: check is not done unless it is enabled when the buffer
@@ -220,7 +217,7 @@ C     -------------
          Else
             Write(Lupri,*) 'Vectors ',jVec1,' to ',jVec1+jNum-1,
      &                     ' of symmetry ',iSym,' copied from buffer.'
-            If (l_nDimRS .gt. 0) Then
+            If (Allocated(nDimRS)) Then
                kOffV = 1
                Do iVec = 1,jNum
                   jVec = jVec1 + iVec - 1
