@@ -23,11 +23,13 @@
 *> @param[out] irc Return code
 ************************************************************************
       Subroutine Cho_X_Final(irc)
+      use ChoArr, only: MySP
+      use ChoBkm, only: BkmVec, BkmThr, nRow_BkmVec, nCol_BkmVec,
+     &                   nRow_BkmThr, nCol_BkmThr
       Implicit None
       Integer irc
 #include "choini.fh"
-#include "choptr2.fh"
-#include "chobkm.fh"
+#include "stdalloc.fh"
 
       Character*11 SecNam
       Parameter (SecNam = 'Cho_X_Final')
@@ -69,21 +71,14 @@ C        ------------------
          Call Cho_X_Dealloc(irc)
          If (irc .ne. 0) Go To 1
 
-         If (l_mySP .gt. 0) Then
-            Call GetMem('mySP','Free','Inte',ip_mySP,l_mySP)
-            l_mySP = 0
-         End If
-         If (l_BkmVec.gt.0) Then
-            Call GetMem('BkmVec','Free','Inte',ip_BkmVec,l_BkmVec)
-            ip_BkmVec=0
-            l_BkmVec=0
+         If (Allocated(MySP)) Call mma_deallocate(MySP)
+         If (Allocated(BkmVec)) Then
+            Call mma_deallocate(BkmVec)
             nRow_BkmVec=0
             nCol_BkmVec=0
          End If
-         If (l_BkmThr.gt.0) Then
-            Call GetMem('BkmThr','Free','Real',ip_BkmThr,l_BkmThr)
-            ip_BkmThr=0
-            l_BkmThr=0
+         If (Allocated(BkmThr)) Then
+            Call mma_deallocate(BkmThr)
             nRow_BkmThr=0
             nCol_BkmThr=0
          End If
