@@ -28,21 +28,21 @@ C
 C
 C     Purpose: setup for parallel DF.
 C
+#if defined (_MOLCAS_MPP_)
+      Use Para_Info, Only: MyRank, nProcs, Is_Real_Par
+#endif
       Implicit None
       Integer irc
 
-      Character*17 SecNam
-      Parameter (SecNam = 'Cho_X_Init_Par_DF')
+      Character(LEN=17), Parameter:: SecNam = 'Cho_X_Init_Par_DF'
 
-      Logical LocDbg
 #if defined (_DEBUGPRINT_)
-      Parameter (LocDbg = .True.)
+      Logical, Parameter:: LocDbg = .True.
 #else
-      Parameter (LocDbg = .False.)
+      Logical, Parameter:: LocDbg = .False.
 #endif
 
 #if defined (_MOLCAS_MPP_)
-#include "para_info.fh"
 #include "cholesky.fh"
       Integer nV(8)
       Integer iSym
@@ -102,40 +102,31 @@ C     ------------
 C
 C     Purpose: setup for parallel Cholesky.
 C
+#if defined (_MOLCAS_MPP_)
+      Use Para_Info, Only: MyRank, nProcs, Is_Real_Par
+      use ChoSwp, only: InfVec
+#endif
       Implicit None
       Integer irc
 
-      Character*18 SecNam
-      Parameter (SecNam = 'Cho_X_Init_Par_Cho')
+      Character(LEN=18), Parameter:: SecNam = 'Cho_X_Init_Par_Cho'
 
-      Logical LocDbg
 #if defined (_DEBUGPRINT_)
-      Parameter (LocDbg = .True.)
+      Logical, Parameter:: LocDbg = .True.
 #else
-      Parameter (LocDbg = .False.)
+      Logical, Parameter:: LocDbg = .False.
 #endif
 
 #if defined (_MOLCAS_MPP_)
-#include "para_info.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
-
-      Integer N2
-      Parameter (N2 = InfVec_N2)
+#include "stdalloc.fh"
 
       Integer nV(8)
-      Integer ip_IDV, l_IDV
-      Integer ip_myInfV, l_myInfV
-      Integer iSym
+      Integer iSym, i, j
       Logical isSerial
 
-      Integer InfVec, IDV, myInfV
-      Integer i, j, k
 
-      InfVec(i,j,k)=iWork(ip_InfVec-1+MaxVec*N2*(k-1)+MaxVec*(j-1)+i)
-      IDV(i)=iWork(ip_IDV-1+i)
-      myInfV(i)=iWork(ip_myInfV-1+i)
+      Integer, Allocatable:: IDV(:), myInfV(:)
 
       irc = 0
 
@@ -162,28 +153,21 @@ C     -----------------------------------------------------
       Do iSym = 1,nSym
          nV(iSym) = 0
          If (NumCho(iSym) .gt. 0) Then
-            l_IDV = NumCho(iSym)
-            Call GetMem('IDV','Allo','Inte',ip_IDV,l_IDV)
-            Call Cho_Distrib_Vec(1,NumCho(iSym),iWork(ip_IDV),nV(iSym))
+            Call mma_allocate(IDV,NumCho(iSym),Label='IDV')
+            Call Cho_Distrib_Vec(1,NumCho(iSym),IDV,nV(iSym))
             If (nV(iSym) .gt. 0) Then
-               l_myInfV = nV(iSym)
-               Call GetMem('myInfV','Allo','Inte',ip_myInfV,l_myInfV)
-               Do j = 1,N2
+               Call mma_allocate(myInfV,nV(iSym),Label='myInfV')
+               Do j = 1,SIZE(InfVec,2)
                   If (j .ne. 3) Then
-                     k = ip_myInfV - 1
                      Do i = 1,nV(iSym)
-                        iWork(k+i) = InfVec(IDV(i),j,iSym)
-                     End Do
-                     k = ip_InfVec - 1
-     &                 + MaxVec*N2*(iSym-1) + MaxVec*(j-1)
-                     Do i = 1,nV(iSym)
-                        iWork(k+i) = myInfV(i)
+                        myInfV(i) = InfVec(IDV(i),j,iSym)
                      End Do
+                     InfVec(:,j,iSym) = myInfV(:)
                   End If
                End Do
-               Call GetMem('myInfV','Free','Inte',ip_myInfV,l_myInfV)
+               Call mma_deallocate(myInfV)
             End If
-            Call GetMem('IDV','Free','Inte',ip_IDV,l_IDV)
+            Call mma_deallocate(IDV)
          End If
       End Do
 
@@ -217,24 +201,19 @@ C     ------------
 
       End
       SubRoutine Cho_X_Init_Par_GenBak()
+      Use Para_Info, Only: Is_Real_Par
+      use ChoSwp, only: InfVec, InfVec_Bak
       Implicit None
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "chopar.fh"
-#include "WrkSpc.fh"
-
-#include "para_info.fh"
+#include "chpari.fh"
+#include "stdalloc.fh"
 
+      NumCho_Bak(:)=0
       If (Is_Real_Par()) Then
-         l_InfVec_Bak = l_InfVec
-         Call GetMem('InfVec_Bak','Allo','Inte',ip_InfVec_Bak,
-     &                                           l_InfVec_Bak)
-         Call iCopy(l_InfVec,iWork(ip_InfVec),1,iWork(ip_InfVec_Bak),1)
-         Call iCopy(nSym,NumCho,1,NumCho_Bak,1)
-      Else
-         ip_InfVec_Bak = 0
-         l_InfVec_Bak = 0
-         Call iZero(NumCho_Bak,nSym)
+         Call mma_allocate(InfVec_Bak,SIZE(InfVec,1),SIZE(InfVec,2),
+     &                     SIZE(InfVec,3),Label='InfVec_Bak')
+         InfVec_Bak(:,:,:)=InfVec(:,:,:)
+         NumCho_Bak(1:nSym)=NumCho(1:nSym)
       End If
 
       End
