@@ -18,6 +18,9 @@ C
 C     Purpose: write partial Cholesky vectors to disk.
 C              (Parallel two-step algorithm)
 C
+#if defined (_DEBUGPRINT_)
+      use ChoSwp, only: nnBstRSh
+#endif
       Implicit None
       Integer irc
       Integer l_Vec, l_NVT, l_myRankSP
@@ -29,15 +32,9 @@ C
 
 #if defined (_DEBUGPRINT_)
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 
       Integer iSym, iSP, n
 
-      Integer i, j, k
-      Integer nnBstRSh
-      nnBstRSh(i,j,k)=iWork(ip_nnBstRSh-1+nSym*nnShl*(k-1)+nSym*(j-1)+i)
-
       If (l_NVT.lt.nSym .or. l_myRankSP.lt.nnShl) Then
          irc=-1
          Return
@@ -91,24 +88,18 @@ C
 C     Simply write the partial vectors to disk at the appropriate
 C     addresses on the vector files.
 C
+      use ChoSwp, only: nnBstRSh, iiBstRSh
       Implicit None
       Integer irc
       Real*8  Vec(*)
       Integer iSP
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 
       Integer iOpt
       Parameter (iOpt=1)
 
       Integer iSym, kV
-      Integer lTot, iAdr, iAdr0
-
-      Integer i, j, k
-      Integer iiBstRSh, nnBstRSh
-      iiBstRSh(i,j,k)=iWork(ip_iiBstRSh-1+nSym*nnShl*(k-1)+nSym*(j-1)+i)
-      nnBstRSh(i,j,k)=iWork(ip_nnBstRSh-1+nSym*nnShl*(k-1)+nSym*(j-1)+i)
+      Integer lTot, iAdr, iAdr0, j
 
       irc=0
 
@@ -133,6 +124,7 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C     Write the vectors in blocks.
 C
+      use ChoSwp, only: nnBstRSh
       Implicit None
       Integer irc
       Real*8  Vec(*)
@@ -140,20 +132,13 @@ C
       Integer myRankSP(*)
       Integer SP
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 
-      Integer iOpt
-      Parameter (iOpt=1)
+      Integer, Parameter:: iOpt=1
 
-      Integer iSym, kV
+      Integer iSym, kV, j
       Integer lTot, iAdr
       Integer iSP
 
-      Integer i, j, k
-      Integer nnBstRSh
-      nnBstRSh(i,j,k)=iWork(ip_nnBstRSh-1+nSym*nnShl*(k-1)+nSym*(j-1)+i)
-
       irc=0
 
       iSP=myRankSP(SP)
