@@ -34,6 +34,7 @@ C     Other input such as orbital energies are read from mbpt2 include
 C     files.
 C
 C
+      use ChoMP2, only: OldVec
 #include "implicit.fh"
       External ChoMP2_Col, ChoMP2_Vec
       Integer  irc
@@ -44,14 +45,13 @@ C
 #include "chomp2_cfg.fh"
 #include "chomp2.fh"
 #include "chomp2_dec.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 
-      Character*6  ThisNm
-      Character*13 SecNam
-      Parameter (SecNam = 'ChoMP2_DecDrv', ThisNm = 'DecDrv')
+      Character(LEN=6), Parameter:: ThisNm = 'DecDrv'
+      Character(LEN=13), Parameter:: SecNam = 'ChoMP2_DecDrv'
 
-      Logical Restart, Failed, ConventionalCD
-      Parameter (Restart = .false.)
+      Logical, Parameter:: Restart = .false.
+      Logical Failed, ConventionalCD
 
       Integer nOption
       Parameter (nOption = 2)
@@ -61,6 +61,9 @@ C
       Integer iClos(2)
       Integer MxCDVec(8)
 
+      Real*8, Allocatable:: ErrStat(:), Bin(:), Qual(:), Buf(:)
+      Integer, Allocatable:: iQual(:), iPivot(:)
+
 C     Initializations.
 C     ----------------
 
@@ -104,13 +107,13 @@ C For now, I simply define the array here:
       End Do
 
       lErrStat = 3
-      Call GetMem('ErrStat','Allo','Real',ipErrStat,lErrStat)
+      Call mma_allocate(ErrStat,lErrStat,Label='ErrStat')
       If (Verbose) Then
          nBin = 18
-         Call GetMem('Bin','Allo','Real',ipBin,nBin)
+         Call mma_allocate(Bin,nBin,Label='Bin')
       Else
-         ipBin = -999999
          nBin  = 0
+         Call mma_allocate(Bin,1,Label='Bin')
       End If
 
       Do iSym = 1,nSym
@@ -118,8 +121,6 @@ C For now, I simply define the array here:
          InCore(iSym)  = .false.
       End Do
       NowSym    = -999999
-      ip_OldVec = -999999
-      l_OldVec  = 0
 
       If (DelOrig) Then
          iClos(1) = 3  ! signals close and delete original vectors
@@ -154,9 +155,9 @@ C     --------------------
             ConventionalCD = MxCDVec(iSym).lt.1 .or.
      &                       MxCDVec(iSym).ge.nDim
             If (Verbose .and. nBin.gt.0) Then
-               Work(ipBin) = 1.0D2
-               Do iBin = ipBin+1,ipBin+nBin-1
-                  Work(iBin) = Work(iBin-1)*1.0D-1
+               Bin(1) = 1.0D2
+               Do iBin = 2,nBin
+                  Bin(iBin) = Bin(iBin-1)*1.0D-1
                End Do
                If (ConventionalCD) Then
                   Write(6,'(//,1X,A,I2,A,I9)')
@@ -170,7 +171,7 @@ C     --------------------
      &            ', dimension: ',nDim
                End If
                Write(6,'(/,1X,A)') 'Analysis of initial diagonal:'
-               Call Cho_AnaSize(Diag(kOffD),nDim,Work(ipBin),nBin,6)
+               Call Cho_AnaSize(Diag(kOffD),nDim,Bin,nBin,6)
             End If
 
 C           Open files.
@@ -213,29 +214,24 @@ C           --------------------
             End If
 #endif
 
-            lQual   = nDim*(MxQual + 1)
-            liQual  = MxQual
-            liPivot = nDim
-            Call GetMem('Qual','Allo','Real',ipQual,lQual)
-            Call GetMem('iQual','Allo','Inte',ipiQual,liQual)
-            Call GetMem('iPivot','Allo','Inte',ipiPivot,liPivot)
+            Call mma_allocate(Qual,nDim*(MxQual + 1),Label='Qual')
+            Call mma_allocate(iQual,MxQual,Label='iQual')
+            Call mma_allocate(iPivot,nDim,Label='iPivot')
 
-            Call GetMem('GetMax','Max ','Real',ipB,lB)
+            Call mma_maxDBLE(lB)
             lBuf = min((nDim+MxQual)*MxQual,lB)
             Left = lB - lBuf
             nInC = Left/nDim
             If (nInC .ge. NumCho(iSym)) Then
                InCore(iSym) = .true.
-               l_OldVec = nDim*NumCho(iSym)
-               Call GetMem('OldVec','Allo','Real',ip_OldVec,l_OldVec)
+               lTot = nDim*NumCho(iSym)
+               Call mma_allocate(OldVec,lTot,Label='OldVec')
                iOpt = 2
-               lTot = l_OldVec
                iAdr = 1
-               Call ddaFile(lUnit_F(iSym,1),iOpt,
-     &                      Work(ip_OldVec),lTot,iAdr)
+               Call ddaFile(lUnit_F(iSym,1),iOpt,OldVec,lTot,iAdr)
             End If
-            Call GetMem('GetMx2','Max ','Real',ipB,lBuf)
-            Call GetMem('DecBuf','Allo','Real',ipBuf,lBuf)
+            Call mma_maxDBLE(lBuf)
+            Call mma_allocate(Buf,lBuf,Label='Buf')
 
 C           Decompose this symmetry block.
 C           ------------------------------
@@ -245,10 +241,10 @@ C           ------------------------------
             If (ConventionalCD) Then
                Call ChoDec(ChoMP2_Col,ChoMP2_Vec,
      &                     Restart,Thr,Span,MxQual,
-     &                     Diag(kOffD),Work(ipQual),Work(ipBuf),
-     &                     iWork(ipiPivot),iWork(ipiQual),
+     &                     Diag(kOffD),Qual,Buf,
+     &                     iPivot,iQual,
      &                     nDim,lBuf,
-     &                     Work(ipErrStat),nMP2Vec(iSym),irc)
+     &                     ErrStat,nMP2Vec(iSym),irc)
                If (irc .ne. 0) Then
                   Write(6,*) SecNam,': ChoDec returned ',irc,
      &                              '   Symmetry block: ',iSym
@@ -257,19 +253,19 @@ C           ------------------------------
             Else
                Call ChoDec_MxVec(ChoMP2_Col,ChoMP2_Vec,MxCDVec(iSym),
      &                           Restart,Thr,Span,MxQual,
-     &                           Diag(kOffD),Work(ipQual),Work(ipBuf),
-     &                           iWork(ipiPivot),iWork(ipiQual),
+     &                           Diag(kOffD),Qual,Buf,
+     &                           iPivot,iQual,
      &                           nDim,lBuf,
-     &                           Work(ipErrStat),nMP2Vec(iSym),irc)
+     &                           ErrStat,nMP2Vec(iSym),irc)
                If (irc .ne. 0) Then
                   Write(6,*) SecNam,': ChoDec_MxVec returned ',irc,
      &                              '   Symmetry block: ',iSym
                   Go To 1 ! exit...
                End If
             End If
-            XMn = Work(ipErrStat)
-            XMx = Work(ipErrStat+1)
-            RMS = Work(ipErrStat+2)
+            XMn = ErrStat(1)
+            XMx = ErrStat(2)
+            RMS = ErrStat(3)
             If (Verbose) Then
                Write(6,'(/,1X,A)')
      &         '- decomposition completed!'
@@ -312,9 +308,9 @@ C           ----------------------------------
                Write(6,*) 'Symmetry block: ',iSym
                Write(6,*) 'Threshold, Span, MxQual: ',Thr,Span,MxQual
                Write(6,*) 'Error statistics for diagonal [min,max,rms]:'
-               Write(6,*) (Work(ipErrStat+i),i=0,2)
-               Call ChoMP2_DecChk(irc,iSym,Work(ipQual),nDim,MxQual,
-     &                            Work(ipBuf),lBuf,Work(ipErrStat))
+               Write(6,*)  ErrStat(:)
+               Call ChoMP2_DecChk(irc,iSym,Qual,nDim,MxQual,
+     &                            Buf,lBuf,ErrStat)
                If (irc .ne. 0) Then
                   If (irc .eq. -123456) Then
                      Write(6,*)
@@ -328,9 +324,9 @@ C           ----------------------------------
      &                                ' ')
                   End If
                Else
-                  XMn = Work(ipErrStat)
-                  XMx = Work(ipErrStat+1)
-                  RMS = Work(ipErrStat+2)
+                  XMn = ErrStat(1)
+                  XMx = ErrStat(2)
+                  RMS = ErrStat(3)
                   Write(6,'(A,A,A)')
      &            'Error statistics for ',Option,' [min,max,rms]:'
                   Write(6,*) XMn,XMx,RMS
@@ -359,15 +355,11 @@ C           ----------------------------------
 C           Free memory.
 C           ------------
 
-            Call GetMem('DecBuf','Free','Real',ipBuf,lBuf)
-            If (InCore(iSym)) Then
-               Call GetMem('OldVec','Free','Real',ip_OldVec,l_OldVec)
-               ip_OldVec = -999999
-               l_OldVec  = 0
-            End If
-            Call GetMem('iPivot','Free','Inte',ipiPivot,liPivot)
-            Call GetMem('iQual','Free','Inte',ipiQual,liQual)
-            Call GetMem('Qual','Free','Real',ipQual,lQual)
+            Call mma_deallocate(Buf)
+            If (InCore(iSym)) Call mma_deallocate(OldVec)
+            Call mma_deallocate(iPivot)
+            Call mma_deallocate(iQual)
+            Call mma_deallocate(Qual)
 
 C           Close (possibly deleting original) files.
 C           -----------------------------------------
@@ -400,6 +392,7 @@ C           ---------------------------------
             End Do
          End Do
       End If
-      Call GetMem('Flush','Flush','Real',ipErrStat,lErrStat)
-      Call GetMem('ErrStat','Free','Real',ipErrStat,lErrStat)
+
+      Call mma_deallocate(Bin)
+      Call mma_deallocate(ErrStat)
       End
