@@ -23,6 +23,7 @@ C
 C     Modified by F. Aquilante to add contributions from T1 amplitudes
 C                              determined from Thouless formula
 C
+      use ChoMP2, only: iFirstS, LnOcc, LnT1am, LiT1am, LiMatij
 #include "implicit.fh"
       Real*8  EOcc(*), EVir(*), Xaibj(LnT2am)
       Integer LiT2am(8)
@@ -35,11 +36,6 @@ C
 
       MulD2h(i,j)=iEor(i-1,j-1)+1
       iTri(i,j)=max(i,j)*(max(i,j)-3)/2+i+j
-      iFirstS(i,j)=iWork(ip_FirstS-1+nSym*(j-1)+i)
-      LnOcc(i,j)=iWork(ip_LnOcc-1+nSym*(j-1)+i)
-      LiT1am(i,j,k)=iWork(ip_LiT1am-1+nSym*nSym*(k-1)+nSym*(j-1)+i)
-      LnT1am(i,j)=iWork(ip_LnT1am-1+nSym*(j-1)+i)
-      LiMatij(i,j,k)=iWork(ip_LiMatij-1+nSym*nSym*(k-1)+nSym*(j-1)+i)
 
       Call Cho_GAdGOp(Xaibj,LnT2am,'+')
 
