@@ -18,13 +18,13 @@ C     Purpose: compute MP2 energy contribution using original (i.e. not
 C              sorted according to batches over occupied orbitals)
 C              Cholesky vectors on disk.
 C
+      use ChoMP2, only: iFirstS, LnOcc, LnT1am, LiMatij
 #include "implicit.fh"
       Logical Delete
       Real*8  EOcc(*), EVir(*), Wrk(lWrk)
 #include "cholesky.fh"
 #include "chomp2_cfg.fh"
 #include "chomp2.fh"
-#include "WrkSpc.fh"
 
       Character*10 ThisNm
       Character*17 SecNam
@@ -39,10 +39,6 @@ C
       Real*8 X(0:1)
       Data X /0.0D0,1.0D0/
 
-      iFirstS(i,j)=iWork(ip_FirstS-1+nSym*(j-1)+i)
-      LnT1am(i,j)=iWork(ip_LnT1am-1+nSym*(j-1)+i)
-      LiMatij(i,j,k)=iWork(ip_LiMatij-1+nSym*nSym*(k-1)+nSym*(j-1)+i)
-      LnOcc(i,j)=iWork(ip_LnOcc-1+nSym*(j-1)+i)
       MulD2h(i,j)=iEor(i-1,j-1)+1
       iTri(i,j)=max(i,j)*(max(i,j)-3)/2+i+j
 
