@@ -10,23 +10,22 @@
 *                                                                      *
 * Copyright (C) 2010, Jonas Bostrom                                    *
 ************************************************************************
-      SubRoutine ChoMP2g_AmpDiag(irc,ipDiag,EOcc,EVir)
+      SubRoutine ChoMP2g_AmpDiag(irc,Diag,EOcc,EVir)
 C
 C     Jonas Bostrom, Jan. 2010.
 C
-C     Purpose: Construct diagonal for decomposition
-C              of amplitude vectors.
+C     Purpose: Construct diagonal for decomposition of amplitude
+C              vectors.
 C
 #include "implicit.fh"
-      Real*8  EOcc(*), EVir(*)
+      Integer irc
+      Real*8  Diag(*), EOcc(*), EVir(*)
 #include "cholesky.fh"
 #include "chomp2.fh"
 #include "chomp2g.fh"
-#include "WrkSpc.fh"
 
-      Character*7  ThisNm
-      Character*15 SecNam
-      Parameter (SecNam = 'ChoMP2g_AmpDiag', ThisNm = 'AmpDiag')
+      Character(LEN=7), Parameter:: ThisNm = 'AmpDiag'
+      Character(LEN=15), Parameter:: SecNam = 'ChoMP2g_AmpDiag'
 
       MulD2h(k,l)=iEor(k-1,l-1)+1
 
@@ -36,7 +35,7 @@ C     Initialization.
 C     ------------------------
 
       iVecType = 6
-      kD0 = ipDiag - 1
+      kD0 = 0
 
 C     Construct Diagonal
 C     ------------------------
@@ -51,7 +50,7 @@ C     ------------------------
                   Do iA = 1, nVir(iSymA)
                      iAI = kD2 + iA
                      DE = 2.0d0*(EVir(iVir(iSymA)+iA)-Ei)
-                     Work(iAI) = Work(iAI)/DE
+                     Diag(iAI) = Diag(iAI)/DE
                   End Do
                End Do
             End Do
