@@ -31,14 +31,6 @@
      &        itOffs(0:mSym-1,0:mSym-1,0:mSym-1), MapOrg(4)
       Logical Shijij,IJeqKL
 *
-* some dummy assignments to avoid compiler warnings about unused
-* variables.
-*
-      If (mSym.gt.0.and.nSkal.gt.0) Then
-         iDummy_2  = itOffs(0,0,0)
-         iDummy_3  = MapOrg(1)
-      End If
-*
 * call sorting routine
 *
       If (IfcSew .eq. 1) Then
@@ -82,4 +74,10 @@
       End If
 *
       Return
+* Avoid unused argument warnings
+      IF (.False.) Then
+         Call Unused_integer_array(MapOrg)
+         Call Unused_integer(nSkal)
+         Call Unused_integer_array(itOffs)
+      End If
       End
