@@ -28,14 +28,12 @@
 *                                                                      *
 ************************************************************************
       use SOAO_Info, only: iAOtSO
+      use ChoArr, only: iSOShl, iShlSO, nBstSh, iShP2RS, iShP2Q,
+     &                  nDim_Batch
       Implicit Real*8 (A-H,O-Z)
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "chosew.fh"
 #include "real.fh"
 #include "print.fh"
-#include "srt0.fh"
-#include "WrkSpc.fh"
 *
       Real*8 AOint(ijkl,iCmp,jCmp,kCmp,lCmp), TInt(lInt)
       Integer iShell(4), iAO(4), kOp(4),
@@ -47,11 +45,6 @@
       INTEGER ABCD, CDAB, CD, AB, A, B, C, D
 *
       iTri(i,j)=Max(i,j)*(Max(i,j)-3)/2 + i + j
-      iSOShl(i)=iWork(ip_iSOShl-1+i)
-      iShlSO(i)=iWork(ip_iShlSO-1+i)
-      nBstSh(i)=iWork(ip_nBstSh-1+i)
-      iShP2RS(i,j)=iWork(ip_iShP2RS-1+2*(j-1)+i)
-      iShP2Q(i,j)=iWork(ip_iShP2Q-1+2*(j-1)+i)
 *
       irout = 109
       jprint = nprint(irout)
@@ -64,10 +57,6 @@
       If (jPrint.ge.99) Call RecPrt(' In Plf_Cho_3: AOInt',' ',
      &                              AOInt,ijkl,iCmp*jCmp*kCmp*lCmp)
 
-      If (Shijij) Then ! avoid compiler warnings about unused variables
-         iDummy_1 = iShell(1)
-      End If
-
       NUMC = NBSTSH(SHC)
       NUMD = NBSTSH(SHD)
       NUMA = NBSTSH(SHA)
@@ -104,8 +93,6 @@ C to avoid stupid compiler warnings:
       iAOj=iAO(2)
       iAOk=iAO(3)
       iAOl=iAO(4)
-*
-      ijklCmp=iCmp*jCmp*kCmp*lCmp
 *
       Do 100 i1 = 1, iCmp
          iSOs(1)=iAOtSO(iAOi+i1,kOp(1))+iAOsti
@@ -244,5 +231,10 @@ C to avoid stupid compiler warnings:
 300         Continue
 200      Continue
 100   Continue
-
+      Return
+* Avoid unused argument warnings
+      If (.False.) Then
+         Call Unused_integer_array(iShell)
+         Call Unused_logical(Shijij)
+      End If
       End
