@@ -15,9 +15,7 @@
       IMPLICIT REAL*8 (A-H,O-Z)
       DIMENSION JSY(*),HDIAG(*),FC(*),FIJ(*),FJI(*)
       DIMENSION ICASE(*)
-      CALL QENTER('DIAG')
       CALL IIJJ_CPF(ICASE,JSY,HDIAG,FC,FIJ,FJI)
       CALL IJIJ_CPF(JSY,HDIAG,FJI)
-      CALL QEXIT('DIAG')
       RETURN
       END
