@@ -12,14 +12,13 @@
      &                    nP2_ontop,nDmat,F_xc,
      &                    dF_dRho,ndF_dRho,dF_dP2ontop,ndF_dP2ontop,
      &                    T_X)
+      use OFembed, only: KEonly
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "hflda.fh"
       Real*8 Rho(nRho,mGrid),dF_dRho(ndF_dRho,mGrid),
      &       P2_ontop(nP2_ontop,mGrid), F_xc(mGrid),
      &       dF_dP2ontop(ndF_dP2ontop,mGrid)
-      Logical Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
 *
 ************************************************************************
 *
