@@ -154,7 +154,6 @@ c      If(.False.) Then
       t21 = t20**2
       t23 = log(t21*t8)
       t24 = 0.8862747535D-2*t23
-      eP = t12+t18+t24
       t26 = t4+0.1584942279D2*t5+0.101578D3
       t27 = 1/t26
       t30 = log(0.6203504908D0*t3*t27)
@@ -166,20 +165,18 @@ c      If(.False.) Then
       t38 = t37**2
       t40 = log(t38*t27)
       t41 = 0.5334620013D-2*t40
-      eF = t31+t36+t41
-      t43 = (rho_a-rho_b)*t2
+      !t43 = (rho_a-rho_b)*t2
 
-      t44 = 1+t43
-      t45 = t44**(1.D0/3.D0)
-      t47 = 1-t43
-      t48 = t47**(1.D0/3.D0)
-      t51 = 2**(1.D0/3.D0)
-      fzz = (t45*t44+t48*t47-2)/(2*t51-2)
+      !t44 = 1+t43
+      !t45 = t44**(1.D0/3.D0)
+      !t47 = 1-t43
+      !t48 = t47**(1.D0/3.D0)
+      !t51 = 2**(1.D0/3.D0)
       t56 = rho_a-1.D0*rho_b
       t57 = t56*t2
-      t58 = 1.D0+t57
+      t58 = max(0.0D0,1.D0+t57)
       t59 = t58**(1.D0/3.D0)
-      t62 = 1.D0-1.D0*t57
+      t62 = max(0.0D0,1.D0-1.D0*t57)
       t63 = t62**(1.D0/3.D0)
       t65 = t59*t58+t63*t62-2.D0
       t66 = t31+t36+t41-t12-t18-t24
