@@ -18,8 +18,8 @@ C            V     POTENTIAL
 C            H     RELATIVISTIC KINETIC ENERGY
 C            EV2   PVP INTEGRALS
 C
+      USE DKH_Info, ONLY: CLightAU
       IMPLICIT REAL*8(A-H,O-Z)
-#include "RelLight.fh"
       DIMENSION V(ISIZE),SMAT(ISIZE),MULT(ISIZE),P(ISIZE),G(ISIZE),
      *          H(ISIZE),BU(ISIZE),EV2(ISIZE),
      *          EIG(N,N),SINV(N,N),REVT(N,N),AUX(N,N),OVE(N,N),
@@ -34,7 +34,6 @@ C
 C      CALL PRMAT(6,SMAT,N,0,'SMAT    ')
       VELIT=CLightAU
       ISIZE=N*(N+1)/2
-      TOL=1.D-14
       PREA=1/(VELIT*VELIT)
       CON2=PREA+PREA
       CON=1.D0/PREA
