@@ -24,17 +24,15 @@ c           the original routines by Hess are called!
 c
       Implicit real*8(a-h,o-z)
 #include "Molcas.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "rinfo.fh"
 #include "print.fh"
 #include "real.fh"
 #include "WrkSpc.fh"
 #include "wldata.fh"
 #include "oneswi.fh"
-#include "RelLight.fh"
 #include "dkhparameters.fh"
       Integer DKHMemMax, DKHMemCheck, xOrder_save
-#include "relae.fh"
       integer ipaddr(3)
       Character*8 Label, pXpLbl
 #ifdef MOLPRO
@@ -48,7 +46,7 @@ c
       logical dkhscfflg
       Integer snumber,tnumber,unumber,nbasp,nbaso
       Integer Get_sNumber, Get_tNumber, Get_uNumber
-      logical delflag,no_hamil,no_prop,no_s,no_u,LDKpert
+      logical no_hamil,no_prop,no_s,no_u,LDKpert
       dimension nInt(1)
 *                                                                      *
 ************************************************************************
@@ -378,13 +376,11 @@ CMR - IF THAT IS .TRUE. WE SHOULD WRITE XORDER.EQ.0
          tnumber=Get_tNumber(dkhunit4)
          unumber=Get_uNumber(dkhunit5)
 *
-         delflag=.FALSE.
          no_hamil=.false.
          no_prop=.true.
          k=0
 *
          Do L = 0, nSym-1
-            If (L.eq.nSym-1) delflag=.TRUE.
             n=nBas(L)
             iSize=n*(n+1)/2
             If (iSize.eq.0) Go To 911
@@ -613,13 +609,10 @@ C           Write (6,*) 'lOper=',lOper
 *
             Call GetMem('Core','Max','Real',iDum,Mem_Available)
 C           Write (6,*) 'Mem_Available=',Mem_Available
-            delflag=.FALSE.
             no_hamil=.true.
             no_prop=.false.
             k=0
             Do L = 0, nSym-1
-               If (L.eq.nSym-1 .and.
-     &             iProps.eq.numb_props) delflag=.TRUE.
                n=nBas(L)
                iSize=n*(n+1)/2
                If (iSize.eq.0) Go To 91
@@ -699,7 +692,7 @@ C              Write (6,*) 'dkhmemmax=',dkhmemmax
 *           First contract the result, store in Work(ip_Prop)
 *
             Call Allocate_Work(ip_Prop,iSizec+4)
-            Call repmat(idbg,Work(iX),Work(ip_Prop))
+            Call repmat(idbg,Work(iX),Work(ip_Prop),.True.)
 *
 *                                                                      *
 ************************************************************************
@@ -783,10 +776,8 @@ C    &                                  1.0D0,0)
 *        Loop over the symmetry blocks
 *
          epsilon=1.d-10
-         delflag=.FALSE.
          k=0
          Do L = 0, nSym-1
-            If (L.eq.nSym-1) delflag=.TRUE.
             n=nBas(L)
             iSize=n*(n+1)/2
             If (iSize.eq.0) goto 9
@@ -864,7 +855,7 @@ C    &                                  1.0D0,0)
 c
 #ifdef MOLPRO
 c... store relativistic H
-      Call repmat(idbg,Work(ik),Work(iH_temp))
+      Call repmat(idbg,Work(ik),Work(iH_temp),.True.)
       call fperm(Work(iH_temp),Work(ih))
       Call writem(Work(iH),isizec+2,1,1200,0,'H0')
       Call writem(Work(iH),isizec+2,1,1210,0,'H01')
@@ -932,7 +923,7 @@ c... reset contracted basis size
       End If
       call dcopy_(4,[Zero],0,Work(iH_Temp+iSizec),1)
 *     Contract and store in iH_temp
-      Call repmat(idbg,Work(iV),Work(iH_temp))
+      Call repmat(idbg,Work(iV),Work(iH_temp),.True.)
 *
       CALL GetMem('V       ','FREE','REAL',iV,iSizep+4)
       CALL GetMem('SS      ','FREE','REAL',iSS,iSizep+4)
@@ -962,7 +953,7 @@ c... reset contracted basis size
          Call PrMtrx('iK (prim)',[lOper],nComp,[iK],Work)
          Call iSwap(8,nBas,1,nBas_Prim,1)
       End If
-      Call repmat(idbg,Work(iK),Work(iH))
+      Call repmat(idbg,Work(iK),Work(iH),.True.)
       If (iPrint.ge.20) Then
          Call iSwap(8,nBas,1,nBas_Cont,1)
          Call PrMtrx('iH (cont)',[lOper],nComp,[iH],Work)
@@ -1016,7 +1007,7 @@ c... reset contracted basis size
 *
 *     Replace overlap on ONEINT
 *
-         Call repmat(idbg,Work(ipVp),Work(iH))
+         Call repmat(idbg,Work(ipVp),Work(iH),.True.)
          iRC = -1
          Label='Mltpl  0'
          Call WrOne(iRC,iOpt,Label,1,Work(iH),lOper)
