@@ -242,8 +242,7 @@ C     FUNCTION DCOF CALCULATES COEFFICIENT D NEEDED FOR FT
 C     DCOF(E,LX,IX)= ((-E)**IX * FAK(LX))/(FAK(LX-2*IX)*FAK(IX))
 C     V 1.0 - 12.3.86 - BERND HESS
 C
-      COMMON /CRELOP/ PI,ZWP,SQPI,VELIT,PREA,CSQ,ZWPH32,FAK(26),
-     *ZWPH12,BCO(210),GA(20),IMAX
+#include "crelop.fh"
       SAVE /CRELOP/
       I=LX-2*IX
       D=1.D0
@@ -336,8 +335,7 @@ C     XB**LB * YB**MB * ZB**NB * EXP(-AB*RB**2)
 C     WITH XA=X ,YA=Y ZA=Z
 C     V 1.1 - 1.6.86 - BERND HESS
 C
-      COMMON /CRELOP/ PI,ZWP,SQPI,VELIT,PREA,CSQ,ZWPH32,FAK(26),
-     *ZWPH12,BCO(210),GAM(20),IMAX
+#include "crelop.fh"
 C@    WRITE (6,922) LA,MA,NA,LB,MB,NB,AA,AB
 C@922 FORMAT(' SQROPY ',3I2,2X,3I2,2X,3D14.6)
 C
@@ -359,7 +357,7 @@ C
        RETURN
       ENDIF
       EX=-0.5D0*DBLE(IMAX)
-      OVL=0.5D0*ANG*GAM(IMAX)*((AA+AB)**EX)
+      OVL=0.5D0*ANG*GA(IMAX)*((AA+AB)**EX)
 C
 C     CALCULATE SQR INTEGRAL IN MOMENTUM SPACE
 C
@@ -444,14 +442,14 @@ C
       KK=NA+NA
       ANG=THETA(II+JJ,KK)*PHI(JJ,II)
       EX=-0.5D0*DBLE(II+JJ+KK+3)
-      OV1=0.5D0*ANG*GAM(II+JJ+KK+3)*((AA+AA)**EX)
+      OV1=0.5D0*ANG*GA(II+JJ+KK+3)*((AA+AA)**EX)
 C#    WRITE (6,*) ' SRQ  OV1',LA,MA,NA,AA,ANG,sqrt(1/OV1)
       II=LB+LB
       JJ=MB+MB
       KK=NB+NB
       ANG=THETA(II+JJ,KK)*PHI(JJ,II)
       EX=-0.5D0*DBLE(II+JJ+KK+3)
-      OV2=0.5D0*ANG*GAM(II+JJ+KK+3)*((AB+AB)**EX)
+      OV2=0.5D0*ANG*GA(II+JJ+KK+3)*((AB+AB)**EX)
 C#    WRITE (6,*) ' SRQ  OV2',LB,MB,NB,AB,ANG,sqrt(1/OV2)
       SQROPY=S/sqrt(OV1*OV2)
       RETURN
