@@ -20,12 +20,12 @@ C
       SUBROUTINE SCFCLI(idbg,epsilon,S,H,V,PVP,N,ISIZE,VELIT,
      *                  TMP1,TMP2,TMP3,TMPA,TMPB,TMPC,EW,E,AA,RR,TT,
      *                  TMP4,TMPD,TMPE,TMPF,TWRK4,IDIM)
+      USE DKH_Info, ONLY: IRELAE
       IMPLICIT REAL*8(A-H,O-Z)
       DIMENSION S(ISIZE),H(ISIZE),V(ISIZE),PVP(ISIZE)
       DIMENSION TMP1(IDIM*(IDIM+1)/2),TMP2(ISIZE),TMP3(ISIZE),
      *          TMPA(N,N),TMPB(N,N),TMPC(N,N),
      *          EW(N),E(N),AA(N),RR(N),TT(N)
-#include "relae.fh"
       DIMENSION TMP4(IDIM*(IDIM+1)/2)
       DIMENSION TMPD(IDIM,IDIM)
       DIMENSION TMPE(N,N)
@@ -34,7 +34,6 @@ C
 *
 C
 c      write(6,*) ' in SCFCLI', N, iSize
-      TOL=1.D-14
       PREA=1d0/(VELIT*VELIT)
       CON2=PREA+PREA
       CON=1.D0/PREA
@@ -47,7 +46,7 @@ c      do i=1,n
 c         write(6,'(5f10.5)') (TMPB(i,j),j=1,n)
 c      enddo
       icontr=-1
-      dtol=tol
+      dtol=1.D-14
       CALL dcopiv(TMPB,TMPB,n,1,n,dtol,det,iex,icontr,TMP2)
       if(idbg.gt.0)WRITE (idbg,2016) icontr,det,iex
 2016  FORMAT('  relsew| DCOPIV rc=',I2,', |S|=',D20.6,'x 10**(',I4,') ')
@@ -516,8 +515,8 @@ C***** NAME AddMar
       Call dCopy_(n*n,[0.0D0],0,Eig,1)
       Call dCopy_(n,[1.0D0],0,Eig,n+1)
       Call dCopy_(N*(N+1)/2,AUXI,1,AUX,1)
-C      Call NIDiag(AUXI,EIG,N,N,0)
-      Call NIDiag_New(AUXI,EIG,N,N,0)
+C      Call NIDiag(AUXI,EIG,N,N)
+      Call NIDiag_New(AUXI,EIG,N,N)
       Call vEig(N,AUXI,EW)
       Call JacOrd2(EW, Eig, n, n)
 *
