@@ -11,6 +11,7 @@
       Subroutine espf (ireturn,StandAlone)
       use Real_Spherical
       use Basis_Info, only: nBas
+      use Symmetry_Info, only: VarR, VarT, Symmetry_Info_Dmp
       Implicit Real*8 (A-H,O-Z)
 *
 * ESPF Module
@@ -37,7 +38,6 @@
 * Some warnings
 *
       Call Get_iScalar('nSym',nSym)
-      nIrrep=nSym
       If (nSym.gt.1) Then
          Write(6,'(A)')' Symmetry cannot be used together with ESPF.'
          Call Quit_OnUserError()
@@ -169,7 +169,7 @@
      &                 ' Nuclear energy, including Ext Pot = ',RepNuc
       Else
          Call StatusLine(' espf:',' Computing gradient components')
-         Call espf_grad(natom,nAtQM,nGrdPt,ipExt,ipGrid,ipB,ipDB,ipIsMM,
+         Call espf_grad(natom,nGrdPt,ipExt,ipGrid,ipB,ipDB,ipIsMM,
      &                  ipGradCl,DoTinker,DoGromacs)
          If (ipMltp.eq.ip_Dummy)
      &      Call GetMem('ESPFMltp','Allo','Real',ipMltp,nMult)
@@ -211,10 +211,9 @@
 *     and rotational invariant.
 *
       If (.not.Forces .and. natMM.gt.0) Then
-         Call Get_iScalar('System BitSwitch',iOption)
-         iOption=iOr(iOption,2**7)
-         iOption=iOr(iOption,2**8)
-         Call Put_iScalar('System BitSwitch',iOption)
+         VarR = .true.
+         VarT = .true.
+         Call Symmetry_Info_Dmp()
       End If
 *
       iReturn=0
