@@ -25,7 +25,6 @@
       iPrint = 5
       If (iPL.ge.3) iPrint = 50
       If (iPL.ge.4) iPrint = 99
-      nDiff = 0
       Call GetMem('Atomic Numbers','Allo','Inte',ipAN,natom)
       Call GetMem('Get_Atoms','Allo','Real',ipChrg,natom)
       Call Get_dArray('Nuclear charge',Work(ipChrg),natom)
@@ -77,7 +76,7 @@ c
             Call GetMem('LcCoor','Allo','Real',ip_LcCoor,3*natom)
             Call GetMem('LcANr','Allo','Inte',ip_LcANr,natom)
             nPCM_info = 0
-            Call PCM_Cavity(iPrint,0,natom,Angstrom,Work(ipCord),
+            Call PCM_Cavity(iPrint,0,natom,Work(ipCord),
      &                      iWork(ipAN),iWork(ipIsMM),Work(ip_LcCoor),
      &                      iWork(ip_LcANr),J)
             Call GetMem('LcANr','Free','Inte',ip_LcANr,natom)
