@@ -11,7 +11,7 @@
 * Copyright (C) Francesco Aquilante                                    *
 ************************************************************************
       SUBROUTINE CHO_FOCKTWO_RED(rc,nBas,nDen,DoCoulomb,DoExchange,
-     &           FactC,FactX,ipDLT,ipDSQ,ipFLT,ipFSQ,ipNocc,MinMem)
+     &           FactC,FactX,DLT,DSQ,FLT,FSQ,pNocc,MinMem)
 
 ************************************************************************
 *  Author : F. Aquilante
@@ -57,66 +57,71 @@
 *  ip{X}FS(nDen) : pointer to the array containing {X} in SQ storage
 *    {X=D,F --- Density, Fock matrix}
 *
-*  ipNocc(nDen) : pointer to the array of the Occupation numbers
+*  pNocc(nDen) : pointer to the array of the Occupation numbers
 *                 for the corresponding density
 *
 *  MinMem(nSym) : minimum amount of memory required to read
 *                 a single Cholesky vector in full storage
 *
 ************************************************************************
-
+      use Data_Structures, only: SBA_type, Deallocate_SBA, Map_to_SBA
+      use Data_Structures, only: DSBA_type, Integer_Pointer
       Implicit Real*8 (a-h,o-z)
 
       Integer  rc,nDen,nBas(*)
       Real*8   FactC(nDen),FactX(nDen)
-      Integer  KSQ1(8),ISTSQ(8),ISTLT(8),iSkip(8),MinMem(*)
-      Integer  ipDLT(nDen),ipDSQ(nDen),ipNocc(nDen)
-      Integer  ipFLT(nDen),ipFSQ(nDen)
-      Logical  DoExchange(nDen),DoCoulomb(nDen),DoSomeX,DoSomeC,Debug
+      Integer  KSQ1(8),iSkip(8),MinMem(*)
+
+      Type (DSBA_Type) DLT(nDen), FLT(nDen), FSQ(nDen), DSQ(nDen)
+
+      Type (Integer_Pointer) :: pNocc(nDen)
+
+#ifdef _DEBUGPRINT_
+      Logical  Debug
+#endif
+      Logical  DoExchange(nDen),DoCoulomb(nDen),DoSomeX,DoSomeC
       Real*8   tread(2),tcoul(2),texch(2)
-      Logical  timings
 
-      COMMON   /CHOTIME /timings
+#include "chotime.fh"
+#include "real.fh"
       Character*50 CFmt
-      Character*15 SECNAM
-      Parameter (SECNAM = 'CHO_FOCKTWO_RED')
-
-      parameter (zero = 0.0D0, one = 1.0D0)
-      Logical DoRead
-      parameter (DoRead = .true.)
+      Character(LEN=15), Parameter :: SECNAM = 'CHO_FOCKTWO_RED'
 
+      Logical, Parameter :: DoRead = .true.
 
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
+
+      Type (SBA_Type), Target:: Wab
+
+      Real*8, Pointer :: VJ(:)=>Null(), LrJs(:,:,:)=>Null(),
+     &                   XpJs(:,:,:)=>Null(), XdJb(:,:,:)=>Null(),
+     &                   XgJb(:,:,:)=>Null(), Scr(:)=>Null()
 
 **************************************************
       MulD2h(i,j) = iEOR(i-1,j-1) + 1
 ******
       iTri(i,j) = max(i,j)*(max(i,j)-3)/2 + i + j
+******
+      nOcc(jSym,jDen) = pNocc(jDen)%I1(jSym)
 **************************************************
 
-
 #ifdef _DEBUGPRINT_
-c      Debug=.true.
       Debug=.false.! to avoid double printing in SCF-debug
-#else
-      Debug=.false.
 #endif
       IREDC = -1  ! unknown reduced set in core
 
-        CALL CWTIME(TOTCPU1,TOTWALL1) !start clock for total time
+      CALL CWTIME(TOTCPU1,TOTWALL1) !start clock for total time
 
-        do i=1,2            ! 1 --> CPU   2 --> Wall
-           tread(i) = zero  !time read/rreorder vectors
-           tcoul(i) = zero  !time for computing Coulomb
-           texch(i) = zero  !time for computing Exchange
-        end do
+      ! 1 --> CPU   2 --> Wall
+      tread(:) = zero  !time read/rreorder vectors
+      tcoul(:) = zero  !time for computing Coulomb
+      texch(:) = zero  !time for computing Exchange
 
 C --- Tests on the type of calculation
-        DoSomeC=.false.
-        DoSomeX=.false.
-        MaxSym=0
+      DoSomeC=.false.
+      DoSomeX=.false.
+      MaxSym=0
 c
         jD=0
         do while (jD.lt.nDen .and. .not.DoSomeX)
@@ -139,18 +144,6 @@ c
            End If
         End If
 
-c ISTSQ: Offsets to full symmetry block in DSQ,FSQ
-c ISTLT: Offsets to packed LT symmetry blocks in DLT,FLT
-        ISTSQ(1)=0
-        ISTLT(1)=0
-      DO ISYM=2,NSYM
-        NB=NBAS(ISYM-1)
-        NB2=NB*NB
-        NB3=(NB2+NB)/2
-        ISTSQ(ISYM)=ISTSQ(ISYM-1)+NB2
-        ISTLT(ISYM)=ISTLT(ISYM-1)+NB3
-      END DO
-
 C *************** BIG LOOP OVER VECTORS SYMMETRY *****************
       DO jSym=1,MaxSym
 
@@ -160,13 +153,11 @@ C *************** BIG LOOP OVER VECTORS SYMMETRY *****************
 C ------------------------------------------------------
 
 C --- Pointers to be used for the vectors
-         do i=1,nSym
-            KSQ1(i)=-6666
-         end do
+         KSQ1(:)=-6666
 
 C SET UP THE READING
 C ------------------
-      Call GetMem('Maxmem','MAX ','REAL',KDUM,LWORK)
+      Call mma_maxDBLE(LWORK)
 
       If (MinMem(jSym) .gt. 0) Then
          nVec = Min(LWORK/MinMem(jSym),NumCho(jSym))
@@ -209,7 +200,10 @@ C *************** BATCHING  *****************
 
 C --- Allocate memory for reading the vectors
          kTOT = MinMem(jSym)*NumV
-         Call GetMem('MemR','ALLO','REAL',kWab,kTOT)
+         Call mma_allocate(Wab%A0,kTOT,Label='Wab%A0')
+         Wab%iSym=JSYM
+         Wab%nSym=nSym
+         Wab%iCase=7
 
 c--- setup the skipping flags according to # Occupied
       do k=1,nSym
@@ -219,8 +213,7 @@ c--- setup the skipping flags according to # Occupied
             iSkip(k) = 666 ! always contribute to Coulomb
          else
           do jDen=1,nDen
-               iSkip(k) = iSkip(k) + iWork(ipNocc(jDen)+k-1)
-     &                             + iWork(ipNocc(jDen)+l-1)
+               iSkip(k) = iSkip(k) + nOcc(k,jDen) + nOcc(l,jDen)
           end do
          endif
       end do
@@ -231,35 +224,43 @@ C Max dimension of a read symmetry block
         Do iSym=1,nSym
            if(NBAS(iSym).gt.Nmax .and. iSkip(iSym).ne.0)then
            Nmax = NBAS(iSym)
-           iSymMax= iSym
            endif
         End Do
 
 C --- Compute the total amount of memory needed to have the
 C --- vectors in core (full storage)
-         lChoV=0
+         iE=0
          Do iSymq=1,nSym
             iSymp = muld2h(jSym,iSymq)
-            IF (nBas(iSymq)*nBas(iSymp).ne.0) THEN
-             If(iSymp.gt.iSymq .and. iSkip(iSymp).ne.0) then
-               KSQ1(iSymp) = kWab + lChoV
-               lChoV = lChoV + Nbas(iSymp)*Nbas(iSymq)*NumV
+            nq=nBas(iSymq)
+            np=nBas(iSymp)
+            IF (nq*np<=0) Cycle
+
+            iS = iE + 1
+            If(iSymp.gt.iSymq .and. iSkip(iSymp).ne.0) then
+               NumB= np*nq
+               iE = iE + NumB*NumV
+               Wab%SB(iSymp)%A3(1:np,1:nq,1:NumV) => Wab%A0(iS:iE)
+               Wab%SB(iSymp)%A2(1:NumB,1:NumV) => Wab%A0(iS:iE)
              Else
                if(iSymp.eq.iSymq .and. iSkip(iSymp).ne.0) then
-                 KSQ1(iSymp) = kWab + lChoV
+                 NumB=np*(np+1)/2
 C --- Special trick for the vector L11 ; used to store X(a,Jb)
                  if(iSymp.eq.1.and.jSym.eq.1.and.DoSomeX)then
-                    lChoV = lChoV + (Nmax**2) * NumV
+                    iE = iE + (Nmax**2) * NumV
+                    Wab%SB(iSymp)%A1(1:Nmax**2 * NumV) => Wab%A0(iS:iE)
                  else
-                    lChoV = lChoV + Nbas(iSymp)*(Nbas(iSymp)+1)/2*NumV
+                    iE = iE + NumB*NumV
                  endif
+                 Wab%SB(iSymp)%A2(1:NumB,1:NumV) =>
+     &              Wab%A0(iS:iS-1+NumB*NumV)
                endif
              Endif
-            ENDIF
          End Do
 
-         kLab = kWab + lChoV
-         lScr = kTOT - lChoV
+         Call Map_to_SBA(Wab,KSQ1)
+
+         lScr = kTOT - iE
 
 C --- Reading of the vectors is done in Reduced sets
 
@@ -267,8 +268,10 @@ C --- Reading of the vectors is done in Reduced sets
 
       CALL CWTIME(TCR1,TWR1)
 
-      Call CHO_X_getVfull(irc,Work(kLab),lscr,iVEC,NumV,jSym,iSwap,
+      Scr(1:lScr) => Wab%A0(iE+1:iE+lScr)
+      Call CHO_X_getVfull(irc,Scr,lscr,iVEC,NumV,jSym,iSwap,
      &                    IREDC,KSQ1,iSkip,DoRead)
+      Scr=>Null()
 
        if (irc.ne.0) then
           rc = irc
@@ -281,9 +284,8 @@ C --- Reading of the vectors is done in Reduced sets
 
 #ifdef _DEBUGPRINT_
        write(6,*) 'Batch ',iBatch,' of   ',nBatch,': NumV = ',NumV
-       write(6,*) 'Total allocated :     ',kTOT,' at ',kWab
+       write(6,*) 'Total allocated :     ',kTOT
        write(6,*) 'Memory pointers KSQ1: ',(KSQ1(i),i=1,nSym)
-       write(6,*) 'kLab:                 ',kLab
        write(6,*) 'lScr:                 ',lScr
        write(6,*) 'JSYM:                 ',jSym
 #endif
@@ -308,16 +310,18 @@ C==========================================================
 C
          CALL CWTIME(TCC1,TWC1)
 
-         CALL FZERO(Work(kLab),NumV)
+         VJ(1:NumV) => Wab%A0(iE+1:iE+NumV)
+         VJ(:)=Zero
+
          DO iSymr=1,nSym
-         IF(nBas(iSymr).ne.0.and.iWork(ipNocc(jDen)+iSymr-1).ne.0)THEN
+         IF(nBas(iSymr).ne.0.and.nOcc(iSymr,jDen).ne.0)THEN
 
-         ISDLT = ipDLT(jDen) + ISTLT(ISYMR)
          Naa = nBas(iSymr)*(nBas(iSymr)+1)/2
 
          CALL DGEMV_('T',Naa,NumV,
-     &              ONE,Work(KSQ1(iSymr)),Naa,
-     &              Work(ISDLT),1,ONE,Work(kLab),1)
+     &              ONE,Wab%SB(iSymr)%A2,Naa,
+     &                  DLT(jDen)%SB(ISYMR)%A1,1,
+     &              ONE,VJ,1)
 
          ENDIF
          End DO
@@ -330,12 +334,12 @@ C
           DO iSyms=1,nSym
           IF(nBas(iSyms).ne.0)THEN
 
-           ISFLT = ipFLT(jDen) + ISTLT(ISYMS)
            Naa = nBas(iSyms)*(nBas(iSyms)+1)/2
 
            CALL DGEMV_('N',Naa,NumV,
-     &              FactC(jDen),Work(KSQ1(iSyms)),Naa,
-     &              Work(kLab),1,ONE,Work(ISFLT),1)
+     &              FactC(jDen),Wab%SB(iSyms)%A2,Naa,
+     &                          VJ,1,
+     &                      ONE,FLT(jDen)%SB(ISYMS)%A1,1)
 
           ENDIF
           End DO
@@ -344,6 +348,8 @@ C
         tcoul(1) = tcoul(1) + (TCC2 - TCC1)
         tcoul(2) = tcoul(2) + (TWC2 - TWC1)
 
+        VJ=>Null()
+
        ENDIF  ! jSym=1 & DoCoulomb
 
       END DO ! loop over densities for the Coulomb term
@@ -357,46 +363,29 @@ C ********** REORDER AND SQUARE ONE VECTOR AT THE TIME *****
 C     Reorder: L(rs,J) -> L(r,J,s).
 C     CHOVEC(nrs,numv) ---> CHOVEC(nr,numv,ns)
 
-         KQS1=0
-         KQS2=0
-         ISFSQ=0
-         ISDSQ=0
          DO iSymr=1,nSym
 
           iSymr_Occ=0
           do jDen=1,nDen
-             iSymr_Occ = iSymr_Occ + iWork(ipNocc(jDen)+iSymr-1)
+             iSymr_Occ = iSymr_Occ + nOcc(iSymr,jDen)
           end do
           IF(nBas(iSymr).ne.0.and.iSymr_Occ.gt.0)THEN
 
              CALL CWTIME(TCREO1,TWREO1)
 
-             KQS1 = KSQ1(ISYMR)
-             KQS2 = kLab
-             NRS  = NBAS(iSymr)*(NBAS(iSymr)+1)/2
+             nr=NBAS(iSymr)
+             LrJs(1:nr,1:NUMV,1:nr) => Wab%A0(iE+1:iE+nr*NUMV*nr)
 
-             KOFF1=0
-             KOFF2=0
-             KOFF3=0
-             iSQ = NBAS(iSymr)*NUMV
              Do JVEC=1,NUMV
 
-                iLT = NRS*(JVEC-1)
-                iVR = NBAS(iSymr)*(JVEC-1)
-
                 Do jR=1,NBAS(iSymr)
                    Do jS=jR,NBAS(iSymr)
 
                       jSR = iTri(jS,jR)
-                      KOFF1 = (KQS1-1) + iLT + jSR
 
-                      KOFF2 = (KQS2-1) + iSQ*(jS-1) + iVR + jR
+                      LrJs(jR,JVEC,jS) = Wab%SB(ISYMR)%A2(jSR,jVEC)
 
-                      WORK(KOFF2) = WORK(KOFF1)
-
-                      KOFF3 = (KQS2-1) + iSQ*(jR-1) + iVR + jS
-
-                      WORK(KOFF3) = WORK(KOFF1)
+                      LrJs(jS,JVEC,jR) = Wab%SB(ISYMR)%A2(jSR,jVEC)
 
                    End Do
                 End Do
@@ -410,22 +399,23 @@ C     CHOVEC(nrs,numv) ---> CHOVEC(nr,numv,ns)
 
            IF (DoExchange(jDen)) THEN
 
-               IF (iWork(ipNocc(jDen)+iSymr-1).ne.0) THEN
+               IF (nOcc(iSymr,jDen).ne.0) THEN
 
                CALL CWTIME(TC1X1,TW1X1)
 
 C              Calculate intermediate:
 C              X(p,Js) = Sum(q) D(p,q) * L(q,Js).
 C              -----------------------------------
-               ISDSQ = ISTSQ(ISYMR) + ipDSQ(jDen)
-               ISFSQ = ISTSQ(ISYMR) + ipFSQ(jDen)
+
+               NR=NBAS(ISYMR)
+               XpJs(1:NR,1:NUMV,1:NR) => Wab%A0(1:NR*NUMV*NR)
 
 
                CALL DGEMM_('N','N',
      &               NBAS(ISYMR),NUMV*NBAS(ISYMR),NBAS(ISYMR),
-     &               ONE,WORK(ISDSQ),NBAS(ISYMR),
-     &                   Work(KQS2), NBAS(ISYMR),
-     &               ZERO,WORK(kWab),NBAS(ISYMR))
+     &               ONE,DSQ(jDen)%SB(ISYMR)%A2,NBAS(ISYMR),
+     &                   LrJs, NBAS(ISYMR),
+     &               ZERO,XpJs,NBAS(ISYMR))
 
 C              Calculate exchange contribution:
 C              F(p,q) = F(p,q) - FactX Sum(sJ) L(sJ,p) * X(sJ,q).
@@ -433,23 +423,23 @@ C              --------------------------------------------------
 
                CALL DGEMM_('T','N',
      &                NBAS(ISYMR),NBAS(ISYMR),NBAS(ISYMR)*NUMV,
-     &             -FactX(jDen),WORK(KQS2),NBAS(ISYMR)*NUMV,
-     &                          WORK(kWab),NBAS(ISYMR)*NUMV,
-     &                      One,Work(ISFSQ),NBAS(ISYMR))
+     &             -FactX(jDen),LrJs,NBAS(ISYMR)*NUMV,
+     &                          XpJs,NBAS(ISYMR)*NUMV,
+     &                      One,FSQ(jDen)%SB(ISYMR)%A2,NBAS(ISYMR))
 
 
                CALL CWTIME(TC1X2,TW1X2)
                texch(1) = texch(1) + (TC1X2 - TC1X1)
                texch(2) = texch(2) + (TW1X2 - TW1X1)
 
+               XpJs=>Null()
+
                ENDIF
 
           ENDIF  ! DoExchange(jDen)
 
          END DO  ! loop over the densities
-
-c         write(6,*)'Symmetry block of FSQ= ',isymr
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMR),NBAS(ISYMR))
+         LrJs=>Null()
 
         ENDIF  ! nbas.ne.0 & nOcc.ne.0
 
@@ -474,22 +464,21 @@ C --- COMPUTE EXCHANGE FOR OFF-DIAGONAL VECTORS
 
                ISYMB = MULD2H(ISYMG,JSYM)
 
-            IF(nBas(iSymb)*nBas(iSymg).ne.0)THEN
+            IF(nBas(iSymb)*nBas(iSymg)<=0) Cycle
 
                ISYMD = ISYMG     !only total symmetric Density
                ISYMA = ISYMB     !block diagonal Fock Matrix
 
              IF (ISYMG.gt.ISYMB .and. iSkip(iSymg).ne.0) THEN
 
-               KQS1 = KSQ1(ISYMG)
-
 C -------------------------------
 C --- F(a,b) = - D(g,d) * (ad|gb)
 C -------------------------------
-               if (iWork(ipNocc(jDen)+iSymg-1).ne.0) then
+               if (nOcc(iSymg,jDen).ne.0) then
 
-               ISFSQ = ISTSQ(ISYMB) + ipFSQ(jDen)
-               ISDSQ = ISTSQ(ISYMG) + ipDSQ(jDen)
+               nD=NBAS(ISYMD)
+               nB=NBAS(ISYMB)
+               XdJb(1:nD,1:NumV,1:nB)=> Wab%A0(iE+1:iE+nD*NumV*nB)
 
 C              Calculate intermediate:
 C              X(d,Jb) = Sum(g) D(d,g) * L(g,Jb).
@@ -497,8 +486,9 @@ C              ----------------------------------
 
                CALL DGEMM_('N','N',
      &                    NBAS(ISYMD),NUMV*NBAS(ISYMB),NBAS(ISYMG),
-     &                    ONE,Work(ISDSQ),NBAS(ISYMD),Work(KQS1),
-     &                    NBAS(ISYMG),ZERO,WORK(kLab),NBAS(ISYMD))
+     &                    ONE,DSQ(jDen)%SB(ISYMG)%A2,NBAS(ISYMD),
+     &                        Wab%SB(ISYMG)%A2,NBAS(ISYMG),
+     &                   ZERO,XdJb,NBAS(ISYMD))
 
 
 C              F(a,b) = F(a,b) - Sum(dJ) L(dJ,a) * X(dJ,b).
@@ -506,20 +496,21 @@ C              -------------------------------------------
 
               CALL DGEMM_('T','N',
      &              NBAS(ISYMA),NBAS(ISYMB),NBAS(ISYMD)*NUMV,
-     &              -FactX(jDen),WORK(KQS1),NBAS(ISYMD)*NUMV,
-     & WORK(kLab),NBAS(ISYMD)*NUMV,ONE,Work(ISFSQ),NBAS(ISYMA))
+     &              -FactX(jDen),Wab%SB(ISYMG)%A2,NBAS(ISYMD)*NUMV,
+     &                           XdJb,NBAS(ISYMD)*NUMV,
+     &                       ONE,FSQ(jDen)%SB(ISYMB)%A2,NBAS(ISYMA))
+
+                  XdJb=>Null()
 
-c         write(6,*)'Symmetry block of FSQ= ',isyma
-c         write(6,*)'Symmetry of the density= ',isymg
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMA),NBAS(ISYMA))
                endif
 C -------------------------------
 C --- F(g,d) = - D(a,b) * (ad|gb)
 C -------------------------------
-               if (iWork(ipNocc(jDen)+iSyma-1).ne.0) then
+               if (nOcc(iSyma,jDen).ne.0) then
 
-               ISFSQ = ISTSQ(ISYMG) + ipFSQ(jDen)
-               ISDSQ = ISTSQ(ISYMB) + ipDSQ(jDen)
+               nG=NBAS(ISYMG)
+               nB=NBAS(ISYMB)
+               XgJb(1:nG,1:NumV,1:nB) => Wab%A0(iE+1:iE+nG*NumV*nB)
 
 C              Calculate intermediate:
 C              X(gJ,b) = Sum(a) L(gJ,a)* D(a,b).
@@ -527,8 +518,9 @@ C              ----------------------------------
 
                CALL DGEMM_('N','N',
      &                  NBAS(ISYMG)*NUMV,NBAS(ISYMB),NBAS(ISYMA),
-     &                  ONE,Work(KQS1),NBAS(ISYMG)*NUMV,WORK(ISDSQ),
-     &                  NBAS(ISYMA),ZERO,WORK(kLab),NBAS(ISYMG)*NUMV)
+     &                  ONE,Wab%SB(ISYMG)%A2,NBAS(ISYMG)*NUMV,
+     &                      DSQ(jDen)%SB(ISYMB)%A2,NBAS(ISYMA),
+     &                 ZERO,XgJb,NBAS(ISYMG)*NUMV)
 
 
 C              F(g,d) = F(g,d) - Sum(Jb) X(g,Jb) * L(d,Jb).
@@ -536,16 +528,16 @@ C              -------------------------------------------
 
               CALL DGEMM_('N','T',
      &              NBAS(ISYMG),NBAS(ISYMD),NUMV*NBAS(ISYMB),
-     &              -FactX(jDen),WORK(kLab),NBAS(ISYMG),
-     & WORK(KQS1),NBAS(ISYMD),ONE,Work(ISFSQ),NBAS(ISYMG))
+     &              -FactX(jDen),XgJb,NBAS(ISYMG),
+     &                           Wab%SB(ISYMG)%A2,NBAS(ISYMD),
+     &                       ONE,FSQ(jDen)%SB(ISYMG)%A2,NBAS(ISYMG))
+
+
+              XgJb=>Null()
 
-c         write(6,*)'Symmetry block of FSQ= ',isymg
-c         write(6,*)'Symmetry of the density= ',isyma
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMG),NBAS(ISYMG))
               endif
              ENDIF
 
-            ENDIF
             END DO  ! loop over orbital symmetries
 
             CALL CWTIME(TC2X2,TW2X2)
@@ -563,7 +555,7 @@ C ************ END "OFF-DIAGONAL" EXCHANGE CONTRIBUTION  ***********
 
 
 C --- Free the memory
-         Call GetMem('MemR','FREE','REAL',kWab,kTOT)
+         Call Deallocate_SBA(Wab)
 
       END DO  ! end of the batch procedure
 
@@ -606,7 +598,6 @@ C --- Free the memory
 
 c Print the Fock-matrix
 #ifdef _DEBUGPRINT_
-
       if(Debug) then !to avoid double printing in SCF-debug
 
       WRITE(6,'(6X,A)')'TEST PRINT FROM CHO_FOCKTWO_RED.'
@@ -616,14 +607,11 @@ c Print the Fock-matrix
           WRITE(6,'(6X,A,I2)')'DoExchange: ',DoExchange(jDen)
           WRITE(6,*)
       if(DoExchange(jDen))then
-      icount=0
       DO ISYM=1,NSYM
-      ISQ=ipFSQ(jDen)+icount
         NB=NBAS(ISYM)
         IF ( NB.GT.0 ) THEN
           WRITE(6,'(6X,A,I2)')'SYMMETRY SPECIES:',ISYM
-          call cho_output(Work(ISQ),1,NB,1,NB,NB,NB,1,6)
-          icount=icount+NB**2
+          call cho_output(FSQ(jDen)%SB(ISYM)%A2,1,NB,1,NB,NB,NB,1,6)
         END IF
       END DO
       endif
