@@ -11,8 +11,8 @@
 * Copyright (C) Francesco Aquilante                                    *
 ************************************************************************
       SUBROUTINE CHO_FTWO_MO(rc,nSym,nBas,nDen,DoCoulomb,DoExchange,
-     &                       lOff1,FactC,FactX,ipDLT,ipDSQ,ipFLT,ipFSQ,
-     &                       MinMem,ipMSQ,ipNocc)
+     &                       lOff1,FactC,FactX,DLT,DSQ,FLT,FSQ,
+     &                       MinMem,MSQ,pNocc)
 
 ************************************************************************
 *  Author : F. Aquilante
@@ -52,7 +52,6 @@
 *  FactC(nDen) : factor for the coulomb of the corresponding density
 *  FactX(nDen) : factor for the exchange of the corresponding density
 *
-*  ip{X}LT(nDen) : pointer to the array containing {X} in LT storage
 *  ip{X}SQ(nDen) : pointer to the array containing {X} in SQ storage
 *    {X=D,F,M --- Density, Fock matrix, MOs coeff.}
 *
@@ -60,68 +59,81 @@
 *                 a single Cholesky vector in full storage
 *
 ************************************************************************
-
+      use Data_Structures, only: SBA_Type, Deallocate_SBA
+      use Data_Structures, only: DSBA_Type, Integer_Pointer
       Implicit Real*8 (a-h,o-z)
 
       Integer   rc,nDen,nSym,nBas(nSym),NumCho(nSym),kOcc(nSym)
       Real*8    FactC(nDen),FactX(nDen)
-      Integer   Lunit,KSQ1(nSym),ISTSQ(nSym),ISTLT(nSym),lOff1
-      Integer   ipDLT(nDen),ipDSQ(nDen),ipFLT(nDen),ipFSQ(nDen)
-      Integer   ipMSQ(nDen),ipNocc(nDen),MinMem(nSym),iSkip(nSym)
+      Integer   Lunit,lOff1
+      Integer   MinMem(nSym),iSkip(nSym)
+
+      Type (DSBA_Type) DLT(nDen), FLT(nDen), FSQ(nDen), DSQ(nDen),
+     &                 MSQ(nDen)
+      Type (Integer_Pointer) :: pNocc(nDen)
+
+
       Real*8    tread(2),tcoul(2),texch(2)
-      Common /CHOUNIT / Lunit(8)
+#include "chounit.fh"
       Logical DoExchange(nDen),DoCoulomb(nDen),DoSomeX,DoSomeC
-      Logical Debug,DensityCheck,Square,timings
-      Logical REORD,DECO,ALGO
-      COMMON   /CHOTIME /timings
-      COMMON    /CHODENSITY/ DensityCheck
-      Common /CHOSCF / REORD,DECO,dmpk,dFKmat,ALGO,NSCREEN
+#ifdef _DEBUGPRINT_
+      Logical Debug
+#endif
+      Logical Square
+#include "chotime.fh"
+#include "chodensity.fh"
+#include "choscf.fh"
+#include "real.fh"
       Character*50 CFmt
-      Character*11 SECNAM
-      Parameter (SECNAM = 'CHO_FTWO_MO')
+      Character(LEN=11), Parameter :: SECNAM = 'CHO_FTWO_MO'
 
-      Character*4 BaseNm
+      Character(LEN=4), Parameter :: BaseNm = 'CHFV'
       Character*6 Fname
-      Parameter (BaseNm = 'CHFV')
 
-      parameter (zero = 0.0D0, one = 1.0D0, xone = -1.0D0)
+      Real*8, Parameter :: xone = -One
 
+#include "stdalloc.fh"
 
-#include "WrkSpc.fh"
+      Type (SBA_Type) , Target:: Wab, LqJs
 
+      Real*8, Allocatable :: Dchk(:)
+
+      Real*8, Pointer :: VJ(:)=>Null(), LrJs(:,:,:)=>Null(),
+     &                    XkJs(:)=>Null(), XdJb(:)=>Null(),
+     &                    XgJk(:)=>Null()
+*                                                                      *
+************************************************************************
+*                                                                      *
+      Interface
+        subroutine dgemv_(TRANS,M,N,ALPHA,A,LDA,X,INCX,BETA,Y,INCY)
+          Character(LEN=1) TRANS
+          Integer M, N
+          Real*8 ALPHA, BETA
+          Integer LDA, INCX, INCY
+          Real*8  A(lda,*), X(*), Y(*)
+        End subroutine dgemv_
+      End Interface
+*                                                                      *
+************************************************************************
+*                                                                      *
 **************************************************
       MulD2h(i,j) = iEOR(i-1,j-1) + 1
 ******
       iTri(i,j) = max(i,j)*(max(i,j)-3)/2 + i + j
+******
+      nOcc(jSym,jDen) = pNocc(jDen)%I1(jSym)
 **************************************************
 
-
 #ifdef _DEBUGPRINT_
-c      Debug=.true.
       Debug=.false.! to avoid double printing in SCF-debug
-#else
-      Debug=.false.
 #endif
 
-        CALL CWTIME(TOTCPU1,TOTWALL1) !start clock for total time
+      CALL CWTIME(TOTCPU1,TOTWALL1) !start clock for total time
 
-        do i=1,2            ! 1 --> CPU   2 --> Wall
-           tread(i) = zero  !time read/rreorder vectors
-           tcoul(i) = zero  !time for computing Coulomb
-           texch(i) = zero  !time for computing Exchange
-        end do
-
-c ISTSQ: Offsets to full symmetry block in DSQ,FSQ
-c ISTLT: Offsets to packed LT symmetry blocks in DLT,FLT
-        ISTSQ(1)=0
-        ISTLT(1)=0
-      DO ISYM=2,NSYM
-        NB=NBAS(ISYM-1)
-        NB2=NB*NB
-        NB3=(NB2+NB)/2
-        ISTSQ(ISYM)=ISTSQ(ISYM-1)+NB2
-        ISTLT(ISYM)=ISTLT(ISYM-1)+NB3
-      END DO
+      ! 1 --> CPU   2 --> Wall
+      tread(:) = zero  !time read/rreorder vectors
+      tcoul(:) = zero  !time for computing Coulomb
+      texch(:) = zero  !time for computing Exchange
 
       if(DensityCheck)then
         Thr=1.0d-12
@@ -130,13 +142,13 @@ c ISTLT: Offsets to packed LT symmetry blocks in DLT,FLT
         if (DECO) xf=1.0d0
         Do jDen=1,nDen
           Do jSym=1,nSym
-           if (nBas(jSym).ne.0.and.iWork(ipNocc(jDen)+jSym-1).ne.0) then
-             Call Getmem('Dchk','allo','real',ipDchk,nBas(jSym)**2)
-             Call Cho_X_Test(Work(ipDSQ(jDen)+ISTSQ(jSym)),nBas(jSym),
-     &                       Square,Work(ipMSQ(jDen)+ISTSQ(jSym)),
-     &                       iWork(ipNocc(jDen)+jSym-1),xf,Work(ipDchk),
+           if (nBas(jSym).ne.0.and.nOcc(jSym,jDen).ne.0) then
+             Call mma_allocate(Dchk,nBas(jSym)**2,Label='Dchk')
+             Call Cho_X_Test(DSQ(jDen)%SB(jSym)%A2,nBas(jSym),
+     &                       Square,MSQ(jDen)%SB(jSym)%A2,
+     &                       nOcc(jSym,jDen),xf,Dchk,
      &                       nBas(jSym)**2,Thr,irc)
-             Call Getmem('Dchk','free','real',ipDchk,nBas(jSym)**2)
+             Call mma_deallocate(Dchk)
              if(irc.eq.0)then
                 write(6,*)'*** DENSITY CHECK : OK! *** SYMM= ',jSym
              else
@@ -181,12 +193,10 @@ C ********* Data from the Runfile
 C *************** BIG LOOP OVER VECTORS SYMMETRY *****************
       DO jSym=1,MaxSym
 
-      If (NumCho(jSym).lt.1) GOTO 1000
+         If (NumCho(jSym).lt.1) Cycle
 
 C --- Reading of the vectors is done in the full dimension
-         do i=1,nSym
-            KSQ1(i)=-666
-         end do
+         Lunit(:) = -1
 
 C Open Files
        Do ksym=1,nSym
@@ -200,13 +210,12 @@ C Open Files
         End If
        End Do
 
-
 C ------------------------------------------------------
 
 
 C SET UP THE READING
 C ------------------
-      Call GetMem('Maxavail','MAX ','REAL',KDUM,LWORK)
+      Call mma_maxDBLE(LWORK)
 
       If (MinMem(jSym) .gt. 0) Then
          nVec = Min(LWORK/MinMem(jSym),NumCho(jSym))
@@ -250,7 +259,10 @@ C *************** BATCHING  *****************
 
 C --- Allocate memory for reading the vectors
          kRdMem = MinMem(jSym)*NumV
-         Call GetMem('MemR','ALLO','REAL',kWab,kRdMem)
+         Call mma_allocate(Wab%A0,kRdMem,Label='Wab%A0')
+         Wab%iSym=JSYM
+         Wab%nSym=nSym
+         Wab%iCase=7
 
 c--- setup the skipping flags according to # of Occupied
       do k=1,nSym
@@ -260,8 +272,7 @@ c--- setup the skipping flags according to # of Occupied
             iSkip(k) = 666 ! always contribute to Coulomb
          else
           do jDen=1,nDen
-               iSkip(k) = iSkip(k) + iWork(ipNocc(jDen)+k-1)
-     &                             + iWork(ipNocc(jDen)+l-1)
+               iSkip(k) = iSkip(k) + nOcc(k,jDen) + nOcc(l,jDen)
           end do
          endif
       end do
@@ -271,58 +282,58 @@ C Max dimension of a symmetry block
         Do iSym=1,nSym
            if(NBAS(iSym).gt.Nmax .and. iSkip(iSym).ne.0)then
            Nmax = NBAS(iSym)
-           iSymMax= iSym
            endif
         End Do
-        NNmax = Nmax * (Nmax+1)/2
 
        CALL CWTIME(TCR1,TWR1)
 
-       kcount=0
+       iE=0
        Do ksym=1,nSym
 
-         kSab = kWab + kcount
-
          iSymp=MulD2h(ksym,jSym)
 
-         IF (nBas(kSym)*nBas(iSymp).ne.0) THEN
+         nk=nBas(kSym)
+         np=nBas(iSymp)
+
+         IF (nk*np<=0) Cycle
+         iS = iE + 1
 
          If (iSymp.eq.ksym .and. iSkip(iSymp).ne.0) then
-           NumB = NBAS(ksym)*(NBAS(ksym)+1)/2
-           Call RdChoVec(Work(kSab),NumB,NumV,iVec,Lunit(iSymp))
-           KSQ1(iSymp)=kSab
+           NumB = nk*(nk+1)/2
 C --- Special trick for the vector L11 ; used to store X(a,Jb)
            if(ksym.eq.1.and.jSym.eq.1.and.DoSomeX)then
-              kcount = kcount + lOff1 * NumV
+              iE = iE + lOff1 * NumV
            else
-              kcount = kcount + NumB * NumV
+              iE = iE + NumB * NumV
            endif
+           Wab%SB(iSymp)%A2(1:NumB,1:NumV) => Wab%A0(iS:iS-1+NumB*NumV)
          Else
            If (iSymp.gt.ksym .and. iSkip(iSymp).ne.0) then
-           NumB = NBAS(ksym)*NBAS(iSymp)
-           Call RdChoVec(Work(kSab),NumB,NumV,iVec,Lunit(iSymp))
-           KSQ1(iSymp)=kSab
-           kcount = kcount + NumB * NumV
+              NumB = nk*np
+              iE = iE + NumB * NumV
+              Wab%SB(iSymp)%A3(1:np,1:nk,1:NumV) => Wab%A0(iS:iE)
+              Wab%SB(iSymp)%A2(1:NumB,1:NumV) => Wab%A0(iS:iE)
            End If
          End If
 
-         ENDIF
-
        End Do ! ends the loop over symmetries
 
+       Do kSym = 1, nSym
+         iSymp=MulD2h(ksym,jSym)
+         If (.NOT.Associated(Wab%SB(iSymp)%A2)) Cycle
+         NumB = SIZE(Wab%SB(iSymp)%A2,1)
+         Call RdChoVec(Wab%SB(iSymp)%A2,NumB,NumV,iVec,Lunit(iSymp))
+       End Do
+
+
        CALL CWTIME(TCR2,TWR2)
        tread(1) = tread(1) + (TCR2 - TCR1)
        tread(2) = tread(2) + (TWR2 - TWR1)
 
-
-       kLab = kWab + kcount  ! pointer to the scratch space
-
 #ifdef _DEBUGPRINT_
        write(6,*) 'Batch ',iBatch,' of ',nBatch,': NumV = ',NumV
-       write(6,*) 'Total allocated:     ',kRdMem,' at ',kWab
-       write(6,*) 'Memory pointers KSQ1:',(KSQ1(i),i=1,nSym)
-       write(6,*) 'kcount:              ',kcount
-       write(6,*) 'kLab:                ',kLab
+       write(6,*) 'Total allocated:     ',kRdMem
+       write(6,*) 'iE:              ',iE
        write(6,*) 'JSYM:                ',jSym
 #endif
 
@@ -345,18 +356,20 @@ C==========================================================
 C
          CALL CWTIME(TCC1,TWC1)
 
-         CALL FZERO(Work(kLab),NumV)
+         VJ(1:NumV) => Wab%A0(iE+1:iE+NumV)
+         VJ(:) = Zero
+
          DO iSymr=1,nSym
-         IF(nBas(iSymr).ne.0.and.iWork(ipNocc(jDen)+iSymr-1).ne.0)THEN
+            IF(nBas(iSymr).ne.0.and.nOcc(iSymr,jDen).ne.0)THEN
 
-         ISDLT = ipDLT(jDen) + ISTLT(ISYMR)
-         Naa = nBas(iSymr)*(nBas(iSymr)+1)/2
+               Naa = nBas(iSymr)*(nBas(iSymr)+1)/2
 
-         CALL DGEMV_('T',Naa,NumV,
-     &              ONE,Work(KSQ1(iSymr)),Naa,
-     &              Work(ISDLT),1,ONE,Work(kLab),1)
+                CALL DGEMV_('T',Naa,NumV,
+     &                     ONE,Wab%SB(iSymr)%A2,Naa,
+     &                         DLT(jDen)%SB(iSYMR)%A1,1,
+     &                     ONE,VJ,1)
 
-         ENDIF
+            ENDIF
          End DO
 
 C --- Contraction with the 2nd vector
@@ -365,20 +378,20 @@ C --- Fss{#J} <- Fss{#J} + FactC * sum_J L(ss,{#J})*V{#J}
 C==========================================================
 C
           DO iSyms=1,nSym
-          IF(nBas(iSyms).ne.0)THEN
+             IF(nBas(iSyms).ne.0)THEN
 
-           ISFLT = ipFLT(jDen) + ISTLT(ISYMS)
-           Naa = nBas(iSyms)*(nBas(iSyms)+1)/2
+                Naa = nBas(iSyms)*(nBas(iSyms)+1)/2
 
-           CALL DGEMV_('N',Naa,NumV,
-     &              FactC(jDen),Work(KSQ1(iSyms)),Naa,
-     &              Work(kLab),1,ONE,Work(ISFLT),1)
+                 CALL DGEMV_('N',Naa,NumV,
+     &                FactC(jDen),Wab%SB(iSyms)%A2,Naa,
+     &                            VJ,1,
+     &                        ONE,FLT(jDen)%SB(ISYMS)%A1,1)
 
-c           WRITE(6,'(6X,A,I2)')'SYMMETRY SPECIES:',ISYMS
-c           CALL TRIPRT('Coulomb FLT',' ',Work(ISFLT),nBas(iSyms))
-          ENDIF
+             ENDIF
           End DO
 
+          VJ => Null()
+
         CALL CWTIME(TCC2,TWC2)
         tcoul(1) = tcoul(1) + (TCC2 - TCC1)
         tcoul(2) = tcoul(2) + (TWC2 - TWC1)
@@ -396,47 +409,29 @@ C
 C     CHOVEC(nrs,numv) ---> CHOVEC(nr,numv,ns)
 
        IF (jSym.eq.1.and.DoSomeX) THEN
-         KQS1=0
-         KQS2=0
-         ISFSQ=0
-         ISMSQ=0
          DO iSymr=1,nSym
 
           iSymr_Occ=0
           do jDen=1,nDen
-             iSymr_Occ = iSymr_Occ + iWork(ipNocc(jDen)+iSymr-1)
+             iSymr_Occ = iSymr_Occ + nOcc(iSymr,jDen)
           end do
-          IF(nBas(iSymr).ne.0.and.iSymr_Occ.gt.0)THEN
+          nr=NBAS(iSymr)
+          IF(nr.ne.0.and.iSymr_Occ.gt.0)THEN
 
              CALL CWTIME(TCREO1,TWREO1)
 
-             KQS1 = KSQ1(ISYMR)
-             KQS2 = kLab
-             NRS  = NBAS(iSymr)*(NBAS(iSymr)+1)/2
+             LrJs(1:nr,1:NumV,1:nr) => Wab%A0(iE+1:iE+nr*NumV*nr)
 
-             KOFF1=0
-             KOFF2=0
-             KOFF3=0
-
-             iSQ = NBAS(iSymr)*NUMV
              Do JVEC=1,NUMV
 
-                iLT = NRS*(JVEC-1)
-                iVR = NBAS(iSymr)*(JVEC-1)
-
                 Do jR=1,NBAS(iSymr)
                    Do jS=jR,NBAS(iSymr)
 
                       jSR = iTri(jS,jR)
-                      KOFF1 = (KQS1-1) + iLT + jSR
 
-                      KOFF2 = (KQS2-1) + iSQ*(jS-1) + iVR + jR
+                      LrJs(jR,JVEC,jS) = Wab%SB(ISYMR)%A2(jSR,JVEC)
 
-                      WORK(KOFF2) = WORK(KOFF1)
-
-                      KOFF3 = (KQS2-1) + iSQ*(jR-1) + iVR + jS
-
-                      WORK(KOFF3) = WORK(KOFF1)
+                      LrJs(jS,JVEC,jR) = Wab%SB(ISYMR)%A2(jSR,JVEC)
 
                    End Do
                 End Do
@@ -450,7 +445,7 @@ C     CHOVEC(nrs,numv) ---> CHOVEC(nr,numv,ns)
 
            IF (DoExchange(jDen)) THEN
 
-              kOcc(iSymr) = iWork(ipNocc(jDen)+iSymr-1)
+              kOcc(iSymr) = nOcc(iSymr,jDen)
 
            IF (kOcc(iSymr).ne.0) THEN
 
@@ -460,37 +455,35 @@ C              Calculate intermediate:
 C              X(k,Js) = Sum(r) C(r,k) * L(r,Js).
 C              -----------------------------------
                iSyms=iSymr
-               ISFSQ = ISTSQ(ISYMR) + ipFSQ(jDen)
-               ISMSQ = ISTSQ(ISYMR) + ipMSQ(jDen)
                NK = kOcc(iSymr)
 
+               XkJs(1:NK*NumV*nr) => Wab%A0(1:NK*NumV*nr)
+
                CALL DGEMM_('T','N',
      &               NK,NUMV*NBAS(ISYMR),NBAS(iSYMR),
-     &               ONE,WORK(ISMSQ),NBAS(ISYMR),
-     &                   Work(KQS2), NBAS(ISYMR),
-     &               ZERO,WORK(kWab),NK)
+     &               ONE,MSQ(jDen)%SB(ISYMR)%A2,NBAS(ISYMR),
+     &                   LrJs, NBAS(ISYMR),
+     &              ZERO,XkJs,NK)
 
 C              Calculate exchange contribution:
 C              F(r,s) = F(r,s) - FactX * Sum(kJ) X(kJ,r) * X(kJ,s).
 C              ----------------------------------------------------
 c               CALL DGEMM_('T','N',
 c     &                NBAS(ISYMR),NBAS(ISYMS),NK*NUMV,
-c     &             -FactX(jDen),WORK(KWab),NK*NUMV,
-c     &                          WORK(kWab),NK*NUMV,
-c     &                      One,Work(ISFSQ),NBAS(ISYMR))
+c     &             -FactX(jDen),XkJs,NK*NUMV,
+c     &                          XkJs,NK*NUMV,
+c     &                      One,FSQ(jDen)%SB(ISYMR)%A2,NBAS(ISYMR))
 
 c *** Compute only the LT part of the exchange matrix ***************
-               ipS=0
-               ipF=0
                LKV=NK*NUMV
                DO jS=1,NBAS(iSymS)
-                     ipS = kWab + LKV*(jS-1)
                      NBL = NBAS(iSymR) - (jS-1)
-                     ipF = ISFSQ + NBAS(iSymR)*(jS-1) + (jS-1)
+                     jjS = 1 + LKV*(jS-1)
 
                      CALL DGEMV_('T',LKV,NBL,
-     &                    -FactX(jDen),Work(ipS),LKV,
-     &                    Work(ipS),1,ONE,Work(ipF),1)
+     &                    -FactX(jDen),XkJs(jjS:),LKV,
+     &                                 XkJs(jjS:),1,
+     &                     ONE,FSQ(jDen)%SB(ISYMR)%A2(jS:,jS),1)
 
                END DO
 
@@ -498,17 +491,17 @@ c *** Compute only the LT part of the exchange matrix ***************
              texch(1) = texch(1) + (TC1X2 - TC1X1)
              texch(2) = texch(2) + (TW1X2 - TW1X1)
 
+             XkJs=>Null()
+
          ENDIF  ! if kocc.ne.0
 
        ENDIF  ! Do Exchange(jDen)
 
       END DO  ! loop over the densities
+      LrJs => Null()
 
       ENDIF   ! nbas.ne.0
 
-c         write(6,*)'Symmetry block of FSQ= ',isymr
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMR),NBAS(ISYMR))
-
       END DO  !loop over Fock mat symmetries
 
       END IF  ! jSym=1 & DoSomeX
@@ -528,32 +521,27 @@ C     CHOVEC(nq,ns,numv) ---> CHOVEC(nq,numv,ns)
 C     ------------------------------------------
             CALL CWTIME(TCREO3,TWREO3)
 
-            KQS1=0
-            KQS2=0
+            jE = iE
             DO ISYMS = 1,NSYM
 
-                  ISYMQ = MULD2H(ISYMS,JSYM)
+               ISYMQ = MULD2H(ISYMS,JSYM)
 
-            IF(nBas(iSyms)*nBas(iSymq).ne.0)THEN
+            ns=nBas(iSyms)
+            nq=nBas(iSymq)
+            IF(ns*nq<=0) Cycle
 
              IF (ISYMQ.gt.ISYMS .and. iSkip(iSymq).ne.0) THEN
 
-                  KQS1 = KSQ1(ISYMQ)
-                  KQS2 = kLab + (KQS1 - kWab)
+                  jS = JE + 1
+                  jE = JE + nq*NumV*ns
+                  LqJs%SB(ISYMQ)%A3(1:nq,1:NumV,1:ns) => Wab%A0(jS:jE)
 
-              KOFF1=0
-              KOFF2=0
               DO JVEC = 1,NUMV
 
                 DO jS=1,NBAS(iSyms)
 
-                   KOFF1 = KQS1 + NBAS(iSymq)*NBAS(iSyms)*(JVEC-1)
-     &                   + NBAS(iSymq)*(jS-1)
-
-                   KOFF2 = KQS2 + NBAS(iSymq)*NUMV*(jS-1)
-     &                   + NBAS(iSymq)*(JVEC-1)
-
-                   CALL DCOPY_(NBAS(iSymq),Work(KOFF1),1,Work(KOFF2),1)
+                  LqJs%SB(ISYMQ)%A3(:,jVec,jS) =
+     &               Wab%SB(ISYMQ)%A3(:,jS,jVEC)
 
                 END DO
 
@@ -561,8 +549,6 @@ C     ------------------------------------------
 
              END IF  ! sym(Q) > sym(S)
 
-            END IF
-
             END DO  !loop over symmetry blocks
 
             CALL CWTIME(TCREO4,TWREO4)
@@ -576,7 +562,7 @@ C     -------------- REORDERING DONE !! --------
        IF (DoExchange(jDen)) THEN
 C **** Occupation numbers needed for the Exchange term *****
               do iSym=1,nsym
-                 kOcc(iSym) = iWork(ipNocc(jDen)+iSym-1)
+                 kOcc(iSym) = nOcc(iSym,jDen)
               end do
 C **********************************************************
 C --- COMPUTE EXCHANGE FOR OFF-DIAGONAL VECTORS
@@ -587,36 +573,33 @@ C --- COMPUTE EXCHANGE FOR OFF-DIAGONAL VECTORS
 
                ISYMB = MULD2H(ISYMG,JSYM)
 
-            IF(nBas(iSymb)*nBas(iSymg).ne.0)THEN
-
-               KQS1 = kWab   !mem used to store the intermediate
+            nb=nBas(iSymb)
+            ng=nBas(iSymg)
+            IF(nb*ng<=0) Cycle
 
                ISYMA = ISYMB     !block diagonal Fock Matrix
                ISYMD = ISYMG     !total symmetric densities
 
              IF (ISYMG.gt.ISYMB .and. iSkip(iSymg).ne.0) THEN
 
-               KQS2 = kLab + (KSQ1(ISYMG) - kWab)
-
 C -------------------------------
 C --- F(a,b) = - D(g,d) * (ad|gb)
 C -------------------------------
                NK = kOcc(iSymG)
 
+               XdJb(1:NK*NumV*nb) => Wab%A0(1:NK*NumV*nb)
+
                if(NK.ne.0)then
 
-               ISFSQ = ISTSQ(ISYMB) + ipFSQ(jDen)
-               ISMSQ = ISTSQ(ISYMG) + ipMSQ(jDen)
-
-
 C              Calculate intermediate:
 C              X(k,Jb) = Sum(g) C(g,k) * L(g,Jb).
 C              ----------------------------------
 
                CALL DGEMM_('T','N',
      &                    NK,NUMV*NBAS(ISYMB),NBAS(ISYMG),
-     &                    ONE,Work(ISMSQ),NBAS(ISYMG),Work(KQS2),
-     &                    NBAS(ISYMG),ZERO,WORK(KQS1),NK)
+     &                    ONE,MSQ(jDen)%SB(ISYMG)%A2,NBAS(ISYMG),
+     &                        LqJs%SB(ISYMG)%A3,NBAS(ISYMG),
+     &                    ZERO,XdJb,NK)
 
 
 C              F(a,b) = F(a,b) - Sum(kJ) X(kJ,a) * X(kJ,b).
@@ -624,28 +607,25 @@ C              -------------------------------------------
 
 c               CALL DGEMM_('T','N',
 c     &              NBAS(ISYMA),NBAS(ISYMB),NK*NUMV,
-c     &              -FactX(jDen),WORK(KQS1),NK*NUMV,
-c     & WORK(KQS1),NK*NUMV,ONE,Work(ISFSQ),NBAS(ISYMA))
+c     &              -FactX(jDen),XdJb,NK*NUMV,
+c     &                           XdJb,NK*NUMV,
+c     &                       ONE,FSQ(jDen)%SB(iSYMB)%A2,NBAS(ISYMA))
 
 c *** Compute only the LT part of the exchange matrix ***************
-               ipB=0
-               ipF=0
                LKV=NK*NUMV
                DO jB=1,NBAS(iSymB)
-                     ipB = kQS1 + LKV*(jB-1)
                      NBL = NBAS(iSymA) - (jB-1)
-                     ipF = ISFSQ + NBAS(iSymA)*(jB-1) + (jB-1)
+                     jjB = 1 + LKV*(jB-1)
 
                      CALL DGEMV_('T',LKV,NBL,
-     &                    -FactX(jDen),Work(ipB),LKV,
-     &                    Work(ipB),1,ONE,Work(ipF),1)
+     &                    -FactX(jDen),XdJb(jjB:),LKV,
+     &                                 XdJb(jjB:),1,
+     &                             ONE,FSQ(jDEN)%SB(ISYMB)%A2(jB:,jB),1)
 
                END DO
+               XdJb=>Null()
 c ******************************************************************
 
-c         write(6,*)'Symmetry block of FSQ= ',isyma
-c         write(6,*)'Symmetry block of DSQ= ',isymg
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMA),NBAS(ISYMA))
                endif
 
 C -------------------------------
@@ -655,8 +635,7 @@ C -------------------------------
 
                if(NK.ne.0)then
 
-               ISFSQ = ISTSQ(ISYMG) + ipFSQ(jDen)
-               ISMSQ = ISTSQ(ISYMB) + ipMSQ(jDen)
+               XgJk(1:ng*NumV*NK) => Wab%A0(1:ng*NumV*NK)
 
 C              Calculate intermediate:
 C              X(gJ,k) = Sum(a) L(gJ,a) * C(a,k).
@@ -664,8 +643,9 @@ C              ----------------------------------
 
                CALL DGEMM_('N','N',
      &                  NBAS(ISYMG)*NUMV,NK,NBAS(ISYMA),
-     &                  ONE,Work(KQS2),NBAS(ISYMG)*NUMV,WORK(ISMSQ),
-     &                  NBAS(ISYMA),ZERO,WORK(KQS1),NBAS(ISYMG)*NUMV)
+     &                  ONE,LqJs%SB(ISYMG)%A3,NBAS(ISYMG)*NUMV,
+     &                      MSQ(jDen)%SB(ISYMB)%A2,NBAS(ISYMA),
+     &                  ZERO,XgJk,NBAS(ISYMG)*NUMV)
 
 
 C              F(g,d) = F(g,d) - Sum(Jk) X(g,Jk) * X(d,Jk).
@@ -673,31 +653,27 @@ C              -------------------------------------------
 
 c               CALL DGEMM_('N','T',
 c     &              NBAS(ISYMG),NBAS(ISYMD),NUMV*NK,
-c     &              -FactX(jDen),WORK(KQS1),NBAS(ISYMG),
-c     & WORK(KQS1),NBAS(ISYMD),ONE,Work(ISFSQ),NBAS(ISYMG))
+c     &              -FactX(jDen),XgJk,NBAS(ISYMG),
+c     &                           XgJk,NBAS(ISYMD),
+c     &                       ONE,FSQ(jDen)%SB(ISYMG)%A2,NBAS(ISYMG))
 
 c *** Compute only the LT part of the exchange matrix ***************
-               ipG=0
-               ipF=0
                LVK=NUMV*NK
                DO jD=1,NBAS(iSymD)
-                     ipD = kQS1 + (jD-1)
                      NBL = NBAS(iSymG) - (jD-1)
-                     ipF = ISFSQ + NBAS(iSymG)*(jD-1) + (jD-1)
 
                      CALL DGEMV_('N',NBL,LVK,
-     &                    -FactX(jDen),Work(ipD),NBAS(iSymG),
-     &                    Work(ipD),NBAS(iSymD),ONE,Work(ipF),1)
+     &                    -FactX(jDen),XgJk(jD:),NBAS(iSymG),
+     &                                 XgJk(jD:),NBAS(iSymD),
+     &                             ONE,FSQ(jDen)%SB(ISYMG)%A2(jD:,jD),1)
                END DO
 
-c         write(6,*)'Symmetry block of FSQ= ',isymg
-c         write(6,*)'Symmetry block of DSQ= ',isyma
-c         call recprt('FSQ','',Work(ISFSQ),NBAS(ISYMG),NBAS(ISYMG))
+               XgJk=>Null()
                endif
 
              ENDIF
+             LqJs%SB(ISYMG)%A3=>Null()
 
-            ENDIF
             END DO  ! loop over orbital symmetries
 
             CALL CWTIME(TC2X2,TW2X2)
@@ -716,12 +692,10 @@ C ************ END "OFF-DIAGONAL" EXCHANGE CONTRIBUTION  ***********
 
 
 C --- Free the memory
-         Call GetMem('MemR','FREE','REAL',kWab,kRdMem)
+         Call Deallocate_SBA(Wab)
 
       END DO  ! end of the batch procedure
 
-1000  CONTINUE
-
 C -- Close Files
       Do ksym=1,nSym
        if (Lunit(ksym).ne.-1) then
@@ -767,7 +741,6 @@ C -- Close Files
 
 c Print the Fock-matrix
 #ifdef _DEBUGPRINT_
-
       if(Debug) then !to avoid double printing in SCF-debug
 
       WRITE(6,'(6X,A)')'TEST PRINT FROM CHO_FTWO_MO.'
@@ -777,14 +750,11 @@ c Print the Fock-matrix
           WRITE(6,'(6X,A,I2)')'DoExchange: ',DoExchange(jDen)
           WRITE(6,*)
       if(DoExchange(jDen))then
-      icount=0
       DO ISYM=1,NSYM
-      ISQ=ipFSQ(jDen)+icount
         NB=NBAS(ISYM)
         IF ( NB.GT.0 ) THEN
           WRITE(6,'(6X,A,I2)')'SYMMETRY SPECIES:',ISYM
-          call cho_output(Work(ISQ),1,NB,1,NB,NB,NB,1,6)
-          icount=icount+NB**2
+          call cho_output(FSQ(jDen)%SB(ISYM)%A2,1,NB,1,NB,NB,NB,1,6)
         END IF
       END DO
       endif
