@@ -35,11 +35,10 @@
 
 #include "rasdim.fh"
 #include "general.fh"
-#include "WrkSpc.fh"
 *
       Dimension CMO(*), PUVX(*), TUVX(*)
       Dimension D1I(*), D1A(*), FI(*), FA(*)
-      Integer state_symmetry, SymProd
+      Integer SymProd
       Integer off_PUVX(mxSym,mxSym,mxSym),
      &        off_sqMat(mxSym), off_ltMat(mxSym)
       Logical lSquare
@@ -52,12 +51,8 @@
         Write(6,*) ' Enter transformation section'
         Write(6,*) ' ============================'
         Write(6,*)
-        Call GetMem('TRA_CTL','List','Real',junk,junk)
       End If
 *
-*     nasty, but necessary
-      state_symmetry=lSym
-*
 *     generate offsets
 *
       iStack = 0
@@ -210,9 +205,5 @@ C  Synchronize PUVX if running parallel:
       iDisk=0
       Call DDaFile(LUINTM,1,PUVX,nPUVX,iDisk)
 
-*     nasty, but necessary
-      lSym=state_symmetry
-
-
       Return
       End
