@@ -89,7 +89,7 @@
             if (mdc.gt.MxAtom) then
                Call WarningMessage(2,'MxAtom too small')
                write(LuWr,*) 'MxAtom=',MxAtom
-               write(LuWr,*) 'Increase MxAtom in info.fh and',
+               write(LuWr,*) 'Increase MxAtom in Molcas.fh and',
      &                       ' recompile the code!'
                Call Abend()
             end if
@@ -124,7 +124,7 @@
                End If
                If (iShell.gt.MxShll) Then
                   Call WarningMessage(2,'iShell.gt.MxShll')
-                  Write (LuWr,*) ' Change MxShll in info.fh and re'
+                  Write (LuWr,*) ' Change MxShll in Molcas.fh and re'
      &                      //'compile the code!'
                   Call Abend()
                End If
@@ -266,7 +266,7 @@ Cend
             lSh= 0
             Do kSh = kShStr, kShEnd
                nExpk=Shells(kSh)%nExp
-               If (nExpk.ne.0.and.iCnttp.le.21) Then
+               If (nExpk.ne.0) Then
                   If (lSh.eq.0) Then
                      Write (LuWr,'(4X,A)') '  H Potential'
                   Else
@@ -276,13 +276,11 @@ Cend
                End If
                lSh = lSh + 1
                Write (LuWr,'(A)') '  n     Exponent      Coefficient'
-               iOff = 1
-               Do iExp = 1, nExpk
-                  ncr=Int(Shells(kSh)%Exp(iOff  ))
-                  zcr=    Shells(kSh)%Exp(iOff+1)
-                  ccr=    Shells(kSh)%Exp(iOff+2)
+               Do iExp = 1, nExpk, 3
+                  ncr=Int(Shells(kSh)%Exp(iExp  ))
+                  zcr=    Shells(kSh)%Exp(iExp+1)
+                  ccr=    Shells(kSh)%Exp(iExp+2)
                   Write (LuWr,'(2x,I1,3X,2F15.10)') ncr,zcr,ccr
-                  iOff = iOff + 3
                End Do
                Write (LuWr,*)
 *
