@@ -27,7 +27,7 @@
       use Sizes_of_Seward, only: S
       use Real_Info, only: E1, E2, SadStep, Shake
       use Logical_Info, only: Align_Only, Do_Align, lRP, lRP_Post
-      use Symmetry_Info, only: nIrrep
+      use Symmetry_Info, only: nIrrep, VarR, VarT
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "stdalloc.fh"
@@ -36,13 +36,13 @@
       Character*16 StdIn
       Logical Not_First_Iter, FindTS,Found,quadratic,Invar
 #include "angstr.fh"
-#include "warnings.fh"
+#include "warnings.h"
       Character*2, Dimension(:), Allocatable :: Elm
       Real*8, Dimension(:), Allocatable :: TanVec, TmpA, W
       Real*8, Dimension(:,:), Allocatable :: Vec, MEP
       Integer, Dimension(:), Allocatable :: iStab
       Integer ipX2, ipX3
-      Integer ipRef,ipOpt
+      Integer iRef,iOpt
       Real*8, Dimension(:,:), Allocatable :: XYZ
       Real*8 RandVect(3)
 #include "periodic_table.fh"
@@ -53,8 +53,6 @@
 ************************************************************************
 *
       nSaddle_Max=100
-      Delta_Max=0.10D0
-      ratio=Zero
       quadratic=.false.
 *
 **    Avoid warnings
@@ -83,8 +81,7 @@
 *
 **       Find out whether the energy is assumed invariant to trans. & rot.
 *
-         Call Get_iScalar('System BitSwitch',iSBS)
-         Invar=(iAnd(iSBS,2**7).eq.0).and.(iAnd(iSBS,2**8).eq.0)
+         Invar=.not.(VarR.or.VarT)
 *
          nAt = nRP / 3
          Call qpg_dArray('Saddle',Not_First_Iter,nData)
@@ -503,7 +500,6 @@
                Else
                   HSR=Delta*HSR
                End If
-               ratio=1.0d0
 *
 **        Calculate tangent vector
 *
@@ -553,15 +549,15 @@
             Call Merge_Lists(Mode,nAt)
          End If
          If (Mode.eq.'R') Then
-             ipRef=2
-             ipOpt=1
+             iRef=2
+             iOpt=1
             Write (6,'(A)') '     Reference structure: product side'
             Write (6,'(A,F15.8)') '       Associated Energy: ',E2
             Write (6,'(A)') '     Optimized structure: reactant side'
             Write (6,'(A,F15.8)') '       Associated Energy: ',E1
          Else
-             ipRef=1
-             ipOpt=2
+             iRef=1
+             iOpt=2
             Write (6,'(A)') '     Reference structure: reactant side'
             Write (6,'(A,F15.8)') '       Associated Energy: ',E1
             Write (6,'(A)') '     Optimized structure: product side'
@@ -574,9 +570,9 @@
          Call mma_allocate(XYZ,3*nAt*8,2,label='XYZ')
          iRefAlign=1
          iOptExp  =2
-         Call Expand_Coor(RP_Centers(1,1,ipRef),nAt,
+         Call Expand_Coor(RP_Centers(1,1,iRef),nAt,
      &                    XYZ(1,iRefAlign),mAt)
-         Call Expand_Coor(RP_Centers(1,1,ipOpt),nAt,XYZ(1,iOptExp),mAt)
+         Call Expand_Coor(RP_Centers(1,1,iOpt),nAt,XYZ(1,iOptExp),mAt)
          If (Invar) Then
            Call Superpose_w(XYZ(1,iRefAlign),XYZ(1,iOptExp),W,
      &                      mAt,RMSD,RMax)
