@@ -9,27 +9,29 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine Setup_OffAO()
+      use Basis_Info, only: nCnttp, Shells, dbsc
       Implicit Real*8 (A-H,O-Z)
-#include "itmax.fh"
-#include "info.fh"
+*
+*     For some reason we need a counter which for a given shell index,
+*     kSh, counts how many angular functions have been in the
+*     proceeding shells. This is stored in kOffAO(kSh).
+*     Additionally, lOffAO gives the total number of angular functions
+*     in a given dbsc.
 *
       Do iCnttp = 1, nCnttp
          lComp = 0
-         lSh= 0
-         kShStr = ipVal(iCnttp)
-         kShEnd = ipVal(iCnttp)+nVal_Shells(iCnttp)-1
-         Do kSh = kShStr, kShEnd
-            If (Prjct(kSh)) Then
+         Do lSh = 0, dbsc(iCnttp)%nVal-1
+            kSh = lSh + dbsc(iCnttp)%iVal
+            If (Shells(kSh)%Prjct ) Then
                kComp = 2*lSh + 1
             Else
                kComp = (lSh+1)*(lSh+2)/2
             End If
-            kOffAO(iCnttp,lSh) = lComp
-            If (nBasis_Cntrct(kSh).ne.0.and.nExp(kSh).ne.0)
-     &         lComp = lComp + kComp
-            lSh = lSh + 1
+            Shells(kSh)%kOffAO = lComp
+            If (Shells(kSh)%nBasis_C.ne.0 .and.
+     &          Shells(kSh)%nExp    .ne.0 ) lComp = lComp + kComp
          End Do
-         lOffAO(iCnttp) = lComp
+         dbsc(iCnttp)%lOffAO = lComp
       End Do
 *
       Return
