@@ -18,8 +18,7 @@
       Use Basis_Info
       Implicit Real*8 (A-H,O-Z)
 C...  auxiliar constant pool:       ready only up to g-valence/g-core
-      PARAMETER (lp1=5,lp12=lp1*lp1,lp13=(lp1*lp1+lp1)/2)
-      COMMON/CONST/RCA(lp1,lp13),DFAC(lp12),KOSUU(lp13),NYU(lp1,lp13)
+#include "const.fh"
 *
 *     Define statement function
       VF(N,X)=DFAC(N)/sqrt(X)**(N+1)
@@ -37,18 +36,18 @@ C...  auxiliar constant pool:       ready only up to g-valence/g-core
         Call Abend
       Endif
 *
-      PI=2.D0*ACOS(0.D0)
-      PIPPI=(0.5D0/PI)**0.75D0
+*     PI=2.D0*ACOS(0.D0)
+*     PIPPI=(0.5D0/PI)**0.75D0
       L1=LA
       VPQ=VF(2*NP,ZP)*VF(2*NQ,ZQ)
-      PSMT=0.D0
+*     PSMT=0.D0
 *ls start adding
       Vexch=0.D0
 *ls end adding
 *     loop over angular momentum
       DO 55 ISIM=1,nProj+1
         iCoSh=iCoShll+ISIM-1
-        EDUM=0.5D0*DBLE(ISIM)+0.25D0
+*       EDUM=0.5D0*DBLE(ISIM)+0.25D0
         NR=ISIM
         NS=ISIM
         L2=ISIM
@@ -57,7 +56,6 @@ C...  auxiliar constant pool:       ready only up to g-valence/g-core
         IF(L1.LT.L2) LMT=((L2-1)*L2)/2+L1
         KOMAX=KOSUU(LMT)
 *       loop over core orbitals of a given angular momentum
-        iOff = Shells(iCoSh)%nBasis*Shells(iCoSh)%nExp
         DO 54 ICORB=1,Shells(iCoSh)%nBasis
           OrbPS=0d0
           DO 50 INU=1,KOMAX
