@@ -16,10 +16,8 @@
       DIMENSION BUFOUT(*),INDOUT(*),ICAD(*),IBUFL(*)
 #include "real_guga.fh"
 #include "integ.fh"
-#include "files_guga.fh"
-      COMMON/CNSTS/D0,D1,D2
-#include "addr_guga.fh"
-      COMMON/D/JNDX(500 000)
+#include "files_addr.fh"
+#include "d.fh"
 
       KBUF0=RTOI*KBUF
       KBUF1=KBUF0+KBUF+1
