@@ -25,10 +25,8 @@
 #include "WrkSpc.fh"
 #include "real_guga.fh"
 #include "integ.fh"
-#include "files_guga.fh"
-      COMMON/CNSTS/D0,D1,D2
-#include "addr_guga.fh"
-      COMMON/D/JNDX(500 000)
+#include "files_addr.fh"
+#include "d.fh"
 *      DIMENSION JSYM(30000),SO(1 000 000),JSY(3000)
       DIMENSION JSYM(30000),JSY(3000)
       DIMENSION L0(4*MXVERT),L1(4*MXVERT),L2(4*MXVERT),L3(4*MXVERT)
@@ -46,9 +44,9 @@
       Call GETMEM('SOArr','Allo','Inte',LSOArr,NCOR)
 *     Call SetQue('Trace=On')
       CALL SETTIM
-      CALL XUFLOW
-      CALL ERRSET(208,256,-1,1,1,208)
-      CALL ERRSET(151,256,-1,1,1,151)
+      !CALL XUFLOW
+      !CALL ERRSET(208,256,-1,1,1,208)
+      !CALL ERRSET(151,256,-1,1,1,151)
       CALL JTIME(IST)
 *
 *     Print program header
