@@ -14,13 +14,11 @@
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "niocr.fh"
 #include "SysDef.fh"
-#include "files_guga.fh"
+#include "files_addr.fh"
       DIMENSION ISO(*),JSYM(*),JSY(*),L0(*),L1(*),L2(*),L3(*)
 #include "real_guga.fh"
 #include "integ.fh"
-      COMMON/CNSTS/D0,D1,D2
-#include "addr_guga.fh"
-#include "warnings.fh"
+#include "warnings.h"
       DIMENSION MLL(64),IOCR(nIOCR),JREFX(9000),
      *NISH(8),JJS(18),NVAL(8),NCOR(8),ICOR(55),IONE(8),JONE(8)
 *
@@ -46,7 +44,6 @@
       ILIM=4
       N=-1
       NACTEL=-1
-      IS=1
       NISHT=0
 *     NSYM=1
       Call Get_iScalar('nSym',NSYM)
@@ -124,7 +121,7 @@ CPAM97 IFCORE.ne.0 means core-polarization orbitals (NOCO keyword).
       Write (6,*)'Input_GUGA: keyword SYMMETRY is obsolete and ignored!'
       Read(5,'(A)',End=991) Line
       If ( Line(1:1).eq.'*' ) Goto 400
-      Read(Line,*,Err=992) iDummy
+      Read(Line,*,Err=992) I
       Goto 10
 *
 *---  process ACTIVE   command ----------------------------------------*
@@ -263,7 +260,7 @@ CPAM97 IFCORE was not set -- assume bug. Following line inserted:
       Write(6,'(6X,57A1,A6,57A1)')'*',(' ',i=1,56),'Title:',
      &                                (' ',i=1,56),'*'
       Do i=1,nTit
-         Call Center(Title(i))
+         Call Center_Text(Title(i))
          Write(6,'(6X,24A1,A72,24A1)')
      &        '*',(' ',j=1,23),Title(i),(' ',j=1,23),'*'
       End Do
