@@ -18,10 +18,8 @@
 C     I.LT.L  I.EQ.K  J.EQ.L
 #include "real_guga.fh"
 #include "integ.fh"
-#include "files_guga.fh"
-      COMMON/CNSTS/D0,D1,D2
-#include "addr_guga.fh"
-      COMMON/D/JNDX(500 000)
+#include "files_addr.fh"
+#include "d.fh"
 *
       IJJ=0 ! dummy initialize
       KBUF0=RTOI*KBUF
