@@ -12,8 +12,8 @@ c look for partial loops in active space drt and save them into disk
       subroutine guga_ploop(npl,maxplcon)
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
 
 
       maxplcon=0
@@ -49,15 +49,16 @@ c look for partial loops in active space drt and save them into disk
       subroutine sv_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
-      common/count/mhsum,lp_count(22),mhlpmax
+#include "lpdisk.fh"
+#include "count.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(10)=idisk_lp
 
       imr=1
-      do iml=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
         call act_lp_search(4,4,1)     !id=4
       enddo
       lpblock_sv=lpblock
@@ -69,15 +70,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine sd_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(11)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(1,4,2)    !id=1
         enddo
       enddo
@@ -90,15 +93,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine st_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(12)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(3,4,3)   !id=3
         enddo
       enddo
@@ -111,15 +116,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine ss_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(13)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(3,4,4)    !id=3
         enddo
       enddo
@@ -132,8 +139,8 @@ c look for partial loops in active space drt and save them into disk
       subroutine tv_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
@@ -141,7 +148,8 @@ c look for partial loops in active space drt and save them into disk
 
 
       imr=1
-      do iml=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
         call act_lp_search(4,3,1)       !id=4
       enddo
       lpblock_tv=lpblock
@@ -153,15 +161,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine td_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(7)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(1,3,2)    !id=1
         enddo
       enddo
@@ -174,15 +184,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine tt_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(8)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(3,3,3)    !id=3
         enddo
       enddo
@@ -196,15 +208,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine ts_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(9)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(3,3,4)    !id=3
         enddo
       enddo
@@ -217,15 +231,16 @@ c look for partial loops in active space drt and save them into disk
       subroutine dv_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(2)=idisk_lp
 
       imr=1
-      do iml=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
         call act_lp_search(1,2,1)      !id=1
       enddo
       lpblock_dv=lpblock
@@ -237,15 +252,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine dd_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(3)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(3,2,2)    !id=3
         enddo
       enddo
@@ -259,15 +276,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine dt_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(4)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(2,2,3)      !id=2
         enddo
       enddo
@@ -280,15 +299,17 @@ c look for partial loops in active space drt and save them into disk
       subroutine ds_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(5)=idisk_lp
 
-      do iml=1,ng_sm
-        do imr=1,ng_sm
+      do iml_=1,ng_sm
+        iml=iml_
+        do imr_=1,ng_sm
+          imr=imr_
           call act_lp_search(2,2,4)    !id=2
         enddo
       enddo
@@ -301,15 +322,16 @@ c look for partial loops in active space drt and save them into disk
       subroutine vd_lp_search(npl)
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "count.fh"
+#include "lpdisk.fh"
       mhsum=0
       lpblock=0
       lp_count(1:22)=0
       idisk_array(1)=idisk_lp
 
       iml=1
-      do imr=1,ng_sm
+      do imr_=1,ng_sm
+        imr=imr_
         call act_lp_search(2,1,2)       !id=2
       enddo
       lpblock_vd=lpblock
@@ -323,8 +345,7 @@ c look for partial loops in active space drt and save them into disk
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       call get_jp(iptyl,iml,ipael,0)
       call get_jp(iptyr,imr,ipaer,0)
 
@@ -342,7 +363,8 @@ c look for partial loops in active space drt and save them into disk
         jmlend=ng_sm
         if(jptyl.eq.1) jmlsta=ns_sm
         if(jptyl.eq.1) jmlend=ns_sm
-        do jml=jmlsta,jmlend
+        do jml_=jmlsta,jmlend
+          jml=jml_ ! jml is in common block, is this necessary?
           call get_jp(jptyl,jml,jpadl,0)
           if(nu_ad(jpadl).eq.0) cycle
           jpad=jpadl
@@ -356,7 +378,8 @@ c look for partial loops in active space drt and save them into disk
             jmrend=ng_sm
             if(jptyr.eq.1) jmrsta=ns_sm
             if(jptyr.eq.1) jmrend=ns_sm
-            do jmr=jmrsta,jmrend
+            do jmr_=jmrsta,jmrend
+              jmr=jmr_ ! jmr is in common block, is this necessary?
               call get_jp(jptyr,jmr,jpadr,0)
               if(nu_ad(jpadr).eq.0) cycle
               jpad=jpadr
@@ -616,7 +639,6 @@ c look for partial loops in active space drt and save them into disk
       imlr=mul_tab(iml,imr)
 
       do lra=norb_dz+1,norb_inn
-        lma=lsm_inn(lra)
 !line=9 d&r&l-
           call head_drl_at_given_orb(mh,lra)
           call link_c2_to_given_orb(mh,lra+1,norb_inn)
@@ -1360,9 +1382,8 @@ c look for partial loops in active space drt and save them into disk
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
 #include "files_gugaci.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
-      dimension info(10)
+#include "count.fh"
+#include "lpdisk.fh"
       line=linelp
       mh=mhlp
       lg1=nlg1
@@ -1374,7 +1395,6 @@ c look for partial loops in active space drt and save them into disk
         mhsum=mhsum-mh
         lp_count(line)=lp_count(line)-1
       endif
-      info=0
 !===========================================================
       jpml=mul_tab(jml,ns_sm)
       jpmr=mul_tab(jmr,ns_sm)
@@ -1409,9 +1429,9 @@ c look for partial loops in active space drt and save them into disk
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
 #include "files_gugaci.fh"
-      common/count/mhsum,lp_count(22),mhlpmax
-      common/lpdisk/idisk_lp,idisk_array(13)
-      dimension info(10)
+#include "count.fh"
+#include "lpdisk.fh"
+      dimension info(10),idum(1)
 
       if(mh.gt.mhlpmax) mhlpmax=mh
       mhsum=mhsum+mh
@@ -1459,7 +1479,8 @@ c      print*, "in save_lp, linelp",line,idisk_lp,mh,mtype
         jhyl=jphyl(jph)
         jhyr=jphy(jph)
         in=ihyl(jhyl)
-        call idafile(luloop,1,[in],1,idisk_lp)
+        idum(1)=in
+        call idafile(luloop,1,idum,1,idisk_lp)
         call idafile(luloop,1,ihyl(jhyl+1:jhyl+in),in,idisk_lp)
         call idafile(luloop,1,ihy(jhyr+1:jhyr+in),in,idisk_lp)
 c        write(20)in,ihyl(jhyl+1:jhyl+in),ihy(jhyr+1:jhyr+in)
@@ -1480,7 +1501,7 @@ c      print*, "in read_lp, write coe",idisk_lp,norb_inn-norb_dz
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
 #include "files_gugaci.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "lpdisk.fh"
       dimension info(10)
 
       call idafile(luloop,2,info,10,idisk_lp)
