@@ -11,8 +11,7 @@
       subroutine geth0()
 #include "drt_h.fh"
 #include "pl_structure_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
 c     character*256 filename
       dimension vad0(max_h0)
       real*8, allocatable :: vb1(:), vb2(:)
@@ -32,7 +31,6 @@ c     character*256 filename
         goto 100
 !        return
       endif
-      ni=mod(norb_act,2)
       ipae=1
       jpae=nu_ae(ipae)
       if(jpae.eq.0) return
@@ -122,29 +120,28 @@ c     if(logic_mr) ndim_h0=irf
      *               ecih0,vcm,indx,vector2,nxh,vb1,vb2,nxb,vad0)
 c        vcm(1:mroot*ndim_h0)=vb1(1:mroot*ndim_h0)
 c save ci vector in h0 into vb2
-        numh0=nci_h0 !iw_sta(2,1)
-        vb2(1:numh0*mroot)=0.d0
-        if(logic_mr) then
-          idx1=0
-          idx2=0
-          do i=1,mroot
-            do j=1,ndim_h0
-              m=irfno(j)
-              vb2(idx1+m)=vb1(idx2+j)
-            enddo
-            idx1=idx1+numh0
-            idx2=idx2+ndim_h0
-          enddo
-        else
-          vb2(1:numh0*mroot)=vb1(1:numh0*mroot)
-        endif
+c        numh0=nci_h0 !iw_sta(2,1)
+c        vb2(1:numh0*mroot)=0.d0
+c        if(logic_mr) then
+c          idx1=0
+c          idx2=0
+c          do i=1,mroot
+c            do j=1,ndim_h0
+c              m=irfno(j)
+c              vb2(idx1+m)=vb1(idx2+j)
+c            enddo
+c            idx1=idx1+numh0
+c            idx2=idx2+ndim_h0
+c          enddo
+c        else
+c          vb2(1:numh0*mroot)=vb1(1:numh0*mroot)
+c        endif
       endif
       deallocate(vcm)
 
 400   continue
       write(6,*)
       do m=1,mroot
-        ijcm=indx(m)
         write(6,'(5x,a7,i5,f18.8)')   ' root,',m,ecih0(m)
       enddo
       write(6,*)
@@ -181,8 +178,7 @@ c      stop 888
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       real*8, allocatable :: buff(:)
 
       num=ndim_h0*(ndim_h0+1)/2
@@ -259,7 +255,7 @@ c    b1=(0,0,1.0,0,0,0...) b2=(0,0,0,0,1.0,0...)
 #include "drt_h.fh"
       data dzero/0.d0/dcrita/1.0d-6/epc/5.0d-3/
       dimension vb1(max_kspace*ndim),vad(ndim)
-      dimension th(nxh),ijb1(mroot),vb2(max_kspace*ndim)
+      dimension th(nxh),ijb1(mroot)
       vb1=0.d0
 
       do j=1,mroot
@@ -278,14 +274,12 @@ c    b1=(0,0,1.0,0,0,0...) b2=(0,0,0,0,1.0,0...)
 c=================================================================
       j=mroot
       do m=1,mroot
-        ijb2=indx(m)
         i=mjn(m)
         if(logic_mr)then
           mjnj=mjn(m)
           i=ifrno(mjnj)
         endif
         vadi=vad(i)
-        vb2(ijb2+i)=vadi
         ijh=i*(i-1)/2
         j=j+1
         ijb1(m)=indx(j)
@@ -293,14 +287,12 @@ c=================================================================
           fenmu=vadi-vad(l)
           if(abs(fenmu).lt.epc) fenmu=epc
           vb1(ijb1(m)+l)=th(ijh+l)/fenmu
-          vb2(ijb2+l)=th(ijh+l)
         enddo
         do l=i+1,ndim
           fenmu=vadi-vad(l)
           if(abs(fenmu).lt.epc) fenmu=epc
           ijh=l*(l-1)/2
           vb1(ijb1(m)+l)=th(ijh+i)/fenmu
-          vb2(ijb2+l)=th(ijh+i)
         enddo
       enddo
 
@@ -327,10 +319,10 @@ c--------------------------------------------------------------------
       subroutine minevalue(iselcsf_occ)
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common/config/ndr,nwalk(0:max_orb)
+#include "config.fh"
       dimension iselcsf_occ(max_innorb,max_ref)
       dimension iwalktmp(0:max_orb)
-      data dzero/0.d0/dcrita/1.0d-6/epc/5.0d-3/
+      data dzero/0.d0/
 
       call read_ml(lucidia,1,vector1,nci_dim,1)
 
@@ -396,8 +388,6 @@ c          write(6,"(16(i1))") iwalktmp(norb_dz+1:norb_dz+norb_act)
       subroutine orthnor_ab(n,av,bv,id)  !bv:basis, av:vector for orth a
       real*8 av(n),bv(n),s,ddot_,dcrita
       dcrita=1.0e-10
-      smax2=1.d10
-      smax1=0.0d0
       if(id.ne.0) goto 150
 c     orthogonization av,bv
       s=ddot_(n,av,1,bv,1)
