@@ -17,8 +17,6 @@
 !     :    ,jv,jd(8),jt(8),js(8)
 !      common/sub_drt/jpad,jpae,ipae,ndim,nohy,ihy(max_wei),
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
-      nst=norb_all
-      ndy=norb_ext
 c      do lr0=2,norb_all
 c        do lr=1,lr0-1
 c          vdint(lr,lr0)=voint(lr0,lr)
@@ -38,7 +36,8 @@ c      write(*,*)'         jpad,     jpae,     ndim,      nohy'
       jpae=jv
       ipae=1
       jaedownwei=iseg_downwei(ipae)
-      do jpad=1,mxnode
+      do jpad_=1,mxnode
+        jpad=jpad_ ! jpad is in common block, is this necessary?
         iw_sta(jpad,ipae)=ndimsum
         if(nu_ad(jpad).eq.0) cycle
         call seg_drt()
@@ -54,7 +53,8 @@ c      write(*,*)'         jpad,     jpae,     ndim,      nohy'
         ipae=1+im
         if(nu_ae(ipae).eq.0) cycle
         jaedownwei=iseg_downwei(ipae)
-        do jpad=1,mxnode
+        do jpad_=1,mxnode
+          jpad=jpad_ ! jpad is in common block, is this necessary?
           iw_sta(jpad,ipae)=ndimsum
           if(nu_ad(jpad).eq.0) cycle
           call seg_drt()
@@ -67,7 +67,6 @@ c     endif
           if(ndim .eq. 0) cycle
           call diagonal_act_d_g()
           call diagonal_act_c_g()
-          ista=iw_sta(jpad,ipae)+1
         enddo
       enddo
 
@@ -76,7 +75,8 @@ c     endif
         ipae=9+im
         if(nu_ae(ipae).eq.0) cycle
         jaedownwei=iseg_downwei(ipae)
-        do jpad=1,mxnode
+        do jpad_=1,mxnode
+          jpad=jpad_ ! jpad is in common block, is this necessary?
           iw_sta(jpad,ipae)=ndimsum
           if(nu_ad(jpad).eq.0) cycle
           call seg_drt()
@@ -93,7 +93,8 @@ c     endif
         ipae=17+im
         jaedownwei=iseg_downwei(ipae)
         if(nu_ae(ipae).eq.0) cycle
-        do jpad=1,mxnode
+        do jpad_=1,mxnode
+          jpad=jpad_ ! jpad is in common block, is this necessary?
           iw_sta(jpad,ipae)=ndimsum
           if(nu_ad(jpad).eq.0) cycle
           call seg_drt()
@@ -122,8 +123,8 @@ c     endif
       dimension ndr(max_innorb)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
       real*8, allocatable :: te(:), tee(:)
       integer, allocatable :: jpe(:), jee(:), jwe(:)
 c     write(*,*)'               ***** start h-diaelm *****'
@@ -138,7 +139,6 @@ c      write(*,*)  jpad,jpae
         return
       endif
       mp=0
-      nsum=0
 c 520
           mh=0
           me=0
@@ -248,15 +248,14 @@ c************************************************************
       dimension ndr(max_innorb)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
       real*8, allocatable :: te(:), tee(:)
       integer, allocatable :: jpe(:), jee(:), jwe(:)
 c     write(*,*)'               ***** start h-diaelm *****'
 c      write(*,*)   '   diagonal_act_d:',jpad,ipae
       allocate(te(maxpl),tee(maxpl),jpe(maxpl),jee(maxpl),jwe(maxpl))
       ndr=0
-      nsum=0
       do lr=norb_dz+1,norb_inn
         jp0=no(lr-1)+1
         jp1=no(lr)
@@ -296,7 +295,6 @@ c 520
 c     start '^'
           do idl=1,4
             if(jj_sub(idl,jp).eq.0) cycle
-            idr=idl
             jbl=jb(jp)
             ind1=idl-1
             if(ind1.eq.0) cycle
@@ -402,8 +400,8 @@ c************************************************************
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
       data dsq2,vsq2/1.414213562373095d0,0.7071067811865d0/
 !     dsq2=sqrt(2.d0)
 !     vsq2=1/sqrt(2.d0)
@@ -549,8 +547,8 @@ c     :   vo(lr0,la),vo(lr0,lb),vmd(lr0,la),vmd(lr0,lb)
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
 c      common/delm_value/iq,pd,pdd,pt,ptt,ps1,ps2,ps3,ps4
       data dsq2,vsq2/1.414213562373095d0, 0.7071067811865d0/
 !     dsq2=sqrt(2.d0)
@@ -972,8 +970,8 @@ c         call prodel(4,wlt,mpe,iwt,iwa)
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
       data dsq2,vsq2/1.414213562373095d0, 0.7071067811865d0/
 !     dsq2=sqrt(2.d0)
 !     vsq2=1/sqrt(2.d0)
@@ -1167,8 +1165,8 @@ c         call prodel(4,wlt,mpe,iwt,iwa)
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
       integer, pointer :: jph(:),jeh(:),jwh(:)
       real*8, pointer :: th(:),thh(:)
-      common/ptlph/jph,jeh,jwh
-      common/ptlphv/th,thh
+#include "ptlph.fh"
+#include "ptlphv.fh"
       data dsq2,vsq2/1.414213562373095d0, 0.7071067811865d0 /
       data dsq3vsq2/1.224744871392d0/
 !     dsq2=sqrt(2.d0)
@@ -1267,8 +1265,8 @@ c         call prodel(6,wl,iwd,iwa,iwe)
           do lb=lbsta,lbend
             lrb=norb_all-lb+1
             iwe=iwe+1
-            volalb=0.d0
-            vd2lalb=0.d0
+c            volalb=0.d0
+c            vd2lalb=0.d0
             vlop0=-vl0*vsq2
 
            do lr=1,norb_dz
@@ -1376,8 +1374,8 @@ c      the 8 should be changed to ng_sm
           do lb=lbsta,lbend
             lrb=norb_all-lb+1
             iwe=iwe+1
-            volalb=0.d0
-            vd2lalb=0.d0
+c            volalb=0.d0
+c            vd2lalb=0.d0
 
             wg14 =-vl0*vsq2
 
@@ -1443,7 +1441,7 @@ c         call prodel(6,wl,iwd,iwa,iwe)
            lra=norb_all-la+1
 
            iwe=iwe+1
-           vovdla=0.d0
+c          vovdla=0.d0
 
            wg13 =-vl0*dsq2
 
@@ -1494,7 +1492,7 @@ c            call prodel(6,wl,iwd,iwa,iwe)
 !     :    ,jv,jd(8),jt(8),js(8)
 !      common/sub_drt/jpad,jpae,ipae,ndim,nohy,ihy(max_wei),
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
-      data dzero/0.d0/
+!     data dzero/0.d0/
       logical logic_lij
 
       if(norb_dz.eq.0) return
@@ -1504,7 +1502,8 @@ c        wt0=wt0+voint(lr,lr)+voint(lr,lr)+vdint(lr,lr)
          wt0_1=2.0d0
          wt0_2=1.0d0
          call trans_ijkl_intpos(lr,lr,lr,lr,nxo)
-        do ipae=1,25
+        do ipae_=1,25
+          ipae=ipae_ ! ipae is in common block, is this necessary?
           if(nu_ae(ipae).eq.0) cycle
           iwdownv=iw_downwei(1,ipae)
           do iwa=0,iwdownv-1
@@ -1534,7 +1533,8 @@ c       jps=js(1)
 c         wld=wt0-voint(lr0,lr0)-vdint(lr0,lr0)
 c          wls=wld-voint(lr0,lr0)
            wld_1=1.0d0
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpad,ipae)
             do iwa=0,iwdownv-1
@@ -1545,7 +1545,8 @@ c             call prodel(1,wld,0,ipae,iwad)
           enddo
 
           if(jb_sys.gt.0) then
-            do ipae=1,25
+            do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpad1,ipae)
             do iwa=0,iwdownv-1
@@ -1562,7 +1563,8 @@ c             call prodel(1,wld,0,ipae,iwad)
            wls_1=2.0d0
            wls_2=1.0d0
 
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpad,ipae)
             do iwa=0,iwdownv-1
@@ -1574,7 +1576,8 @@ c             call prodel(1,wld,0,ipae,iwad)
           enddo
 
           if(jb_sys.gt.0) then
-            do ipae=1,25
+            do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpad1,ipae)
             do iwa=0,iwdownv-1
@@ -1588,7 +1591,8 @@ c             call prodel(1,wld,0,ipae,iwad)
 ! 0.....s_800.
           jpad=17+ns_sm
           iwd=just(lr0,lr0)
-          do ipae=1,25
+          do ipae_=1,25
+          ipae=ipae_ ! ipae is in common block, is this necessary?
           if(nu_ae(ipae).eq.0) cycle
           iwdownv=iw_downwei(jpad,ipae)
           do iwa=0,iwdownv-1
@@ -1621,7 +1625,8 @@ c      lr0 and lr
          call trans_ijkl_intpos(lr,lr,lr,lr,nxo)
          nxo_2=nxo
 
-         do ipae=1,25
+         do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -1673,7 +1678,8 @@ c     1 <= lrd < norb_dz and lrd.ne.lr0.and.lrd.ne.lr
          wld_1=2.0d0
          wld_2=1.0d0
          call trans_ijkl_intpos(lrd,lrd,lrd,lrd,nxo)
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -1729,7 +1735,8 @@ c         wt0=wt0-2.d0*vdint(lr,lr0)
            nxo2_0=nxo
            jpad=1
            iwd=0
-           do ipae=1,25
+           do ipae_=1,25
+              ipae=ipae_ ! ipae is in common block, is this necessary?
               if(nu_ae(ipae).eq.0) cycle
               iwdownv=iw_downwei(jpad,ipae)
               do iwa=0,iwdownv-1
@@ -1763,7 +1770,9 @@ c                 call prodel(1,wt0,0,ipae,iwad)
 c              wld=wld+vdint(lr,lrm)
                wld_1=-1.0d0
                wld_2=2.0d0
-               do ipae=1,25
+               do ipae_=1,25
+                  ! ipae is in common block, is this necessary?
+                  ipae=ipae_
                   if(nu_ae(ipae).eq.0) cycle
                      iwdownv=iw_downwei(jpad,ipae)
                   do iwa=0,iwdownv-1
@@ -1794,7 +1803,9 @@ c                        call prodel(1,wld,0,ipae,iwad)
 c              wld=wld+vdint(lrm,lr0)
                wld_1=-1.0d0
                wld_2=2.0d0
-               do ipae=1,25
+               do ipae_=1,25
+                  ! ipae is in common block, is this necessary?
+                  ipae=ipae_
                   if(nu_ae(ipae).eq.0) cycle
                      iwdownv=iw_downwei(jpad,ipae)
                   do iwa=0,iwdownv-1
@@ -1830,7 +1841,8 @@ c      enddo
       if(.not.logic_lij) then
            wt0_1=-2.0d0
            wt0_2=4.0d0
-      do ipae=1,25
+      do ipae_=1,25
+        ipae=ipae_ ! ipae is in common block, is this necessary?
         if(nu_ae(ipae).eq.0) cycle
         iwdownv=iw_downwei(jpad,ipae)
         do iwa=0,iwdownv-1
@@ -1918,7 +1930,8 @@ c          wls1=wt0+(1.50d0-w1)*voint(lr,lr0)-3.d0*vdint(lr,lr0)
             !    ..1.2  (-1/2-w1)*vo(lr0,lr)+vmd(lr0,lr)
            !  w0=-1/2    w1=-(db-1)/(2*db+2)
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -1967,7 +1980,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2015,7 +2029,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2065,7 +2080,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2113,7 +2129,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2164,7 +2181,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2212,7 +2230,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
                   wls1_1=-1.0d0
                   wls1_2=2.0d0
                endif
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2268,7 +2287,8 @@ c                 call prodel(1,wlt,0,ipae,iwad)
               wls1_2=4.0d0
            endif
 
-          do ipae=1,25
+          do ipae_=1,25
+            ipae=ipae_ ! ipae is in common block, is this necessary?
             if(nu_ae(ipae).eq.0) cycle
             iwdownv=iw_downwei(jpat,ipae)
             do iwa=0,iwdownv-1
@@ -2324,8 +2344,6 @@ c ------------- end of .......h_delm --------------
 !     :    ,jv,jd(8),jt(8),js(8)
 !      common/sub_drt/jpad,jpae,ipae,ndim,nohy,ihy(max_wei),
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
-      character*10 cc
-        cc=' out_800_d'
         jws0=0
 c      do mra=1,8
        do mra=1,ng_sm
@@ -2427,9 +2445,9 @@ c           call prodel(2,wlt,0,ipat,jwt)
 #include "grad_h.fh"
 !      common/sub_drt/jpad,jpae,ipae,ndim,nohy,ihy(max_wei),
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "iaib.fh"
 
-      ndr=88
+!      ndr=88
       goto(100,200,300,400,500,600),idb
 ! in dbl_space
 100   ipae=mg2
@@ -2585,7 +2603,7 @@ c          vector1(mm)=vector1(mm)+wl
 !      common/sub_drt/jpad,jpae,ipae,ndim,nohy,ihy(max_wei),
 !     :     jj_sub(4,0:max_node),iy(4,0:max_node),jphy(max_node)
 c      ndr=88
-       ndr=6
+c      ndr=6
       goto(100,200,300,400,500,600),idb
 ! in dbl_space
 100   ipae=mg2
