@@ -23,13 +23,12 @@
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "grad_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
-      common /lgrn/ xlgrn(max_orb,max_orb)
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /grad_xyz/dxyz(3,max_atom),numat
-      common /ncprhf/ nrot,nxyz,ndbl,next,nsolv,nres,n_frz,n_all
+#include "scratch.fh"
+#include "lgrn.fh"
+#include "iaib.fh"
+#include "vect.fh"
+#include "grad_xyz.fh"
+#include "ncprhf.fh"
       parameter (htoklm=627.50956d+00,zero=0.0d+00)
 c================================================
 c    the main subroutine for ci gradient calculations.
@@ -42,7 +41,7 @@ c version of xian-ci
 
       return
 
-      write(6,'(a18,2x,f10.2,2x,a1)') 'end of grad, takes',sc5-sc0,'s'
+c     write(6,'(a18,2x,f10.2,2x,a1)') 'end of grad, takes',sc5-sc0,'s'
       end
 
 
@@ -65,8 +64,7 @@ c=====================================================
       subroutine moread(ii,jj,kk,ll,val)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /pcklab/ labsiz
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "iaib.fh"
 c====================================================
 !    transfer the ci mo indexs to scf mo indexs
 !    and use library function ishft() to save
@@ -101,8 +99,7 @@ c      write(nf2,'(4i4,f18.10)') lri,lrj,lrk,lrl,vector1(nijkl)
       subroutine trans_ijkl_intpos(ii,jj,kk,ll,nxo)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /pcklab/ labsiz
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "iaib.fh"
 c====================================================
 !    transfer the ci mo indexs to scf mo indexs
 !    and use library function ishft() to save
@@ -145,7 +142,6 @@ c      endif
 
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /pcklab/ labsiz
       dimension lijkl(4)
 
 c=========================================================
@@ -163,10 +159,10 @@ c Avoid unused argument warnings
       subroutine lagran_act(x1e)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /ncprhf/ nrot,nxyz,ndbl,next,nsolv,nres,n_frz,n_all
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /lgrn/ xlgrn(max_orb,max_orb)
+#include "vect.fh"
+#include "ncprhf.fh"
+#include "iaib.fh"
+#include "lgrn.fh"
       dimension x1e(50000),fock(n_all,n_all)
       parameter (zero=0.0d+00,two=2.0d+00)
 
@@ -414,9 +410,9 @@ c       write(2,'(a9,2i4,f18.10)') 'xlgrn_all',i,j,xlgrn(i,j)
       subroutine lagran_all(x1e)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /lgrn/ xlgrn(max_orb,max_orb)
-      common /ncprhf/ nrot,nxyz,ndbl,next,nsolv,nres,n_frz,n_all
+#include "iaib.fh"
+#include "lgrn.fh"
+#include "ncprhf.fh"
       dimension x1e(50000)
       parameter (zero=0.0d+00,two=2.0d+00)
 
@@ -424,7 +420,7 @@ c================================================
 c lyb
 c     xlgrn(norb_all,norb_all) is the lagrange matrix.
 
-      norbf=n_frz+1
+c      norbf=n_frz+1
 c      norbf=1
 
       xlgrn(1:norb_all,1:norb_all)=0.0d0
@@ -510,12 +506,11 @@ c       write(2,'(a9,2i4,f18.10)') 'xlgrn_all',i,j,xlgrn(i,j)
       subroutine writedm2(nx)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
-      character*256 filename
+#include "scratch.fh"
+!      character*256 filename
 
-      filename=tmpdir(1:len_str)//"/density"
-      len=len_str+8
+!      filename=tmpdir(1:len_str)//"/density"
+!      len=len_str+8
 ! Need debug
 !      open(nf22,file=filename(1:len),form='unformatted')
 
@@ -531,8 +526,7 @@ c Avoid unused argument warnings
       subroutine readdm2(nx)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
 c     character*256 filename
 
       vector2(1:nx)=0.0d+00
@@ -553,12 +547,11 @@ c      open(nf22,file='density',form='unformatted')
       subroutine backtransmo
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
 c     character*256 filename
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /density/ p(max_orb,max_orb)
+#include "vect.fh"
+#include "iaib.fh"
+#include "density.fh"
       dimension ican_ab(norb_all),c(70000),dm1_act(naorbs,naorbs)
       logical resina
       parameter (htoklm=627.50956d+00,zero=0.0d+00,two=2.0d+00,
@@ -763,8 +756,8 @@ c      open(20,file='backdm2',form='unformatted')
 
       subroutine backtrans_test
 #include "drt_h.fh"
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "vect.fh"
+#include "iaib.fh"
 c-------------------------------------------------------------
 c this subroutine for test the backtrans result by just one density matr
 c ao, such as (ij|kl)
@@ -806,117 +799,122 @@ c
 
       end
 
-      subroutine grad_two
-#include "drt_h.fh"
-      common /grad_xyz/dxyz(3,max_atom),numat
-      common /ndao/ ndao
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
-      character*256 filename
-      dimension index_atom(3,numat*(numat+1)/2),ndi0(ndao),ndj0(ndao),
-     :          ndk0(ndao),ndl0(ndao),daoint1(ndao)
-      dimension dgxyz(3,numat),daoxyz(3,numat)
-      parameter (htoklm=627.50956d+00)
-      parameter (zero=0.0d+00,one=1.0d+00,two=2.0d+00,four=4.0d+00)
-
-      npat=numat*(numat+1)/2
-      index_atom(1:3,1:npat)=0
-
-      filename=tmpdir(1:len_str)//"/daoints"
-      len=len_str+8
-
-!      open(40,file=filename(1:len),form='formatted')
-
-c      open(40,file='daoints',form='formatted')
-!      read(40,*)
-
-!      do i=1,3
-!         read(40,*) (index_atom(i,j),j=1,npat)
-!      enddo
-!      read(40,*) (ndi0(i),i=1,ndao)
-!      read(40,*) (ndj0(i),i=1,ndao)
-!      read(40,*) (ndk0(i),i=1,ndao)
-!      read(40,*) (ndl0(i),i=1,ndao)
-!      read(40,*) (daoint1(i),i=1,ndao)
+! FIXME: ndao is undefined
+!      subroutine grad_two
+!#include "drt_h.fh"
+!#include "grad_xyz.fh"
+!#include "iaib.fh"
+!#include "scratch.fh"
+!!      character*256 filename
+!      dimension index_atom(3,numat*(numat+1)/2),ndi0(ndao),ndj0(ndao),
+!     :          ndk0(ndao),ndl0(ndao),daoint1(ndao)
+!      dimension dgxyz(3,numat),daoxyz(3,numat)
+!      parameter (htoklm=627.50956d+00)
+!      parameter (zero=0.0d+00,one=1.0d+00,two=2.0d+00,four=4.0d+00)
 !
-!      close(40)
-
-      ncon=0
-
-      do i=1,numat
-         do j=1,i-1
-            nnij=ican_a(i)+j
-c            write(nf2,*) i,ican_a(i)
-            do k=1,3
-               ind=index_atom(k,nnij)
-               val=zero
-               do l=1,ind
-                  ncon=ncon+1
-                  i0=ndi0(ncon)
-                  j0=ndj0(ncon)
-                  k0=ndk0(ncon)
-                  l0=ndl0(ncon)
-                  val2=daoint1(ncon)
-c                 write(2,'(4i4,f18.10)')i0,j0,k0,l0,val2
-                  nij=ican_a(j0)+i0
-                  nkl=ican_a(l0)+k0
-                  nijkl=ican_b(nij)+nkl
-                  val1=vector1(nijkl)
-                  aa=one
-                  bb=one
-                  if(i0.ne.j0) aa=two*aa
-                  if(k0.ne.l0) bb=two*bb
-c===================================================
-c this place should multiple two, because the gradient
-c integral always exist the relation that :
-c index nij=i*(i-1)/2+j
-c index nkl=k*(k-1)/2+l
-c but here always the nij >= nkl.
-c
-                  val=val+val1*val2*aa*bb*two
-               enddo
-               daoxyz(k,i)=daoxyz(k,i)+val
-               daoxyz(k,j)=daoxyz(k,j)-val
-
-               dxyz(k,i)=dxyz(k,i)+val
-               dxyz(k,j)=dxyz(k,j)-val
-           enddo
-         enddo
-      enddo
-
-c      dgxyz(1:3,1:numat)=zero
-c      do i=1,numat
-c         do j=1,3
-c            dgxyz(j,i)=daoxyz(j,i)*htoklm
-c         enddo
-c      enddo
-
-
-c      write(nf2,'(//10x,''cartesian coordinate derivatives'',//3x,
-c     1''number  atom '',5x,''x'',12x,''y'',12x,''z'',/)')
-
-c      do i=1,numat
-c         write(nf2,'(6x,i6,3f13.6)') i,(dgxyz(j,i),j=1,3)
-c      enddo
-
-      dgxyz(1:3,1:numat)=zero
-      do i=1,numat
-         do j=1,3
-            dgxyz(j,i)=dxyz(j,i)*htoklm
-         enddo
-      enddo
-
-
-!      write(nf2,'(//10x,''cartesian coordinate derivatives'',//3x,
-!     1''number  atom '',5x,''x'',12x,''y'',12x,''z'',/)')
-
-      do i=1,numat
-         write(6,'(6x,i6,3f13.6)') i,(dgxyz(j,i),j=1,3)
-      enddo
-
-
-      end
+!      npat=numat*(numat+1)/2
+!      index_atom(1:3,1:npat)=0
+!
+!      ndi0(:)=0
+!      ndj0(:)=0
+!      ndk0(:)=0
+!      ndl0(:)=0
+!      daoint1(:)=zero
+!
+!!      filename=tmpdir(1:len_str)//"/daoints"
+!!      len=len_str+8
+!
+!!      open(40,file=filename(1:len),form='formatted')
+!
+!c      open(40,file='daoints',form='formatted')
+!!      read(40,*)
+!
+!!      do i=1,3
+!!         read(40,*) (index_atom(i,j),j=1,npat)
+!!      enddo
+!!      read(40,*) (ndi0(i),i=1,ndao)
+!!      read(40,*) (ndj0(i),i=1,ndao)
+!!      read(40,*) (ndk0(i),i=1,ndao)
+!!      read(40,*) (ndl0(i),i=1,ndao)
+!!      read(40,*) (daoint1(i),i=1,ndao)
+!!
+!!      close(40)
+!
+!      ncon=0
+!
+!      do i=1,numat
+!         do j=1,i-1
+!            nnij=ican_a(i)+j
+!c            write(nf2,*) i,ican_a(i)
+!            do k=1,3
+!               ind=index_atom(k,nnij)
+!               val=zero
+!               do l=1,ind
+!                  ncon=ncon+1
+!                  i0=ndi0(ncon)
+!                  j0=ndj0(ncon)
+!                  k0=ndk0(ncon)
+!                  l0=ndl0(ncon)
+!                  val2=daoint1(ncon)
+!c                 write(2,'(4i4,f18.10)')i0,j0,k0,l0,val2
+!                  nij=ican_a(j0)+i0
+!                  nkl=ican_a(l0)+k0
+!                  nijkl=ican_b(nij)+nkl
+!                  val1=vector1(nijkl)
+!                  aa=one
+!                  bb=one
+!                  if(i0.ne.j0) aa=two*aa
+!                  if(k0.ne.l0) bb=two*bb
+!c===================================================
+!c this place should multiple two, because the gradient
+!c integral always exist the relation that :
+!c index nij=i*(i-1)/2+j
+!c index nkl=k*(k-1)/2+l
+!c but here always the nij >= nkl.
+!c
+!                  val=val+val1*val2*aa*bb*two
+!               enddo
+!               daoxyz(k,i)=daoxyz(k,i)+val
+!               daoxyz(k,j)=daoxyz(k,j)-val
+!
+!               dxyz(k,i)=dxyz(k,i)+val
+!               dxyz(k,j)=dxyz(k,j)-val
+!           enddo
+!         enddo
+!      enddo
+!
+!c      dgxyz(1:3,1:numat)=zero
+!c      do i=1,numat
+!c         do j=1,3
+!c            dgxyz(j,i)=daoxyz(j,i)*htoklm
+!c         enddo
+!c      enddo
+!
+!
+!c      write(nf2,'(//10x,''cartesian coordinate derivatives'',//3x,
+!c     1''number  atom '',5x,''x'',12x,''y'',12x,''z'',/)')
+!
+!c      do i=1,numat
+!c         write(nf2,'(6x,i6,3f13.6)') i,(dgxyz(j,i),j=1,3)
+!c      enddo
+!
+!      dgxyz(1:3,1:numat)=zero
+!      do i=1,numat
+!         do j=1,3
+!            dgxyz(j,i)=dxyz(j,i)*htoklm
+!         enddo
+!      enddo
+!
+!
+!!      write(nf2,'(//10x,''cartesian coordinate derivatives'',//3x,
+!!     1''number  atom '',5x,''x'',12x,''y'',12x,''z'',/)')
+!
+!      do i=1,numat
+!         write(6,'(6x,i6,3f13.6)') i,(dgxyz(j,i),j=1,3)
+!      enddo
+!
+!
+!      end
 
 
 
@@ -924,14 +922,13 @@ c      enddo
 
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
-      character*256 filename
-      common /lgrn/ xlgrn(max_orb,max_orb)
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /grad_xyz/dxyz(3,max_atom),numat
-      common /density/ p(max_orb,max_orb)
+#include "scratch.fh"
+!      character*256 filename
+#include "lgrn.fh"
+#include "iaib.fh"
+#include "vect.fh"
+#include "grad_xyz.fh"
+#include "density.fh"
       dimension dsaos(3,numat,naorbs*(naorbs+1)/2)
       dimension dgxyz(3,numat),dmo1xyz(3,numat),dm1_act(naorbs,naorbs)
       parameter (htoklm=627.50956d+00)
@@ -939,8 +936,8 @@ c      enddo
 
       dsaos(1:3,1:numat,1:naorbs*(naorbs+1)/2)=zero
 
-      filename=tmpdir(1:len_str)//"/dfock1"
-      len=len_str+7
+!      filename=tmpdir(1:len_str)//"/dfock1"
+!      len=len_str+7
 
 !      open(500,file=filename(1:len),form='unformatted')
 
@@ -1035,10 +1032,10 @@ c      enddo
 
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /lgrn/ xlgrn(max_orb,max_orb)
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /grad_xyz/dxyz(3,max_atom),numat
+#include "lgrn.fh"
+#include "iaib.fh"
+#include "vect.fh"
+#include "grad_xyz.fh"
       dimension dsaos(3,numat,naorbs*(naorbs+1)/2)
       dimension dgxyz(3,numat),dmo1xyz(3,numat)
       parameter (htoklm=627.50956d+00)
@@ -1127,8 +1124,8 @@ c      enddo
       subroutine density_ci_one(dm1_act)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
+#include "iaib.fh"
+#include "vect.fh"
       dimension dm1_act(naorbs,naorbs)
       parameter (zero=0.0d+00,one=1.0d+00,two=2.0d+00,four=4.0d+00)
 
@@ -1157,9 +1154,9 @@ c      enddo
       subroutine lagran_fock(x1e,fock)
 #include "drt_h.fh"
 #include "grad_h.fh"
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /ncprhf/ nrot,nxyz,ndbl,next,nsolv,nres,n_frz,n_all
+#include "vect.fh"
+#include "iaib.fh"
+#include "ncprhf.fh"
       dimension x1e(50000),fock(n_all,n_all)
       parameter (zero=0.0d+00,two=2.0d+00)
 
