@@ -22,20 +22,17 @@ c------------------------------------------------------
 c
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
-      common /thresh/ vthreen,vthrealp,vthreresid
+#include "scratch.fh"
+#include "thresh.fh"
       dimension idxvec(max_iter)
       dimension valpha(max_root),vcien(max_root),vcienold(max_root),
      *          difeci(max_root),vresid(max_root)
 c      dimension vad(max_vector),th(max_vector)
       logical log_convergance,log_muliter
-      data dzero/0.d0/,depc/1.0d-7/,ecrita/1.0d-8/,dcrita/1.0d-7/
-      data vortho_criterion/1.d-8/,vreth/1.d-4/
+      data dzero/0.d0/,depc/1.0d-7/
+      data vortho_criterion/1.d-8/
 c      data venergy_criterion/1.d-8/
-c     *     valpha_criterion/1.d-7/,vresid_criterion/1.d-8/,
-c     *     vreth/1.d-4/
-
+c     *     valpha_criterion/1.d-7/,vresid_criterion/1.d-8/
 
       venergy_criterion=vthreen
       valpha_criterion=vthrealp
@@ -230,7 +227,6 @@ c
           call read_ml(lucidia,1,vector2,nd,2)
           nda=nci_dim*mroot
           call read_bv(lucitv1,1,vector1,nda)
-          vsum=dzero
 !          rewind 7
           do mt=1,mtsta-1
             mtidx=indx(mt)
@@ -245,7 +241,6 @@ c
           mid=indx(mtsta-mtsta0+1)
           vector1(mtidx+1:mtidx+nd)=vector2(mid+1:mid+nd)
           call write_bv(lucitv1,1,vector1,nda)
-          vsum=dzero
           do mt=1,mtsta-1
             vet=vcien(mt)
             mtidx=indx(mt)
@@ -453,18 +448,11 @@ c
 !     *                      nf11,nf13,nf15,nf20,nf21,nf22,nf23
 !
 !      logical logic_tdav,logic_inivec_read
-!      common /program_control/ logic_tdav,logic_inivec_read
-!      common /scratch/ tmpdir,len_str
-!      character*256 tmpdir,filename
-      logical logic_tdav,logic_inivec_read,logic_mr,
-     *        logic_mrelcas,logic_calpro,logic_assign_actorb
-      common /program_control/ logic_tdav,logic_inivec_read,
-     *               logic_mr,logic_mrelcas,logic_calpro,
-     *               logic_assign_actorb
-      data dzero/0.d0/,dcrita/1.0d-6/,epc/5.0d-3/
+!#include "scratch.fh"
+#include "program_control.fh"
+      data dzero/0.d0/
       dimension vb1(ncivec*ndim),vb2(ncivec*ndim)
       dimension indx(max_kspace),mjn(2*max_root),vcien(mroot)
-      dimension vdiatmp(2*mroot)
 
 c      write(6,*) "indx",indx(1:2*mroot)
 c      call read_bv(nf8,1,vb2,ndim)
@@ -521,7 +509,6 @@ c      write(6 ,*) "bbs debug 2"
 
       vad=0.d0
       idx=0
-      l=mth_eigen
       do m=1,ndim
         do k=1,mth_eigen
           if(m.eq.mjn(k)) goto 30
@@ -555,7 +542,6 @@ c        read(nf7) vb1(1:ndim)
 c      write(6 ,*) "bbs debug 4"
       call read_ml(lucidia,1,vb2,ndim,1)
 c      call read_bv(nf8,1,vb2,ndim)
-      vdiatmp(2)=vb2(mjntm)
       do i=1,ndim
         vb2(i)=vb1(i)*vb2(i)
       enddo
@@ -597,17 +583,10 @@ c
 !      common /file_descript/nf1,nf2,nf3,nf4,nf7,nf8,nf9,nf10,
 !     *                      nf11,nf13,nf15,nf20,nf21,nf22,nf23
 !      logical logic_tdav,logic_inivec_read
-!      common /program_control/ logic_tdav,logic_inivec_read
-!      common /scratch/ tmpdir,len_str
-!      character*256 tmpdir,filename
-      logical logic_tdav,logic_inivec_read,logic_mr,
-     *        logic_mrelcas,logic_calpro,logic_assign_actorb
+!#include "scratch.fh"
+#include "program_control.fh"
 
-      common /program_control/ logic_tdav,logic_inivec_read,
-     *               logic_mr,logic_mrelcas,logic_calpro,
-     *               logic_assign_actorb
-
-      data dzero/0.d0/,dcrita/1.0d-6/,epc/5.0d-3/
+      data dzero/0.d0/
       dimension vb1(ncivec*ndim),vb2(ncivec*ndim),vdia(2*mroot)
       dimension indx(max_kspace),mjn(2*max_root),vcien(mroot)
       dimension mjntmp(mroot*2),vdiatmp(2*mroot)
@@ -860,14 +839,9 @@ c
       implicit real*8 (a-h,o-z)
 #include "ci_parameter.fh"
 #include "files_gugaci.fh"
-      logical logic_tdav,logic_inivec_read,logic_mr,
-     *        logic_mrelcas,logic_calpro,logic_assign_actorb
+#include "program_control.fh"
 
-      common /program_control/ logic_tdav,logic_inivec_read,
-     *               logic_mr,logic_mrelcas,logic_calpro,
-     *               logic_assign_actorb
-
-      data dzero/0.d0/,dcrita/1.0d-6/,epc/5.0d-3/
+      data dzero/0.d0/,epc/5.0d-3/
       dimension vb1(ncivec*ndim),vb2(ncivec*ndim),vdia(2*mroot)
       dimension indx(max_kspace),mjn(2*max_root),vcien(mroot)
       real*8, allocatable :: diagelement(:)
@@ -990,11 +964,10 @@ c****************************************************************
 #endif
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       dimension valpha(max_root),vcien(max_root),vresid(max_root)
-      dimension dav1(max_root),dav2(max_root),dav3(max_root),
-     *          vcml(max_root),remei(max_root)
+c      dimension dav2(max_root),dav3(max_root),remei(max_root)
+      dimension dav1(max_root),vcml(max_root)
       logical log_muliter
 
       vector1=0.d0
@@ -1003,7 +976,7 @@ c****************************************************************
       if(log_muliter) then
         nc=1
         do i=1,mtsta0-1
-          mtidx=indx(i)
+!          mtidx=indx(i)
           call read_ml(lucivec,1,vector1(nc:nc+nci_dim-1),nci_dim,i)
           nc=nc+nci_dim
         enddo
@@ -1046,16 +1019,16 @@ c
         endif
 
         dedav1=(1.d0-vcml(mt))*de
-        dedav2=dedav1/(vcml(mt))
-        dedav3=dedav1/(2*vcml(mt)-1)
-        demei=dedav2*(n_electron*(n_electron-5)+6)
-     *       /(n_electron*(n_electron-1))
+c        dedav2=dedav1/(vcml(mt))
+c        dedav3=dedav1/(2*vcml(mt)-1)
+c        demei=dedav2*(n_electron*(n_electron-5)+6)
+c     *       /(n_electron*(n_electron-1))
 c        demei=dedav2*(n_electron*(n_electron-5)+6)
 c     :       /(n_electron*(n_electron-1))
         dav1(mt)=vcien(mt)-dedav1
-        dav2(mt)=vcien(mt)-dedav2
-        dav3(mt)=vcien(mt)-dedav3
-        remei(mt)=vcien(mt)-demei
+c        dav2(mt)=vcien(mt)-dedav2
+c        dav3(mt)=vcien(mt)-dedav3
+c        remei(mt)=vcien(mt)-demei
 
         write(6,900)
 c        write(6,901) mt,vcien(mt),dav1(mt),dav2(mt),dav3(mt),remei(mt)
@@ -1113,8 +1086,7 @@ c...end of get_eigvector
 
       subroutine matrix_vector_multi_v(sechc)
 #include "drt_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       external inn_ext_ss_loop_unpack
       external inn_ext_st_loop_unpack
       external inn_ext_ts_loop_unpack
@@ -1141,8 +1113,7 @@ c...end of get_eigvector
 
       subroutine matrix_vector_multi_d(sechc)
 #include "drt_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       external inn_ext_ss_loop_unpack
       external inn_ext_st_loop_unpack
       external inn_ext_ts_loop_unpack
@@ -1177,17 +1148,13 @@ c...end of get_eigvector
 
       subroutine matrix_vector_multi_parellel_drt(sechc)
 #include "drt_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       external inn_ext_ss_loop_unpack
       external inn_ext_st_loop_unpack
       external inn_ext_ts_loop_unpack
       external inn_ext_tt_loop_unpack
       external inn_ext_st_drl_loop_unpack
       external inn_ext_ts_drl_loop_unpack
-      data zero/0.d0/
-*ia32 data zero/0.d0/
-*ia64 data zero/0.e0/
 
       log_prod=1
       sc1=c_time()
@@ -1222,8 +1189,7 @@ c...end of get_eigvector
 
       subroutine matrix_vector_multi_parellel_prt(sc3)
 #include "drt_h.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       external inn_ext_ss_loop_unpack
       external inn_ext_st_loop_unpack
       external inn_ext_ts_loop_unpack
@@ -1427,8 +1393,7 @@ c          e|ck>-h|ck>
 c          |ck>=\sigma(vu(i,m)*vector_i),i=1,j
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       dimension idxvec(max_kspace)
       dimension vresid(max_root),vcien(max_root)
       data dzero/0.d0/
@@ -1466,7 +1431,7 @@ c          |ck>=\sigma(vu(i,m)*vector_i),i=1,j
 
       do mt=mtsta,mroot
         mtidx=indx(mt-mtsta+1)
-        venergy=vcien(mt)
+        !venergy=vcien(mt)
         do l=1,nci_dim
           !vector1(mtidx+l)=venergy*vector1(mtidx+l)
           vector1(mtidx+l)=0.d0
@@ -1532,8 +1497,7 @@ c          e|ck>-h|ck>
 c          |ck>=\sigma(vu(i,m)*vector_i),i=1,j
 #include "drt_h.fh"
 #include "files_gugaci.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
       dimension idxvec(max_kspace)
       dimension vresid(max_root),vcien(max_root)
       data dzero/0.d0/
