@@ -14,24 +14,22 @@
 #include "pl_structure_h.fh"
 #include "grad_h.fh"
 #include "files_gugaci.fh"
-      common /scratch/ tmpdir,len_str
-      character*256 tmpdir
+#include "scratch.fh"
 c     character*256 filename
-      common /lgrn/ xlgrn(max_orb,max_orb)
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /grad_xyz/dxyz(3,max_atom),numat
-      common /ncprhf/ nrot,nxyz,ndbl,next,nsolv,nres,n_frz,n_all
+#include "lgrn.fh"
+#include "iaib.fh"
+#include "vect.fh"
+#include "grad_xyz.fh"
+#include "ncprhf.fh"
       parameter (htoklm=627.50956d+00,zero=0.0d+00)
 c     dimension x1e(50000)
-      logical logic_mulroot
+!      logical logic_mulroot
 c================================================
 c    the main subroutine for ci gradient calculations.
 c    ican_a and ican_b save canonical order.
 c    e(*) save the scf orbital energies.
 c    xlgrn(*) save the lagrangian matrix.
 
-      sc0=c_time()
 c-----------------------------------------------------
 c     initialize the integral index nxo by canonical order
       call init_canonical
@@ -43,13 +41,12 @@ c     calculate the ci reduced one and two electron density matrix
       ncount1=ican_a(norb_all)+norb_all
       ncount2=ican_b(ncount1)+ncount1
 
-      logic_mulroot=.false.
-      ndim=mroot*nci_dim
-      if(ndim.le.max_vector) logic_mulroot=.true.
+!      logic_mulroot=.false.
+!      ndim=mroot*nci_dim
+!      if(ndim.le.max_vector) logic_mulroot=.true.
 
       neigen=mroot
       vector1(1:nci_dim)=zero
-      norb2=norb_all*(norb_all+1)/2
 
 ! calculated ci density matrix
 ! need debug here, density matrix is saved in vector2, it is too large t
@@ -80,7 +77,7 @@ c should we calculated two-electronic density matrix ?
 #include "intsort_h.fh"
 #include "files_gugaci.fh"
 #include "grad_h.fh"
-      dimension lsmorb(max_orb),noidx(8),idisk_array(max_root+1)
+      dimension noidx(8),idisk_array(max_root+1)
       REAL*8, pointer :: x(:)
 !      dimension x(1024*1024)
       dimension xfock(max_orb*(max_orb+1)/2)
@@ -94,7 +91,6 @@ c should we calculated two-electronic density matrix ?
       nintone=0
       nmob=0
       nidx=0
-      ni=0
       do i=1,ng_sm
         nism   = nlsm_all(i)
         nsmint = nism*(nism+1)/2
@@ -103,8 +99,6 @@ c should we calculated two-electronic density matrix ?
         noidx(i)=nidx
         nidx=nidx+nism
         nintone=nintone+nsmint
-        lsmorb(ni+1:nidx)=i
-        ni=nidx
       enddo
 
       allocate(x(nmob))
@@ -175,18 +169,15 @@ c write one electron fock matrix into voint
               if(nspqr.ne.nss) cycle
               nos=norb(nss)
 
-              ityp=0
               if(nsr.eq.nss) then
                 nbpq=(nop+nop**2)/2
                 nbrs=(nos+nos**2)/2
                 if(nsp.eq.nsr) then
 c  (ii|ii) type 1 int
                   nintb=(nbpq+nbpq**2)/2
-                  ityp=1
                 else
 c  (ii|jj) type 3 int
                   nintb=nbpq*nbrs
-                  ityp=3
                 endif
               else
                 nbpq=nop*noq
@@ -194,11 +185,9 @@ c  (ii|jj) type 3 int
                 if(nsp.eq.nsr) then
 c (ij|ij) type 2 int
                   nintb=(nbpq+nbpq**2)/2
-                  ityp=2
                 else
 c (ij|kl) type 4 int
                   nintb=nbpq*nbrs
-                  ityp=4
                 endif
               endif
 
@@ -268,7 +257,7 @@ c                        call ddatard(nft,buff,kbuf,idisk)
 
       subroutine init_canonical
 #include "drt_h.fh"
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "iaib.fh"
 c========================================
 c  calculate the canonical order for index transform
 
@@ -285,8 +274,8 @@ c  calculate the canonical order for index transform
 
       subroutine density_scf_frz
 #include "drt_h.fh"
-      common /vect/ e(max_orb),cf(max_orb,max_orb),naorbs
-      common /density/ p(max_orb,max_orb)
+#include "vect.fh"
+#include "density.fh"
       parameter (zero=0.0d+00,one=1.0d+00,two=2.0d+00,four=4.0d+00)
 
       do i=1,naorbs
@@ -391,7 +380,7 @@ c            write(2,'(2i8,f18.10)') i,j,p(i,j)
 #include "drt_h.fh"
 #include "grad_h.fh"
 #include "files_gugaci.fh"
-      common /iaib/ ican_a(max_orb),ican_b(mtmp+max_orb)
+#include "iaib.fh"
       dimension indx_m(maxgdm),idisk_array(max_root+1)
       parameter (zero=0.0d+00, half=0.5d+00, two=2.0d+00)
 c=============================================================
