@@ -13,12 +13,12 @@
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
+#include "lpdisk.fh"
 
       call external_space_plpmode_value_dv()
 
       idisk_lp=idisk_array(2)
-      do lpblock=1,lpblock_dv
+      do lpb=1,lpblock_dv
         call read_lp()
         ipael=iml+1
         ipae=1
@@ -846,30 +846,15 @@ c        enddo
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
-      data dsq2/1.414213562373d0/vsq2/0.7071067811865d0/
-c      data dsq3/ 1.732050807569d0/
+#include "lpdisk.fh"
 c      write(6,*)'  sd_wyb'
-      w0_d25=vsq2
-      w0_d26=-1.0d0
-      w0_d27d=-vsq2
-      w0_d27v=-vsq2/2
-      w1_d27v=1.5d0*vsq2
-      w0_d28=-vsq2
-      w0_d29=-dsq2
-      w0_d30=-1.0d0
-      w0_d31=vsq2
-      w0_d32sd=vsq2/2
-      w1_d32sd=1.5d0*vsq2
-      w0_d32ds=-0.5d0
-      w1_d32ds=-1.5d0
 
 !      logic_sd=.true.
       call external_space_plpmode_value_sd()
 
       idisk_lp=idisk_array(11)
 
-      do lpblock=1,lpblock_sd
+      do lpb=1,lpblock_sd
         call read_lp()
         ipael=iml+17
         ipae =imr+1
@@ -893,30 +878,15 @@ c        jmlr=mul_tab(jml,jmr)
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
-      data dsq2/1.414213562373d0/vsq2/0.7071067811865d0/
-c      data dsq3/ 1.732050807569d0/
+#include "lpdisk.fh"
 c      write(6,*)'  sd_wyb'
-      w0_d25=vsq2
-      w0_d26=-1.0d0
-      w0_d27d=-vsq2
-      w0_d27v=-vsq2/2
-      w1_d27v=1.5d0*vsq2
-      w0_d28=-vsq2
-      w0_d29=-dsq2
-      w0_d30=-1.0d0
-      w0_d31=vsq2
-      w0_d32sd=vsq2/2
-      w1_d32sd=1.5d0*vsq2
-      w0_d32ds=-0.5d0
-      w1_d32ds=-1.5d0
 
 !      logic_sd=.true.
       call external_space_plpmode_value_sd()
 
       idisk_lp=idisk_array(11)
 
-      do lpblock=1,lpblock_sd
+      do lpb=1,lpblock_sd
         call read_lp()
         ipael=iml+17
         ipae =imr+1
@@ -1773,8 +1743,7 @@ c        enddo
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ia0=(lri-1)*norb_ext
       iabc0=(lri-1)*nabc
@@ -1851,8 +1820,7 @@ c        enddo
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ia0=(lri-1)*norb_ext
       iabc0=(lri-1)*nabc
@@ -1911,8 +1879,7 @@ c        value_lpext(ilwei)=(vint_ci(iposint2)+
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ia0=(lri-1)*norb_ext
       iabc0=(lri-1)*nabc
@@ -1967,8 +1934,7 @@ c        value_lpext(ilwei)=(vint_ci(iposint2)+
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ia0=(lri-1)*norb_ext
       ic=m_jd
@@ -2008,25 +1974,8 @@ c        value_lpext(ilwei)=(vint_ci(iposint2)+
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
 #include "lpextmode_h.fh"
-      common/lpdisk/idisk_lp,idisk_array(13)
-      data dzero/0.d0/dsq2/1.414213562373d0/
-      data dsq3/ 1.732050807569d0/
-      data dsq3vsq2/1.224744871392d0/
+#include "lpdisk.fh"
 c      write(6,*)'  td_wyb'
-      w0_d43=dsq3vsq2
-      w0_d44d=-dsq3vsq2
-      w1_d44d=dzero
-      w0_d44v=-dsq3/(2*dsq2)
-      w1_d44v=w0_d44v
-      w0_d45=dzero
-!     w1_d45=dsq3/dsq2
-!      w0_d46=dsq3/dsq2
-      w1_d45=dsq3vsq2
-      w0_d46=dsq3vsq2
-      w0_d47td=-dsq3/(dsq2*2)
-      w1_d47td=-w0_d47td
-      w0_d47dt=-0.5d0
-      w1_d47dt=-w0_d47dt
 
 !      logic_sd=.true.
       call external_space_plpmode_value_td()
@@ -2034,7 +1983,7 @@ c      write(6,*)'  td_wyb'
       call sd_ext_space_w01plp_value()
 
       idisk_lp=idisk_array(7)
-      do lpblock=1,lpblock_td
+      do lpb=1,lpblock_td
         call read_lp()
         ipael=iml+9
         ipae =imr+1
@@ -2874,11 +2823,9 @@ c        enddo
       subroutine gsd_ext_sequence(iltype,ilsm,irsm,lri)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *      m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ismnodes=ilsm
       ismnoded=irsm
-      ismsd=mul_tab(ismnodes,ismnoded)
       indl=0 !?
       if(iltype.eq.2)indl= 1+ismnodes
       if(iltype.eq.3)indl= 9+ismnodes
@@ -2935,11 +2882,9 @@ c        enddo
 #include "pl_structure_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *      m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       iwuplwei=jpad_upwei(jpadl)
-      iwuprwei=jpad_upwei(jpad)
       ilsegdownwei=iseg_downwei(ipael)
       irsegdownwei=iseg_downwei(ipae)
 
@@ -3026,11 +2971,9 @@ c        enddo
 #include "pl_structure_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *      m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       iwuplwei=jpad_upwei(jpadl)
-      iwuprwei=jpad_upwei(jpad)
       ilsegdownwei=iseg_downwei(ipael)
       irsegdownwei=iseg_downwei(ipae)
 
