@@ -14,7 +14,6 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine dd_ext_plpmode(ilnodesm,irnodesm)
 #include "drt_h.fh"
 #include "lpextmode_h.fh"
-      ilrsm=mul_tab(ilnodesm,irnodesm)
       logic_g36a=.false.
       logic_g36b=.false.
       logic_g1415=.false.
@@ -55,8 +54,7 @@ C Jul. 3, 2009 -BSUO- External space loops
 #include "drt_h.fh"
 #include "intsort_h.fh"
 
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       if ( isma .lt. ismb ) then
       ip3smabc=isma+jp2(ismb)+jp3(ismc)
       ip2cd=m_jc+(m_jd-1)*nlsm_ext(ismc)   !severe_new_error_1206
@@ -102,8 +100,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11a_t_diffsym(isma,ismb,ismc)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(ismc)+jp3(ismb)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       jdoffset=(m_jd-1)*nlsm_ext(ismb)
@@ -129,8 +126,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11b_t_diffsym(isma,ismb,ismc)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=ismc+jp2(isma)+jp3(ismb)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       jdoffset=(m_jd-1)*nlsm_ext(ismb)
@@ -157,8 +153,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g1112_t_symaaaa(isma,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(isma)+jp3(isma)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
 !
@@ -209,8 +204,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11a11b_t_symaacc(isma,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(isma)+jp3(ismc)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       num_smab=nlsm_ext(isma)
@@ -219,7 +213,6 @@ C Jul. 3, 2009 -BSUO- External space loops
       iasta=ibsm_ext(isma)
       iaend=iesm_ext(isma)
 
-      jb=0
       ibdpos=NGW2(m_jd)
       ipos_intbasetmp=ipos_intbasetmp+
      *            ibdpos*num_smab+NGW2(m_jc)*3
@@ -255,8 +248,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g36_t_ext(ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(id-1)*np3_abd_ext   !severe_new_
       iasta=ibsm_ext(ismc)
       ilwei=icnt_base+iwt_orb_ext(iasta,id)
@@ -272,8 +264,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g5_t_ext(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(ic-1)*np3_abd_ext
       ibsta=ibsm_ext(ismd)
       do ib=max(ic+1,ibsta),id-1
@@ -288,8 +279,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine   g9_t_ext(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(ic-1)*np3_abd_ext
       iasta=ibsm_ext(ismd)
       ilwei=icnt_base+iwt_orb_ext(iasta,ic)
@@ -347,9 +337,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g_dd_ext_sequence(ism)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      IPAE=1+ISM
+#include "gext_sequence.fh"
       icano_nnsta=2
       icnt_base=0
       iasta=ibsm_ext(ism)
@@ -372,10 +360,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g_ss_ext_sequence(ism,itype)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      IF(itype.eq.3) IPAE= 9+ism
-      IF(itype.eq.4) IPAE=17  +ism
+#include "gext_sequence.fh"
       icano_nnsta=2
       icnt_base=0
       do ismd=1,ng_sm
@@ -385,7 +370,6 @@ C Jul. 3, 2009 -BSUO- External space loops
          idsta=id_sta
          idend=iesm_ext(ismd)
          ic_sta=ibsm_ext(ismc)
-         icsta=ic_sta
          icend=iesm_ext(ismc)
          if ( ismd.eq.ismc ) idsta=idsta+1
          do id=idsta,idend
@@ -417,9 +401,7 @@ C Jul. 3, 2009 -BSUO- External space loops
                isma=mul_tab(ism,ismd)
                call g11a11b_symaacc(isma,ismd,ic,id)
             endif
-            ib=id
             call g10_ext(ismc,ic,id)
-            ia=ic
             call g5_ext(ismd,ic,id)
             if ( ism.eq.1 ) call g9_ext(ismd,ic,id)
             icnt_base=icnt_base+icano_nn-1
@@ -445,8 +427,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g12_diffsym(isma,ismb,ismc)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       if ( isma .lt. ismb ) then
       ip3smabc=isma+jp2(ismb)+jp3(ismc)
       ip2cd=m_jc+(m_jd-1)*nlsm_ext(ismc)      !severe_new_error_1206
@@ -492,8 +473,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11a_diffsym(isma,ismb,ismc)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(ismc)+jp3(ismb)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       jdoffset=(m_jd-1)*nlsm_ext(ismb)
@@ -519,8 +499,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11b_diffsym(isma,ismb,ismc)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=ismc+jp2(isma)+jp3(ismb)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       jdoffset=(m_jd-1)*nlsm_ext(ismb)
@@ -547,8 +526,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g1112_symaaaa(isma,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(isma)+jp3(isma)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
 !
@@ -600,8 +578,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g11a11b_symaacc(isma,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipsmabc=isma+jp2(isma)+jp3(ismc)
       ipos_intbasetmp=ip4_abcd_ext_base(ipsmabc)
       num_smab=nlsm_ext(isma)
@@ -610,7 +587,6 @@ C Jul. 3, 2009 -BSUO- External space loops
       iasta=ibsm_ext(isma)
       iaend=iesm_ext(isma)
 
-      jb=0
       ibdpos=NGW2(m_jd)
       ipos_intbasetmp=ipos_intbasetmp+
      *            ibdpos*num_smab+NGW2(m_jc)*3
@@ -646,8 +622,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g10_ext(ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(id-1)*np3_abd_ext   !severe_new_
       iasta=ibsm_ext(ismc)
       ilwei=icnt_base+iwt_orb_ext(iasta,id)
@@ -663,8 +638,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine g5_ext(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(ic-1)*np3_abd_ext
       ibsta=ibsm_ext(ismd)
       do ib=max(ic+1,ibsta),id-1
@@ -679,8 +653,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine   g9_ext(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       ipos_intbasetmp=ip3_abd_ext_base+(ic-1)*np3_abd_ext
       iasta=ibsm_ext(ismd)
       ilwei=icnt_base+iwt_orb_ext(iasta,ic)
@@ -696,8 +669,7 @@ C Jul. 3, 2009 -BSUO- External space loops
       subroutine   ext_lp_ab_s1(id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       parameter (   v_sqtwo=1.414213562373095d0 )
       ipos_intbasetmp=ip3_abd_ext_base+(id-1)*np3_abd_ext
       ilwei=icnt_base
@@ -738,8 +710,7 @@ C Jul. 3, 2009 -BSUO- External space loops
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       iabc0=(lri-1)*nabc
       ic=m_jd
@@ -766,8 +737,7 @@ C Jul. 3, 2009 -BSUO- External space loops
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       iabc0=(lri-1)*nabc
 
@@ -793,8 +763,7 @@ C Jul. 3, 2009 -BSUO- External space loops
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       iabc0=(lri-1)*nabc
 
@@ -1041,12 +1010,8 @@ C Jul. 3, 2009 -BSUO- External space loops
       w1g26b=-1.d0
 
       w0plp25=w0g25
-      w0plp25b=w0g25b
-      w1plp25b=w1g25b
       w0plp28=w0g28b
-      w1plp28=w1g28b
       w0plp26=w0g26b
-      w1plp26=w1g26b
 
       end
 
@@ -1328,10 +1293,8 @@ C              numint=(numb-1+ip2(numc))*numa
       subroutine g_dd_ext_sequence_G(ism)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
-      IPAE=1+ISM
+#include "gext_sequence.fh"
+#include "iaib.fh"
       icano_nnsta=2
       icnt_base=0
       iasta=ibsm_ext(ism)
@@ -1358,9 +1321,7 @@ C              numint=(numb-1+ip2(numc))*numa
       subroutine g_tt_ext_sequence_G(ism)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *      m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      IPAE=9+ism
+#include "gext_sequence.fh"
       icano_nnsta=2
       icnt_base=0
       do ismd=1,ng_sm
@@ -1370,7 +1331,6 @@ C              numint=(numb-1+ip2(numc))*numa
             idsta=id_sta
             idend=iesm_ext(ismd)
             ic_sta=ibsm_ext(ismc)
-            icsta=ic_sta
             icend=iesm_ext(ismc)
             if ( ismd.eq.ismc ) idsta=idsta+1
             do id=idsta,idend
@@ -1402,9 +1362,7 @@ C              numint=(numb-1+ip2(numc))*numa
                         isma=mul_tab(ism,ismd)
                         call g11a11b_t_symaacc_G(isma,ismd,ic,id)
                   endif
-                  ib=id
                   call g36_t_ext_G(ismc,ic,id)
-                  ia=ic
                   call g5_t_ext_G(ismd,ic,id)
                   if ( ism.eq.1 ) call g9_t_ext_G(ismd,ic,id)
                   icnt_base=icnt_base+icano_nn-1
@@ -1417,10 +1375,7 @@ C              numint=(numb-1+ip2(numc))*numa
       subroutine g_ss_ext_sequence_G(ism,itype)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      IF(itype.eq.3) IPAE= 9+ism
-      IF(itype.eq.4) IPAE=17  +ism
+#include "gext_sequence.fh"
       icano_nnsta=2
       icnt_base=0
       do ismd=1,ng_sm
@@ -1430,7 +1385,6 @@ C              numint=(numb-1+ip2(numc))*numa
          idsta=id_sta
          idend=iesm_ext(ismd)
          ic_sta=ibsm_ext(ismc)
-         icsta=ic_sta
          icend=iesm_ext(ismc)
          if ( ismd.eq.ismc ) idsta=idsta+1
          do id=idsta,idend
@@ -1462,9 +1416,7 @@ C              numint=(numb-1+ip2(numc))*numa
                isma=mul_tab(ism,ismd)
                call g11a11b_symaacc_G(isma,ismd,ic,id)
             endif
-            ib=id
             call g10_ext_G(ismc,ic,id)
-            ia=ic
             call g5_ext_G(ismd,ic,id)
             if ( ism.eq.1 ) then
                call g9_ext_G(ismd,ic,id)
@@ -1492,8 +1444,7 @@ C              numint=(numb-1+ip2(numc))*numa
       subroutine g12_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 !       write(nf2,*) 'g12_diff'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1551,8 +1502,7 @@ c Avoid unused argument warnings
       subroutine g11a_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
 !       write(nf2,*) 'g11a_diff'
       lrc=norb_number(ic)
@@ -1585,8 +1535,7 @@ c Avoid unused argument warnings
       subroutine g11b_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 !       write(nf2,*) 'g11b_diff'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1617,8 +1566,7 @@ c Avoid unused argument warnings
       subroutine g1112_symaaaa_G(isma,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 !       write(nf2,*) 'g1112_symaaaa'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1679,8 +1627,7 @@ c Avoid unused argument warnings
       subroutine g11a11b_symaacc_G(isma,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
 !       write(nf2,*) 'g11a11b_symaacc'
       lrc=norb_number(ic)
@@ -1726,9 +1673,8 @@ c Avoid unused argument warnings
       subroutine g10_ext_G(ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "iaib.fh"
+#include "gext_sequence.fh"
 !        write(nf2,*) 'g10_ext'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1752,9 +1698,8 @@ c Avoid unused argument warnings
       subroutine g5_ext_G(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
+#include "gext_sequence.fh"
+#include "iaib.fh"
 !        write(nf2,*) 'g5_ext'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1777,9 +1722,8 @@ c Avoid unused argument warnings
       subroutine g9_ext_G(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
+#include "gext_sequence.fh"
+#include "iaib.fh"
 !         write(nf2,*) 'g9_ext'
       lrc=norb_number(ic)
       lrd=norb_number(id)
@@ -1803,9 +1747,8 @@ c Avoid unused argument warnings
       subroutine ext_lp_ab_s1_G(id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
+#include "gext_sequence.fh"
+#include "iaib.fh"
       parameter (   v_sqtwo=1.414213562373095d0 )
 !         write(nf2,*) 'ext_lp_ab_s1'
       lrd=norb_number(id)
@@ -1861,8 +1804,7 @@ C  non-triangle <Ci|H|Cj> which designates that I > J.
       subroutine g12_t_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
 
@@ -1918,8 +1860,7 @@ c Avoid unused argument warnings
       subroutine g11a_t_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
 
@@ -1949,8 +1890,7 @@ c Avoid unused argument warnings
       subroutine g11b_t_diffsym_G(isma,ismb,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
 
@@ -1981,8 +1921,7 @@ c Avoid unused argument warnings
       subroutine g1112_t_symaaaa_G(isma,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
 
@@ -2042,8 +1981,7 @@ c Avoid unused argument warnings
       subroutine g11a11b_t_symaacc_G(isma,ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
 
@@ -2087,9 +2025,8 @@ c Avoid unused argument warnings
       subroutine g36_t_ext_G(ismc,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "iaib.fh"
+#include "gext_sequence.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
       iasta=ibsm_ext(ismc)
@@ -2112,9 +2049,8 @@ c Avoid unused argument warnings
       subroutine g5_t_ext_G(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
+#include "gext_sequence.fh"
+#include "iaib.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
       ibsta=ibsm_ext(ismd)
@@ -2136,9 +2072,8 @@ c Avoid unused argument warnings
       subroutine g9_t_ext_G(ismd,ic,id)
 #include "drt_h.fh"
 #include "intsort_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
-      COMMON /IAIB/ ICAN_A(MAX_ORB),ICAN_B(MTMP+MAX_ORB)
+#include "gext_sequence.fh"
+#include "iaib.fh"
       lrc=norb_number(ic)
       lrd=norb_number(id)
       iasta=ibsm_ext(ismd)
@@ -2163,10 +2098,8 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
-      ic=m_jd
       LRC=norb_number(m_jd)
 
       ibsta=ibsm_ext(ismb)
@@ -2198,10 +2131,8 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
-      ic=m_jd
       LRC=norb_number(m_jd)
       ibsta=ibsm_ext(ismb)
       ibend=iesm_ext(ismb)
@@ -2228,10 +2159,8 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
-      ic=m_jd
       LRC=norb_number(m_jd)
       ibsta=ibsm_ext(ismb)
       ibend=iesm_ext(ismb)
@@ -2260,8 +2189,7 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ic=m_jd
       lrc=norb_number(ic)
@@ -2361,8 +2289,7 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
 
       ic=m_jd
@@ -2392,10 +2319,8 @@ c Avoid unused argument warnings
       enddo
 
       ilwei=icnt_base+iwt_orb_ext(iasta,ic+1)
-      jb=m_jc
       do ib=ic+1,ibend
          LRB=norb_number(IB)
-         jb=jb+1
         do ia=iasta,iaend
            LRA=norb_number(IA)
          !g32a
@@ -2431,8 +2356,7 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ic=m_jd
       lrc=norb_number(ic)
@@ -2496,8 +2420,7 @@ c Avoid unused argument warnings
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "lpextmode_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *   m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ic=m_jd
       lrc=norb_number(ic)
