@@ -18,12 +18,12 @@
 
       subroutine inner_space_loop_g()
       implicit REAL*8 (a-h,o-z)
-      wsc0=c_time()
+c      wsc0=c_time()
       call dbl_space_loop_g()
-      wsc1=c_time()
+c      wsc1=c_time()
       call act_space_cloop_g()
       call act_space_ploop_g()
-      wsc2=c_time()
+c      wsc2=c_time()
 c      write(6,'(2x,2(a5,f12.4))')'dbl',wsc1-wsc0,'act',wsc2-wsc1
       return
       end
@@ -33,11 +33,12 @@ c      write(6,'(2x,2(a5,f12.4))')'dbl',wsc1-wsc0,'act',wsc2-wsc1
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
       if(norb_act.eq.0) return
-      ni=mod(norb_act,2)
-      do ipae=1,25
+      do ipae_=1,25
+        ipae=ipae_ ! ipae is in common block, is this necessary?
         jpae=nu_ae(ipae)
         if(jpae.eq.0) cycle
-        do jpad=1,mxnode
+        do jpad_=1,mxnode
+          jpad=jpad_ ! jpad is in common block, is this necessary?
           if(nu_ad(jpad).eq.0) cycle
           call seg_drt()
           if(ndim .eq. 0) cycle
@@ -54,17 +55,19 @@ c      write(6,'(2x,2(a5,f12.4))')'dbl',wsc1-wsc0,'act',wsc2-wsc1
 #include "pl_structure_h.fh"
 
       if(norb_act.eq.0) return
-      ni=mod(norb_act,2)
-      do ipae=1,25
+      do ipae_=1,25
+        ipae=ipae_ ! ipae is in common block, is this necessary?
         jpae=nu_ae(ipae)
         if(jpae.eq.0) cycle
-        do jpadl=1,mxnode                                ! jpadl
+        do jpadl_=1,mxnode                               ! jpadl
+          jpadl=jpadl_ ! jpadl is in common block, is this necessary?
           if(nu_ad(jpadl).eq.0) cycle
             jpad=jpadl
             call seg_drt()
             if(ndim .eq. 0) cycle
             call copy_to_drtl()
-          do jpad=1,mxnode                                !jpadr
+          do jpad_=1,mxnode                               !jpadr
+            jpad=jpad_ ! jpad is in common block, is this necessary?
             if(nu_ad(jpad).eq.0) cycle
             call seg_drt()
             if(ndim .eq. 0) cycle
@@ -128,7 +131,6 @@ c          write(6,'(6i6)')2,mh,lrai,lraj,lrak,0
 c-----------------------------------------------------------
 !line=3 a&r-b&r-d^r^r
           do lrak=lraj+1,norb_inn
-            list=list3(lrai,lraj,lrak)
            call head_ar_at_given_orb(mh,lrai)
             call link_c1_to_given_orb(mh,lrai+1,lraj-1)
             call link_b4_at_given_orb(mh,lraj)
@@ -150,7 +152,6 @@ c          write(6,'(6i6)')5,mh,lrai,lraj,lrak,0
           enddo
 c-----------------------------------------------------------
           do lrak=norb_dz+1,lrai-1
-            list=list3(lrai,lraj,lrak)
 !line=10 d&rr--b^r--a^r
             call head_drr_at_given_orb(mh,lrak)
             logic_br(1:mh)=.true.
@@ -354,12 +355,13 @@ c-----------------------------------------------------------
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
       dimension lpcoe(norb_dz+1:norb_inn)
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
       line=lin
       lrg=lrg0
       lrs=lrs0
       jph=0
-      do mhlp=1,mh
+      do mhlp_=1,mh
+        mhlp=mhlp_ ! mhlp is in common block, is this necessary?
         jpel=lpnew_ltail(mhlp)
         jper=lpnew_rtail(mhlp)
         jwl =lpnew_lwei(mhlp)
@@ -381,12 +383,13 @@ c-----------------------------------------------------------
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
       dimension lpcoe(norb_dz+1:norb_inn)
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
       parameter (two=2.0d+00,half=0.5d+00)
       line=lin
       lrg=lrg0
       lrs=lrs0
-      do mhlp=1,mh
+      do mhlp_=1,mh
+        mhlp=mhlp_ ! mhlp is in common block, is this necessary?
         jph =lpnew_head(mhlp)
         jpel=lpnew_ltail(mhlp)
         jper=lpnew_rtail(mhlp)
@@ -554,7 +557,7 @@ c-----------------------------------------------------------
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
 !td(13-1) (22)a&(23)
 !td(13-1) a&(23)c'(22)
 !td(13-2) a&(23)b&r(23)b^r(32)
@@ -615,7 +618,7 @@ c           call prodab_1(3,jpel,iwdl,iwdr,jwl,jwr,wl2,jper,list2,list3)
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
 !t1d1(15-1)  ar(13)-
 !t1d1(15-1)  ar(13)-c'(11)-
 
@@ -820,7 +823,7 @@ c-----------------------------------------------------------
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
       jmlr=mul_tab(jml,jmr)
       do lri=norb_frz+1,norb_dz
         lmi=lsm_inn(lri)
@@ -912,7 +915,7 @@ c           call prodab_1(3,jpel,iwdl,iwdr,jwl,jwr,wl2,jper,list2,list3)
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
       jmlr=mul_tab(jml,jmr)
       do lri=norb_frz+1,norb_dz
         lmi=lsm_inn(lri)
@@ -999,8 +1002,7 @@ c           call prodab_1(3,jpel,iwdl,iwdr,jwl,jwr,wl2,jper,list2,list3)
 
       subroutine ext_space_loop_g()
 #include "drt_h.fh"
-      common /gext_sequence/icnt_base,icano_nnsta,icano_nnend,
-     *      m_jc,m_jd, isegsta,isegupwei,isegdownwei
+#include "gext_sequence.fh"
 
       ism=0
       do inx=18,25
@@ -1037,7 +1039,7 @@ c           call prodab_1(3,jpel,iwdl,iwdr,jwl,jwr,wl2,jper,list2,list3)
 #include "intsort_h.fh"
 #include "pl_structure_h.fh"
       dimension lpcoe(norb_dz+1:norb_inn)
-      common/onepl/line,jph,jpel,jper,lrg,lrs,jwl,jwr,w0,w1
+#include "onepl.fh"
       lra=kk(jpel)-1
       jml=mod((jpadl-1),8)
       jmr=mod((jpad-1),8)
@@ -1333,7 +1335,6 @@ c            wl=(vlop0-vlop1)*vint_ci(list)-2*vlop0*vint_ci(list+1) !1.1
 !td(13-5) (22)d&&l(33)b^l(23)
 213   do lri=norb_frz+1,norb_dz
         lmi=lsm_inn(lri)
-        isma=lmi
         if(lmi.ne.jmlr) cycle
         w0td1=w0_td(1)
         w0td4=w0_td(4)
@@ -1584,14 +1585,14 @@ c         wl=wl+nocc*vlop0*(vint_ci(list+1)+tcoe*vint_ci(list))   !act_c
           call prodab_2(3,jpel,iwdl,iwdr,jwl,jwr,wl,jper,nxo)
 
          enddo
-          wl_430=0.d0
+c          wl_430=0.d0
           w0dv2=w0_dv(2)
           ni=mod(norb_dz-lrd,2)
           if(ni.eq.1) w0dv2=-w0dv2
          do lrk=1,lrd-1
 c            list=list3(lr0,lr,lrk)
             vlop0=w0*w0dv2
-c          wl_430=wl_430+vlop0*(vint_ci(list)-2*vint_ci(list+1))       !
+c            wl_430=wl_430+vlop0*(vint_ci(list)-2*vint_ci(list+1))
             wl=vlop0
          call trans_ijkl_intpos(lr,lrk,lr0,lrk,nxo)
           call prodab_2(3,jpel,iwdl,iwdr,jwl,jwr,wl,jper,nxo)
@@ -1653,8 +1654,8 @@ c         wl=wl+nocc*vlop0*(vint_ci(list+1)+tcoe*vint_ci(list))   !act_c
           call prodab_2(3,jpel,iwdl,iwdr,jwl,jwr,wl,jper,nxo)
 
          enddo
-          wl_430=0.d0
-            w0dv2=w0_d1v(2)
+c          wl_430=0.d0
+          w0dv2=w0_d1v(2)
           ni=mod(norb_dz-lrd,2)
           if(ni.eq.1) w0dv2=-w0dv2
          do lrk=1,lrd-1
