@@ -12,7 +12,7 @@
 #include "drt_h.fh"
 #include "intsort_h.fh"
 #include "files_gugaci.fh"
-      dimension idx(4)
+      dimension idx(4),idum(1)
       data zero/0.d0/
 
       idx=0
@@ -51,7 +51,8 @@ c --------     vtint(*)-->vint_ci(*)    ------------
       call idafile(luciint,1,idx,4,idisk)
       idx(1)=idisk
       numb=numb-1
-      call idafile(luciint,1,[numb],1,idisk)
+      idum(1)=numb
+      call idafile(luciint,1,idum,1,idisk)
       call ddafile(luciint,1,vint_ci,numb,idisk)
       write(6,902) numb
       maxintseg=numb
@@ -62,7 +63,8 @@ c --------     vtint(*)-->vint_ci(*)    ------------
       call int_sort_inn_3(numb)       !_ext_1    (ijka)
       idx(2)=idisk
       numb=numb-1
-      call idafile(luciint,1,[numb],1,idisk)
+      idum(1)=numb
+      call idafile(luciint,1,idum,1,idisk)
       call ddafile(luciint,1,vint_ci,numb,idisk)
       write(6,903) numb
       if(numb.gt.maxintseg) then
@@ -92,7 +94,8 @@ c  sum over iaqq
       call int_sort_inn_2(numb)   !_ext_2_1  (ijcc, ijab, abkk)
       idx(3)=idisk
       numb=numb-1
-      call idafile(luciint,1,[numb],1,idisk)
+      idum(1)=numb
+      call idafile(luciint,1,idum,1,idisk)
       call ddafile(luciint,1,vint_ci,numb,idisk)
       write(6,904) numb
       if(numb.gt.maxintseg) then
@@ -117,7 +120,8 @@ c  sum over (abkk)
       call int_sort_ext(numb)         !_ext_4_3_2  (abcd,abcc,aabb)
       idx(4)=idisk
       numb=numb-1
-      call idafile(luciint,1,[numb],1,idisk)
+      idum(1)=numb
+      call idafile(luciint,1,idum,1,idisk)
       call ddafile(luciint,1,vint_ci,numb,idisk)
       write(6,905) numb
       if(numb.gt.maxintseg) then
@@ -572,7 +576,6 @@ c      write(10,*)'     start intind_iaqq',ii
       call determine_para_array_for_int1ind()
 
       do lri=norb_frz+1,norb_inn
-        li=lri-norb_frz
         lsmi=lsm_inn(lri)
         call int_ext_3_2_1(lri,lsmi,ii)
       enddo
@@ -653,7 +656,7 @@ c      la<lb<lc<ld
             do 40 la = norb_inn,lb+1,-1
               if(lsm_inn(la).ne.msa) cycle
               nolra=nolra+1
-              list = loijk(njkl)+3*(nolra-1)
+c              list = loijk(njkl)+3*(nolra-1)
 
 c        write(6,'(2x,4i3,2i7)')  la,lb,lc,ld,list,numb
 
