@@ -24,9 +24,6 @@
 #include "print.fh"
 #include "real.fh"
       REAL*8 Fm(nT,0:mHigh), T(nT)
-*
-      iRout = 53
-      iPrint = nPrint(iRout)
 *
       Call HighFm(Fm(1,mHigh),T,mHigh,nT)
 *
