@@ -8,6 +8,8 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
+#include "compiler_features.h"
+#ifdef _IN_MODULE_
       Subroutine DeDe_SCF(Dens,TwoHam,nDens,mDens)
       use k2_arrays
       use Basis_Info, only: nBas
@@ -75,4 +77,12 @@
          pFq => Twoham(:)
       End If
 
-      End
+      End Subroutine DeDe_SCF
+
+#elif !defined (EMPTY_FILES)
+
+! Some compilers do not like empty files
+#include "macros.fh"
+      dummy_empty_procedure(DeDe_SCF)
+
+#endif
