@@ -14,19 +14,11 @@
       use Sizes_of_Seward, only: S
       Implicit Real*8 (a-h,o-z)
 #include "Molcas.fh"
-#include "Basis_Mode_Parameters.fh"
 #include "Basis_Mode.fh"
 #include "disp.fh"
 *
       Integer iSD(0:nSD,mSkal)
-      Logical  TF, TstFnc
-*                                                                      *
-************************************************************************
-*                                                                      *
-*     Statement functions
-*
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
+      Logical, External :: TF
 *                                                                      *
 ************************************************************************
 *                                                                      *
