@@ -12,19 +12,21 @@
      &                     nr_of_Densities)
       use k2_arrays
       Implicit Real*8 (a-h,o-z)
-#include "WrkSpc.fh"
-#include "k2.fh"
 *
       ipDij = ipOffD(1,ijS)
       mDCRij= ipOffD(2,ijS)
       nDij  = ipOffD(3,ijS)
-      ipDSij= ip_Dummy
-      If (nr_of_Densities.eq.2) ipDSij=ipOffD(4,ijS)
+      If (nr_of_Densities.eq.2) Then
+         ipDSij=ipOffD(4,ijS)
+      Else
+         ipDSij= 1
+      End If
+*
       If (mDCRij*nDij.ne.0) Then
          ipDDij = ipTmp
          ipTmp = ipTmp + nDij*mDCRij
       Else
-         ipDDij = ip_Dummy
+         ipDDij = 1
       End If
 *
       Return
