@@ -80,7 +80,7 @@
 #include "setup.fh"
 #include "status.fh"
 *
-      Common /ibas_ricd/ jbas_, lbas_
+#include "ibas_ricd.fh"
 *     local variables to save
       Integer ipDDij,ipDDkl,ipDDik,ipDDil,ipDDjk,ipDDjl,
      &        iBsInc,jBsInc,kBsInc,lBsInc,iPrInc,jPrInc,kPrInc,lPrInc,
@@ -334,13 +334,6 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     FacInt : scaling factor for the integrals passed down to         *
-*              Integ_Proc                                              *
-*
-      FacInt=1.0D0
-*                                                                      *
-************************************************************************
-*                                                                      *
 *     These loops will partition the contraction loops if there is not
 *     enough memory to store the whole SO/AO-block simultaneously. The
 *     memory partitioning is determined by PSOAO0.
