@@ -19,6 +19,7 @@
 *             University of Lund, SWEDEN                               *
 *             January 1992                                             *
 ************************************************************************
+      Use Iso_C_Binding
       use Real_Spherical
       use Her_RW
       use External_Centers
@@ -33,11 +34,7 @@
 #include "nq_info.fh"
 #include "status.fh"
       Logical DoRys
-      Integer iix(2)
-      Real*8 rix(2)
 #include "SysDef.fh"
-      nbyte_i = iiloc(iix(2)) - iiloc(iix(1))
-      nbyte_r = idloc(rix(2)) - idloc(rix(1))
 *
       Call GetInf_Internal(cRFStrt,iRFStrt,lRFStrt,rRFStrt,
      &                     cQStrt,iQStrt,rQStrt)
@@ -46,7 +43,6 @@
       Contains
       SubRoutine GetInf_Internal(cRFStrt,iRFStrt,lRFStrt,rRFStrt,
      &                           cQStrt,iQStrt,rQStrt)
-      Use Iso_C_Binding
       Integer, Target :: cRFStrt,iRFStrt,lRFStrt,cQStrt,iQStrt
       Real*8, Target :: rRFStrt,rQStrt
       Integer, Pointer :: p_cRF(:),p_iRF(:),p_lRF(:),p_cQ(:),p_iQ(:)
@@ -66,23 +62,19 @@
 *                                                                      *
 *     Reaction field parameters
 *
-      Len = ilLoc(lRFEnd)-ilLoc(lRFStrt)
-      Len = (Len+nByte_i)/nByte_i
+      Len = ip_of_iWork(lRFEnd)-ip_of_iWork(lRFStrt)+1
       Call C_F_Pointer(C_Loc(lRFStrt),p_lRF,[Len])
       Call Get_iArray('RFlInfo',p_lRF,Len)
 *
-      Len = idLoc(rRFEnd)-idLoc(rRFStrt)
-      Len = (Len+nByte_r)/nByte_r
+      Len = ip_of_Work(rRFEnd)-ip_of_Work(rRFStrt)+1
       Call C_F_Pointer(C_Loc(rRFStrt),p_rRF,[Len])
       Call Get_dArray('RFrInfo',p_rRF,Len)
 *
-      Len = iiLoc(iRFEnd)-iiLoc(iRFStrt)
-      Len = (Len+nByte_i)/nByte_i
+      Len = ip_of_iWork(iRFEnd)-ip_of_iWork(iRFStrt)+1
       Call C_F_Pointer(C_Loc(iRFStrt),p_iRF,[Len])
       Call Get_iArray('RFiInfo',p_iRF,Len)
 *
-      Len = iiLoc(cRFEnd)-iiLoc(cRFStrt)
-      Len = (Len+nByte_i)/nByte_i
+      Len = ip_of_iWork(cRFEnd)-ip_of_iWork(cRFStrt)+1
       Call C_F_Pointer(C_Loc(cRFStrt),p_cRF,[Len])
       Call Get_iArray('RFcInfo',p_cRF,Len)
 *
@@ -92,18 +84,15 @@
 *                                                                      *
 *     Numerical integration information and parameters
 *
-      Len = idLoc(rQEnd)-idLoc(rQStrt)
-      Len = (Len+nByte_r)/nByte_r
+      Len = ip_of_Work(rQEnd)-ip_of_Work(rQStrt)+1
       Call C_F_Pointer(C_Loc(rQStrt),p_rQ,[Len])
       Call Get_dArray('Quad_r',p_rQ,Len)
 *
-      Len = iiLoc(iQEnd)-iiLoc(iQStrt)
-      Len = (Len+nByte_i)/nByte_i
+      Len = ip_of_iWork(iQEnd)-ip_of_iWork(iQStrt)+1
       Call C_F_Pointer(C_Loc(iQStrt),p_iQ,[Len])
       Call Get_iArray('Quad_i',p_iQ,Len)
 *
-      Len = iiLoc(cQEnd)-iiLoc(cQStrt)
-      Len = (Len+nByte_i)/nByte_i
+      Len = ip_of_iWork(cQEnd)-ip_of_iWork(cQStrt)+1
       Call C_F_Pointer(C_Loc(cQStrt),p_cQ,[Len])
       Call Get_iArray('Quad_c',p_cQ,Len)
 *
