@@ -49,7 +49,10 @@
       Character ChOper(0:7)*3, Label*8, dbas*(LENIN)
       Integer nOp(2), lOper(nComp), iChO(nComp),
      &        iDCRR(0:7), iDCRT(0:7), iStabM(0:7), iStabO(0:7)
-      Logical Do_PGamma,NATEST
+      Logical Do_PGamma
+#ifdef _GEN1INT_
+      Logical NATEST, DO_TRAN
+#endif
       Real*8  SOInt(l_SOInt)
       Integer iTwoj(0:7), i
       Data iTwoj/1,2,4,8,16,32,64,128/
@@ -71,8 +74,7 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     Kamal Sharkas  01/29/2015
-      If (Label(1:4).eq.'PSOI') Then !  PSO Integrals
+      If (Label(1:3).eq.'MAG') Then
       iCmp   = iSD( 2,iS)
       iBas   = iSD( 3,iS)
       iAO    = iSD( 7,iS)
@@ -158,21 +160,26 @@
         Call Get_nAtoms_All(nAtoms)
         l_Coord=3*nAtoms
         Call Get_dArray('Bfn Coordinates',Coord,l_Coord)
-         NATEST=.false.
         if (nAtoms.eq.2) then
          nAtoms=nAtoms+1
-         NATEST=.true.
-         endif
+        endif
 #ifdef _GEN1INT_
-        call test_f90mod_sgto_pso(iShell,jShell,iCmp,jCmp,
-     &                                     iBas,jBas,iAng,jAng,
-     &                                     iPrim,jPrim,mdci,mdcj,
-     &                                     Shells(iShll)%Exp,
-     &                                     Shells(jShll)%Exp,
-     &                                     Shells(iShll)%Cff_c(1,1,2),
-     &                                     Shells(jShll)%Cff_c(1,1,2),
-     &                                     nAtoms,NATEST,
-     &                                     Coord,nPSOI,Final)
+        NATEST=(nAtoms.eq.2)
+        If (label(4:5).eq.'PX') Then
+            Do_Tran = .TRUE.
+        Else
+            Do_Tran = .FALSE.
+        End If
+        read(Label(6:),'(I3)') iatom
+        call test_f90mod_sgto_mag(iShell,jShell,iCmp,jCmp,
+     &                            iPrim,jPrim,iAng,jAng,
+     &                            iPrim,jPrim,mdci,mdcj,
+     &                            Shells(iShll)%Exp,Shells(jShll)%Exp,
+     &                            Shells(iShll)%Cff_p(1,1,2),
+     &                            Shells(jShll)%Cff_p(1,1,2),
+     &                            nAtoms,
+     &                            Coord,nComp,Final,.TRUE.,
+     &                            iatom,Do_Tran)
 #else
          Call WarningMessage(2,
      &   'OneEl_IJ: NO Gen1int interface available!')
@@ -201,8 +208,7 @@
          End Do
       End If
 
-         else  !  PSO Integrals
-*   Kamal Sharkas 01/29/2015
+         else  !  MAG Integrals
 
 *                                                                      *
 ************************************************************************
