@@ -32,7 +32,6 @@
       use RICD_Info, only: Do_RI
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
-#include "Basis_Mode_Parameters.fh"
 #include "Basis_Mode.fh"
 #include "print.fh"
 #include "real.fh"
@@ -53,17 +52,17 @@
 ************************************************************************
 *                                                                      *
 *
-!      write(*,*)"Print out in integral_util/pget0 starting"
-!      Call RecPrt('DSO in PGet0',' ',D0,ndens,5)  ! ====== yma ======
+!     write(*,*)"Print out in integral_util/pget0 starting"
+!     Call RecPrt('DSO in PGet0',' ',D0,ndens,5)  ! ====== yma ======
 
       PMax=One
       nSA=1
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*       RASSCF wavefunction
+*     RASSCF wavefunction
 *
-        If (lPSO) Then
+      If (lPSO) Then
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -181,7 +180,6 @@
             Call abend()
          End If
 *
-         iComp = 1
          If (nIrrep.eq.1) Then
             kOp(1) = 0
             kOp(2) = 0
