@@ -29,11 +29,10 @@
       use k2_arrays, only: Sew_Scr
       use lw_Info
       use REal_Info, only: ThrInt
+      use sort_data, only: DimSyB, lSll
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "print.fh"
-#include "srt0.fh"
-#include "srt1.fh"
 *
       Real*8 AOint(ijkl,iCmp,jCmp,kCmp,lCmp)
       Integer iShell(4), iAO(4), kOp(4), iAOst(4), iSOs(4)
