@@ -34,11 +34,9 @@
 #include "rmat.fh"
 #include "gam.fh"
 #include "real.fh"
-#include "relae.fh"
 #include "FMM.fh"
 #include "nac.fh"
 #include "srint.fh"
-      Logical lGENINT
       Character(LEN=180) Env
 *                                                                      *
 ************************************************************************
@@ -62,9 +60,6 @@ C
       Seward_Status=InActive
 *
 *-----LInfo
-*
-      IRFLAG1=0
-      lGENINT=.False.
 *
       Call GetEnvF('MOLCAS_NEW_DEFAULTS', Env)
       Call UpCase(Env)
@@ -115,9 +110,6 @@ C
 *
       NDDO=.False.
 *
-      GT_Status=InActive
-      T_Status =InActive
-      PP_Status=InActive
       k2_Status=InActive
       RctFld_Status=InActive
       ERI_Status=InActive
@@ -152,10 +144,6 @@ C
 *---- gam.fh
 *
       lgamma = 9
-*
-*     relae.fh
-*
-      irelae=-1
 *
       Call DCR_Init()
 *
