@@ -32,9 +32,8 @@
       Real*8 CGrad(3,MxAtom)
       Dimension GradIn(nGrad)
       Character CNames(MxAtom)*(LENIN5)
-      Logical TF,TstFnc
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
+      Logical, External :: TF
+*
       mdc=0
       iIrrep=0
 *
