@@ -28,11 +28,11 @@
 
 #include "glbbas.fh"
 #include "rasscf_lucia.fh"
-#include "warnings.fh"
+#include "warnings.h"
 *.Scratch : A character line
 *
 *.    No floating point underflow
-      CALL XUFLOW
+      !CALL XUFLOW
 *. Assign diskunits
 c      IF (ENVIRO(1:6) .EQ. 'RASSCF') THEN
          CALL DISKUN2
@@ -77,12 +77,6 @@ c      IF(PNTGRP.GT.1) CALL MLSM(IREFSM,IREFPA,IREFSM,'CI',1)
         WRITE(6,*) ' End of calculation without integrals'
         CALL QUIT(_RC_ALL_IS_WELL_)
       END IF
-*
-*. Last space where CI vectors were stored
-*
-      ISTOSPC = 0
-      IF(IRESTR.EQ.1) ISTOSPC = 1
-      IRESTR_ORIG=IRESTR
 *
       LBLOCK = MXSOOB
       LBLOCK = MAX(LBLOCK,LCSBLK)
