@@ -25,7 +25,6 @@
 #include "buffer.fh"
 #include "disp.fh"
 #include "disp2.fh"
-#include "WrkSpc.fh"
 *
       Real*8 rIn(ibas*icmp*jbas*jcmp,0:nIrrep-1,
      &       nAco*(1+naco)/2,*)
@@ -88,7 +87,6 @@
 *
 *           Symmetry of Q matrix
 *
-            iis=nropr(ieor(iOper(jIrr),ioper(mIrr)))
             jis=nropr(ieor(iOper(iIrr),ioper(mIrr)))
 *
             lMax=nAsh(lIrr)
