@@ -42,7 +42,6 @@
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "print.fh"
 #include "disp.fh"
 
@@ -55,8 +54,6 @@
       Integer Index(3,4)
 
       nelem(ixyz) = (ixyz+1)*(ixyz+2)/2
-      iprint =0
-
 
       nZeta = nAlpha*nBeta
       call dcopy_(nZeta*nElem(la)*nElem(lb)*6,
