@@ -45,8 +45,7 @@
       External Kernel, KrnlMm
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-c#include "print.fh"
+#include "stdalloc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 #include "nsd.fh"
@@ -54,18 +53,19 @@ c#include "print.fh"
 * log trans   integer dcent
       Real*8 A(3), B(3), RB(3),CCoor(3)
       Character Label*8
-      Integer nOp(2), ip(8),ipc(0:7),
+      Integer nOp(2), ip(8),
      &          iDCRR(0:7), iDCRT(0:7), iStabM(0:7), iStabO(0:7),
      &          IndGrd(0:7)
-      Logical AeqB,TstFnc,TF,IfGrd(3,2),EQ,DiffOP,DiffCnt,Trans(2)
-      Integer iTwoj(0:7)
-      Character*8 Lab_dsk
-      Data iTwoj/1,2,4,8,16,32,64,128/
+      Logical IfGrd(3,2),EQ,DiffOP,DiffCnt,Trans(2)
+      Integer, Parameter:: iTwoj(0:7)=[1,2,4,8,16,32,64,128]
+      Character(LEN=8) Lab_dsk
+      Real*8, Allocatable:: Zeta(:), ZI(:), PCoor(:,:), Kappa(:),
+     &                      Kern(:), Fnl(:), ScrSph(:), SO(:),
+     &                      Integrals(:), Scr(:)
+      Logical, External :: TF
 *
-*     Statement functions
+*     Statement function
 *
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *
 *-----Compute the number of blocks from each component of the operator
@@ -75,11 +75,6 @@ c#include "print.fh"
       Call FZero(CCoor,3)
       Call iCopy(nIrrep,[0],0,IndGrd,1)
       loper=0
-      ii=1
-      Do i=0,nirrep-1
-         ipC(i)=ii
-         ii=ii+nBas(i)**2
-      End Do
       nnIrrep=nIrrep
       If (sIrrep) nnIrrep=1
       Do iIrrep=0,nnIrrep-1
@@ -98,15 +93,23 @@ c#include "print.fh"
       End Do
       nIC=0
       If (loper.eq.0) Return
+
       Call ICopy(nIrrep,[0],0,ip,1)
+
+      iStart=1
       Do iIrrep =0,nIrrep-1
          If (iAnd(2**iIrrep,loper).ne.0) Then
             LenInt=nFck(iIrrep)
             nIc=nIC+1
-            Call GetMem(Label,'ALLO','REAL',ip(NIC),LenInt)
-            call dcopy_(LenInt,[Zero],0,Work(ip(nIC)),1)
+            ip(NIC)=iStart
+            iStart=iStart+LenInt
          End If
       End Do
+      LenInt_Tot=iStart - 1
+      Call mma_allocate(Integrals,LenInt_Tot,Label='Integrals')
+      Integrals(:)=Zero
+
+
       Call SOS(iStabO,nStabO,1)
 *
 *-----Auxiliary memory allocation.
@@ -154,47 +157,43 @@ c#include "print.fh"
 *       memory internally.
 *
         maxi=S%maxPrm(iAng)*S%maxprm(jang)
-        Call GetMem('Zeta','ALLO','REAL',iZeta,maxi)
-        Call GetMem('Zeta','ALLO','REAL',ipZI ,Maxi)
-        Call GetMem('Kappa','ALLO','REAL',iKappa,Maxi)
-        Call GetMem('PCoor','ALLO','REAL',iPCoor,Maxi*3)
+        Call mma_allocate(Zeta,maxi,Label='Zeta')
+        Call mma_allocate(ZI,maxi,Label='ZI')
+        Call mma_allocate(Kappa,maxi,Label='Kappa')
+        Call mma_allocate(PCoor,maxi,3,Label='PCoor')
         Call KrnlMm(nOrder,MemKer,iAng,jAng,nOrdOp)
 *
 *       Memory requirements for contraction and Symmetry
 *       adoption of derivatives.
 *
-        MaxP= Max(S%MaxPrm(iAng),S%MaxPrm(jAng))
-        MaxZeta=S%MaxPrm(iAng)*S%MaxPrm(jAng)
-        MaxB= Max(S%MaxBas(iAng),S%MaxBas(jAng))
         lFinal = S%MaxPrm(iAng) * S%MaxPrm(jAng) *
      &           nElem(iAng)*nElem(jAng)*nIrrep
 *
         MemKrn=Max(MemKer*Maxi,lFinal)
-        Call GetMem('Kernel','ALLO','REAL',iKern,MemKrn)
+        Call mma_allocate(Kern,MemKrn,Label='Kern')
 *
-*            Save some memory and use Scrt area for
-*            transformation
+*       Save some memory and use Scrt area for
+*       transformation
 *
 *       Allocate memory for the final integrals all in the
 *       primitive basis.
 *
-        Call GetMem('Final','ALLO','REAL',ipFnl,lFinal)
+        Call mma_allocate(Fnl,lFinal,Label='Fnl')
 *
 *       Scratch area for the transformation to spherical gaussians
 *
         nScr1=S%MaxBas(iAng)*S%MaxBas(jAng)*nElem(iAng)*nElem(jAng)*nIC
-        Call GetMem('ScrSph','ALLO','REAL',iScrt1,nScr1)
+        Call mma_allocate(ScrSph,nScr1,Label='ScfSph')
 *
 *         At this point we can compute Zeta.
 *         This is now computed in the ij or ji order.
 *
-          Call ZXia(Work(iZeta),Work(ipZI),
+          Call ZXia(Zeta,ZI,
      &              iPrim,jPrim,Shells(iShll)%Exp,
      &                          Shells(jShll)%Exp)
 *
             DiffCnt=(mdci.eq.iDCnt).or.(mdcj.eq.iDCnt)
             If ((.not.DiffCnt).and.(.not.DiffOp)) Goto 131
-            AeqB = iS.eq.jS
             Call lCopy(6,[.false.],0,IfGrd,1)
             Call lCopy(2,[.false.],0,trans,1)
             If (mdci.eq.iDCnt) Then
@@ -223,8 +222,8 @@ c#include "print.fh"
             End Do
 c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
             If (nSO.eq.0) Go To 131
-            Call GetMem(' SO ','ALLO','REAL',ipSO,nSO*iBas*jBas)
-            call dcopy_(nSO*iBas*jBas,[Zero],0,Work(ipSO),1)
+            Call mma_allocate(SO,iBas*jBas*nSO,Label='SO')
+            SO(:)=Zero
 *
 *           Find the DCR for A and B
 *
@@ -263,17 +262,17 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
 *
              Call Setup1(Shells(iShll)%Exp,iPrim,
      &                   Shells(jShll)%Exp,jPrim,
-     &                   A,RB,Work(iKappa),Work(iPCoor),Work(ipZI))
+     &                   A,RB,Kappa,PCoor,ZI)
 *
 *            Compute AO integrals.
 *            for easy implementation of NA integrals.
 *
              Call Kernel(Shells(iShll)%Exp,iPrim,
      &                   Shells(jShll)%Exp,jPrim,
-     &                   Work(iZeta),Work(ipZI),
-     &                   Work(iKappa),Work(iPCoor),
-     &                   Work(ipFnl),iPrim*jPrim,
-     &                   iAng,jAng,A,RB,nOrder,Work(iKern),
+     &                   Zeta,ZI,
+     &                   Kappa,PCoor,
+     &                   Fnl,iPrim*jPrim,
+     &                   iAng,jAng,A,RB,nOrder,Kern,
      &                   MemKrn,Ccoor,nOrdOp,IfGrd,IndGrd,nop,
      &                   dc(mdci)%nStab,
      &                   dc(mdcj)%nStab,nic,idcar,idcnt,
@@ -290,17 +289,17 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
              kk=nElem(iAng)*nElem(jAng)*nIC
              Call DGEMM_('T','N',
      &                   jPrim*kk,iBas,iPrim,
-     &                   1.0d0,Work(ipFnl),iPrim,
+     &                   1.0d0,Fnl,iPrim,
      &                         Shells(iShll)%pCff,iPrim,
-     &                   0.0d0,Work(iKern),jPrim*kk)
+     &                   0.0d0,Kern,jPrim*kk)
 *
 *            Transform j,abxI to abxI,J
 *
              Call DGEMM_('T','N',
      &                   kk*iBas,jBas,jPrim,
-     &                   1.0d0,Work(iKern),jPrim,
+     &                   1.0d0,Kern,jPrim,
      &                         Shells(jShll)%pCff,jPrim,
-     &                   0.0d0,Work(ipFnl),kk*iBas)
+     &                   0.0d0,Fnl,kk*iBas)
 *
 *            Transform to spherical gaussians if needed.
 *
@@ -310,26 +309,26 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
 *
 *             Result comes back as IJAB or IJAb
 *
-                   Call CarSph(Work(ipFnl),kk,iBas*jBas*nIC,
-     &                    Work(iKern),nScr1,
+                   Call CarSph(Fnl,kk,iBas*jBas*nIC,
+     &                         Kern,nScr1,
      &                    RSph(ipSph(iAng)),iAng,
      &                    Shells(iShll)%Transf,
      &                    Shells(iShll)%Prjct,
      &                    RSph(ipSph(jAng)),jAng,
      &                    Shells(jShll)%Transf,
-     &                    Shells(jShll)%Prjct,Work(iScrt1),iCmp*jCmp)
+     &                    Shells(jShll)%Prjct,ScrSph,iCmp*jCmp)
 *
-                  Call DGeTmO(Work(iScrt1),nIC,nIC,
-     &                    iBas*jBas*iCmp*jCmp,
-     &                    Work(iKern),iBas*jBas*iCmp*jCmp)
+                  Call DGeTmO(ScrSph,nIC,nIC,
+     &                        iBas*jBas*iCmp*jCmp,
+     &                        Kern,iBas*jBas*iCmp*jCmp)
 
 *
                 Else
 *
 *             Transpose abx,IJ back to IJ,abx
 *
-                    Call DGeTmO(Work(ipFnl),kk*nIC,kk*nIC,
-     &                   iBas*jBas,Work(iKern),iBas*jBas)
+                    Call DGeTmO(Fnl,kk*nIC,kk*nIC,
+     &                   iBas*jBas,Kern,iBas*jBas)
                 End If
 *
 *            At this point accumulate the batch of integrals onto the
@@ -337,12 +336,12 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
 *
 *               If (iPrint.ge.99) Then
 *                 Call RecPrt (' Accumulated SO integrals, so far...',
-*    &                               ' ',Work(ipSO),iBas*jBas,nSO)
+*    &                               ' ',SO,iBas*jBas,nSO)
 *               End If
 *
 *------------Symmetry adapt component by component
 *
-             iSOBlk = ipSO
+             iSOBlk = 1
              iIC=1
              Do iIrrep = 0, nIrrep-1
                 iSmLbl=iAnd(lOper,iTwoj(iIrrep))
@@ -354,8 +353,8 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
                 Else
                    Call SymAd1(iSmLbl,iAng,jAng,iCmp,jCmp,
      &                         iShell,jShell,iShll,jShll,iAO,jAO,
-     &                         Work(iKern),iBas,jBas,nIC,iIC,
-     &                         Work(iSOBlk),mSO,nOp)
+     &                         Kern,iBas,jBas,nIC,iIC,
+     &                         SO(iSOBlk),mSO,nOp)
                    iSOBlk = iSOBlk + mSO*iBas*jBas
                 End If
              End Do
@@ -364,12 +363,12 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
 *
 *           Multiply with factors due to projection operators
 *
-           If (Fact.ne.One) Call DScal_(nSO*iBas*jBas,Fact,Work(ipSO),1)
+           If (Fact.ne.One) Call DScal_(nSO*iBas*jBas,Fact,SO,1)
 *
 *           Scatter the SO's on to the non-zero blocks of the
 *           lower triangle.
 *
-             iSOBlk=ipSO
+             iSOBlk=1
              iIC=0
              Do  iIrrep = 0, nIrrep-1
                If (iAnd(lOper,2**iIrrep).ne.0) Then
@@ -377,34 +376,33 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
                  iiC=iiC+1
                  mSO=MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
                  If (nfck(iirrep).ne.0.and.mSO.ne.0)
-     &            Call SOSctt(Work(iSOBlk),iBas,jBas,mSO,
-     &                    Work(ip(iIC)),nFck(iIrrep),iSmLbl,
+     &            Call SOSctt(SO(iSOBlk),iBas,jBas,mSO,
+     &                    Integrals(ip(iIC)),nFck(iIrrep),iSmLbl,
      &                    iCmp,jCmp,iShell,jShell,
      &                    iAO,jAO,nIC,Label,2**iIrrep,rHrmt)
                  iSOBlk = iSOBlk + mSO*iBas*jBas
                End If
              End Do
 *
-            Call GetMem('  SO ','FREE','REAL',ipSO,nSO*iBas*jBas)
+            Call mma_deallocate(SO)
  131        Continue
-        Call GetMem('Kappa','FREE','REAL',iKappa,Maxi)
-        Call GetMem('PCoor','FREE','REAL',iPCoor,Maxi*3)
-        Call GetMem('Zeta','FREE','REAL',ipZI ,Maxi)
-        Call GetMem('Zeta','FREE','REAL',iZeta,Maxi)
-        Call GetMem('ScrSph','Free','REAL',iScrt1,nScr1)
-        Call GetMem('Final','FREE','REAL',ipFnl,lFinal)
-        Call GetMem('Kernel','FREE','REAL',iKern,MemKrn)
+         Call mma_deallocate(pCoor)
+         Call mma_deallocate(Kappa)
+         Call mma_deallocate(ZI)
+         Call mma_deallocate(Zeta)
+         Call mma_deallocate(ScrSph)
+         Call mma_deallocate(Fnl)
+         Call mma_deallocate(Kern)
+
          End Do
       End Do
+
       Call Free_iSD()
 *
 *     Compute properties or write integrals to disc and
 *     deallocate core.
 *
-      ipOut = 0
-      mDim = 0
       nDens=0
-      ipNuc = 0
       ndenssq=0
       Do iI=0,nIrrep-1
          ndenssq=ndenssq+nbas(ii)**2
@@ -412,7 +410,7 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
       End Do
       nrOp=0
 
-      Call Getmem('Temp','ALLO','REAL',ipscr,ndenssq)
+      Call mma_allocate(Scr,ndenssq,Label='Scr')
       Do 16 iIrrep = 0, nIrrep-1
          iSmLbl = 2**iIrrep
          If (iAnd(ismLbl,loper).ne.0) Then
@@ -423,26 +421,23 @@ c           If (iPrint.ge.29) Write (*,*) ' nSO=',nSO
             If (iadd.ne.0) Then
                irc=-1
                iopt=0
-               iipscr=ip_of_iWork_d(work(ipscr))
-               call rdmck(irc,iOpt,Lab_dsk,jdisp,iwork(iipscr),koper)
-               If (irc.ne.0)
-     & Call SysAbendMsg('cnt1el2','error during read in rdmck',' ')
-               call daxpy_(nfck(iirrep),one,
-     &                    work(ipscr),1,
-     &                   work(ip(nrop)),1)
+               call drdmck(irc,iOpt,Lab_dsk,jdisp,Scr,koper)
+               If (irc.ne.0) Call SysAbendMsg('cnt1el2',
+     &                                 'error during read in rdmck',' ')
+               call daxpy_(nfck(iirrep),one,scr,1,Integrals(ip(nrop)),1)
             End If
             irc=-1
             iopt=0
 *           Write(*,*) Lab_dsk,jdisp,koper
-            call dwrmck(irc,iOpt,Lab_dsk,jdisp,work(ip(nrop)),koper)
-            If (irc.ne.0)
-     & Call SysAbendMsg('cnt1el2','error during write in dwrmck',' ')
-         Call GetMem(Label,'FREE','REAL',ip(nrOp),nFck(iIrrep))
+            call dwrmck(irc,iOpt,Lab_dsk,jdisp,Integrals(ip(nrop)),
+     &                  koper)
+            If (irc.ne.0) Call SysAbendMsg('cnt1el2',
+     &                               'error during write in dwrmck',' ')
          End If
  16   Continue
 *
-
-      Call Getmem('Temp','FREE','REAL',ipscr,2*ii)
+      Call mma_deallocate(Scr)
+      Call mma_deallocate(Integrals)
 *
       Return
       End
