@@ -17,9 +17,11 @@
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (a-h,o-z)
 #include "etwas.fh"
-#include "WrkSpc.fh"
+#include "real.fh"
+#include "stdalloc.fh"
       Real*8 Dens(nDens)
       Integer na(0:7),ipcm(0:7)
+      Real*8, Allocatable:: Temp1(:), Temp2(:), Temp3(:)
 *
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
 *
@@ -32,53 +34,53 @@
          nA(i)=nnA
          ipcm(i)=ipCC
          nnA=nnA+nAsh(i)
-         ipCC=ipCC+nBAs(i)**2
+         ipCC=ipCC+nBas(i)**2
       End Do
 *
-      Call GetMem('Temp1','ALLO','REAL',ipTemp1,ndensSQ)
-      Call GetMem('Temp2','ALLO','REAL',ipTemp2,ndensSQ)
-      Call GetMem('Temp3','ALLO','REAL',ipUrk,ndensSQ)
+      Call mma_allocate(Temp1,nDensSQ,Label='Temp1')
+      Call mma_allocate(Temp2,nDensSQ,Label='Temp2')
+      Call mma_allocate(Temp3,nDensSQ,Label='Temp3')
 *
       Do iS=0,nIrrep-1
-         call dcopy_(nBas(is)**2,[0.0d0],0,Work(ipTemp1),1)
+         Temp1(:)=Zero
          If (nBas(is).gt.0) Then
             Do iB=1,nAsh(iS)
                iiB=nA(iS)+iB
                Do jB=1,nAsh(iS)
                   jjB=nA(iS)+jB
                   ijB=iTri(iiB,jjB)
-                  ip1=ipTemp1+
-     &                nBas(iS)*(nISh(iS)+iB-1)+nIsh(is)+jb -1
-                  Work(ip1)=G1(ijB,1)
+                  ip1= nBas(iS)*(nISh(iS)+iB-1)+nIsh(is)+jb
+                  Temp1(ip1)=G1(ijB,1)
                End Do
             End Do
 *
             Call DGEMM_('N','N',
      &                  nBas(is),nBas(is),nBas(is),
      &                  1.0d0,CMO(ipCM(iS),1),nBas(is),
-     &                  Work(ipTemp1),nBas(is),
-     &                  0.0d0,Work(ipUrk),nBas(is))
+     &                  Temp1,nBas(is),
+     &                  0.0d0,Temp3,nBas(is))
             Call DGEMM_('N','T',
      &                  nBas(is),nBas(is),nBas(is),
-     &                  1.0d0,Work(ipUrk),nBas(is),
+     &                  1.0d0,Temp3,nBas(is),
      &                  CMO(ipCM(is),1),nBas(is),
-     &                  0.0d0,Work(ipTemp2),nBas(is))
+     &                  0.0d0,Temp2,nBas(is))
 *
             Do iBas=1,nBas(iS)
                Do jBas=1,iBas
                   ip1=(iBas-1)*nBas(iS)+jBas
                   ip2=iTri(iBas,jBas)
                   Fact=2.0d0
-                  If (iBas.eq.jbas) Fact=1.0d0
-                  Dens(ipD+ip2)=Work(ipTemp2+ip1-1)*Fact
+                  If (iBas.eq.jBas) Fact=1.0d0
+                  Dens(ipD+ip2)=Temp2(ip1)*Fact
                End Do
             End Do
-            ipD=ipD+nBas(is)*(nBAs(is)+1)/2
+            ipD=ipD+nBas(is)*(nBas(is)+1)/2
          End If
       End Do
-      Call GetMem('Temp1','FREE','REAL',ipTemp1,ndensSQ)
-      Call GetMem('Temp2','FREE','REAL',ipTemp2,ndensSQ)
-      Call GetMem('Temp3','FREE','REAL',ipUrk,ndensSQ)
+
+      Call mma_deallocate(Temp3)
+      Call mma_deallocate(Temp2)
+      Call mma_deallocate(Temp1)
 *
       Return
       End
