@@ -9,21 +9,21 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine DeDe_Mck(FD,nFD,ipOffD,nOffD,DDen,lDDen,mDeDe,mIndij)
-#include "k2.fh"
-#include "WrkSpc.fh"
+      use k2_arrays, only: MaxDe
       Real*8 FD(nFD), DDen(lDDen)
       Integer ipOffD(nOffD)
       Logical Special_NoSym, DFT_Storage
-      Call QEnter('DeDe_Mck')
 *
       Special_NoSym=.False.
       DFT_Storage=.False.
       nr_of_Densities=1
-      jpDeDe=ip_of_Work(DDen(1))
-      ipD00=jpDeDe
-      Call DeDe(FD,nFD,nr_of_Densities,ipOffD,nOffD,jpDeDe,ipD00,MaxDe,
-     &          mDeDe,mIndij,Special_NoSym,DFT_Storage,Work,1)
 *
-      Call QExit('DeDe_Mck ')
+      ipDeDe=1
+      ipD00=1
+!     ipDijS is controlled in the calling routine
+      Call mk_DeDe(FD,nFD,nr_of_Densities,ipOffD,nOffD,ipDeDe,ipD00,
+     &             MaxDe,mDeDe,mIndij,Special_NoSym,DFT_Storage,
+     &             DDen,lDDen)
+*
       Return
       End
