@@ -18,8 +18,9 @@
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "etwas.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
       Real*8 Dens(nDens)
+      Real*8, Allocatable:: Temp2(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -27,30 +28,36 @@
       Do iIrr=0,nIrrep-1
          nTemp2=Max(nTemp2,nBas(iIrr))
       End Do
-      Call GetMem('Temp2','ALLO','REAL',ipTemp2,nTemp2**2)
+
+      Call mma_allocate(Temp2,nTemp2**2,Label='Temp2')
+
       ip=1
       ipD=0
       Do iIrr=0,nIrrep-1
-         If (nBas(iIrr).ne.0) Then
-            Call DGEMM_('N','T',
-     &                  nBas(iIrr),nBas(iIrr),nIsh(iIrr),
-     &                  1.0d0,CMO(ip,1),nBas(iIrr),
-     &                        CMO(ip,1),nBas(iIrr),
-     &                  0.0d0,Work(ipTemp2),nBas(iIrr))
-            Do iBas=1,nBas(iIrr)
-               Do jBas=1,iBas-1
-                  ip1=(iBas-1)*nBas(iIrr)+jBas
-                  ip2=iBas*(iBas-1)/2+jBas
-                  Dens(ipD+ip2)=Work(ipTemp2+ip1-1)*Four
-               End Do
-               ip1=(iBas-1)*nBas(iIrr)+iBas
-               ip2=iBas*(iBas+1)/2
-               Dens(ipD+ip2)=Work(ipTemp2+ip1-1)*Two
+
+         If (nBas(iIrr)==0) Cycle
+
+         Call DGEMM_('N','T',
+     &               nBas(iIrr),nBas(iIrr),nIsh(iIrr),
+     &               One,CMO(ip,1),nBas(iIrr),
+     &                     CMO(ip,1),nBas(iIrr),
+     &               Zero,Temp2,nBas(iIrr))
+         Do iBas=1,nBas(iIrr)
+            Do jBas=1,iBas-1
+               ip1=(iBas-1)*nBas(iIrr)+jBas
+               ip2=iBas*(iBas-1)/2+jBas
+               Dens(ipD+ip2)=Temp2(ip1)*Four
             End Do
-            ip=ip+nBas(iIrr)**2
-            ipd=ipD+nBas(iIrr)*(nBas(iIrr)+1)/2
-         End If
+            ip1=(iBas-1)*nBas(iIrr)+iBas
+            ip2=iBas*(iBas+1)/2
+            Dens(ipD+ip2)=Temp2(ip1)*Two
+         End Do
+         ip=ip+nBas(iIrr)**2
+         ipd=ipD+nBas(iIrr)*(nBas(iIrr)+1)/2
+
       End Do
-      Call GetMem('Temp2','FREE','REAL',ipTemp2,nTemp2**2)
+
+      Call mma_deallocate(Temp2)
+
       Return
       End
