@@ -46,8 +46,7 @@
       External KrnlMm
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-c#include "print.fh"
+#include "stdalloc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 #include "nsd.fh"
@@ -59,9 +58,12 @@ c     Character ChOper(0:7)*3
       Integer iDCRR(0:7), iDCRT(0:7), iStabM(0:7),iCoM(0:7,0:7),
      &          IndHss(0:1,0:2,0:1,0:2,0:7), nOp(2),
      &           iStabO(0:7),lOper(nComp),IndGrd(0:2,0:1,0:7)
-      Logical AeqB, EQ, TstFnc, DiffOp, IfHss(0:1,0:2,0:1,0:2),
-     &        TF,Chck,ifgrd(0:2,0:1)
-c     Data ChOper/'E  ','x  ','y  ','xy ','z  ','xz ','yz ','xyz'/
+      Logical AeqB, EQ, DiffOp, IfHss(0:1,0:2,0:1,0:2),
+     &        Chck,ifgrd(0:2,0:1)
+      Real*8, Allocatable:: Zeta(:), ZI(:), Kappa(:), PCoor(:,:),
+     &                      Kern(:), Fnl(:), Scrt1(:), Scrt2(:),
+     &                      DAO(:), DSOpr(:), DSO(:)
+      Logical, External :: TF, TstFnc
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -81,17 +83,15 @@ c     Data ChOper/'E  ','x  ','y  ','xy ','z  ','xz ','yz ','xyz'/
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       itri(i1,i2)=MAX(i1,i2)*(MAX(i1,i2)-1)/2+MIN(i1,i2)
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
 *
       call dcopy_(nHess,[Zero],0,Hess,1)
 *
 *     Auxiliary memory allocation.
 *
-      Call GetMem('Zeta','ALLO','REAL',iZeta,S%m2Max)
-      Call GetMem('Zeta','ALLO','REAL',ipZI ,S%m2Max)
-      Call GetMem('Kappa','ALLO','REAL',iKappa,S%m2Max)
-      Call GetMem('PCoor','ALLO','REAL',iPCoor,S%m2Max*3)
+      Call mma_allocate(Zeta,S%m2Max,Label='Zeta')
+      Call mma_allocate(ZI,S%m2Max,Label='ZI')
+      Call mma_allocate(Kappa,S%m2Max,Label='Kappa')
+      Call mma_allocate(PCoor,S%m2Max,3,Label='PCoor')
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -150,32 +150,32 @@ C        write(6,*) (iSD(i,jS),i=0,11)
         nOrdOp = 0  ! not used in this implementation
         Call KrnlMm(nOrder,MemKer,iAng,jAng,nOrdOp)
         MemKrn=MemKer*S%m2Max
-        Call GetMem('Kernel','ALLO','REAL',iKern,MemKrn)
+        Call mma_allocate(Kern,MemKrn,Label='Kern')
 *
 *       Allocate memory for the final integrals, all in the
 *       primitive basis.
 *
         lFinal = 21 * S%MaxPrm(iAng) * S%MaxPrm(jAng) *
      &           nElem(iAng)*nElem(jAng)
-        Call GetMem('Final','ALLO','REAL',ipFnl,lFinal)
+        Call mma_allocate(Fnl,lFinal,Label='Fnl')
 *
 *       Scratch area for contraction step
 *
-        nScr1 =  S%MaxPrm(iAng)*S%MaxPrm(jAng) *
+        nScrt1 =  S%MaxPrm(iAng)*S%MaxPrm(jAng) *
      &           nElem(iAng)*nElem(jAng)
-        Call GetMem('Scrtch','ALLO','REAL',iScrt1,nScr1)
+        Call mma_allocate(Scrt1,nScrt1,Label='Scrt1')
 *
 *       Scratch area for the transformation to spherical gaussians
 *
-        nScr2=S%MaxPrm(iAng)*S%MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
-        Call GetMem('ScrSph','Allo','Real',iScrt2,nScr2)
+        nScrt2=S%MaxPrm(iAng)*S%MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
+        Call mma_allocate(Scrt2,nScrt2,Label='Scrt2')
 *
-          Call GetMem(' DAO ','Allo','Real',ipDAO,
-     &                iPrim*jPrim*nElem(iAng)*nElem(jAng))
+        nDAO=iPrim*jPrim*nElem(iAng)*nElem(jAng)
+        Call mma_allocate(DAO,nDAO,Label='DAO')
 *
 *         At this point we can compute Zeta.
 *
-          Call ZXia(Work(iZeta),Work(ipZI),
+          Call ZXia(Zeta,ZI,
      &              iPrim,jPrim,Shells(iShll)%Exp,
      &                          Shells(jShll)%Exp)
 *
@@ -224,7 +224,6 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
                If (nMax.eq.nIrrep/nStabM) Go To 439
  435         Continue
  439         Continue
-             nCoM=nIrrep/nStabM
              Call LCopy(36,[.false.],0,IfHss,1)
              Do 400 iAtom=0,1
                Do 410 iCar=0,2
@@ -336,14 +335,14 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
             iSmLbl = 1
             nSO = MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
             If (nSO.eq.0) Go To 131
-            Call GetMem('DSOpr ','ALLO','REAL',ipDSOp,nSO*iPrim*jPrim)
-            Call GetMem('DSO ','ALLO','REAL',ipDSO,nSO*iPrim*jPrim)
-            call dcopy_(nSO*iPrim*jPrim,[Zero],0,Work(ipDSO),1)
-            call dcopy_(nSO*iPrim*jPrim,[Zero],0,Work(ipDSOp),1)
+            Call mma_allocate(DSOpr,nSO*iPrim*jPrim,Label='DSOpr')
+            DSOpr(:)=Zero
+            Call mma_allocate(DSO,nSO*iPrim*jPrim,Label='DSO')
+            DSO(:)=Zero
 *
 *           Gather the elements from 1st order density / Fock matrix.
 *
-            Call SOGthr(Work(ipDSO),iBas,jBas,nSO,FD,
+            Call SOGthr(DSO,iBas,jBas,nSO,FD,
      &                  n2Tri(iSmLbl),iSmLbl,
      &                  iCmp,jCmp,iShell,jShell,
      &                  AeqB,iAO,jAO)
@@ -361,23 +360,23 @@ c           End If
 *           Transform IJ,AB to J,ABi
             Call DGEMM_('T','T',
      &                  jBas*nSO,iPrim,iBas,
-     &                  1.0d0,Work(ipDSO),iBas,
-     &                        Shells(iShll)%pCff,iPrim,
-     &                  0.0d0,Work(ipDSOp),jBas*nSO)
+     &                  One,DSO,iBas,
+     &                      Shells(iShll)%pCff,iPrim,
+     &                  Zero,DSOpr,jBas*nSO)
 *           Transform J,ABi to AB,ij
             Call DGEMM_('T','T',
      &                  nSO*iPrim,jPrim,jBas,
-     &                  1.0d0,Work(ipDSOp),jBas,
-     &                        Shells(jShll)%pCff,jPrim,
-     &                  0.0d0,Work(ipDSO),nSO*iPrim)
+     &                  One,DSOpr,jBas,
+     &                      Shells(jShll)%pCff,jPrim,
+     &                  Zero,DSO,nSO*iPrim)
 *           Transpose to ij,AB
-            Call DGeTmO(Work(ipDSO),nSO,nSO,iPrim*jPrim,Work(ipDSOp),
+            Call DGeTmO(DSO,nSO,nSO,iPrim*jPrim,DSOpr,
      &                  iPrim*jPrim)
-            Call GetMem('DSO ','Free','Real',ipDSO,nSO*iBas*jBas)
+            Call mma_deallocate(DSO)
 *
 c           If (iPrint.ge.99) Call
 c    &         RecPrt(' Decontracted 1st order density/Fock matrix',
-c    &                ' ',Work(ipDSOp),iPrim*jPrim,nSO)
+c    &                ' ',DSOpr,iPrim*jPrim,nSO)
 *
 *           Loops over symmetry operations.
 *
@@ -423,8 +422,8 @@ c              End If
 *
                Call DesymD(iSmLbl,iAng,jAng,iCmp,jCmp,
      &                     iShell,jShell,iShll,jShll,
-     &                     iAO,jAO,Work(ipDAO),iPrim,jPrim,
-     &                     Work(ipDSOp),nSO,nOp,FactNd)
+     &                     iAO,jAO,DAO,iPrim,jPrim,
+     &                     DSOpr,nSO,nOp,FactNd)
 *
 *--------------Project the spherical harmonic space onto the
 *              cartesian space.
@@ -433,28 +432,28 @@ c              End If
                If (Shells(iShll)%Transf.or.Shells(jShll)%Transf) Then
 *
 *-----------------ij,AB --> AB,ij
-                  Call DGeTmO(Work(ipDAO),iPrim*jPrim,iPrim*jPrim,
-     &                        iCmp*jCmp,Work(iScrt1),iCmp*jCmp)
+                  Call DGeTmO(DAO,iPrim*jPrim,iPrim*jPrim,
+     &                        iCmp*jCmp,Scrt1,iCmp*jCmp)
 *-----------------AB,ij --> ij,ab
-                  Call SphCar(Work(iScrt1),iCmp*jCmp,iPrim*jPrim,
-     &                        Work(iScrt2),nScr2,
+                  Call SphCar(Scrt1,iCmp*jCmp,iPrim*jPrim,
+     &                        Scrt2,nScr2,
      &                        RSph(ipSph(iAng)),iAng,
      &                        Shells(iShll)%Transf,
      &                        Shells(iShll)%Prjct,
      &                        RSph(ipSph(jAng)),jAng,
      &                        Shells(jShll)%Transf,
      &                        Shells(jShll)%Prjct,
-     &                        Work(ipDAO),kk)
+     &                        DAO,kk)
                End If
 c              If (iPrint.ge.99) Call RecPrt(
 c    &                  ' Decontracted FD in the cartesian space',
-c    &                  ' ',Work(ipDAO),iPrim*jPrim,kk)
+c    &                  ' ',DAO,iPrim*jPrim,kk)
 *
 *--------------Compute kappa and P.
 *
                Call Setup1(Shells(iShll)%Exp,iPrim,
      &                     Shells(jShll)%Exp,jPrim,
-     &                     A,RB,Work(iKappa),Work(iPCoor),Work(ipZI))
+     &                     A,RB,Kappa,PCoor,ZI)
 *
 *--------------Compute gradients of the primitive integrals and
 *              trace the result.
@@ -464,13 +463,13 @@ CBS            write(6,*) 'Call the  Kernel'
 *
                Call Kernel(Shells(iShll)%Exp,iPrim,
      &                     Shells(jShll)%Exp,jPrim,
-     &                     Work(iZeta),Work(ipZI),
-     &                     Work(iKappa),Work(iPcoor),
-     &                     Work(ipFnl),iPrim*jPrim,
-     &                     iAng,jAng,A,RB,nOrder,Work(iKern),
+     &                     Zeta,ZI,
+     &                     Kappa,Pcoor,
+     &                     Fnl,iPrim*jPrim,
+     &                     iAng,jAng,A,RB,nOrder,Kern,
      &                     MemKer*iPrim*jPrim,Ccoor,
      &                     nOrdOp,Hess,nHess,
-     &                     IfHss,IndHss,ifgrd,indgrd,Work(ipDAO),
+     &                     IfHss,IndHss,ifgrd,indgrd,DAO,
      &                     mdci,mdcj,nOp,lOper,nComp,
      &                     iStabM,nStabM,nIrrep)
 
@@ -481,15 +480,13 @@ CBS            write(6,*) 'Call the  Kernel'
 *
  140        Continue
 *
-            Call GetMem('DSOpr ','Free','REAL',ipDSOp,nSO*iPrim*jPrim)
+            Call mma_deallocate(DSOpr)
  131        Continue
-          Call GetMem(' DAO ','Free','Real',ipDAO,iPrim*jPrim*
-     &                nElem(iAng)*nElem(jAng))
-        Call GetMem('ScrSph','Free','Real',iScrt2,nScr2)
-        Call GetMem('Scrtch','Free','Real',iScrt1,nScr1)
-*
-        Call GetMem('Final','Free','Real',ipFnl,lFinal)
-        Call GetMem('Kernel','Free','Real',iKern,MemKrn)
+        Call mma_deallocate(DAO)
+        Call mma_deallocate(Scrt2)
+        Call mma_deallocate(Scrt1)
+        Call mma_deallocate(Fnl)
+        Call mma_deallocate(Kern)
 *
 C        End Do
 C     End Do
@@ -497,10 +494,10 @@ C     End Do
 *
       Call Free_iSD()
 *
-      Call GetMem('Kappa','FREE','REAL',iKappa,S%m2Max)
-      Call GetMem('PCoor','FREE','REAL',iPCoor,S%m2Max*3)
-      Call GetMem('Zeta','FREE','REAL',ipZI ,S%m2Max)
-      Call GetMem('Zeta','FREE','REAL',iZeta,S%m2Max)
+      Call mma_deallocate(PCoor)
+      Call mma_deallocate(Kappa)
+      Call mma_deallocate(ZI)
+      Call mma_deallocate(Zeta)
 *
       Return
 c Avoid unused argument warnings
