@@ -15,12 +15,6 @@
 *                                                                      *
 * Object: driver for computation of gradients of one-electron matrices.*
 *                                                                      *
-* Called from: Mckinley                                                *
-*                                                                      *
-* Calling    :                                                         *
-*              GetMem                                                  *
-*              Cnt1El2                                                 *
-*                                                                      *
 *             Written by Anders Bernhardsson for electric field        *
 *             Gradients                                                *
 *             October  97                                              *
@@ -31,66 +25,72 @@
       External ElGrd,elgrddot
       External ElMem
 #include "Molcas.fh"
-#include "WrkSpc.fh"
+#include "real.fh"
 #include "stdalloc.fh"
 #include "disp.fh"
       Character*8 Lbl
       Real*8 Ccoor(3)
-      Real*8, Allocatable:: D0(:)
+      Real*8, Allocatable:: D0(:), EG(:), Temp(:)
+
+      Ccoor(:)=Zero
 
-      iRc=-1
-      iOpt=1
       nDens = 0
       Do iIrrep = 0, nIrrep - 1
          nDens = nDens + nBas(iIrrep)*(nBas(iIrrep)+1)/2
       End Do
+
       Call mma_Allocate(D0,nDens,Label='D0')
       Call Get_D1ao_Var(D0,nDens)
-*     Write(*,*) Ddot_(ndens,D0,1,D0,1)
-      call dcopy_(3,[0.0d0],0,CCOOR,1)
-      ncomp=1
-      loper=0
-      Call GetMem('ELEGRD','ALLO','REAL',ipEG,3*ngrad)
-      Call Dot1El2(ElGrddot,ElMem,Work(ipEG),3*nGrad,
-     &                 .true.,CCoor,D0,1)
-      CALL DSCAL_(3*ngrad,-1.0d0,Work(ipEG),1)
+
+      Call mma_allocate(EG,3*nGrad,Label='EG')
+      Call Dot1El2(ElGrddot,ElMem,EG,3*nGrad,.true.,CCoor,D0,1)
       Call mma_deallocate(D0)
-      Call GetMem('TEMP','ALLO','Real',ipTemp,3*ngrad)
-      Call GetMem('TEMP','CHEC','Real',ipTemp,3*ngrad)
-      call dcopy_(3*ngrad,[0.0d0],0,Work(ipTemp),1)
-      Call Drvel1(Work(ipTemp))
-      Call DaXpY_(3*ngrad,1.0d0,Work(ipTemp),1,Work(ipEG),1)
+
+      EG(:) = -EG(:)
+
+      Call mma_allocate(Temp,3*nGrad,Label='Temp')
+      Temp(:)=Zero
+
+      Call Drvel1(Temp)
+
+      EG(:) = EG(:) + Temp(:)
+
       Lbl='NUCELGR'
       idum=1
       iopt=128
       irc=3*ngrad
-      Call dWrMCk(irc,iopt,LBL,idum,Work(ipTemp),idum)
-      if(irc.ne.0)
-     & Call SysAbendMsg('drvect','error during write in dwrmck',' ')
+      Call dWrMCk(irc,iopt,LBL,idum,Temp,idum)
+      If(irc.ne.0) Call SysAbendMsg('drvect',
+     &                           'error during write in dwrmck',' ')
+
       idum=1
       iopt=128
       irc=3*ngrad
       Lbl='DOTELGR'
-      Call dWrMCk(irc,iopt,LBL,idum,Work(ipEG),idum)
-      if (irc.ne.0)
-     & Call SysAbendMsg('drvect','error during write in dwrmck',' ')
-      Call GetMem('ELGR','FREE','REAL',ipeg,3*ngrad)
-      Call GetMem('TEMP','FREE','Real',ipTemp,3*ngrad)
+      Call dWrMCk(irc,iopt,LBL,idum,EG,idum)
+      If (irc.ne.0) Call SysAbendMsg('drvect',
+     &                           'error during write in dwrmck',' ')
+      Call mma_deallocate(EG)
+      Call mma_deallocate(Temp)
+
 * needed in RASSI
+      loper=0
       Do iCar=1,3
-      isym=irrfnc(2**(icar-1))! nropr(ichbas(1+iCar))
-      Write(Lbl,'(a,i2)') 'ELEC ',iCar
-      idcnt=0
-      Do iCnttp=1,nCnttp
-        Do iCnt=1,dbsc(iCnttp)%nCntr
-          idcnt=idcnt+1
-          Do idCar=1,3
-            Call Cnt1El2(ELGRD,ELMEM,Lbl,idcnt,idcar,loper,
-     &               1.0d0,.true.,
-     &               lbl,0,isym,icar,1)
-          End Do
-        End Do
-      End Do
+
+         isym=irrfnc(2**(icar-1))      ! nropr(ichbas(1+iCar))
+         Write(Lbl,'(a,i2)') 'ELEC ',iCar
+         idcnt=0
+         Do iCnttp=1,nCnttp
+           Do iCnt=1,dbsc(iCnttp)%nCntr
+             idcnt=idcnt+1
+             Do idCar=1,3
+               Call Cnt1El2(ELGRD,ELMEM,Lbl,idcnt,idcar,loper,
+     &                      One,.true.,lbl,0,isym,icar,1)
+             End Do
+           End Do
+         End Do
+
       End Do
+
       Return
       End
