@@ -32,9 +32,6 @@
       Real*8 A(3), B(3), RB(3), Grad(nGrad)
       Integer iDCRR(0:7)
       Logical EQ, TstFnc
-*
-      iRout = 33
-      iPrint = nPrint(iRout)
 *
       iIrrep = 0
       mdc = 0
