@@ -24,46 +24,46 @@
       use Real_Spherical
       use Basis_Info
       Implicit Real*8 (a-h,o-z)
-#include "WrkSpc.fh"
+#include "real.fh"
+#include "stdalloc.fh"
       Real*8 F(*)
+      Real*8, Allocatable:: Tmp1(:), Tmp2(:)
 
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       nac=nelem(la)*nelem(iang)
       nExpi=Shells(iShll)%nExp
       nBasisi=Shells(iShll)%nBasis
-      Call Getmem('TMP1','ALLO','REAL',iptmp,
-     &             nExpi*nac*nVecAC*nalpha)
-      Call Getmem('TMP2','ALLO','REAL',ipF,
-     &             nExpi*nac*nVecAC*nalpha)
+      Call mma_allocate(Tmp1,nExpi*nac*nVecAC*nalpha,Label='Tmp1')
+      Call mma_allocate(Tmp2,nExpi*nac*nVecAC*nalpha,Label='Tmp2')
 *--------------From the lefthandside overlap, form iKaC from ikac by
 *              1) i,kac -> k,aci
 *
       n = nExpi*nac*nVecAC
       Call DgeTMo(F,nAlpha,
      &            nAlpha, n,
-     &            Work(ipTmp),n)
+     &            Tmp1,n)
 *
 *--------------2) aciK =  k,aci * k,K (Contract over core orbital)
 *
       Call DGEMM_('T','N',
      &            nac*nVecAC*nAlpha,nBasisi,nExpi,
-     &            1.0d0,Work(ipTmp),nExpi,
-     &            Shells(iShll)%pCff,nExpi,
-     &            0.0d0,Work(ipF),nac*nVecAC*nAlpha)
+     &            One,Tmp1,nExpi,
+     &                Shells(iShll)%pCff,nExpi,
+     &            Zero,Tmp2,nac*nVecAC*nAlpha)
 *
 *--------------3) Mult by shiftoperators aci,K -> Bk(K) * aci,K
 *
       Do iBk = 1, nBasisi
          Call DYaX(nac*nVecAC*nAlpha,Shells(iShll)%Bk(iBk),
-     &              Work((iBk-1)*nac*nVecAC*nAlpha+ipF),1,
-     &              Work((iBk-1)*nac*nVecAC*nAlpha+ipTmp),1)
+     &              Tmp2((iBk-1)*nac*nVecAC*nAlpha+1),1,
+     &              Tmp1((iBk-1)*nac*nVecAC*nAlpha+1),1)
       End Do
 *
 *--------------4) a,ciK -> ciKa
 *
-      Call DgeTMo(Work(ipTmp),nElem(la),nElem(la),
+      Call DgeTMo(Tmp1,nElem(la),nElem(la),
      &            nElem(iAng)*nVecAC*nAlpha*nBasisi,
-     &            Work(ipF),
+     &            Tmp2,
      &            nElem(iAng)*nVecAC*nAlpha*nBasisi)
 *
 *--------------5) iKa,C = c,iKa * c,C
@@ -71,20 +71,17 @@
       Call DGEMM_('T','N',
      &            nVecAC*nAlpha*nBasisi*nElem(la),
      &            (2*iAng+1),nElem(iAng),
-     &            1.0d0,Work(ipF),nElem(iAng),
-     &            RSph(ipSph(iAng)),nElem(iAng),
-     &            0.0d0,Work(ipTmp),
-     &            nVecAC*nAlpha*nBasisi*nElem(la))
+     &            One,Tmp2,nElem(iAng),
+     &                 RSph(ipSph(iAng)),nElem(iAng),
+     &            Zero,Tmp1,nVecAC*nAlpha*nBasisi*nElem(la))
 *
-      Call DgeTMo(Work(ipTmp),nVecAC,nVecAC,
+      Call DgeTMo(Tmp1,nVecAC,nVecAC,
      &            nAlpha*nBasisi*nElem(la)*(2*iAng+1),
      &            F,
      &            nAlpha*nBasisi*nElem(la)*(2*iAng+1))
 
-      Call Getmem('TMP1','FREE','REAL',iptmp,
-     &            nExpi*nac*nVecAC*nalpha)
+      Call mma_deallocate(Tmp2)
+      Call mma_deallocate(Tmp1)
 
-      Call Getmem('TMP2','FREE','REAL',ipF,
-     &            nExpi*nac*nVecAC*nalpha)
       Return
       End
