@@ -30,24 +30,23 @@
       use Basis_Info
       use Real_Spherical
       Implicit Real*8 (a-h,o-z)
-
-#include "WrkSpc.fh"
-      Dimension F(*)
+#include "real.fh"
+#include "stdalloc.fh"
+      Real*8 F(*)
+      Real*8, Allocatable:: Tmp1(:), Tmp2(:)
 
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *******************************************************************************
 *
       nExpi=Shells(iShll)%nExp
       nac=nelem(la)*nelem(iang)
-      Call Getmem('TMP1','ALLO','REAL',iptmp,
-     &             nExpi*nac*nVecAC*nalpha)
-      Call Getmem('TMP2','ALLO','REAL',ipF,
-     &             nExpi*nac*nVecAC*nalpha)
+      Call mma_allocate(Tmp1,nExpi*nac*nVecAC*nalpha,Label='Tmp1')
+      Call mma_allocate(Tmp2,nExpi*nac*nVecAC*nalpha,Label='Tmp2')
 
 
       Call DgeTMo(F,nAlpha*nExpi*nElem(la),
      &            nAlpha*nExpi*nElem(la),
-     &            nElem(iAng)*nVecAC,Work(ipTmp),
+     &            nElem(iAng)*nVecAC,Tmp1,
      &            nElem(iAng)*nVecAC)
 *
 *--------------2) xika,C = c,xika * c,C
@@ -55,24 +54,22 @@
       Call DGEMM_('T','N',
      &            nVecAC*nAlpha*nExpi*nElem(la),
      &            (2*iAng+1),nElem(iAng),
-     &            1.0d0,Work(ipTmp),nElem(iAng),
-     &            RSph(ipSph(iAng)),nElem(iAng),
-     &            0.0d0,Work(ipF),
+     &            One,Tmp1,nElem(iAng),
+     &                RSph(ipSph(iAng)),nElem(iAng),
+     &            Zero,Tmp2,
      &            nVecAC*nAlpha*nExpi*nElem(la))
 *
 *--------------3) x,ikaC -> ikaC,x
 *
-      Call DGetMo(Work(ipF),nVecAC,nVecAC,
+      Call DGetMo(Tmp2,nVecAC,nVecAC,
      &            nAlpha*nExpi*nElem(la)*(2*iAng+1),
-     &            Work(ipTmp),
+     &            Tmp1,
      &            nAlpha*nExpi*nElem(la)*(2*iAng+1))
       call dcopy_(nVecAC*
      &           nAlpha*nExpi*nElem(la)*(2*iAng+1),
-     &           Work(ipTmp),1,F,1)
+     &           Tmp1,1,F,1)
 *
-      Call Getmem('TMP1','FREE','REAL',iptmp,
-     &             nExpi*nac*nVecAC*nalpha)
-      Call Getmem('TMP2','FREE','REAL',ipF,
-     &             nExpi*nac*nVecAC*nalpha)
+      Call mma_deallocate(Tmp2)
+      Call mma_deallocate(Tmp1)
       Return
       End
