@@ -32,7 +32,6 @@
       External TNAI1, Fake, Cff2D
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 
@@ -47,15 +46,10 @@
      &        kndgrd(3,4,0:7)
       Logical JfGrd(3,4), kfgrd(3,4), jfg(4)
       Dimension Dum(1)
-*
-      nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
-*
 *
 c     If (iPrint.ge.99) Then
 c        Write (*,*) ' In NAGrd: nArr=',nArr
 c     End If
-      nGrad=lDisp(0)
-      Call GetMem('Grad','Allo','REAL',ipGrad,nGrad)
       call icopy(144*nirrep,[0],0,inddum,1)
       call lcopy(144,[.false.],0,ifdum,1)
 *
@@ -68,7 +62,6 @@ c     End If
       nip = nip + nAlpha*nBeta
       If (nip-1.gt.nArr)
      &   Write (6,*) ' nip-1.gt.nArr'
-      nArray = nArr - nip +1
 *
       iIrrep = 0
       iAng(1) = la
@@ -100,12 +93,9 @@ c     End If
          call dcopy_(nBeta,Beta,1,Array(ipBOff),nAlpha)
          ipBOff = ipBOff + 1
  210  Continue
-*
-      nDAO = 1
 *
 *-----Loop over nuclear centers
 *
-      nb=nZeta*nElem(la)*nElem(lb)
       kdc = 0
       Do 100 kCnttp = 1, nCnttp
          If (.Not.dbsc(kCnttp)%ECP) Go To 111
@@ -206,7 +196,6 @@ c           End If
  101     Continue
  111     kdc = kdc + dbsc(kCnttp)%nCntr
  100  Continue
-      Call GetMem('Grad','Free','REAL',ipGrad,nGrad)
 *
       Return
 c Avoid unused argument warnings
