@@ -35,10 +35,9 @@
       use Temporary_Parameters
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
-*
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 #include "cputime.fh"
@@ -50,7 +49,8 @@ cpcm_solvent end
 c      Parameter (nLines=12)
       Character*120 Lines
       Logical DoRys, Run_MCLR
-#include "warnings.fh"
+      Real*8, Allocatable:: Hess(:), Temp(:), GradN(:)
+#include "warnings.h"
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -91,8 +91,8 @@ C     Call Banner(Lines,nLines,lLine)
 *                                                                      *
 *     Set error conditions
 *
-      Call XuFlow()
-      Call ErrSet(209,1,1,2,1,209)
+      !Call XuFlow()
+      !Call ErrSet(209,1,1,2,1,209)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -133,10 +133,10 @@ cpcm_solvent end
 *
       nHess=nGrad*(nGrad+1)/2
 *
-      Call GetMem('Hess','Allo','Real',ipHess,nHess)
-      Call GetMem('Temp','Allo','Real',ipTemp,nHess)
-      call dcopy_(nHess,[Zero],0,Work(ipHess),1)
-      call dcopy_(nHess,[Zero],0,Work(ipTemp),1)
+      Call mma_allocate(Hess,nHess,Label='Hess')
+      Hess(:)=Zero
+      Call mma_allocate(Temp,nHess,Label='Temp')
+      Temp(:)=Zero
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -155,7 +155,7 @@ cpcm_solvent end
          Write(6,*)
          End If
          Call Timing(dum1,Time,dum2,dum3)
-         Call Drvh2(Work(ipHess),Work(ipTemp),nHess,show)
+         Call Drvh2(Hess,Temp,nHess,show)
          Call DrvEtc(nGrad)
       End If
 *                                                                      *
@@ -166,20 +166,20 @@ cpcm_solvent end
 ************************************************************************
 *                                                                      *
       If (lHss) Then
-         Call DrvN2(Work(ipTemp),nGrad)
-         If (SHOW) Call HssPrt(Work(ipTemp),nHess)
-         Call DaXpY_(nHess,One,Work(ipTemp),1,Work(ipHess),1)
-         If (Show) Call HssPrt(Work(ipHess),nHess)
+         Call DrvN2(Temp,nGrad)
+         If (SHOW) Call HssPrt(Temp,nHess)
+         Call DaXpY_(nHess,One,Temp,1,Hess,1)
+         If (Show) Call HssPrt(Hess,nHess)
       End If
       If (lGrd) Then
-          Call GetMem('Gradn','Allo','Real',ipGradn,nGrad)
-          Call DrvN1_mck(Work(ipGradn),nGrad)
+          Call mma_allocate(GradN,nGrad,Label='GradN')
+          Call DrvN1_mck(GradN,nGrad)
           iopt=0
           irc=-1
-          Call dWrMCK(iRC,iOpt,'NUCGRAD',1,Work(ipGradn),1)
+          Call dWrMCK(iRC,iOpt,'NUCGRAD',1,GradN,1)
           If (irc.ne.0) Call SysAbendMsg('mckinley','Error in writing',
      &                                   'Option=NUCGRAD')
-          Call GetMem('Gradn','Free','Real',ipGradn,nGrad)
+          Call mma_deallocate(GradN)
       End If
 *                                                                      *
 ************************************************************************
@@ -211,52 +211,47 @@ cpcm_solvent end
       Call Timing(dum1,Time,dum2,dum3)
       CPUStat(nOneel)=CPUStat(nOneel)+Time
       If (.Not.Onenly) Then
-          Call GetMem('Grad','ALLO','Real',ipGrad,nGrad)
-          call dcopy_(nGrad,[Zero],0,Work(ipGrad),1)
 *
-          Call ICopy(8,[0],0,nISh,1)
-          Call ICopy(8,[0],0,nASh,1)
+          nIsh(:)=0
+          nAsh(:)=0
 *
-          Call PrepP
+          Call PrepP()
 *
           iOpt = 0
           iRC = -1
-          Call iWrMck(iRC,iOpt,'NISH',1,nish,iDummer)
+          Call iWrMck(iRC,iOpt,'NISH',1,nIsh,iDummer)
           If (iRC.ne.0) Then
              Write (6,*) 'Mckinley: Error writing to MckInt!'
              Call Abend()
           End If
           iOpt = 0
           iRC = -1
-          Call iWrMck(iRC,iOpt,'NASH',1,nash,iDummer)
+          Call iWrMck(iRC,iOpt,'NASH',1,nAsh,iDummer)
           If (iRC.ne.0) Then
              Write (6,*) 'Mckinley: Error writing to MckInt!'
              Call Abend()
           End If
 *
 *
-*         Call GetMem(' LIST ','LIST','REAL',iDum,iDum)
 
-          Call Drvg2(Work(ipTemp),nhess, lGrd,lHss)
+          Call Drvg2(Temp,nhess, lGrd,lHss)
 *
-          Call GetMem('Grad','Free','Real',ipGrad,nGrad)
           Call CloseP
 *
           If (lHss) Then
-             Call GADSum(Work(ipTemp),nHess)
-             Call DScal_(nHess,Half,Work(ipTemp),1)
-             If (Show) Call HssPrt(Work(ipTemp),nHess)
+             Call GADSum(Temp,nHess)
+             Call DScal_(nHess,Half,Temp,1)
+             If (Show) Call HssPrt(Temp,nHess)
 *
 *----------- Accumulate contribution to the hessian!
 *
-             Call DaXpY_(nhess,One,Work(ipTemp),1,
-     &                  Work(ipHess),1)
+             Call DaXpY_(nhess,One,Temp,1,Hess,1)
 *
              If (Show) Then
                 Call Banner('Complete static Hessian',1,23)
-                Call HssPrt(Work(ipHess),nHess)
+                Call HssPrt(Hess,nHess)
              End If
-             Call WrHDsk(Work(ipHess),ngrad)
+             Call WrHDsk(Hess,ngrad)
           End If
 *
       End If
@@ -271,8 +266,8 @@ cpcm_solvent end
          Write (6,*) 'McKinley: Error closing MCKINT!'
          Call Abend()
       End If
-      Call GetMem('Temp','Free','Real',ipTemp,nHess)
-      Call GetMem('Hess','Free','Real',ipHess,nHess)
+      Call mma_deallocate(Temp)
+      Call mma_deallocate(Hess)
 *
       Call ClsSew
 *                                                                      *
@@ -288,7 +283,6 @@ cpcm_solvent end
       Call CWTime(TCpu2,TWall2)
       Call SavTim(5,TCpu2-TCpu1,TWall2-TWall1)
 *
-C     Call DaTimm
       Call Timing(Time,dum,dum,dum)
       CPUStat(nTotal)=Time
       If (iPrint.ge.6) Call Sttstc
@@ -303,7 +297,7 @@ C     Call DaTimm
       Subroutine Request_MCLR_Run(Run_MCLR,ireturn,iPrint)
       Logical Run_MCLR
       Character*16 StdIn
-#include "warnings.fh"
+#include "warnings.h"
 *
       If (Run_MCLR) Then
 *
