@@ -32,7 +32,6 @@
       External TNAI1, Fake, Cff2D
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 
@@ -59,8 +58,6 @@ c     iPrint = nPrint(iRout)
 c     If (iPrint.ge.99) Then
 c        Write (*,*) ' In NAGrd: nArr=',nArr
 c     End If
-      nGrad=lDisp(0)
-      Call GetMem('Grad','Allo','REAL',ipGrad,nGrad)
 *
       nRys=nHer
 *
@@ -113,6 +110,7 @@ c     End If
       nb=nZeta*nElem(la)*nElem(lb)
       kdc = 0
       Do 100 kCnttp = 1, nCnttp
+         If (kCnttp==iCnttp_Dummy) Go To 111
          If (dbsc(kCnttp)%Charge.eq.Zero) Go To 111
          Do 101 kCnt = 1, dbsc(kCnttp)%nCntr
             C(1:3)=dbsc(kCnttp)%Coor(1:3,kCnt)
@@ -227,7 +225,6 @@ c    &            Call RecPrt('In NaGrd FI',' ',Final,nb,nrOp)
  101     Continue
  111     kdc = kdc + dbsc(kCnttp)%nCntr
  100  Continue
-      Call GetMem('Grad','Free','REAL',ipGrad,nGrad)
 *
       Return
 c Avoid unused argument warnings
