@@ -30,8 +30,6 @@
       External TNAI1, Fake, Cff2D
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-c#include "print.fh"
 #include "disp.fh"
 #include "disp2.fh"
 
@@ -39,7 +37,7 @@ c#include "print.fh"
 
 *     Local variables
       Integer iDCRT(0:7), Index(3,4)
-      Logical TstFnc, TF, EQ,IfG(0:3),Tr(0:3)
+      Logical EQ,IfG(0:3),Tr(0:3)
 #ifdef _PATHSCALE_
       Save Fact
 #endif
@@ -51,18 +49,14 @@ c#include "print.fh"
      &        JndHss(0:3,0:2,0:3,0:2,0:7),
      &        mOp(4), iuvwx(4)
       Logical JfHss(0:3,0:2,0:3,0:2),JfGrd(0:2,0:3)
+      Logical, External :: TF
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       itri(i1,i2)=MAX(i1,i2)*(MAX(i1,i2)-1)/2+MIN(i1,i2)
-      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
-     &                              iIrrep,iComp,dc(mdc)%nStab)
 *
-c     iRout = 150
-c     iPrint = nPrint(iRout)
-*
-c     If (iPrint.ge.99) Then
-c        Write (6,*) ' In NAHss: nArr=',nArr
-c     End If
+#ifdef _DEBUGPRINT_
+      Write (6,*) ' In NAHss: nArr=',nArr
+#endif
 *
       nRys=nHer
 *
@@ -119,12 +113,15 @@ c     End If
             DAO(iZeta,iDAO) = Fact * DAO(iZeta,iDAO)
          End Do
       End Do
-c     If (iPrint.ge.99) Call RecPrt('DAO',' ',DAO,nZeta,nDAO)
+#ifdef _DEBUGPRINT_
+      Call RecPrt('DAO',' ',DAO,nZeta,nDAO)
+#endif
 *
 *-----Loop over nuclear centers
 *
       kdc = 0
       Do kCnttp = 1, nCnttp
+         If (kCnttp==iCnttp_Dummy) Go To 111
          If (dbsc(kCnttp)%Charge.eq.Zero) Go To 111
          Do kCnt = 1, dbsc(kCnttp)%nCntr
             C(1:3)=dbsc(kCnttp)%Coor(1:3,kCnt)
