@@ -17,11 +17,9 @@
       Implicit Real*8 (a-h,o-z)
 #include "etwas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
       Real*8 COUT(nOut)
       Integer iCmp(4),iBas(4),nBs(4)
-      Integer iTwoj(0:7),iAOii(4)
-      Data iTwoj/1,2,4,8,16,32,64,128/
+      Integer iAOii(4)
 *
       iBas(1)=iBasi
       iBas(2)=jBasj
@@ -32,10 +30,7 @@
       nBs(3)=kBasn
       nBs(4)=lBasn
       ip2=1
-      nA=0
-      Do iIrrep=0,nIrrep-1
-          nA=nA+nAsh(iIrrep)
-      End Do
+
       Do iCnt=3,4
          ipC=0
          Do iIrrep=0,nIrrep-1
