@@ -53,8 +53,6 @@
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-#include "print.fh"
 #include "disp.fh"
 
 #include "grd_mck_interface.fh"
@@ -73,25 +71,23 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      iprint = 0
       iuvwx(1) = iu
       iuvwx(2) = iv
       mop(1) = nOp(1)
       mop(2) = nOp(2)
       DiffCnt=(IfGrad(iDCar,1).or.IfGrad(iDCar,2))
-      iComp = 1
 
-      If (iPrint.ge.49) Then
-            Call RecPrt(' In PrjGrd: A',' ',A,1,3)
-            Call RecPrt(' In PrjGrd: RB',' ',RB,1,3)
-            Call RecPrt(' In PrjGrd: P',' ',P,nZeta,3)
-            Call RecPrt(' In PrjGrd: Alpha',' ',Alpha,nAlpha,1)
-            Call RecPrt(' In PrjGrd: Beta',' ',Beta,nBeta,1)
-            Write (6,*) ' In PrjGrd: la,lb=',' ',la,lb
-            Write (6,*) ' In PrjGrd: Diffs=',' ',
-     &                    IfGrad(iDCar,1),IfGrad(iDCar,2)
-            Write (6,*) ' In PrjGrd: Center=',' ',iDCNT
-      End If
+#ifdef _DEBUGPRINT_
+      Call RecPrt(' In PrjGrd: A',' ',A,1,3)
+      Call RecPrt(' In PrjGrd: RB',' ',RB,1,3)
+      Call RecPrt(' In PrjGrd: P',' ',P,nZeta,3)
+      Call RecPrt(' In PrjGrd: Alpha',' ',Alpha,nAlpha,1)
+      Call RecPrt(' In PrjGrd: Beta',' ',Beta,nBeta,1)
+      Write (6,*) ' In PrjGrd: la,lb=',' ',la,lb
+      Write (6,*) ' In PrjGrd: Diffs=',' ',
+     &              IfGrad(iDCar,1),IfGrad(iDCar,2)
+      Write (6,*) ' In PrjGrd: Center=',' ',iDCNT
+#endif
 
       kdc = 0
       Do 1960 kCnttp = 1, nCnttp
@@ -150,12 +146,12 @@
                iShll = dbsc(kCnttp)%iPrj + iAng
                nExpi=Shells(iShll)%nExp
                nBasisi=Shells(iShll)%nBasis
-               If (iPrint.ge.49) Then
-                  Write (6,*) 'nExp(iShll)=',nExpi
-                  Write (6,*) 'nBasisi=',nBasisi
-                  Write (6,*) ' iAng=',iAng
-                  Call RecPrt('TC',' ',TC,1,3)
-               End If
+#ifdef _DEBUGPRINT_
+               Write (6,*) 'nExp(iShll)=',nExpi
+               Write (6,*) 'nBasisi=',nBasisi
+               Write (6,*) ' iAng=',iAng
+               Call RecPrt('TC',' ',TC,1,3)
+#endif
 
                If (nExpi.eq.0 .or. nBasisi.eq.0) Go To 1966
 *
@@ -180,18 +176,32 @@
                call dcopy_(nArr,[0.0d0],0,Array,1)
 
 *
+#ifdef _DEBUGPRINT_
                Call Acore(iang,la,ishll,nordop,TC,A,Array(ip),
      &                     narr-ip+1,Alpha,nalpha,Array(ipFA1),
      &                     array(ipFA2),jfgrad(1,1),ifhess_dum,
-     &                     1,iprint.ge.49)
+     &                     1,.TRUE.)
+#else
+               Call Acore(iang,la,ishll,nordop,TC,A,Array(ip),
+     &                     narr-ip+1,Alpha,nalpha,Array(ipFA1),
+     &                     array(ipFA2),jfgrad(1,1),ifhess_dum,
+     &                     1,.FALSE.)
+#endif
                call LToCore(Array(ipFA1),nalpha,ishll,la,iAng, 4)
 
 
 
+#ifdef _DEBUGPRINT_
                Call coreB(iang,lb,ishll,nordop,TC,RB,Array(ip),
      &                    narr-ip+1,Beta,nbeta,Array(ipFB1),
      &                    array(ipFB2),jfgrad(1,2),ifhess_dum,1,
-     &                    iprint.ge.49)
+     &                    .TRUE.)
+#else
+               Call coreB(iang,lb,ishll,nordop,TC,RB,Array(ip),
+     &                    narr-ip+1,Beta,nbeta,Array(ipFB1),
+     &                    array(ipFB2),jfgrad(1,2),ifhess_dum,1,
+     &                    .FALSE.)
+#endif
                call RToCore(Array(ipFB1),nBeta,ishll,lb,iAng,4)
 
 
@@ -221,6 +231,7 @@ c Avoid unused argument warnings
          Call Unused_real_array(Zeta)
          Call Unused_real_array(ZInv)
          Call Unused_real_array(rKappa)
+         Call Unused_real_array(P)
          Call Unused_integer(nHer)
          Call Unused_real_array(Ccoor)
          Call Unused_logical_array(Trans)
