@@ -41,12 +41,11 @@
       use Integral_Parameters, only: iWROpt
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
-#include "WrkSpc.fh"
 #include "real.fh"
 #include "print.fh"
 #include "lCache.fh"
 #include "pstat.fh"
-#include "warnings.fh"
+#include "warnings.h"
       Integer iAnga(4), iCmpa(4)
       Logical QiBas, QjBas, QkBas, QlBas, QjPrim, QlPrim, Fail
 #include "SysDef.fh"
@@ -55,8 +54,6 @@
 *
       nabSz(ixyz) = (ixyz+1)*(ixyz+2)*(ixyz+3)/6  - 1
 *
-      iRout = 10
-      iPrint = nPrint(iRout)
 *     iQ = 1
       la = iAnga(1)
       lb = iAnga(2)
@@ -72,7 +69,6 @@
       mcdMin=nabSz(Max(lc,ld)-1)+1
       mcdMax=nabSz(lc+ld)
       mabcd=(mabMax-mabMin+1)*(mcdMax-mcdMin+1)
-      nabcd=iCmp*jCmp*kCmp*lCmp
 *
       iBsInc = iBas
       jBsInc = jBas
@@ -244,8 +240,6 @@
       ipMem3 = ipMem2 + Mem2
       ipMem4 = ipMem2 + Mem2 - Mem4
       Mend=0
-*
-      MemSum=Mem1+Mem2+Mem3
 *
       r1 = r1 + DBLE(iBsInc)/DBLE(iBas)
       r2 = r2 + DBLE(jBsInc)/DBLE(jBas)
