@@ -53,8 +53,6 @@
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-#include "print.fh"
 #include "disp.fh"
 
 #include "grd_mck_interface.fh"
@@ -77,22 +75,19 @@
       mOp(1) = nOp(1)
       mOp(2) = nOp(2)
 *
-      iprint = 0
       DiffCnt=(IfGrad(iDCar,1).or.IfGrad(iDCar,2))
 
-
-
-      If (iPrint.ge.49) Then
-            Call RecPrt(' In SROGrd: A',' ',A,1,3)
-            Call RecPrt(' In SROGrd: RB',' ',RB,1,3)
-            Call RecPrt(' In SROGrd: P',' ',P,nZeta,3)
-            Call RecPrt(' In SROGrd: Alpha',' ',Alpha,nAlpha,1)
-            Call RecPrt(' In SROGrd: Beta',' ',Beta,nBeta,1)
-            Write (6,*) ' In SROGrd: la,lb=',' ',la,lb
-            Write (6,*) ' In SROGrd: Diffs=',' ',
-     &                    IfGrad(iDCar,1),IfGrad(iDCar,2)
-            Write (6,*) ' In SROGrd: Center=',' ',iDCNT
-      End If
+#ifdef _DEBUGPRINT_
+      Call RecPrt(' In SROGrd: A',' ',A,1,3)
+      Call RecPrt(' In SROGrd: RB',' ',RB,1,3)
+      Call RecPrt(' In SROGrd: P',' ',P,nZeta,3)
+      Call RecPrt(' In SROGrd: Alpha',' ',Alpha,nAlpha,1)
+      Call RecPrt(' In SROGrd: Beta',' ',Beta,nBeta,1)
+      Write (6,*) ' In SROGrd: la,lb=',' ',la,lb
+      Write (6,*) ' In SROGrd: Diffs=',' ',
+     &              IfGrad(iDCar,1),IfGrad(iDCar,2)
+      Write (6,*) ' In SROGrd: Center=',' ',iDCNT
+#endif
 
       kdc = 0
       Do 1960 kCnttp = 1, nCnttp
@@ -154,13 +149,13 @@
             Do 1966 iAng = 0, dbsc(kCnttp)%nSRO-1
                iShll = dbsc(kCnttp)%iSRO + iAng
                nExpi=Shells(iShll)%nExp
+#ifdef _DEBUGPRINT_
                nBasisi=Shells(iShll)%nBasis
-               If (iPrint.ge.49) Then
-                  Write (6,*) 'nExpi=',nExpi
-                  Write (6,*) 'nBasis(iShll)=',nBasisi
-                  Write (6,*) ' iAng=',iAng
-                  Call RecPrt('TC',' ',TC,1,3)
-               End If
+               Write (6,*) 'nExpi=',nExpi
+               Write (6,*) 'nBasis(iShll)=',nBasisi
+               Write (6,*) ' iAng=',iAng
+               Call RecPrt('TC',' ',TC,1,3)
+#endif
 
                If (nExpi.eq.0) Go To 1966
 *
@@ -186,7 +181,11 @@
                Call Acore(iang,la,ishll,nordop,TC,A,Array(ip),
      &                     narr-ip+1,Alpha,nalpha,Array(ipFA1),
      &                     array(ipFA2),jfgrad(1,1),ifhess_dum,
-     &                     1,iprint.ge.49)
+#ifdef _DEBUGPRINT_
+     &                     1,.TRUE.)
+#else
+     &                     1,.FALSE.)
+#endif
                call LToSph(Array(ipFA1),nalpha,ishll,la,iAng,2)
 
 
@@ -196,7 +195,11 @@
                Call coreB(iang,lb,ishll,nordop,TC,RB,Array(ip),
      &                    narr-ip+1,Beta,nbeta,Array(ipFB1),
      &                    array(ipFB2),jfgrad(1,2),ifhess_dum,1,
-     &                    iprint.ge.49)
+#ifdef _DEBUGPRINT_
+     &                     .TRUE.)
+#else
+     &                     .FALSE.)
+#endif
                call RToSph(Array(ipFB1),nBeta,ishll,lb,iAng,2)
 
 
@@ -225,6 +228,7 @@ c Avoid unused argument warnings
          Call Unused_real_array(Zeta)
          Call Unused_real_array(ZInv)
          Call Unused_real_array(rKappa)
+         Call Unused_real_array(P)
          Call Unused_integer(nHer)
          Call Unused_real_array(Ccoor)
          Call Unused_logical_array(Trans)
