@@ -10,11 +10,12 @@
 ************************************************************************
       Subroutine SuperMac()
       Implicit Real*8 (a-h,o-z)
-#include "WrkSpc.fh"
-      Character*8 Method
-      Character*16 StdIn
+#include "stdalloc.fh"
+      Integer, Allocatable:: Scr1(:)
+      Character(LEN=8) Method
+      Character(LEN=16) StdIn
       Logical Do_Cholesky, Do_ESPF, Numerical, Found
-#include "warnings.fh"
+#include "warnings.h"
 #include "temperatures.fh"
 *
       Call Get_cArray('Relax Method',Method,8)
@@ -66,13 +67,13 @@
       Call fCopy('RUNFILE','RUNBACK',iErr)
       If (iErr.ne.0) Call Abend()
 *
-      Call GetMem('Scr1','Allo','Inte',ipScr1,7)
-      iWork(ipScr1)=0
-      iWork(ipScr1+1)=0
-      iWork(ipScr1+2)=-99
-      iWork(ipScr1+3)=0
-      Call Put_iArray('Slapaf Info 1',iWork(ipScr1),7)
-      Call GetMem('Scr1','Free','Inte',ipScr1,7)
+      Call mma_allocate(Scr1,7,Label='Scr1')
+      Scr1(1)=0
+      Scr1(2)=0
+      Scr1(3)=-99
+      Scr1(4)=0
+      Call Put_iArray('Slapaf Info 1',Scr1,7)
+      Call mma_deallocate(Scr1)
       LuInput=11
       LuInput=IsFreeUnit(LuInput)
       Call StdIn_Name(StdIn)
@@ -80,8 +81,6 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      iPL = iPrintLevel(-1)
-*
       Write (LuInput,'(A)') '>ECHO OFF'
       Write (LuInput,'(A)') '>export MCK_OLD_TRAP=$MOLCAS_TRAP'
       Write (LuInput,'(A)') '>export MCK_OLD_MAXITER=$MOLCAS_MAXITER'
@@ -164,7 +163,7 @@
       Subroutine Lu2Lu(Filename,LuInput)
       Character FileName*(*), Line*180
       Logical Exist
-#include "warnings.fh"
+#include "warnings.h"
 *
       Call f_inquire(Filename,Exist)
       If (.Not.Exist) Then
