@@ -22,13 +22,15 @@
 #include "Molcas.fh"
 #include "buffer.fh"
 #include "etwas.fh"
-#include "WrkSpc.fh"
+#include "real.fh"
+#include "stdalloc.fh"
 #include "disp.fh"
 #include "disp2.fh"
 #include "print.fh"
       Real*8 rIn(nrIn)
       Character*8 Label
       Integer ip(0:7),ip2(0:7),nA(0:7),ipCM(0:7)
+      Real*8, Allocatable:: Act(:), InAct(:), Out(:), TempX(:), TempY(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -71,15 +73,14 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call GetMem('ACTIVE','ALLO','REAL',ipAct,nIn2)
-      Call GetMem('INACTIVE','ALLO','REAL',ipIN,nIn2)
-      Call GetMem('OUT','ALLO','REAL',ipOUT1,nIn2)
-      Call GetMem('TEMP1','ALLO','REAL',ipY,nIn2)
-      Call GetMem('TEMP2','ALLO','REAL',ipX,nIn2)
-*
-      call dcopy_(nIn2,[0.0d0],0,Work(ipAct),1)
-      call dcopy_(nIn2,[0.0d0],0,Work(ipIN),1)
-      call dcopy_(nIn2,[0.0d0],0,Work(ipOut1),1)
+      Call mma_allocate(Act,nIn2,Label='Act')
+      Act(:)=Zero
+      Call mma_allocate(InAct,nIn2,Label='InAct')
+      InAct(:)=Zero
+      Call mma_allocate(Out,nIn2,Label='Out')
+      Out(:)=Zero
+      Call mma_allocate(TempX,nIn2,Label='TempX')
+      Call mma_allocate(TempY,nIn2,Label='TempY')
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -96,14 +97,14 @@
             If (kIrrep.lt.jIrrep) Then
                Call DGEMM_('N','N',
      &                     nBas(jIrrep),nBas(kIrrep),nBas(kIrrep),
-     &                1.0d0,rIn(ipDisp(jDisp)+ip(jIrrep)),nBas(jIrrep),
+     &                One,rIn(ipDisp(jDisp)+ip(jIrrep)),nBas(jIrrep),
      &                     CMO(ipCM(kIrrep),1),nBas(kIrrep),
-     &                     0.0d0,Work(ipY),nBas(jIrrep))
+     &                Zero,TempY,nBas(jIrrep))
                Call DGEMM_('T','N',
      &                     nBas(jIrrep),nBas(kirrep),nBas(jIrrep),
-     &                     1.0d0,CMO(ipCM(jIrrep),1),nBas(jIrrep),
-     &                     Work(ipY),nBas(jIrrep),
-     &                     0.0d0,Work(ipAct+ip2(kIrrep)),nBas(jIrrep))
+     &                     One,CMO(ipCM(jIrrep),1),nBas(jIrrep),
+     &                         TempY,nBas(jIrrep),
+     &                     Zero,Act(1+ip2(kIrrep)),nBas(jIrrep))
             If (Show) Then
                Write (6,*)
                Write (6,*) 'ipDisp(jDisp),ip(jIrrep)=',
@@ -124,27 +125,27 @@
      &                    CMO(ipCM(jIrrep),1),1,
      &                    CMO(ipCM(jIrrep),1),1)
             End If
-               Call DGetMO(Work(ipAct+ip2(kIrrep)),Nbas(jIrrep),
+               Call DGetMO(Act(1+ip2(kIrrep)),Nbas(jIrrep),
      &                  nbas(jIrrep),nBas(kIrrep),
-     &                  Work(ipAct+ip2(jIrrep)),nBas(kIrrep))
+     &                  Act(1+ip2(jIrrep)),nBas(kIrrep))
             Else If (kIrrep.eq.jIrrep) Then
-               Call Square(rIn(ipDisp(jDisp)+ip(jIrrep)),Work(ipX),
+               Call Square(rIn(ipDisp(jDisp)+ip(jIrrep)),TempX,
      &                  1,nBas(kirrep),nBas(kirrep))
                Call DGEMM_('N','N',
      &                     nBas(jIrrep),nBas(kIrrep),nBas(kIrrep),
-     &                     1.0d0,work(ipX),nBas(jIrrep),
-     &                     CMO(ipCM(kIrrep),1),nBas(kIrrep),
-     &                     0.0d0,Work(ipY),nBas(jIrrep))
+     &                     One,TempX,nBas(jIrrep),
+     &                         CMO(ipCM(kIrrep),1),nBas(kIrrep),
+     &                     Zero,TempY,nBas(jIrrep))
                Call DGEMM_('T','N',
      &                     nBas(jIrrep),nBas(kirrep),nBas(jIrrep),
-     &                     1.0d0,CMO(ipCM(jIrrep),1),nBas(jIrrep),
-     &                     Work(ipY),nBas(jIrrep),
-     &                     0.0d0,Work(ipAct+ip2(jIrrep)),nBas(jIrrep))
+     &                     One,CMO(ipCM(jIrrep),1),nBas(jIrrep),
+     &                         TempY,nBas(jIrrep),
+     &                     Zero,Act(1+ip2(jIrrep)),nBas(jIrrep))
             End If
             If (Show) Then
                Write (6,*) 'jIrrep,kIrrep=',jIrrep,kIrrep
-               Write (6,'(A,G20.10)') 'ipAct:',
-     &               DDot_(nIn2,Work(ipAct),1,Work(ipAct),1)
+               Write (6,'(A,G20.10)') 'Act:',
+     &               DDot_(nIn2,Act,1,Act,1)
             End If
          End If
       End Do
@@ -165,37 +166,37 @@
             kIrrep=NrOpr(iEOr(iOper(jIrrep),iOper(iIrrep)))
             If (nBas(jIrrep).gt.0.and.nBas(kIrrep).gt.0) Then
                If (kIrrep.eq.jIrrep) Then
-                  Call Square(rIn(ipDisp2(jDisp)+ip(jIrrep)),Work(ipX),
+                  Call Square(rIn(ipDisp2(jDisp)+ip(jIrrep)),TempX,
      &                        1,nBas(kirrep),nBas(kirrep))
                   Call DGEMM_('N','N',
      &                        nBas(jIrrep),nBas(kIrrep),nBas(kIrrep),
-     &                        1.0d0,Work(ipX),nBas(jIrrep),
-     &                        CMO(ipCM(kIrrep),1),nBas(kIrrep),
-     &                        0.0d0,Work(ipY),nBas(jIrrep))
+     &                        One,TempX,nBas(jIrrep),
+     &                            CMO(ipCM(kIrrep),1),nBas(kIrrep),
+     &                        Zero,TempY,nBas(jIrrep))
                   Call DGEMM_('T','N',
      &                     nBas(jIrrep),nBas(kirrep),nBas(jIrrep),
-     &                     1.0d0,CMO(ipCM(jIrrep),1),nBas(jIrrep),
-     &                     Work(ipY),nBas(jIrrep),
-     &                     0.0d0,Work(ipIn+ip2(jIrrep)),nBas(jIrrep))
+     &                     One,CMO(ipCM(jIrrep),1),nBas(jIrrep),
+     &                         TempY,nBas(jIrrep),
+     &                     Zero,InAct(1+ip2(jIrrep)),nBas(jIrrep))
                 Else If (kirrep.lt.jirrep) Then
                    Call DGEMM_('N','N',
      &                nBas(jIrrep),nBas(kIrrep),nBas(kIrrep),
-     &                1.0d0,rin(ipDisp2(jDisp)+ip(jIrrep)),nBas(jIrrep),
-     &                CMO(ipCM(kIrrep),1),nBas(kIrrep),
-     &                0.0d0,Work(ipY),nBas(jIrrep))
+     &                One,rin(ipDisp2(jDisp)+ip(jIrrep)),nBas(jIrrep),
+     &                    CMO(ipCM(kIrrep),1),nBas(kIrrep),
+     &                Zero,TempY,nBas(jIrrep))
                    Call DGEMM_('T','N',
      &                    nBas(jIrrep),nBas(kirrep),nBas(jIrrep),
-     &                    1.0d0,CMO(ipCM(jIrrep),1),nBas(jIrrep),
-     &                    Work(ipY),nBas(jIrrep),
-     &                    0.0d0,Work(ipIn+ip2(kIrrep)),nBas(jIrrep))
-                   Call DGetMO(Work(ipIn+ip2(kIrrep)),Nbas(jIrrep),
+     &                    One,CMO(ipCM(jIrrep),1),nBas(jIrrep),
+     &                        TempY,nBas(jIrrep),
+     &                    Zero,InAct(1+ip2(kIrrep)),nBas(jIrrep))
+                   Call DGetMO(InAct(1+ip2(kIrrep)),Nbas(jIrrep),
      &                         nBas(jIrrep),nBas(kIrrep),
-     &                         Work(ipIn+ip2(jIrrep)),nBas(kIrrep))
+     &                         InAct(1+ip2(jIrrep)),nBas(kIrrep))
                 End If
                 If (Show) Then
                    Write (6,*) 'jIrrep,kIrrep=',jIrrep,kIrrep
-                   Write (6,'(A,G20.10)') 'ipIn:',
-     &                   DDot_(nIn2,Work(ipIn),1,Work(ipIn),1)
+                   Write (6,'(A,G20.10)') 'InAct:',
+     &                   DDot_(nIn2,InAct,1,InAct,1)
                 End If
              End If
           End Do
@@ -215,29 +216,29 @@
 *
             If (nBas(jIrrep)*nIsh(kIrrep).gt.0) Then
                Call DaXpY_(nIsh(kIrrep)*nBas(jIrrep),2.0d0,
-     &                    Work(ipAct+ip2(kIrrep)),1,
-     &                    Work(ipOut1+ip2(kIrrep)),1)
+     &                    Act(1+ip2(kIrrep)),1,
+     &                    Out(1+ip2(kIrrep)),1)
                Call DaXpY_(nIsh(kIrrep)*nBas(jIrrep),2.0d0,
-     &                    Work(ipIn+ip2(kIrrep)),1,
-     &                    Work(ipOut1+ip2(kIrrep)),1)
+     &                    InAct(1+ip2(kIrrep)),1,
+     &                    Out(1+ip2(kIrrep)),1)
             End If
 *
             If (nBas(jIrrep).gt.0) Then
                Do jAsh=1,nAsh(kIrrep)
                   Do kAsh=1,nAsh(kIrrep)
                      rDe=  G1(iTri(nA(kIrrep)+jAsh,nA(kIrrep)+kAsh),1)
-                     ipOut=ipOut1+ip2(kIrrep)+nIsh(kIrrep)*nBas(jIrrep)+
+                     ipOut=1+ip2(kIrrep)+nIsh(kIrrep)*nBas(jIrrep)+
      &                     nBas(jIrrep)*(kAsh-1)
-                     ipIn1=ipIn+ip2(kIrrep)
+                     ipIn1=1+ip2(kIrrep)
      &                    +nBas(jIrrep)*(jAsh-1+nIsh(kIrrep))
-                     Call DaXpY_(nBas(jIrrep),rde,Work(ipIn1),1,
-     &                                           Work(ipOut),1)
+                     Call DaXpY_(nBas(jIrrep),rde,InAct(ipIn1),1,
+     &                                              Out(ipOut),1)
                   End Do
                End Do
             End If
 *
             If (nBas(jIrrep)*nAsh(kIrrep).gt.0) Then
-               ipOut=ipOut1+ip2(kIrrep)+nIsh(kIrrep)*nBas(jIrrep)
+               ipOut=1+ip2(kIrrep)+nIsh(kIrrep)*nBas(jIrrep)
                If (Show) Then
                   Write (6,*) 'jIrrep,kIrrep=',jIrrep,kIrrep
                   Write (6,'(A,G20.10)') 'ipDisp3:',
@@ -247,12 +248,12 @@
                End If
                Call DGEMM_('T','N',
      &                     nBas(jIrrep),nAsh(kIrrep),nBas(jIrrep),
-     &                     1.0d0,CMO(ipCM(jIrrep),1),nBas(jIrrep),
-     &                     rin(ipDisp3(jDisp)+iii),nBas(jIrrep),
-     &                     0.0d0,Work(ipY),nBas(jIrrep))
-               Call DaXpY_(nAsh(kIrrep)*nBas(jIrrep),1.0d0,
-     &                    Work(ipY),1,
-     &                    Work(ipOut),1)
+     &                     One,CMO(ipCM(jIrrep),1),nBas(jIrrep),
+     &                         rin(ipDisp3(jDisp)+iii),nBas(jIrrep),
+     &                     Zero,TempY,nBas(jIrrep))
+               Call DaXpY_(nAsh(kIrrep)*nBas(jIrrep),One,
+     &                    TempY,1,
+     &                    Out(ipOut),1)
                iii=iii+nBas(jIrrep)*nAsh(kIrrep)
             End If
 #ifdef __INTEL_COMPILER
@@ -260,8 +261,8 @@
 #endif
             If (Show) Then
                Write (6,*) 'jIrrep,kIrrep=',jIrrep,kIrrep
-               Write (6,'(A,G20.10)') 'ipOut1:',
-     &               DDot_(nIn2,Work(ipOut1),1,Work(ipOut1),1)
+               Write (6,'(A,G20.10)') 'Out:',
+     &               DDot_(nIn2,Out,1,Out,1)
             End If
          End Do
          If (Show) Write (6,*)
@@ -271,7 +272,7 @@
          irc=-1
          iopt=0
          Label='TOTAL'
-         Call dWrMck(irc,iopt,Label,jdisp,Work(ipOut1),2**iIrrep)
+         Call dWrMck(irc,iopt,Label,jdisp,Out,2**iIrrep)
          If (iRc.ne.0) Then
             Write (6,*) 'WrDisk: Error writing to MCKINT'
             Write (6,'(A,A)') 'Label=',Label
@@ -279,13 +280,13 @@
          End If
          If (Show) Then
             Write (6,'(A,G20.10)') 'TOTAL:',
-     &            DDot_(nIn2,Work(ipOut1),1,Work(ipOut1),1)
+     &            DDot_(nIn2,Out,1,Out,1)
          End If
 *
          irc=-1
          iopt=0
          Label='INACTIVE'
-         Call dWrMck(irc,iopt,Label,jdisp,work(ipIn),2**iIrrep)
+         Call dWrMck(irc,iopt,Label,jdisp,InAct,2**iIrrep)
          If (iRc.ne.0) Then
             Write (6,*) 'WrDisk: Error writing to MCKINT'
             Write (6,'(A,A)') 'Label=',Label
@@ -293,7 +294,7 @@
          End If
          If (Show) Then
             Write (6,'(A,G20.10)') 'INACTIVE:',
-     &            DDot_(nIn2,Work(ipIn),1,Work(ipIn),1)
+     &            DDot_(nIn2,InAct,1,InAct,1)
             Write (6,*)
          End If
 *
@@ -320,7 +321,7 @@
          irc=-1
          iopt=0
          Label='TOTAL'
-         Call dWrMck(irc,iopt,Label,jdisp,Work(ipAct),2**iIrrep)
+         Call dWrMck(irc,iopt,Label,jdisp,Act,2**iIrrep)
          If (iRc.ne.0) Then
             Write (6,*) 'WrDisk: Error writing to MCKINT'
             Write (6,'(A,A)') 'Label=',Label
@@ -328,18 +329,18 @@
          End If
          If (Show) Then
             Write (6,'(A,G20.10)') 'TOTAL:',
-     &            DDot_(nIn2,Work(ipAct),1,Work(ipAct),1)
+     &            DDot_(nIn2,Act,1,Act,1)
          End If
 *
       End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call GetMem('TEMP2','FREE','REAL',ipX,nIn2)
-      Call GetMem('TEMP1','FREE','REAL',ipY,nIn2)
-      Call GetMem('OUT','FREE','REAL',ipOUT1,nIn2)
-      Call GetMem('INACTIVE','FREE','REAL',ipIN,nIn2)
-      Call GetMem('ACTIVE','FREE','REAL',ipAct,nIn2)
+      Call mma_deallocate(TempY)
+      Call mma_deallocate(TempX)
+      Call mma_deallocate(Out)
+      Call mma_deallocate(InAct)
+      Call mma_deallocate(Act)
 *                                                                      *
 ************************************************************************
 *                                                                      *
