@@ -10,7 +10,7 @@
 *                                                                      *
 * Copyright (C) Mickael G. Delcey                                      *
 ************************************************************************
-      SUBROUTINE CHO_Prec_MCLR(ipCMO,nIsh,nAsh,LuAChoVec,LuChoInt)
+      SUBROUTINE CHO_Prec_MCLR(CMO,nIsh,nAsh,LuAChoVec,LuChoInt)
 ************************************************************************
 *                                                                      *
 *  Author : M. G. Delcey                                               *
@@ -25,36 +25,50 @@
 *           the full list of integrals!                                *
 *                                                                      *
 ************************************************************************
+      use ChoArr, only: nDimRS
+      use ChoSwp, only: InfVec
+      use Data_structures, only: DSBA_Type, Allocate_DSBA
+      use Data_structures, only: Deallocate_DSBA
+      use Data_structures, only: SBA_Type
+      use Data_structures, only: Allocate_SBA, Deallocate_SBA
       Implicit Real*8 (a-h,o-z)
-#include "warnings.fh"
-      Character*13 SECNAM
-      Parameter (SECNAM = 'CHO_PREC_MCLR')
-      Integer   ISTLT(8),ISTSQ(8),ISSQ(8,8),ipLpq(8)
-      Integer   LuAChoVec(8),ipCMOt(8),LuChoInt(2)
-      Integer  nAsh(8),nIsh(8),nIshb(8),nIshe(8),iSkip(8),
-     &        nAshb(8),nAshe(8)
+      Real*8 CMO(*)
+#include "warnings.h"
+      Character(LEN=13), Parameter:: SECNAM = 'CHO_PREC_MCLR'
+
+      Integer   ISTSQ(8)
+      Integer   LuAChoVec(8),LuChoInt(2)
+      Integer   nAsh(8),nIsh(8),nIshb(8),nIshe(8),nAshb(8),nAshe(8)
       Real*8    tread(2),ttran(2),tform(2) ,tform2(2) ,
      &                            tforma(2),tforma2(2),tMO(2)
       Logical timings
+#include "real.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
 #include "choorb.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
       Character*50 CFmt
-      parameter ( N2 = InfVec_N2 )
-      parameter (zero = 0.0D0, one = 1.0D0, xone=-1.0D0)
+      Real*8, parameter:: xone=-One
       Character*6 mode
-      Logical DoRead,taskleft
-      parameter (DoRead = .false. )
-      Integer   Cho_LK_MaxVecPerBatch
-      External  Cho_LK_MaxVecPerBatch
+      Logical taskleft, add
+      Logical, Parameter :: DoRead = .false.
+      Integer, External::  Cho_LK_MaxVecPerBatch
+      Real*8, Allocatable:: iiab(:), tupq(:), Lrs(:,:), Integral(:)
+      Real*8, Allocatable, Target:: iirs(:), turs(:)
+      Real*8, Pointer :: piirs(:,:)=>Null(), pturs(:,:)=>Null()
+
+      Type (DSBA_Type) CMOt, Tmp
+      Type (SBA_Type) Lpq(1)
+
+      Real*8, Allocatable, Target :: Lii(:), Lij(:)
+      Real*8, Pointer :: pLii(:,:)=>Null(), pLij(:,:)=>Null()
+*                                                                      *
 ************************************************************************
+*                                                                      *
       MulD2h(i,j) = iEOR(i-1,j-1) + 1
-******
-      InfVec(i,j,k) = iWork(ip_InfVec-1+MaxVec*N2*(k-1)+MaxVec*(j-1)+i)
-******
-      nDimRS(i,j) = iWork(ip_nDimRS-1+nSym*(j-1)+i)
+*                                                                      *
 ************************************************************************
+*                                                                      *
       timings=.false.
       CALL CWTIME(TCstart1,TWstart1)
       do i=1,2            ! 1 --> CPU   2 --> Wall
@@ -69,11 +83,8 @@
       MaxVecPerBatch=Cho_LK_MaxVecPerBatch()
       iLoc = 3
 *
-      ISTLT(1)=0
       ISTSQ(1)=0
       DO ISYM=2,NSYM
-        NBB=NBAS(ISYM-1)*(NBAS(ISYM-1)+1)/2
-        ISTLT(ISYM)=ISTLT(ISYM-1)+NBB
         ISTSQ(iSYM)=ISTSQ(iSYM-1)+NBAS(ISYM-1)**2
       END DO
 *
@@ -124,7 +135,7 @@
 **      Check for maxmem to see if integrals would fit in memory
 **      or if batching is required
 *
-        Call GetMem('MaxM','Max','Real',KDUM,LWORK)
+        Call mma_MaxDBLE(LWORK)
         Call GAIGOP_SCAL(LWORK,'min')
 *
         Do i=1,nsym
@@ -216,29 +227,26 @@
         Do i=1,nsym
           k=MulD2h(i,jsym)
           nip=nip+nIshe(i)*nBas(k)
-          ntotie=ntotie+nIshe(i)
+          ntotie=ntotie+nIshe(i) ! For Lii^J
         End Do
         nip=nip+ntotie ! for Lii^J
 *
-        Call GetMem('iiab','Allo','Real',ipiiab,libatch)
+        Call mma_allocate(iiab,libatch,Label='iiab')
         nab=0
         If ((jsym.eq.1).and.(ntotie.gt.0)) Then
           nab=npq
-          Call GetMem('iirs','Allo','Real',ipiirs,ntotie*maxRS)
+          Call mma_allocate(iirs,ntotie*maxRS,Label='iirs')
         EndIf
-        ipiaib=ipiiab+nab*ntotie
-        Call dcopy_(libatch,[0.0d0],0,Work(ipiiab),1)
-
-*init for compilers
-        iptupq=ip_Dummy
-        iptpuq=iptupq
+        ipiaib=1+nab*ntotie
+        iiab(:)=Zero
 *
         If (taskleft) Then
            ntotae=0
            ntue=0
            ntp=0      ! do not allocate those
            labatch=0
-           write(6,*) 'Batching loop i'
+           iptpuq=-1
+*          write(6,*) 'Batching loop i'
         Else
 *
 **        Batching T loop
@@ -276,40 +284,31 @@
              ntp  =ntp + nAsh(i)*(nBas(k)+nAshe(i))
            End Do
 
-           If (ntotae.gt.0)
-     &        Call GetMem('tupq','Allo','Real',iptupq,labatch)
+           If (ntotae.gt.0) Call mma_allocate(tupq,labatch,Label='tupq')
            nab=0
            If (jsym.eq.1) Then
              nab=npq
-             If (ntue.gt.0)
-     &          Call GetMem('turs','Allo','Real',ipturs,ntue*maxRS)
+             If (ntue.gt.0) Call mma_allocate(turs,ntue*maxRS,
+     &                                        Label='turs')
            EndIf
-           iptpuq=iptupq+nab*ntue
-           call dcopy_(labatch,[0.0d0],0,Work(iptupq),1)
+           iptpuq=1+nab*ntue
+           tupq(:)=0.0D0
            If (taskleft) Then
               write(6,*) 'Batching loop a'
            EndIf
         EndIf
-*FIXME: can iptpuq be uninitialized?
 *
 **    Transpose CMO
 *
-        nCMO=0
-        Do i=1,nsym
-          nCMO=nCMO+nIshe(i)*nBas(i)
-        End Do
-        Call GetMem('CMOt','Allo','Real',ipCMOt(1),nCMO)
+        Call Allocate_DSBA(CMOt,nIShe,nBas,nSym)
+
         ioff =0
-        ioff2=0
         Do iSym=1,nsym
-          ipCMOt(iSym)=ipCMOt(1)+ioff2
           Do j=1,nIshe(iSym)
             ioff3=ioff+nBas(iSym)*(nIshb(iSym)+j-1)
-            call dcopy_(nBas(iSym),Work(ipCMO+ioff3),1,
-     &                 Work(ipCMOt(isym)+j-1),nIshe(iSym))
+            CMOt%SB(iSym)%A2(j,:) = CMO(ioff3+1:ioff3+nBas(iSym))
           End Do
           ioff =ioff +nBas(iSym)**2
-          ioff2=ioff2+nBas(iSym)*nIshe(iSym)
         End Do
 *
 **      Loop over reduced sets
@@ -337,13 +336,17 @@ c         !set index arrays at iLoc
           nRS = nDimRS(JSYM,JRED)
 
           If (jSym.eq.1) Then
-            If (ntotie.gt.0)
-     &         call dcopy_(ntotie*nRS,[0.0d0],0,Work(ipiirs),1)
-            If (ntue.gt.0)
-     &         call dcopy_(ntue*nRS,[0.0d0],0,Work(ipturs),1)
+            If (ntotie.gt.0) Then
+               piirs(1:nRS,1:ntotie) => iirs(1:nRS*ntotie)
+               piirs(:,:)=Zero
+            End If
+            If (ntue.gt.0) Then
+               pturs(1:nRS,1:ntue) => turs(1:nRS*ntue)
+               pturs(:,:)=Zero
+            End If
           EndIf
 
-          Call GetMem('MaxM','Max','Real',KDUM,LWORKe)
+          Call mma_MaxDBLE(LWORKe)
           nVec= min(LWORKE/(nRS+max(nip,ntp)),min(nVrs,MaxVecPerBatch))
           If (nVec.lt.1) Then
             WRITE(6,*) SECNAM//': Insufficient memory for J batch'
@@ -354,8 +357,7 @@ c         !set index arrays at iLoc
           EndIf
           LREAD = nRS*nVec
 *
-          Call GetMem('rsL','Allo','Real',ipLrs,LREAD)
-          Call GetMem('ChoT','Allo','Real',ipChoT,max(nIP,ntp)*nVec)
+          Call mma_allocate(Lrs,nRS,nVec,Label='Lrs')
 *
           nBatch = (nVrs-1)/nVec + 1
 *
@@ -370,9 +372,14 @@ c         !set index arrays at iLoc
             endif
             JVEC = nVec*(jBatch-1) + iVrs
             IVEC2 = JVEC - 1 + JNUM
+
+            iSwap = 1 ! Lqi,J are returned
+            Call Allocate_SBA(Lpq(1),nIshe,nBas,nVec,JSYM,nSym,iSwap)
+            Call mma_allocate(Lii,ntotie*nVec,Label='Lii')
+************************************************************************
 ************************************************************************
 *                                                                      *
-*                Let's start the real work                             *
+*                Let''s start the real work                            *
 *                                                                      *
 ************************************************************************
 *
@@ -380,11 +387,10 @@ c         !set index arrays at iLoc
 *
             CALL CWTIME(TCR1,TWR1)
 
-            CALL CHO_VECRD(Work(ipLrs),LREAD,JVEC,IVEC2,JSYM,
+            CALL CHO_VECRD(Lrs,LREAD,JVEC,IVEC2,JSYM,
      &                     NUMV,IREDC,MUSED)
 
             If (NUMV.le.0 .or.NUMV.ne.JNUM ) then
-               rc=77
                RETURN
             End If
 
@@ -396,29 +402,14 @@ c         !set index arrays at iLoc
 **          MO Half-transformation
 **          Liq^J= sum_p Lpq^J Xip
 *
-            lChoI=0
-            Do i=1,nSym
-
-               k = Muld2h(i,JSYM)
-               iSkip(k) = Min(1,
-     &              nBas(k)*nIshe(i))
-
-               ipLpq(k) = ipChoT + lChoI       ! Lvb,J
-
-               lChoI= lChoI + nIshe(i)*nBas(k)*JNUM
-
-            End Do
-
-            iSwap = 1 ! Lqi,J are returned
             kMOs = 1  !
             nMOs = 1  ! Active MOs (1st set)
 *
-            CALL CHO_X_getVtra(irc,Work(ipLrs),LREAD,jVEC,JNUM,
-     &                        JSYM,iSwap,IREDC,nMOs,kMOs,ipCMOt,
-     &                        nIshe,ipLpq,iSkip,DoRead)
+            CALL CHO_X_getVtra(irc,Lrs,LREAD,jVEC,JNUM,
+     &                        JSYM,iSwap,IREDC,nMOs,kMOs,[CMOt],
+     &                        Lpq(1),DoRead)
 
             if (irc.ne.0) then
-               rc = irc
                RETURN
             endif
 
@@ -434,13 +425,11 @@ c         !set index arrays at iLoc
             Do isym=1,nsym
               ksym=MulD2h(iSym,jsym)
               Do ii=1,nIshe(isym)
-*                 ipLip=ipLpq(isym)+nBas(kSym)*(ii-1)
-                 ipLip=ipLpq(ksym)+nBas(kSym)*(ii-1)
 *
                  Call DGEMM_('N','T',nBas(kSym),nBas(kSym),JNUM,
-     &                        1.0d0,Work(ipLip),nBas(kSym)*nIshe(iSym),
-     &                              Work(ipLip),nBas(kSym)*nIshe(iSym),
-     &                        1.0d0,Work(ip1)  ,nBas(kSym))
+     &          1.0D0,Lpq(1)%SB(kSym)%A3(:,ii,1),nBas(kSym)*nIshe(iSym),
+     &                Lpq(1)%SB(kSym)%A3(:,ii,1),nBas(kSym)*nIshe(iSym),
+     &          1.0d0,iiab(ip1:)  ,nBas(kSym))
                  ip1=ip1+nBas(kSym)**2
               End Do
             End Do
@@ -453,80 +442,93 @@ c         !set index arrays at iLoc
 **          Lii^J = sum_q Liq^J Xiq
 *
             If (jSym.eq.1) Then
-*             The end of ipChoT is allocated for Lii^J
-              ipLii=ipChoT+(nIP-ntotie)*nVec
-              ipMO=ipCMO
+              ipMO=1
+
+              iE = 0
               Do isym=1,nsym
+                iS = 1 + iE
+                iE = iE + JNUM*nIshe(iSym)
+
+                pLii(1:JNUM,1:nIshe(iSym)) => Lii(iS:iE)
+
                 Do ii=1,nIshe(iSym)
                   ipMO=ipMO+ISTSQ(iSym)
-                  ipLip=ipLpq(iSym)+nBas(iSym)*(ii-1)
                   ipMOi=ipMO+(nIshb(isym)+ii-1)*nBas(iSym)
-                  ipLiii=ipLii+(ii-1)*JNUM
                   Call dGeMV_('T',nBas(iSym),JNUM,
-     &                       1.0d0,Work(ipLip),nBas(iSym)*nIshe(iSym),
-     &                             Work(ipMOi),1,
-     &                       0.0d0,Work(ipLiii),1)
+     &          1.0d0,Lpq(1)%SB(iSym)%A3(:,ii,1),nBas(iSym)*nIshe(iSym),
+     &                            CMO(ipMOi),1,
+     &                       0.0d0,pLii(:,ii),1)
                 End Do
-*                ipMO=ipMO+nIsh(iSym)*nBas(iSym)
-                ipLii=ipLii+JNUM*nIshe(iSym)
+                pLii => Null()
               End Do
-            CALL CWTIME(TCR1,TWR1)
-            ttran(1) = ttran(1) + (TCR1 - TCR2)
-            ttran(2) = ttran(2) + (TWR1 - TWR2)
+
+              CALL CWTIME(TCR1,TWR1)
+              ttran(1) = ttran(1) + (TCR1 - TCR2)
+              ttran(2) = ttran(2) + (TWR1 - TWR2)
 *
 ************************************************************************
 **            Integral formation
 **            (i i | p q ) = sum_J Lii^J  Lpq^J
 *
-              ipLii=ipChoT+(nIP-ntotie)*nVec
+              pLii(1:JNUM,1:ntotie) => Lii(1:JNUM*ntotie)
               Call DGEMM_('N','N',nRS,ntotie,JNUM,
-     &                    1.0d0,Work(ipLrs),nRS,
-     &                          Work(ipLii),JNUM,
-     &                    1.0d0,Work(ipiirs),nRS)
-            CALL CWTIME(TCR2,TWR2)
-            tform2(1) = tform2(1) + (TCR2 - TCR1)
-            tform2(2) = tform2(2) + (TWR2 - TWR1)
+     &                    1.0d0,Lrs,nRS,
+     &                          pLii,JNUM,
+     &                    1.0d0,piirs,nRS)
+              pLii => Null()
 
-            EndIf
+              CALL CWTIME(TCR2,TWR2)
+              tform2(1) = tform2(1) + (TCR2 - TCR1)
+              tform2(2) = tform2(2) + (TWR2 - TWR1)
+
+            End If  ! jSym
+
+            Call mma_deallocate(Lii)
+            Call Deallocate_SBA(Lpq(1))
 *
 ************************************************************************
+************************************************************************
 **          Read half-transformed active vectors
 *
-            lChoA=0
-            Do i=1,nSym
-               k = Muld2h(i,JSYM)
-               ipLpq(k) = ipChoT + lChoA       ! Lvb,J
-               lChoA= lChoA + nAsh(k)*nBas(i)*JNUM
-            End Do
-*
-            ioff=0
+            iSwap = 0 ! Lvb,J
+            Call Allocate_SBA(Lpq(1),nAsh,nBas,nVec,JSYM,nSym,iSwap)
+
+            Call mma_allocate(Lij,ntue*nVec,Label='Lij')
+
             Do i=1,nSym
               k = Muld2h(i,JSYM)
               lvec=nAsh(k)*nBas(i)*JNUM
-              iAdr2=(JVEC-1)*nAsh(k)*nBas(i)+ioff
-              call DDAFILE(LuAChoVec(Jsym),2,Work(ipLpq(k)),
-     &                     lvec,iAdr2)
+              iAdr2=(JVEC-1)*nAsh(k)*nBas(i)
+              call DDAFILE(LuAChoVec(Jsym),2,Lpq(1)%SB(i)%A3,lvec,iAdr2)
             End Do
 *
 ************************************************************************
 **          Form (tp|uq) integrals
 *
             Do j=1,JNUM
+
               ioff=0
               Do i=1,nsym
                 k = Muld2h(i,JSYM)
+
                 Do it=0,nAshe(k)-1
-                  ipLtp=ipLpq(k)+nAshb(k)+it+nAsh(k)*nBas(i)*(j-1)
+                  itt = nAshb(k)+it + 1
+
                   Do iu=0,nAshb(k)+it
+                     iuu = iu + 1
+
                     itu=it*(2*nAshb(k)+it+1)/2+iu
-                    ipLuq=ipLpq(k)+iu+nAsh(k)*nBas(i)*(j-1)
+
                     ipInt=iptpuq+ioff+itu*nBas(i)**2
+
                     Call DGER(nBas(i),nBas(i),
-     &                        1.0d0,Work(ipLtp),nAsh(k),
-     &                              Work(ipLuq),nAsh(k),
-     &                              Work(ipInt),nBas(i))
+     &                 1.0d0,Lpq(1)%SB(i)%A3(itt,1,j),nAsh(k),
+     &                       Lpq(1)%SB(i)%A3(iuu,1,j),nAsh(k),
+     &                              tupq(ipInt),nBas(i))
+
                   End Do
                 End Do
+
                 ioff=ioff+nAshe(k)*(2*nAshb(k)+nAshe(k)+1)/2*
      &               nBas(i)**2
               End Do
@@ -539,39 +541,46 @@ c         !set index arrays at iLoc
 **          Second MO transformation
 *
            If (jsym.eq.1) Then
-             ipLtu=ipChoT+(ntp-ntue)*nVec
+             ipLtu=1
+
              ioff=0
+             iE = 0
              Do i=1,nsym
+               iS = iE + 1
                Do j=1,JNUM
-                 ipLtp=ipLpq(i)+(j-1)*(nBas(i)*nAsh(i))
-                 ipMO=ipCMO+ioff+nBas(i)*(nIsh(i)+nAshb(i))
+
+                 ipMO=1+ioff+nBas(i)*(nIsh(i)+nAshb(i))
                  Do k=0,nAshe(i)-1
                    Call dGeMV_('N',nAshb(i)+k+1,nBas(i),
-     &                         1.0d0,Work(ipLtp),nAsh(i),
-     &                               Work(ipMO+k*nBas(i)),1,
-     &                         0.0d0,Work(ipLtu),1)
+     &                  1.0d0,Lpq(1)%SB(i)%A3(:,1,j),nAsh(i),
+     &                               CMO(ipMO+k*nBas(i)),1,
+     &                         0.0d0,Lij(ipLtu),1)
                    ipLtu=ipLtu+(nAshb(i)+k+1)
                  EndDo
                End Do
                ioff=ioff+nBas(i)**2
              End Do
+
             CALL CWTIME(TCR2,TWR2)
 *
 ************************************************************************
 **           Formation of the (tu|rs) integral
 *
-             ipInt=ipturs
-             ipLtu=ipChoT+(ntp-ntue)*nVec
+             ipInt=1
+             iE = 0
              Do i=1,nsym
-               na2=nAshe(i)*nAshb(i)+nAshe(i)*(nAshe(i)+1)/2
-               If (na2.gt.0) Then
-                 Call DGEMM_('N','T',nRS,na2,JNUM,
-     &                       1.0d0,Work(ipLrs),nRS,
-     &                             Work(ipLtu),na2,
-     &                       1.0d0,Work(ipInt),nRS)
-                 ipLtu=ipLtu+na2*JNUM
-                 ipInt=ipInt+nRS*na2
-               End If
+               na2 = nAshe(i)*nAshb(i) + nAshe(i)*(nAshe(i)+1)/2
+               If (na2==0) Cycle
+               iS = iE + 1
+               iE = iE + na2 * JNUM
+
+               pLij(1:na2,1:JNUM) => Lij(iS:iE)
+
+               Call DGEMM_('N','T',nRS,na2,JNUM,
+     &                     1.0d0,Lrs,nRS,
+     &                           pLij,na2,
+     &                     1.0d0,turs(ipInt),nRS)
+               ipInt=ipInt+nRS*na2
              End Do
             CALL CWTIME(TCR1,TWR1)
             tforma2(1) = tforma2(1) + (TCR1 - TCR2)
@@ -581,40 +590,48 @@ c         !set index arrays at iLoc
 *                                                                      *
 *                Cholesky loop is over!                                *
 *                                                                      *
+************************************************************************
 ************************************************************************
 
-          End Do ! J batch
+           Call mma_deallocate(Lij)
+           Call Deallocate_SBA(Lpq(1))
+          End Do ! jbatch
 *
 **        Transform to full storage, use Lrs as temp storage
 *
           If (jsym.eq.1) Then
+            add = .True.
+            mode = 'tofull'
+            nMat = 1
             Do i=1,ntotie
-              ip1=ipiiab+nab*(i-1)
-              ipRS1=ipiirs+nRS*(i-1)
-              mode = 'tofull'
-              Call play_rassi_sto(irc,iLoc,JSYM,ISTSQ,ISSQ,
-     &                                   ip1,ipRS1,mode)
+              Call Allocate_DSBA(Tmp,nBas,nBas,nSym,aCase='TRI',
+     &                           Ref=iiab(1+nab*(i-1):))
+              Call swap_rs2full(irc,iLoc,nRS,nMat,JSYM,
+     &                          [Tmp],piirs(:,i),mode,add)
+              Call Deallocate_DSBA(Tmp)
             End Do
             Do i=1,ntue
-              ip1=iptupq+npq*(i-1)
-              ipRS1=ipturs+nrs*(i-1)
-              mode = 'tofull'
-*              Call play_rassi_sto(irc,iLoc,JSYM,ISTLT,ISSQ,
-              Call play_rassi_sto(irc,iLoc,JSYM,ISTSQ,ISSQ,
-     &                                   ip1,ipRS1,mode)
+              Call Allocate_DSBA(Tmp,nBas,nBas,nSym,aCase='TRI',
+     &                           Ref=tupq(1+npq*(i-1):))
+              Call swap_rs2full(irc,iLoc,nRS,nMat,JSYM,
+     &                          [Tmp],pturs(:,i),mode,add)
+              Call Deallocate_DSBA(Tmp)
             End Do
           EndIf
 *
-          Call GetMem('rsL','Free','Real',ipLrs,LREAD)
-          Call GetMem('ChoT','Free','Real',ipChoT,max(nIP,ntp)*nVec)
+          Call mma_deallocate(Lrs)
  998      Continue
         End Do ! reduced set JRED
 *
         If (jsym.eq.1) Then
-          If (ntotie.gt.0)
-     &      Call GetMem('iirs','Free','Real',ipiirs,ntotie*maxRS)
-          If (ntue.gt.0)
-     &      Call GetMem('turs','Free','Real',ipturs,ntue*maxRS)
+          If (ntotie.gt.0) Then
+             Call mma_deallocate(iirs)
+             piirs=>Null()
+          End If
+          If (ntue.gt.0) Then
+             Call mma_deallocate(turs)
+             pturs=>Null()
+          End If
         EndIf
 *
 ** MGD  Gather integrals from parallel runs
@@ -622,7 +639,7 @@ c         !set index arrays at iLoc
 
 *
         CALL CWTIME(TCR1,TWR1)
-        Call GetMem('MOt-int','Allo','Real',ipInt,maxpq)
+        Call mma_allocate(Integral,maxpq,Label='Integral')
         ip1=ipiaib
         ip3=iptpuq
         isum=0
@@ -630,30 +647,32 @@ c         !set index arrays at iLoc
         Do isym=1,nSym
           ksym=MulD2h(iSym,jsym)
           nvirt=nBas(kSym)-nIsh(kSym)
-          ipMO=ipCMO+ISTSQ(kSym)+nBas(kSym)*nIsh(kSym)
+          ipMO=1+ISTSQ(kSym)+nBas(kSym)*nIsh(kSym)
+
           Do ii=1,nIshe(isym)
 *
 **          MO transform ( i i | p q)
 *
             If (jsym.eq.1) Then
               isum=isum+1
-              ip2=ipiiab+nab*(isum-1)
+              ip2=1+nab*(isum-1)
               ioff2=0
               Do ksym2=1,nsym
-                ipMO2=ipCMO+ioff2+nBas(kSym2)*nIsh(kSym2)
+                ipMO2=1+ioff2+nBas(kSym2)*nIsh(kSym2)
                 nvirt2=nBas(kSym2)-nIsh(kSym2)
                 Do j=1,nvirt2
                   ipMOj=ipMO2+(j-1)*nBas(kSym2)
-                  ipIntj=ipInt+(j-1)*nBas(kSym2)
-                  Call DSPMV_('U',nBas(kSym2),1.0d0,Work(ip2),
-     &                       Work(ipMOj),1,0.0d0,Work(ipIntj),1)
+                  ipIntj=1+(j-1)*nBas(kSym2)
+                  Call DSPMV_('U',nBas(kSym2),1.0d0,iiab(ip2),
+     &                       CMO(ipMOj),1,0.0d0,Integral(ipIntj),1)
                 End Do
                 Call DGEMM_('T','N',nvirt2,nvirt2,nBas(kSym2),
-     &                      1.0d0,Work(ipInt),nBas(kSym2),
-     &                            Work(ipMO2),nBas(kSym2),
-     &                      0.0d0,Work(ip2)  ,nvirt2)
+     &                      1.0d0,Integral,nBas(kSym2),
+     &                            CMO(ipMO2),nBas(kSym2),
+     &                      0.0d0,iiab(ip2)  ,nvirt2)
 *
-                call DDAFILE(LuChoInt(1),1,Work(ip2),nvirt2**2,iAdr)
+                Call GADSum(iiab(ip2),nvirt2**2)
+                call DDAFILE(LuChoInt(1),1,iiab(ip2),nvirt2**2,iAdr)
 *
                 ip2=ip2+nBas(kSym2)**2
                 ioff2 =ioff2 +nBas(kSym2)**2
@@ -667,18 +686,19 @@ c         !set index arrays at iLoc
 **      MO transform ( i p | i q)
 *
             Call DGEMM_('N','N',nBas(kSym),nvirt,nBas(kSym),
-     &                  1.0d0,Work(ip1)  ,nBas(kSym),
-     &                        Work(ipMO),nBas(kSym),
-     &                  0.0d0,Work(ipInt),nBas(kSym))
+     &                  1.0d0,iiab(ip1:)  ,nBas(kSym),
+     &                        CMO(ipMO),nBas(kSym),
+     &                  0.0d0,Integral,nBas(kSym))
             Call DGEMM_('T','N',nvirt,nvirt,nBas(kSym),
-     &                  1.0d0,Work(ipInt),nBas(kSym),
-     &                        Work(ipMO),nBas(kSym),
-     &                  0.0d0,Work(ip1)  ,nvirt)
+     &                  1.0d0,Integral,nBas(kSym),
+     &                        CMO(ipMO),nBas(kSym),
+     &                  0.0d0,iiab(ip1:)  ,nvirt)
 *
             Do i=1,ksym-1
                 iAdr=iAdr+(nBas(i)-nIsh(i))**2
             End Do
-            call DDAFILE(LuChoInt(1),1,Work(ip1),nvirt**2,iAdr)
+            Call GADSum(iiab(ip1:),nvirt**2)
+            call DDAFILE(LuChoInt(1),1,iiab(ip1:),nvirt**2,iAdr)
             Do i=ksym+1,nsym
                 iAdr=iAdr+(nBas(i)-nIsh(i))**2
             End Do
@@ -700,28 +720,29 @@ c         !set index arrays at iLoc
             End Do
           End Do
 *
-          ipMO=ipCMO+ISTSQ(iSym)
+          ipMO=1+ISTSQ(iSym)
           na2=nAshe(ksym)*nAshb(ksym)+nAshe(ksym)*(nAshe(ksym)+1)/2
           Do itu=1,na2
             If (jsym.eq.1) Then
               isum2=isum2+1
-              ip2=iptupq+npq*(isum2-1)
+              ip2=1+npq*(isum2-1)
               ioff2=0
               Do ksym2=1,nsym
-                ipMO2=ipCMO+ioff2
+                ipMO2=1+ioff2
                 Do j=1,nBas(ksym2)
                   ipMOj=ipMO2+(j-1)*nBas(kSym2)
-                  ipIntj=ipInt+(j-1)*nBas(kSym2)
-                  Call DSPMV_('U',nBas(kSym2),1.0d0,Work(ip2),
-     &                       Work(ipMOj),1,0.0d0,Work(ipIntj),1)
+                  ipIntj=1+(j-1)*nBas(kSym2)
+                  Call DSPMV_('U',nBas(kSym2),1.0d0,tupq(ip2),
+     &                       CMO(ipMOj),1,0.0d0,Integral(ipIntj),1)
                 End Do
                 If (nBas(ksym2).gt.0) Then
                   Call DGEMM_('T','N',nBas(ksym2),nBas(kSym2),
      &                              nBas(kSym2),1.0d0,
-     &                              Work(ipInt),nBas(kSym2),
-     &                              Work(ipMO2),nBas(kSym2),
-     &                        0.0d0,Work(ip2)  ,nBas(kSym2))
-                  call DDAFILE(LuChoInt(2),1,Work(ip2),nBas(kSym2)**2,
+     &                              Integral,nBas(kSym2),
+     &                              CMO(ipMO2),nBas(kSym2),
+     &                        0.0d0,tupq(ip2)  ,nBas(kSym2))
+                  Call GADSum(tupq(ip2),nBas(kSym2)**2)
+                  call DDAFILE(LuChoInt(2),1,tupq(ip2),nBas(kSym2)**2,
      &            iAdrtu)
 *
                   ip2=ip2+nBas(kSym2)**2
@@ -735,28 +756,25 @@ c         !set index arrays at iLoc
 **        MO transform ( t p | u q)
 *
             Call DGEMM_('N','N',nBas(iSym),nBas(iSym),nBas(iSym),
-     &                  1.0d0,Work(ip3)  ,nBas(iSym),
-     &                        Work(ipMO),nBas(iSym),
-     &                  0.0d0,Work(ipInt),nBas(iSym))
+     &                  1.0d0,tupq(ip3)  ,nBas(iSym),
+     &                        CMO(ipMO),nBas(iSym),
+     &                  0.0d0,Integral,nBas(iSym))
             Call DGEMM_('T','N',nBas(iSym),nBas(iSym),nBas(iSym),
-     &                  1.0d0,Work(ipInt),nBas(iSym),
-     &                        Work(ipMO),nBas(iSym),
-     &                  0.0d0,Work(ip3) ,nBas(iSym))
+     &                  1.0d0,Integral,nBas(iSym),
+     &                        CMO(ipMO),nBas(iSym),
+     &                  0.0d0,tupq(ip3) ,nBas(iSym))
             Do i=1,isym-1
                 iAdrtu=iAdrtu+nBas(i)**2
             End Do
 
-            call DDAFILE(LuChoInt(2),1,Work(ip3),nBas(iSym)**2,iAdrtu)
+            Call GADSum(tupq(ip3),nBas(iSym)**2)
+            call DDAFILE(LuChoInt(2),1,tupq(ip3),nBas(iSym)**2,iAdrtu)
 
             Do i=isym+1,nsym
-*               j=MulD2h(i,jsym)
                 iAdrtu=iAdrtu+nBas(i)**2
             End Do
             ip3=ip3+nBas(iSym)**2
 *
-*            Do i=1,nsym
-*              iAdrtu=iAdrtu+nBas(i)**2
-*            enddo
           End Do
 
         End Do
@@ -764,16 +782,15 @@ c         !set index arrays at iLoc
         tMO(1) = tMO(1) + (TCR2 - TCR1)
         tMO(2) = tMO(2) + (TWR2 - TWR1)
 *
-        Call GetMem('MOt-int','Free','Real',ipInt,maxpq)
+        Call mma_deallocate(Integral)
 *
         Do i=1,nsym
           nIshb(i)=nIshb(i)+nIshe(i)  ! now those are done!
           nAshb(i)=nAshb(i)+nAshe(i)  ! now those are done!
         EndDo
-        Call GetMem('CMOt','Free','Real',ipCMOt(1),nCMO)
-        Call GetMem('iiab','Free','Real',ipiiab,libatch)
-        If (ntotae.gt.0)
-     &     Call GetMem('tupq','Free','Real',iptupq,labatch)
+        Call Deallocate_DSBA(CMOt)
+        Call mma_deallocate(iiab)
+        If (ntotae.gt.0) Call mma_deallocate(tupq)
         If (taskleft) Go to 50  ! loop over i/t batches
 *
  999    Continue
