@@ -9,6 +9,7 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine PrInp_MCLR(iPL)
+      use Exp, only: nexp_max
 ************************************************************************
 *                                                                      *
 *     Echo input                                                       *
@@ -27,15 +28,10 @@
 #include "cicisp_mclr.fh"
 #include "disp_mclr.fh"
 #include "sa.fh"
-      Character*8   Fmt1,Fmt2
-      Character XYZ(3)
-      Character*100  Line,BlLine,StLine
-      Data XYZ / 'X','Y','Z' /
-*----------------------------------------------------------------------*
-*     Start and define the paper width                                 *
-*----------------------------------------------------------------------*
-      lPaper=110
-*     lPaper=80
+      Character(LEN=8) Fmt1,Fmt2
+      Character(LEN=100)  Line,BlLine,StLine
+      Character(LEN=1) :: XYZ(3)=['X','Y','Z']
+      Logical :: RICD=.FALSE.
 *----------------------------------------------------------------------*
 *     Initialize blank and header lines                                *
 *----------------------------------------------------------------------*
@@ -45,11 +41,13 @@
          BlLine(i:i)=' '
          StLine(i:i)='*'
       End Do
-      lPaper=132
+*     lPaper=132
 *     left=(lPaper-lLine)/2
       left=5
       Write(Fmt1,'(A,I3.3,A)') '(',left,'X,A)'
       Write(Fmt2,'(A,I3.3,A)') '(',left,'X,'
+*----------------------------------------------------------------------*
+      Call DecideOnCholesky(RICD)
 *----------------------------------------------------------------------*
 *     Print the project title                                          *
 *----------------------------------------------------------------------*
@@ -63,7 +61,7 @@
             If ( i.ge.4 .and. i.le.nLine-2 )
      &         Write(Line,'(18A4)')(TitleIN((i-4)*18+j),j=1,18)
             If (iPL.ge.3) Then
-               Call Center(Line)
+               Call Center_Text(Line)
                Write(6,Fmt1) '*'//Line//'*'
             End If
          End Do
@@ -77,9 +75,9 @@
          Write(6,Fmt1) 'Header of the ONEINT file:'
          Write(6,Fmt1) '--------------------------'
          Write(Line,Fmt1)  Header1I(1)
-         Write(6,'(A)') Line(:mylen(Line))
+         Write(6,'(A)') trim(Line)
          Write(Line,Fmt1)  Header1I(2)
-         Write(6,'(A)') Line(:mylen(Line))
+         Write(6,'(A)') trim(Line)
          Write(6,*)
 *----------------------------------------------------------------------*
 *     Print cartesian coordinates of the system                        *
@@ -182,7 +180,7 @@
             Write(6,Fmt2//'A,T47,8I6)')
      &               'Number of Orbitals',
      &                              (nOrb(iSym),iSym=1,nSym)
-            Write(6,Fmt2//'A,T47,8I8)')
+            Write(6,Fmt2//'A,T47,8I6)')
      &            'Number of configurations',
      &                             (ncsf(isym),isym=1,nsym)
 
@@ -239,6 +237,13 @@
      &      'Convergence threshold= ',Epsilon
          Write(6,Fmt2//'A,T45,I8)')
      &      'Max number of iterations in PCG: ',nIter
+         If (RICD) Then
+            If (NewCho) Then
+               Write(6,Fmt2//'A)') 'Using the Cho-Fock Algorithm'
+            Else
+               Write(6,Fmt2//'A)') 'Using the Cho-MO Algorithm'
+            End If
+         End If
 *
       If (SPINPOL) Then
          Write(6,Fmt1) 'CALCULATING SPIN POLARIZATION'
