@@ -21,19 +21,53 @@
 *     iDSym  : Symmetry of transformation
 *     sign   : 1:real -1:complex
 *     jspin  : 0:singlet 1:triplet
-*
+*                                                                      *
 ************************************************************************
-*
+*                                                                      *
+      use Arrays, only: CMO, G1t, FAMO, FIMO
       Implicit Real*8 (a-h,o-z)
 #include "Pointers.fh"
 #include "Input.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
       Logical lFI,lFA,lMo
       Parameter ( One = 1.0d0 )
       Real*8 rKappa(nDens2),rMO1(nMba),rmo2(*),FockI(nDens2),
      &       FockA(nDens2)
-      Dimension rdum(1)
+      Real*8 rdum(1)
+      Real*8, Allocatable:: T1(:), Tmp2(:), T3(:), T4(:), DIL(:),
+     &                      DI(:), DIR(:), FI(:), FI1(:),
+     &                      K1(:), DAL(:), DAR(:), DA(:), FA1(:)
+*                                                                      *
+************************************************************************
+*                                                                      *
+      Interface
+        SubRoutine Read2_ns(rMO1,rMO2,FockI,FockA,
+     &                      Temp1,nTemp,Temp2,Temp3,Temp4,
+     &                      DI13,DI24,DI,
+     &                      DA13,DA24,DA,
+     &                      rkappa,idsym,
+     &                      Signa,Fact,jSpin,lfat,lfit,lMOt,CMO)
+           Real*8 rmo1(*), rmo2(*), FockA(*), FockI(*), Temp1(ntemp)
+           Integer ntemp
+           Real*8 Temp2(*), Temp3(*), Temp4(*),
+     &            DI13(*), DI24(*), DI(*),
+     &            DA13(*), DA24(*), DA(*),
+     &            rkappa(*)
+           Integer idsym
+           Real*8 Signa,Fact
+           Integer jSpin
+           Logical lFAt,lFIt,lmot
+           Real*8 CMO(*)
+        End SubRoutine Read2_ns
+      End Interface
+*                                                                      *
+************************************************************************
+*                                                                      *
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
+*
+************************************************************************
+*
+
       ndens22=ndens2
       iAM=0
       iBM=0
@@ -45,55 +79,53 @@
        iBM=Max(iBM,nBAs(i))
       End Do
       imem=nDens22
-      Call GetMem('Temp1','ALLO','REAL',ipT1,imem)
-      Call GetMem('Scr  ','ALLO','REAL',ipScr,imem)
-      Call GetMem('Temp2','ALLO','REAL',ipTmp2,nDens22)
-      Call GetMem('Temp3','ALLO','REAL',ipT3,nDens22)
-      Call GetMem('Temp4','ALLO','REAL',ipT4,nDens22)
-      Call GetMem('DIL  ','ALLO','REAL',ipDIL,nDens2)
-      Call GetMem('DI   ','ALLO','REAL',ipDI,nCMO)
-      Call GetMem('DIR  ','ALLO','REAL',ipDIR,nDens2)
-      Call GetMem('FociI','ALLO','REAL',ipFI,ndens2)
-      Call GetMem('FociI','ALLO','REAL',ipFI1,ndens2)
-      Call GetMem('kappa','ALLO','REAL',ipK1,ndens2)
 
-      call dcopy_(ndens2,[0.0d0],0,FockI,1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipFI),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipFI1),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipK1),1)
-      call dcopy_(ndens2,[0.0d0],0,FockA,1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDir),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDil),1)
-      call dcopy_(nCMO,[0.0d0],0,Work(ipDi),1)
+      Call mma_allocate(T1,imem,Label='T1')
+      Call mma_allocate(Tmp2,nDens22,Label='Tmp2')
+      Call mma_allocate(T3,nDens22,Label='T3')
+      Call mma_allocate(T4,nDens22,Label='T4')
+      Call mma_allocate(DIL,nDens2,Label='DIL')
+      Call mma_allocate(DI,nCMO,Label='DI')
+      Call mma_allocate(DIR,nDens2,Label='DIR')
+      Call mma_allocate(FI,ndens2,Label='FI')
+      Call mma_allocate(FI1,ndens2,Label='FI1')
+      Call mma_allocate(K1,ndens2,Label='K1')
+
+      FockI(:)=0.0d0
+      FockA(:)=0.0d0
+      FI(:)   =0.0d0
+      FI1(:)  =0.0d0
+      K1(:)   =0.0d0
+      DIR(:)  =0.0d0
+      DIL(:)  =0.0d0
+      DI(:)   =0.0d0
       lFI=.true.
       lFa=.false.
       lMo=.false.
+
       If (iMethod.eq.2) Then
-         Call GetMem('DAL  ','ALLO','REAL',ipDAL,nDens2)
-         Call GetMem('DAR  ','ALLO','REAL',ipDAR,nDens2)
-         Call GetMem('DA   ','ALLO','REAL',ipDA,nCMO)
-         Call GetMem('FockA','ALLO','REAL',ipFA,nDens2)
-         Call GetMem('FockA','ALLO','REAL',ipFA1,nDens2)
+         Call mma_allocate(DAL,nDens2,Label='DAL')
+         Call mma_allocate(DAR,nDens2,Label='DAR')
+         Call mma_allocate(DA,nCMO,Label='DA')
+         Call mma_allocate(FA1,nDens2,Label='FA1')
          lFa=.true.
          lMo=.true.
-         call dcopy_(ndens2,[0.0d0],0,Work(ipFA),1)
-         call dcopy_(ndens2,[0.0d0],0,Work(ipFA1),1)
-         call dcopy_(ndens2,[0.0d0],0,Work(ipDar),1)
-         call dcopy_(ndens2,[0.0d0],0,Work(ipDal),1)
-         call dcopy_(nCMO,[0.0d0],0,Work(ipDa),1)
       Else
-         ipDAL = ip_Dummy
-         ipDAR = ip_Dummy
-         ipDA  = ip_Dummy
-         ipFA  = ip_Dummy
-         ipFA1 = ip_Dummy
+         Call mma_allocate(DAL,1,Label='DAL')
+         Call mma_allocate(DAR,1,Label='DAR')
+         Call mma_allocate(DA,1,Label='DA')
+         Call mma_allocate(FA1,1,Label='FA1')
       End If
+      FA1(:)=0.0D0
+      DAL(:)=0.0D0
+      DAR(:)=0.0D0
+      DA(:) =0.0D0
 c THIS IS THE ENTIRE DENSITY FOR MULTICONF
       Do iS=1,nSym
-      Do iB=1,nIsh(iS)
-      ip=ipCM(iS)+(ib-1)*nBas(is)+ib-1
-      Work(ipDI+ip-1)=2.0d0
-      End Do
+         Do iB=1,nIsh(iS)
+            ip=ipCM(iS)+(ib-1)*nBas(is)+ib-1
+            DI(ip)=2.0d0
+         End Do
       End Do
       If (iMethod.eq.2) Then
        Do iS=1,nSym
@@ -103,7 +135,7 @@ c THIS IS THE ENTIRE DENSITY FOR MULTICONF
           iA=nA(is)+ib
           jA=nA(is)+jb
           ip2=itri(iA,jA)
-          Work(ipDA+ip-1)=Work(ipG1t+ip2-1)
+          DA(ip)=G1t(ip2)
          End Do
         End Do
        End Do
@@ -114,53 +146,53 @@ c THIS IS THE ENTIRE DENSITY FOR MULTICONF
 *     from one index tranformation of contracted indexes
 *
 *      If (iDsym.eq.2) Then
-*           Call RecPrt('Work(ipFI)',' ',Work(ipFI),ndens2,1)
-*           Call RecPrt('Work(ipDI)',' ',Work(ipDI),ndens2,1)
+*           Call RecPrt('FI',' ',FI,ndens2,1)
+*           Call RecPrt('DI',' ',DI,ndens2,1)
 *           Stop 10
 *      End If
       FacR=Fact
       Call Read2_ns(rmo1,rmo2,
      &           FockI,FockA,
-     &           Work(ipT1),imem,Work(ipScr),Work(ipTmp2),
-     &           Work(ipT3),Work(ipT4),
-     &           Work(ipDIR),Work(ipDIL),
-     &           Work(ipDI),
-     &           Work(ipDAR),Work(ipDAL),
-     &           Work(ipDA),
+     &           T1,imem,Tmp2,
+     &           T3,T4,
+     &           DIR,DIL,
+     &           DI,
+     &           DAR,DAL,
+     &           DA,
      &           rkappa,idsym,Sign,Facr,jSpin,
      &           lFA,lfi,lMo,
-     &           Work(ipCMO))
+     &           CMO)
 *      If (iDsym.eq.2) Then
-*           Call RecPrt('Work(ipFI)',' ',Work(ipFI),ndens2,1)
-*           Call RecPrt('Work(ipDI)',' ',Work(ipDI),ndens2,1)
+*           Call RecPrt('FI',' ',FI,ndens2,1)
+*           Call RecPrt('DI',' ',DI,ndens2,1)
 *           Stop 10
 *      End If
       Do iS=1,nsym
       js=ieor(idsym-1,is-1)+1
       If (nbas(is)*nbas(js).ne.0)
      &Call DGETMO(rkappa(ipmat(is,js)),nbas(is),nbas(is),nbas(js),
-     &            Work(ipK1-1+ipmat(js,is)),nbas(js))
+     &            K1(ipmat(js,is)),nbas(js))
       End Do
-      Call DSCAL_(ndens2,-1.0d0,Work(ipK1),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDir),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDil),1)
+      Call DSCAL_(ndens2,-1.0d0,K1,1)
+      DIR(:)=0.0d0
+      DIL(:)=0.0d0
       If (imethod.eq.2) Then
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDar),1)
-      call dcopy_(ndens2,[0.0d0],0,Work(ipDal),1)
+         DAR(:)=0.0d0
+         DAL(:)=0.0d0
       End If
       Call Read2_ns(rdum,rdum,
-     &           Work(ipFi1),Work(ipFA1),
-     &           Work(ipT1),imem,Work(ipScr),Work(ipTmp2),
-     &           Work(ipT3),Work(ipT4),
-     &           Work(ipDIR),Work(ipDIL),
-     &           Work(ipDI),
-     &           Work(ipDAR),Work(ipDAL),
-     &           Work(ipDA),
-     &           Work(ipK1),idsym,Sign,Facr,jSpin,
+     &           FI1,FA1,
+     &           T1,imem,Tmp2,
+     &           T3,T4,
+     &           DIR,DIL,
+     &           DI,
+     &           DAR,DAL,
+     &           DA,
+     &           K1,idsym,Sign,Facr,jSpin,
      &           lFA,lfi,.false.,
-     &           Work(ipCMO))
+     &           CMO)
 *      If (iDsym.eq.2)
-*     &      Call RecPrt('Work(ipFI1)',' ',Work(ipFI1),ndens2,1)
+*     &      Call RecPrt('FI1',' ',FI1,ndens2,1)
 *
 *      Calculate contribution from uncontracted indexes.
 *
@@ -168,47 +200,45 @@ c THIS IS THE ENTIRE DENSITY FOR MULTICONF
        jS=iEOr(iS-1,iDSym-1)+1
        If (nBas(iS)*nBas(jS).ne.0) Then
        Call DGEMM_('N','N',nBas(iS),nBas(jS),nBas(iS),Sign*Facr,
-     &            Work(ipFIMO+ipCM(iS)-1),nBas(is),
+     &            FIMO(ipCM(iS)),nBas(is),
      &            rkappa(ipMat(iS,jS)),nBas(iS),
      &            One,FockI(ipMat(iS,jS)),nBas(iS))
        Call DGEMM_('N','N',nBas(iS),nBas(jS),nBas(jS),Facr,
      &            rkappa(ipMat(iS,jS)),nBas(is),
-     &            Work(ipFIMO+ipCM(jS)-1),nBas(jS),
+     &            FIMO(ipCM(jS)),nBas(jS),
      &            One,FockI(ipMat(iS,jS)),nBas(is))
        If (iMethod.eq.2) Then
          Call DGEMM_('N','N',nBas(iS),nBas(jS),nBas(iS),Sign*Facr,
-     &            Work(ipFAMO+ipCM(iS)-1),nBas(is),
+     &            FAMO(ipCM(iS)),nBas(is),
      &            rkappa(ipMat(iS,jS)),nBas(iS),
      &            One,FockA(ipMat(iS,jS)),nBas(iS))
          Call DGEMM_('N','N',nBas(iS),nBas(jS),nBas(jS),Facr,
      &            rkappa(ipMat(iS,jS)),nBas(is),
-     &            Work(ipFAMO+ipCM(jS)-1),nBas(jS),
+     &            FAMO(ipCM(jS)),nBas(jS),
      &            One,FockA(ipMat(iS,jS)),nBas(is))
        End If
        End If
       End Do
 *
-      If (iMethod.eq.2) Then
-         Call GetMem('FockA','FREE','REAL',ipFA,nF)
-         Call GetMem('FockA','FREE','REAL',ipFA1,nF)
-         Call GetMem('DAR  ','FREE','REAL',ipDAR,nDens2)
-         Call GetMem('DA   ','FREE','REAL',ipDA,nDens2)
-         Call GetMem('DAL  ','FREE','REAL',ipDAL,nDens2)
-      End If
-*
-      Call GetMem('FociI','Free','REAL',ipFI,nF)
-      Call GetMem('FociI','Free','REAL',ipFI1,nF)
-      Call GETMEM('KAP1 ','FREE','REAL',ipK1,ndens2)
-      Call GetMem('DIR  ','FREE','REAL',ipDIR,nDens2)
-      Call GetMem('DIL  ','FREE','REAL',ipDIL,nDens22)
-      Call GetMem('DI   ','FREE','REAL',ipDI,nDens2)
-      Call GetMem('Temp4','FREE','REAL',ipT4,nDens22)
-      Call GetMem('Temp3','FREE','REAL',ipT3,nDens22)
-      Call GetMem('Temp2','FREE','REAL',ipTmp2,nDens22)
-      Call GetMem('Scr  ','FREE','REAL',ipScr,imem)
-      Call GetMem('Temp1','FREE','REAL',ipT1,imem)
+      Call mma_deallocate(DA)
+      Call mma_deallocate(DAR)
+      Call mma_deallocate(DAL)
+      Call mma_deallocate(FA1)
+      Call mma_deallocate(FI)
+      Call mma_deallocate(FI1)
+      Call mma_deallocate(K1)
+      Call mma_deallocate(DIR)
+      Call mma_deallocate(DI)
+      Call mma_deallocate(DIL)
+      Call mma_deallocate(T4)
+      Call mma_deallocate(T3)
+      Call mma_deallocate(Tmp2)
+      Call mma_deallocate(T1)
+
 *                                                                      *
 ************************************************************************
 *                                                                      *
       Return
+c Avoid unused argument warnings
+      IF (.FALSE.) CALL Unused_integer(nF)
       End
