@@ -8,7 +8,7 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-       Subroutine RdInp_MCLR
+       Subroutine RdInp_MCLR()
 ************************************************************************
 *                                                                      *
 *     Locate input stream and read commands                            *
@@ -23,12 +23,12 @@
 ************************************************************************
       Use Basis_Info, only: Basis_Info_Get
       Use Center_Info, only: Center_Info_Get
+      Use Exp, only: NewPre, nexp_max
+      use negpre
       Implicit Real*8 (a-h,o-z)
 #include "Input.fh"
 #include "Files_mclr.fh"
 #include "disp_mclr.fh"
-#include "WrkSpc.fh"
-#include "negpre.fh"
 #include "sa.fh"
       Parameter ( nCom=38 )
       Character*72 Line
@@ -44,7 +44,7 @@
      &            'EXPD','NEGP','LOWM','ELHE','SAVE',
      &            'RASS','DISO','CASI','SALA','NODE',
      &            'ESTE','MOUT','MASS','NAC ','$$$$',
-     &            'THER','NEWC','TWOS'/
+     &            'THER','CHOF','TWOS'/
       Integer iDum(1)
 *----------------------------------------------------------------------*
 *     Locate "start of input"                                          *
@@ -60,7 +60,7 @@
       Call Get_info_Static()
       istate=1     ! State for which the Lagrangian is calc.
       override=.false.
-      If (debug) write(6,*) 'Got info.fh'
+      If (debug) write(6,*) 'Got Basis_Info and Center_Info'
       lRoots=-1
       kprint=0
       ngp=.false.
@@ -70,12 +70,10 @@
       elechess=.false.
       TimeDep=.false.
       PrCI=.false.
-      nexp_max=100
       CIthrs=0.05d0
       PrOrb=.false.
       SewLab='NONE    '
       Page=.false.
-      OEthrs=1.0d0
       ibreak=2
       nIter=200
       RASSI=.false.
@@ -83,7 +81,6 @@
       SA=.false.
       esterr=.false.
       FANCY_PRECONDITIONER=.true.
-      newpre=.true.
       save=.false.
       isotop=.true.
       Call lCopy(mxAtm*3+3,[.true.],0,lCalc,1)
