@@ -8,7 +8,7 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine RdJobIph_td
+      Subroutine RdJobIph_td(CIVec)
 ************************************************************************
 *                                                                      *
 *     Read the contents of the JOBIPH file.                            *
@@ -21,15 +21,19 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
+      Use Arrays, only: CMO, G2t, G2sq, G1t
       Implicit Real*8 (a-h,o-z)
 #include "Input.fh"
 #include "Files_mclr.fh"
-#include "glbbas_mclr.fh"
 #include "Pointers.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "SysDef.fh"
       Character*72 Line
-      Dimension rdum(1)
+      Real*8 rdum(1)
+      Character(Len=1), Allocatable:: TempTxt(:)
+      Real*8, Allocatable::  Tmp2(:), G2tts(:), G2tta(:)
+      Real*8, Allocatable:: CIVec(:,:)
+
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
 
 *----------------------------------------------------------------------*
@@ -45,19 +49,18 @@
 *----------------------------------------------------------------------*
 *     Read the the system description                                  *
 *----------------------------------------------------------------------*
-      ndum=lenin8*mxorb
-      Call Getmem('TMP','ALLO','CHAR',ipdum,ndum)
+      Call mma_allocate(TempTxt,LENIN8*MxOrb,Label='TempTxt')
       iDisk=iToc(1)
       Call WR_RASSCF_Info(LuJob,2,iDisk,
      &                    nActEl,iSpin,nSym,State_sym,nFro,
      &                    nIsh,nAsh,nDel,
-     &                    nBas,MxSym,cwork(ipdum),LENIN8*mxorb,
+     &                    nBas,MxSym,TempTxt,LENIN8*mxorb,
      &                    nConf,HeaderJP,144,
      &                    TitleJP,4*18*mxTit,PotNuc0,lRoots,
      &                    nRoots,iRoot,mxRoot,
      &                    nRs1,nRs2,nRs3,
      &                    nHole1,nElec3,iPt2,Weight)
-      Call Getmem('TMP','FREE','CHAR',ipdum,ndum)
+      Call mma_deallocate(TempTxt)
 *----------------------------------------------------------------------*
 *     Overwrite the variable lroots if approriate                      *
 *----------------------------------------------------------------------*
@@ -114,41 +117,41 @@
 *     Load the orbitals used in the last macro iteration               *
 *----------------------------------------------------------------------*
 *
-      Call GetMem('CMO','Allo','Real',ipCMO,Length)
-      Call Get_CMO(Work(ipCMO),Length)
+      Call mma_allocate(CMO,Length,Label='CMO')
+      Call Get_CMO(CMO,Length)
 *     iDisk=iToc(9)
 *     IF(IPT2.EQ.0) iDisk=iToc(2)
-*     Call dDaFile(LuJob,2,Work(ipCMO),ntBsqr,iDisk)
+*     Call dDaFile(LuJob,2,CMO,ntBsqr,iDisk)
       If ( .false. ) then
-         jpCMO=ipCMO
+         jpCMO=1
          Do 15 iSym=1,nSym
             Write(Line,'(A,i2.2)') 'MO coefficients, iSym = ',iSym
-            Call RecPrt(Line,' ',Work(jpCMO),nBas(iSym),nBas(iSym))
+            Call RecPrt(Line,' ',CMO(jpCMO),nBas(iSym),nBas(iSym))
             jpCMO=jpCMO+nBas(iSym)*nBas(iSym)
 15       Continue
       End If
 *----------------------------------------------------------------------*
 *     Load the CI vector for the root lRoots                           *
 *----------------------------------------------------------------------*
-      Call GetMem('OCIvec','Allo','Real',ipCI,nConf)
+      Call mma_allocate(CIVec,nConf,1,Label='CIVec')
       iDisk=iToc(4)
       Do i=1,lroots-1
-      Call dDaFile(LuJob,0,Work(ipCI),nConf,iDisk)
+         Call dDaFile(LuJob,0,CIVec,nConf,iDisk)
       End Do
-      Call dDaFile(LuJob,2,Work(ipCI),nConf,iDisk)
-      If (.false.) Call DVcPrt('CI coefficients',' ',Work(ipCI),nConf)
+      Call dDaFile(LuJob,2,CIVec,nConf,iDisk)
+      If (.false.) Call DVcPrt('CI coefficients',' ',CIVec,nConf)
 *----------------------------------------------------------------------*
 *     Load state energy                                                *
 *----------------------------------------------------------------------*
-      Call GetMem('Temp2','Allo','Real',ipTmp2,mxRoot*mxIter)
+      Call mma_allocate(Tmp2,mxRoot*mxIter,Label='Tmp2')
       iDisk=iToc(6)
-      Call dDaFile(LuJob,2,Work(ipTmp2),mxRoot*mxIter,iDisk)
+      Call dDaFile(LuJob,2,Tmp2,mxRoot*mxIter,iDisk)
       ERASSCF(1)=0.0d0
       Do 20 iter=0,mxIter-1
-         Temp=Work(ipTmp2+iter*mxRoot+lRoots-1)
+         Temp=Tmp2(iter*mxRoot+lRoots)
          If ( Temp.ne.0.0D0 ) ERASSCF(1)=Temp
 20    Continue
-      Call GetMem('Temp2','Free','Real',ipTmp2,mxRoot*100)
+      Call mma_deallocate(Tmp2)
 *     If ( debug ) Write(*,*) ' RASSCF energy =',ERASSCF(1)
 *
       nAct  = 0
@@ -170,9 +173,8 @@
 * One electron dens - triang stor.
 *-----------------------------------
       nG1 = nAct*(nAct+1)/2
-      Call GetMem(' G1 ','Allo','Real',ipG1t,nG1)
-      call dcopy_(nG1,[0.0d0],0,Work(ipG1t),1)
-      ipG1=ipg1t
+      Call mma_allocate(G1t,nG1,Label='G1t')
+      G1t(:)=0.0d0
 *
 *--------------------------------------------------
 * Triangular part of two electron dens,
@@ -180,10 +182,10 @@
 *--------------------------------------------------
       nG2=nG1*(nG1+1)/2
 
-      Call GetMem(' G2 ','Allo','Real',ipG2sq,nAct**4)
-      Call GetMem(' G2 ','Allo','Real',ipG2t,nG2)
-      Call GetMem(' G2i ','Allo','Real',ipG2tts,nG2)
-      Call GetMem(' G2i ','Allo','Real',ipG2tta,nG2)
+      Call mma_allocate(G2sq,nAct**4,Label='G2sq')
+      Call mma_allocate(G2t,nG2,Label='G2t')
+      Call mma_allocate(G2tts,nG2,Label='G2tts')
+      Call mma_allocate(G2tta,nG2,Label='G2tta')
       iDisk=iToc(3)
       Do i=1,lroots-1
          Call dDaFile(LuJob,0,rdum,nG1,iDisk)
@@ -191,10 +193,10 @@
          Call dDaFile(LuJob,0,rdum,nG2,iDisk)
          Call dDaFile(LuJob,0,rdum,nG2,iDisk)
       End Do
-      Call dDaFile(LuJob,2,Work(ipG1t),nG1,iDisk)
+      Call dDaFile(LuJob,2,G1t,nG1,iDisk)
       Call dDaFile(LuJob,0,rdum,nG1,iDisk)
-      Call dDaFile(LuJob,2,Work(ipG2tts),nG2,iDisk)
-      Call dDaFile(LuJob,2,Work(ipG2tta),nG2,iDisk)
+      Call dDaFile(LuJob,2,G2tts,nG2,iDisk)
+      Call dDaFile(LuJob,2,G2tta,nG2,iDisk)
 
       Do iB=1,nAct
          Do jB=1,iB
@@ -206,16 +208,12 @@
                   if(iDij.ge.iDkl .and. kB.eq.lB) fact=2.0d00
                   if(iDij.lt.iDkl .and. iB.eq.jB) fact=2.0d00
                   iijkl=itri(iDij,iDkl)
-                  Work(ipG2t+iijkl-1)=Fact*Work(ipG2tts+iijkl-1)
+                  G2t(iijkl)=Fact*G2tts(iijkl)
                End Do
             End Do
          End Do
       End Do
 *
-      ipg2=ipg2t
-      ipg2tmm=ipg2t
-      ipg2tpp=ipg2t
-
 *---------------------------------------------------------------
 * Rectangular part of the two el dens,
 * symmetric and asymmetric contributions added
@@ -241,14 +239,13 @@
                   iijkl=itri(iDij,iDkl)
                   iijkl2=iDij2+nact**2*(iDkl2-1)
 *
-                  Work(ipG2sq+iijkl2-1)=Fact*(Work(ipG2tts+iijkl-1)+
-     &                                    Work(ipG2tta+iijkl-1)*Fact2)
+                  G2sq(iijkl2)=Fact*(G2tts(iijkl)+G2tta(iijkl)*Fact2)
                End Do
             End Do
          End Do
       End Do
-      Call GetMem('G2i     ','FREE','REAL',ipg2tts,ng2)
-      Call GetMem('G2i     ','FREE','REAL',ipg2tta,ng2)
+      Call mma_deallocate(G2tts)
+      Call mma_deallocate(G2tta)
 *----------------------------------------------------------------------*
 *     exit                                                             *
 *----------------------------------------------------------------------*
