@@ -1,4 +1,4 @@
-************************************************************************
+***********************************************************************
 * This file is part of OpenMolcas.                                     *
 *                                                                      *
 * OpenMolcas is free software; you can redistribute it and/or modify   *
@@ -33,34 +33,50 @@
 * Author: Anders Bernhardsson, 1995                                *
 *         Theoretical Chemistry, University of Lund                *
 ********************************************************************
+      use ipPage, only: W
+      use Arrays, only: G2t, G1t
       Implicit Real*8 (a-h,o-z)
 #include "Pointers.fh"
-
 #include "Input.fh"
 #include "disp_mclr.fh"
-#include "WrkSpc.fh"
-*for the integrals needed in sigma gen
-#include "glbbas_mclr.fh"
-#include "lbbas1.fh"
-
-      Character*8 Label
+#include "stdalloc.fh"
+      Character(LEN=8) Label
       Logical CI
       Real*8 E2
       Real*8 Temp1(nDens),rKappa(nDens),Temp4(nDens),
-     &      Temp2(nDens),Temp3(nDens),CMO(nCMO),Temp5(nDens),
-     &      Temp6(nDens),temp7(ndens)
+     &       Temp2(nDens),Temp3(nDens),CMO(nCMO),Temp5(nDens),
+     &       Temp6(nDens),temp7(ndens)
+      Real*8 rDum(1)
+      Real*8, Allocatable:: MOX(:), MOT(:), FIX(:), MOT2(:)
+*                                                                     *
+***********************************************************************
+*                                                                     *
+      Interface
+      SubRoutine CISigma(iispin,iCsym,iSSym,Int1,nInt1,Int2s,nInt2s,
+     &                   Int2a,nInt2a,ipCI1,ipCI2, Have_2_el)
+       Integer iispin, iCsym, iSSym
+       Integer nInt1, nInt2s, nInt2a
+       Real*8, Target:: Int1(nInt1), Int2s(nInt2s), Int2a(nInt2a)
+       Integer ipCI1, ipCI2
+       Logical Have_2_el
+      End SubRoutine CISigma
+      End Interface
+*                                                                     *
+***********************************************************************
+*                                                                     *
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
-
-*
+*                                                                     *
+***********************************************************************
+*                                                                     *
       one=1.0d0
       debug=.true.
       iRC=-1
       idsym=loper+1
       iOpt=0
       iOp=2**loper
-*
-*-------------------------------------------------------------------*
-*
+*                                                                     *
+***********************************************************************
+*                                                                     *
 *     Read in connection matrix
 *     and transform it to MO basis
 *
@@ -77,6 +93,7 @@
           Write (6,*) 'Label=',Label
           Call Abend()
       End If
+
       ip=1
       Do iS=1,nSym
        Do jS=1,is
@@ -94,24 +111,24 @@
            End If
            Call DGEMM_('T','N',
      &                 nOrb(iS),nBas(jS),nBas(iS),
-     &                 1.0d0,Work(ipCMO+ipCM(iS)-1),nBas(iS),
+     &                 1.0d0,CMO(ipCM(iS)),nBas(iS),
      &                 Temp6,nBas(iS),
      &                 0.0d0,Temp5,nOrb(iS))
            Call DGEMM_('N','N',
      &                 nOrb(is),nOrb(jS),nBAs(jS),
      &                 1.0d0,Temp5,nOrb(iS),
-     &                 Work(ipCMO+ipCM(jS)-1),nBas(jS),
+     &                 CMO(ipCM(jS)),nBas(jS),
      &                 0.0d0,Temp1(ipMat(iS,jS)),nOrb(is))
            If (is.ne.js) Then
            Call DGEMM_('T','T',
      &                 nOrb(jS),nBas(iS),nBAs(jS),
-     &                 1.0d0,Work(ipCMO+ipCM(jS)-1),nBas(js),
+     &                 1.0d0,CMO(ipCM(jS)),nBas(js),
      &                 Temp6,nBas(iS),
      &                 0.0d0,Temp5,nOrb(jS))
            Call DGEMM_('N','N',
      &                 nOrb(js),nOrb(iS),nBas(iS),
      &                 1.0d0,Temp5,nOrb(jS),
-     &                 Work(ipCMO+ipCM(iS)-1),nBas(iS),
+     &                 CMO(ipCM(iS)),nBas(iS),
      &                 0.0d0,Temp1(ipMat(jS,iS)),nOrb(jS))
           End If
 
@@ -127,14 +144,15 @@
 *
       rone=0.0d0
       If ((iMethod.eq.2).and.(n2dens.ne.0)) Then
-        Call GetMem('MOOIX','ALLO','REAL',ipMOX,n2dens)
-        call dcopy_(n2dens,[0.0d0],0,Work(ipMOX),1)
+        Call mma_allocate(MOX,n2dens,Label='MOX')
       Else
-        ipMOX = ip_Dummy
+        Call mma_allocate(MOX,1,Label='MOX')
       End If
-      Call GetMem('FIX','ALLO','REAL',ipFiX,nDens2)
-      Call IntX(Work(ipFIX),temp7,temp6,temp5,temp4,rkappa,
-     &          Work(ipMOX),loper,idisp,rone)
+      MOX(:)=0.0D0
+      Call mma_allocate(FiX,nDens2,Label='FIX')
+
+      Call IntX(FIX,temp7,temp6,temp5,temp4,rkappa,
+     &          MOX,loper,idisp,rone)
 *
 *-------------------------------------------------------------------*
 *
@@ -148,32 +166,30 @@
 *
       If (iAnd(ntpert(idisp),2**3).eq.8)  Then
        If (iMethod.eq.2) Then
-          Call GetMem('MOOIT','ALLO','REAL',ipMOT ,nmba)
-          Call GetMem('MOOIT2','ALLO','REAL',ipMOT2,nmba)
-          call dcopy_(nmba,[0.0d0],0,work(ipMOT),1)
-          call dcopy_(nmba,[0.0d0],0,work(ipMOT2),1)
+          Call mma_allocate(MOT ,nmba,Label='MOT')
+          Call mma_allocate(MOT2,nmba,Label='MOT2')
        Else
-          ipMOT =ip_Dummy
-          ipMOT2=ip_Dummy
+          Call mma_allocate(MOT ,   1,Label='MOT')
+          Call mma_allocate(MOT2,   1,Label='MOT2')
        End If
+       MOT(:)=0.0D0
+       MOT2(:)=0.0D0
 *
 *      kappa rmo Fi Fa
 *
-       Call r2ElInt(Temp1,Work(ipMOT),  Work(ipMOT2),
+       Call r2ElInt(Temp1,MOT,MOT2,
      &             Temp4,Temp5,ndens2,iDSym,1.0d0,-0.5d0,0)
 
-       If (imethod.eq.2) Then
-           Call DaXpY_(nmba,1.0d0,Work(ipmot2),1,Work(ipmot),1 )
-           Call GetMem('MOOIT2','FREE','REAL',ipMOT2,nmba)
-       End If
+       If (imethod.eq.2) Call DaXpY_(nmba,1.0d0,MOT2,1,MOT,1)
+       Call mma_deallocate(MOT2)
+
 *----- ix  ix  ~i
        call dcopy_(ndens2,[0.0d0],0,temp7,1)
 *------ F  =F  + F
-       Call DaXpY_(nDens2,One,Temp4,1,Work(ipFIX),1)
+       Call DaXpY_(nDens2,One,Temp4,1,FIX,1)
 *
 
-       If (iMethod.eq.2)
-     &  Call CreQ(Temp6,Work(ipMOT),Work(ipG2t),loper+1)
+       If (iMethod.eq.2) Call CreQ(Temp6,MOT,G2t,loper+1)
 *
        Do iS=1,nSym
         jS=iEOr(iS-1,loper)+1
@@ -186,7 +202,7 @@
      &            Temp5(ipMat(js,is)),1,Temp7(ipMat(js,is)),1)
          Do iAsh=1,nAsh(iS)
           Do jAsh=1,nAsh(is)
-           Dij=Work(ipg1t+itri(iash+nA(is),jAsh+nA(is))-1)
+           Dij=G1t(itri(iash+nA(is),jAsh+nA(is)))
 *
 *           F~=F~+DFi~
 *
@@ -206,33 +222,33 @@
 *     Calculate connection contribution to hessian
 *
       End If ! ntpert
+
       Call Hess(Temp7,rkappa,Temp1,temp4,Temp5,temp6,
      &            Temp3,loper+1,jdisp,idisp)
 *
 *----- F=F~+Fx
       If (iAnd(ntpert(idisp),2**3).eq.8)
-     & call daxpy_(nDens,One,Temp7,1,rKappa,1)
+     &    call daxpy_(nDens,One,Temp7,1,rKappa,1)
 
 *
 *     Add connection to 2el MO integrals
 *
 *---- Adds (pb|cd) to triangular (ab|cd)
       If (iMethod.eq.2.and.iAnd(ntpert(idisp),2**2).eq.4)
-     &Call ABXpY(Work(ipMOT),Work(ipMOX),idsym)
+     &    Call ABXpY(MOT,MOX,idsym)
 *
       If (CI) Then
-       ipMX=0
-       If (iAnd(ntPert(idisp),2**3).ne.0) ipMX=ipMOX
 *
        Call CiSigma(0,State_Sym,iEor(State_sym-1,idsym-1)+1,
-     &             ipFix,ipMx,idum,ipCI,ipst,'N')
+     &              FIX,nDens2,MOX,SIZE(MOX),rdum,1,ipCI,ipst,.True.)
 *
+       irc=ipin(ipst)
        If (idsym.eq.1) Then
-        EnA=E2(Work(ipFix),Work(ipmox),idsym-1,idisp)
-        Call DaXpY_(nConf1,-Ena,Work(ipin(ipCI))
-     &   ,1,Work(ipin(ipst)),1)
+        EnA=E2(Fix,MOX,idsym-1,idisp)
+        irc=ipin(ipCI)
+        Call DaXpY_(nConf1,-Ena,W(ipCI)%Vec,1,W(ipST)%Vec,1)
        End If
-       Call DSCAL_(nConf1,2.0d0,Work(ipin(ipst)),1)
+       Call DSCAL_(nConf1,2.0d0,W(ipST)%Vec,1)
       End If
 *
       Call DYAX(ndens2,2.0d0,rkappa,1,Temp1,1)
@@ -246,11 +262,9 @@
      &              nOrb(is),nOrb(js))
       End Do
 *
-      Call GetMem('FIX','FREE','REAL',ipFix,ndens2)
-      If ((iMethod.eq.2).and.(n2dens.ne.0))
-     &    Call GetMem('MOOIX','FREE','REAL',ipMOX,n2dens)
-      If (iMethod.eq.2.and.iAnd(ntpert(idisp),2**3).eq.8)
-     &   Call GetMem('MOOIT','FREE','REAL',ipMOT,nmba)
+      Call mma_deallocate(FIX)
+      If (Allocated(MOX)) Call mma_deallocate(MOX)
+      If (Allocated(MOT)) Call mma_deallocate(MOT)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -258,7 +272,6 @@
 c Avoid unused argument warnings
       If (.False.) Then
          Call Unused_real_array(Temp2)
-         Call Unused_real_array(CMO)
          Call Unused_integer(jspin)
       End If
       End
