@@ -32,11 +32,8 @@
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='ClsFls  ')
 
-#include "davctl.fh"
-#include "qnctl.fh"
-#include "raswfn.fh"
+#include "qnctl_mcpdft.fh"
 *----------------------------------------------------------------------*
 *     Start                                                            *
 *-------------------------------------- -------------------------------*
@@ -53,9 +50,6 @@ C Local print level (if any)
         Call DaClos(JOBIPH)
         JOBIPH=-1
       End If
-#ifdef _HDF5_
-      call mh5_close_file(wfn_fileid)
-#endif
 *---  close the ORDINT file -------------------------------------------*
       CALL DecideOnCholesky(DoCholesky)
        If (.not.DoCholesky) then
