@@ -32,7 +32,6 @@
 #include "general.fh"
 #include "gas.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='INPPRI  ')
 #include "ciinfo.fh"
 #include "rctfld.fh"
 #include "WrkSpc.fh"
@@ -41,11 +40,9 @@
       Character*8   Fmt1,Fmt2, Label
       Character*120  Line,BlLine,StLine
       Character*3 lIrrep(8)
-      Logical DoCholesky,DoDMRG
-      Logical DoLocK,Deco, lOPTO
-      Real*8  dmpK
-      Integer nScreen
-      COMMON /CHOLK / DoLocK,Deco,dmpk,Nscreen
+      Logical DoCholesky
+      Logical lOPTO
+#include "cholk.fh"
 
 * Print level:
       IPRLEV=IPRLOC(1)
@@ -83,7 +80,7 @@
      &     Line='Project:'
            If ( i.ge.4 .and. i.le.nLine-2 )
      &     Write(Line,'(A72)')Title(i-3)
-           Call Center(Line)
+           Call Center_Text(Line)
            Write(LF,Fmt1) '*'//Line//'*'
          End Do
        Write(LF,*)
@@ -98,10 +95,10 @@
        Write(LF,Fmt1) '--------------------------'
        Write(Line,'(36A2)') (Header(i),i=1,36)
        Call LeftAd(Line)
-       Write(LF,Fmt1)  Line(:mylen(Line))
+       Write(LF,Fmt1)  trim(Line)
        Write(Line,'(36A2)') (Header(i),i=37,72)
        Call LeftAd(Line)
-       Write(LF,Fmt1)  Line(:mylen(Line))
+       Write(LF,Fmt1)  trim(Line)
        Write(LF,*)
 *----------------------------------------------------------------------*
 *     Print the status of ORDINT                                       *
@@ -162,7 +159,7 @@ C.. for GAS
       Write(LF,Fmt2//'A,T45,F6.1)')'Spin quantum number',
      &                           (DBLE(ISPIN-1))/2.0d0
       Write(LF,Fmt2//'A,T45,I6)')'State symmetry',
-     &                           LSYM
+     &                           STSYM
       Call CollapseOutput(0,'Wave function specifications:')
 *
       Call Get_cArray('Irreps',lIrrep,24)
@@ -236,14 +233,14 @@ C.. for GAS
       Write(LF,Fmt1)'----------------------------'
       Write(LF,*)
       Write(LF,Fmt2//'A,T40,I11)')'Number of CSFs',
-     &                           NCSASM(LSYM)
+     &                           NCSASM(STSYM)
       Write(LF,Fmt2//'A,T40,I11)')'Number of determinants',
-     &                           NDTASM(LSYM)
+     &                           NDTASM(STSYM)
         n_Det=2
         n_unpaired_elec=(iSpin-1)
         n_paired_elec=nActEl-n_unpaired_elec
         If(n_unpaired_elec+n_paired_elec/2.eq.nac.or.
-     &     NDTASM(LSYM).eq.1) n_Det = 1
+     &     NDTASM(STSYM).eq.1) n_Det = 1
         If(KSDFT.eq.'DIFF')   n_Det = 1
         If(KSDFT.eq.'ROKS')   n_Det = 1
 
@@ -344,9 +341,9 @@ C.. for GAS
 * Check that the user doesn't try to calculate more roots than it's possible
 * NN.14 FIXME: in DMRG-CASSCF, skip this check for the time
 *              since Block DMRG code will check this internally
-*     If (NROOTS .GT. NCSASM(LSYM)) Then
+*     If (NROOTS .GT. NCSASM(STSYM)) Then
       If (.false.) Then
-!      If (.NOT.DoDMRG .AND. NROOTS .GT. NCSASM(LSYM)) Then
+!      If (.NOT.DoDMRG .AND. NROOTS .GT. NCSASM(STSYM)) Then
          Write(LF,*) '************ ERROR ***********'
          Write(LF,*) ' You can''t ask for more roots'
          Write(LF,*) ' than there are configurations '
@@ -356,14 +353,14 @@ C.. for GAS
       End If
 * If the calculation will be too big:
       call GetMem('ChkMx','Max','Real',iDum,MaxRem)
-      WillNeedMB=(8.0D0*1.50D0*6.0D0*NDTASM(LSYM)/1.048D6)
+      WillNeedMB=(8.0D0*1.50D0*6.0D0*NDTASM(STSYM)/1.048D6)
       AvailMB=(8.0D0*MaxRem/1.048D6)
       if (WillNeedMB .gt. AvailMB) then
         write(6,*)
         write(6,*)' *************************************************'
         write(6,*)' Sorry, but your calculation will probably be too'
         write(6,*)' large for the available memory.'
-        write(6,*)' The number of determinants is ',NDTASM(LSYM)
+        write(6,*)' The number of determinants is ',NDTASM(STSYM)
         write(6,*)' During CI equation solution, there will be'
         write(6,*)' up to six vectors of this size in memory.'
         write(6,*)' We estimate an additional 50% for other stuff.'
@@ -495,6 +492,9 @@ C.. for GAS
         Write(LF,Fmt1)
      &  'Starting CI array(s) will be read from file'
        End If
+      END IF
+      Write(LF,*)
+
        Call Put_dScalar('EThr',ThrE)
 *
 *---- Print out grid information in case of DFT
@@ -504,9 +504,6 @@ C.. for GAS
          Call Put_dScalar('DFT corr coeff',CoefR)
          Call Funi_Print
        End If
-      END IF
-      Write(LF,*)
-
   900 CONTINUE
       Call XFlush(LF)
 *----------------------------------------------------------------------*
