@@ -51,13 +51,14 @@
 ************************************************************************
 
       use stdalloc, only : mma_allocate, mma_deallocate
+      use OFembed, only: Do_OFemb, FMaux
       Implicit Real*8 (A-H,O-Z)
 
 #include "WrkSpc.fh"
 #include "wadr.fh"
 #include "rasdim.fh"
-#include "warnings.fh"
-#include "input_ras.fh"
+#include "warnings.h"
+#include "input_ras_mcpdft.fh"
 #include "rasscf.fh"
 #include "rasrc.fh"
 #include "general.fh"
@@ -65,7 +66,6 @@
 #include "splitcas.fh"
 #include "bk_approx.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='MCPDFT  ')
 #include "rctfld.fh"
 #include "timers.fh"
 #include "casvb.fh"
@@ -74,13 +74,13 @@
 #include "csfbas.fh"
 #include "gugx.fh"
 #include "pamint.fh"
-#include "davctl.fh"
-#include "qnctl.fh"
-#include "orthonormalize.fh"
+#include "qnctl_mcpdft.fh"
+#include "orthonormalize_mcpdft.fh"
 #include "ciinfo.fh"
-#include "raswfn.fh"
 *JB XMC-PDFT stuff
 #include "mspdft.fh"
+*Chen write JOBIPH
+#include "wjob.fh"
       Integer LRState,NRState         ! storing info in Do_Rotate.txt
       Integer LHrot,NHrot             ! storing info in H0_Rotate.txt
       CHARACTER(Len=18)::MatInfo
@@ -90,34 +90,26 @@
       External IsFreeUnit
 
       Logical DSCF
-      Logical lTemp, lOPTO
+      Logical lOPTO
       Character*80 Line
-      Logical DoQmat,DoActive
       Logical IfOpened
       Logical Found
       Character(len=8),DIMENSION(:),Allocatable::VecStat
       CHARACTER(Len=8)::StatVec
       CHARACTER(Len=30)::mspdftfmt
+      Logical RefBas
       Logical Gradient
 
 * --------- Cholesky stuff:
-      Integer ALGO
-      Logical DoCholesky
-      Logical timings,DoLock,Deco
-      Integer Nscreen
-      COMMON /CHOTODO /DoActive,DoQmat,ipQmat
-      COMMON /CHLCAS /DoCholesky,ALGO
-      COMMON /CHOPAR/ ChFracMem
-      COMMON /CHOTIME / timings
-      Common /CHOLK / DoLocK,Deco,dmpk,Nscreen
+#include "chotodo.fh"
+#include "chlcas.fh"
+#include "chopar.fh"
+#include "chotime.fh"
+#include "cholk.fh"
 * --------- End Cholesky stuff
-      Logical Do_OFemb, KEonly, OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_I / ipFMaux, ip_NDSD, l_NDSD
       Character*8 EMILOOP
-* --------- End Orbital-Free Embedding stuff
 
-      Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
+#include "sxci_mcpdft.fh"
 
       External Get_ProgName
 !      External Get_SuperName
@@ -134,12 +126,10 @@
       real*8, allocatable :: PLWO(:)
       integer ivkcnf
       Dimension Dummy(1)
-* Start the traceback utilities
-*
 * Set status line for monitor:
       Call StatusLine('MCPDFT:',' Just started.')
 * Set the return code(s)
-      CASDFT_E = 0d0
+      !CASDFT_E = 0d0
       ITERM  = 0
       IRETURN=_RC_ALL_IS_WELL_
 
@@ -160,7 +150,6 @@
       If (ProgName(1:5).eq.'casvb') IfVB=2
 * Default option switches and values, and initial data.
       EAV = 0.0d0
-      EAV1=0.0d0
       Call RasScf_Init_m()
       Call Seward_Init()
 * Open the one-olectron integral file:
@@ -184,8 +173,7 @@
 * with '*' or '!' or ' '  when left-adjusted, and replacing any rightmost
 * substring beginning with '!' with blanks.
 * That copy will be in file 'CleanInput', and its unit number is returned
-* as LUInput in common (included file input_ras.fh) by the following call:
-      LUSpool = 5
+* as LUInput in common (included file input_ras_mcpdft.fh) by the following call:
       Call cpinp_(LUInput,iRc)
 !      write(*,*) LUINPUT, IRC
 * If something wrong with input file:
@@ -362,8 +350,6 @@ CGG03 Aug 03
       ECAS   = 0.0d0
       ROTMAX = 0.0d0
       ITER   = 0
-      IFINAL = 0
-      TMXTOT = 0.0D0
       Call GetMem('FOcc','ALLO','REAL',ipFocc,nTot1)
 *                                                                      *
 ************************************************************************
@@ -394,7 +380,6 @@ CGG03 Aug 03
       ITER=ITER+1
       If ( ITER.EQ.1 ) THEN
         Start_Vectors=.True.
-        lTemp = lRf
 
 !        Call Get_D1I_RASSCF(Work(LCMO),Work(lD1I))
 
@@ -562,7 +547,6 @@ CGG03 Aug 03
             ExFac=0.0d0
 *        ExFac=Get_ExFac(KSDFT)
         end IF
-      IF(ICIONLY.NE.0) IFINAL=1
 
 *
 * Transform two-electron integrals and compute at the same time
@@ -647,7 +631,7 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
            end do
            Call DDafile(JOBOLD,1,Work(LW4),nConf,iDisk)
           call getmem('kcnf','allo','inte',ivkcnf,nactel)
-          Call Reord2(NAC,NACTEL,LSYM,1,
+          Call Reord2(NAC,NACTEL,STSYM,1,
      &                iWork(KICONF(1)),iWork(KCFTP),
      &                Work(LW4),Work(LW11),iWork(ivkcnf))
           Call dcopy_(nconf,Work(LW11),1,Work(LW4),1)
@@ -655,7 +639,7 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
          C_Pointer = Lw4
          CALL GetMem('Lucia','Allo','Real',Lucia_Base, 1)
 !Andrew - changed here
-         CALL Lucia_Util('Densi',0,iDummy,Dummy)
+         CALL Lucia_Util('Densi',ip_Dummy,iDummy,Dummy)
                  If (IFCAS.GT.2 .OR. iDoGAS) Then
                    Call CISX_m(IDXSX,Work(LW6),Work(LW7),Work(LW8),
      &                     Work(LW9),Work(LW10))
@@ -705,8 +689,10 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
         CALL GETMEM('CASDFT_Fock','ALLO','REAL',LFOCK,NACPAR)
         Call MSCtl(Work(LCMO),Work(LFOCK),Work(LFI),Work(LFA),
      &       Work(iRef_E))
+        If(IWJOB==1.and.(.not.Do_Rotate)) Call writejob(iadr19)
+
         If (Do_Rotate) Then
-        NHRot=lroots**2
+         NHRot=lroots**2
          Do Jroot=1,lroots
           Work(LHRot+Jroot-1+(Jroot-1)*lroots)=Work(iRef_E-1+Jroot)
          End DO
@@ -738,6 +724,9 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
      &'::    ',MSPDFTMethod,' Root',
      &     Jroot,'Total energy:',Work(LRState+Jroot-1)
          End Do
+      Call Put_iScalar('Number of roots',nroots)
+      Call Put_dArray('Last energies',WORK(LRState),nroots)
+      Call Put_dScalar('Last energy',WORK(iRlxRoot-1))
          Write(6,*)
          CALL mma_allocate(VecStat,lRoots)
          Do Jroot=1,lRoots
@@ -745,6 +734,7 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
           VecStat(JRoot)=StatVec
          End Do
          write(6,'(6X,2A)')MSPDFTMethod,' Eigenvectors:'
+         write(6,'(7X,A)')'Intermediate-state Basis'
          if(lroots.lt.10) then
           write(mspdftfmt,'(A5,I1,A9)')
      &     '(13X,',lRoots,'(A8,16X))'
@@ -754,13 +744,45 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
      &     '(13X,',lRoots,'(A8,16X))'
           write(6,mspdftfmt)((VecStat(JRoot)),JRoot=1,lroots)
          end if
-         CALL mma_deallocate(VecStat)
+*Added by Chen to write energies and states of MS-PDFT into JOBIPH
+         If(IWJOB==1) Call writejobms(iadr19,LRState,LHRot)
          Call RecPrt(' ','',Work(LHRot),lroots,lroots)
-         Write(6,*)
-         Write(6,'(6X,80a)') ('*',i=1,80)
+*         Write(6,*)
+         refbas=.false.
+         call f_inquire('ROT_VEC',RefBas)
          Call GetMem('XScratch','FREE','Real',LXScratch,NXScratch)
+*print MS-PDFT final states in basis of reference states
+*re-use RotStat, XScratch and LRState
+         if(RefBas) then
+          NXScratch=NHRot
+          Call GetMem('XScratch','ALLO','Real',LXScratch,NXScratch)
+          Call FZero(Work(LXScratch),NXScratch)
+          Call FZero(Work(LRState)  ,NXScratch)
+          LUMS=IsFreeUnit(LUMS)
+          CALL Molcas_Open(LUMS,'ROT_VEC')
+          Do Jroot=1,lroots
+            read(LUMS,*) (Work(LRState+kroot-1+(jroot-1)*lroots)
+     &                   ,kroot=1,lroots)
+          End Do
+          CALL DGEMM_('n','n',lRoots,lRoots,lRoots,1.0d0,Work(LRState),
+     &         lRoots,Work(LHRot),lRoots,0.0d0,Work(LXScratch),lRoots)
+          write(6,'(7X,A)')'Reference-state Basis'
+          write(6,mspdftfmt)((VecStat(JRoot)),JRoot=1,lroots)
+          Call RecPrt(' ',' ',Work(LXScratch),lroots,lroots)
+          close(LUMS)
+          CALL Molcas_Open(LUMS,'FIN_VEC')
+          Do JRoot=1,lRoots
+           write(LUMS,*)(Work(LXScratch+(JRoot-1)*lRoots+kRoot-1),
+     &     kRoot=1,lRoots)
+          End Do
+          write(LUMS,*) MSPDFTMethod
+          Call GetMem('XScratch','FREE','Real',LXScratch,NXScratch)
+          Close(LUMS)
+         end if
+         Write(6,'(6X,80a)') ('*',i=1,80)
          CALL GETMEM('HRot','FREE','REAL',LHRot,NHRot)
          CALL GETMEM('RotStat','FREE','REAL',LRState,NRState)
+         CALL mma_deallocate(VecStat)
         End If
         CALL GETMEM('CASDFT_Fock','FREE','REAL',LFOCK,NACPAR)
       END IF
@@ -782,7 +804,6 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      IFINAL=2
       ICICH=0
 *****************************************************************************************
 ***************************           Closing up MC-PDFT      ***************************
@@ -816,7 +837,7 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
         !  CASDFT_E = ECAS
         !end if
 
-        Elec_Ener = CASDFT_E-PotNuc
+!        Elec_Ener = CASDFT_E-PotNuc
         write(6,*) "PLWO"
         write(6,*) PLWO(:)
 !        Call Calc_E(Work(LDMAT),Work(LDSPN),WORK(LPMAT),
@@ -847,7 +868,7 @@ c      call triprt('P-mat 1',' ',WORK(LPMAT),nAc*(nAc+1)/2)
             Write(LF,*)' Try to recover. Calculation continues.'
          endif
          If (Do_OFemb) Then
-            Call GetMem('FMaux','Free','Real',ipFMaux,nTot1)
+            Call mma_deallocate(FMaux)
             Call OFE_print(EAV)
          EndIf
       endif
