@@ -57,6 +57,9 @@
 *                                                                      *
 ************************************************************************
 
+#ifdef _HDF5_
+      Use mh5, Only: mh5_open_file_r, mh5_fetch_dset, mh5_close_file
+#endif
       Implicit Real*8 (A-H,O-Z)
 
 *     global data declarations
@@ -65,14 +68,14 @@
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='READVC  ')
 #include "WrkSpc.fh"
 #include "SysDef.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "wadr.fh"
 #include "casvb.fh"
-#include "raswfn.fh"
-      Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
+#include "sxci_mcpdft.fh"
 *     calling arguments
 
       Dimension CMO(*),OCC(*),D(*),DS(*),P(*),PA(*)
@@ -266,7 +269,7 @@ C Local print level (if any)
          Else
             Write(LF,'(6X,A)')
      &      'The MO-coefficients are taken from the file:'
-            Write(LF,'(6X,A)') IPHNAME(:mylen(IPHNAME))
+            Write(LF,'(6X,A)') trim(IPHNAME)
          End If
          Write(VecTit(1:72),'(A72)') JobTit(1)
          Write(LF,'(6X,2A)') 'Title:',VecTit(1:72)
@@ -284,7 +287,7 @@ C Local print level (if any)
            Else
               Write(LF,'(6X,A)')
      &        'The active density matrices (D,DS,P,PA) are read from'//
-     &        ' file '//IPHNAME(:mylen(IPHNAME))//
+     &        ' file '//trim(IPHNAME)//
      &        ' and weighted together.'
            End If
          End If
