@@ -50,7 +50,7 @@
       Character*80 Line
       Integer StrnLn
       Logical No_Input_OK
-      common /igetline/igetline,myunit
+#include "igetline.fh"
         igetline=0
 *----------------------------------------------------------------------*
 *     push the entry name on the calling stack                         *
@@ -64,7 +64,6 @@
 *     read until an input Line is located which starts with            *
 *     the string, Name, not before the second column                   *
 *----------------------------------------------------------------------*
-      lLine=LEN(Line)
 100   Read(iUnit,'(A)',End=900) Line
       Call LeftAd(Line)
       Call UpCase(Line)
