@@ -304,8 +304,8 @@ INT allocmem(double ref[],char cref[],INT *intof,INT *dblof,INT *sglof, INT *chr
 #endif
      }
 #ifdef _DEBUGPRINT_MEM_
-     printf("ref=%p\n",ref);
-     printf("cref=%p\n",cref);
+     printf("ref=%p\n",(void*)ref);
+     printf("cref=%p\n",(void*)cref);
      setvbuf(stdout, NULL, _IOLBF,0);
 #endif
 #ifdef _OPENMP
@@ -706,6 +706,13 @@ void flushMM(mstat *MM, mentry mentries[], mentry *tmp) {
 #endif
 #ifdef _DEBUGPRINT_MEM_
     printf("Going to delete all memory entries older than atime=%ld\n",LIFMT(latime));
+#endif
+#ifdef _DEBUGPRINT_FLUSH_
+    printf("---------------------------------------------------------------------------------------------\n");
+    printf("  Nr.\t Label\t\tType\t\tOffset\t\tLength\t   Atime\t  Address\n");
+    printf("---------------------------------------------------------------------------------------------\n");
+    for(i=MM->nmentry-1;i>0;i--) if(mentries[i].atime>latime) printf("%3ld\t%-12s\t%4s\t%14ld\t%12ld   %9ld\t[%p]\n", LIFMT(i+1),mentries[i].elbl,mentries[i].etyp,LIFMT(mentries[i].offset),LIFMT(mentries[i].len),LIFMT(mentries[i].atime),mentries[i].addr);
+    printf("---------------------------------------------------------------------------------------------\n");
 #endif
     for(i=MM->nmentry-1;i>0;i--) if(mentries[i].atime>latime) del_mentry( MM, mentries, &mentries[i], i);
 
