@@ -61,23 +61,29 @@
 ************************************************************************
 
 #include "SysCtl.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "WrkSpc.fh"
 #include "mama.fh"
-#ifdef _OPENMP
-      Include 'omp_lib.h'
-#endif
 *
 *
       Character*(*) NameIn,KeyIn,TypeIn
       Character*8   FldNam,eopr,eoprcc,elbl,etyp
       Character*4   Key,VarTyp
-      Integer       c_getmem
-      External      c_getmem
 #ifdef _GARBLE_
       Character*5   xKey
       Logical       SkipGarble
 #endif
+      Interface
+        Function c_getmem(name_,Op,dtyp,offset,len_)
+     &           bind(C,name='c_getmem_')
+          Use, Intrinsic :: iso_c_binding, only: c_char
+          Use Definitions, only: MOLCAS_C_INT
+          Integer(kind=MOLCAS_C_INT) :: c_getmem
+          Character(kind=c_char) :: name_(*), Op(*), dtyp(*)
+          Integer(kind=MOLCAS_C_INT) :: offset, len_
+        End Function c_getmem
+      End Interface
+
 
 *----------------------------------------------------------------------*
 *     Initialize the Common / MemCtl / the first time it is referenced *
@@ -197,9 +203,9 @@
 #include "WrkSpc.fh"
       integer :: ipos, length
       character(len=*) :: vartyp
-      real*8, parameter ::    dgarbage(1) = [0.730432726d308]
-      integer, parameter ::   igarbage(1) = [730432726]
-      real*4, parameter ::    sgarbage(1) = [0.730432726e38]
+      real*8, parameter ::    dgarbage(1) = [huge(1.0d0)]
+      integer, parameter ::   igarbage(1) = [huge(1)]
+      real*4, parameter ::    sgarbage(1) = [huge(1.0)]
       character, parameter :: cgarbage = 'x'
 
       integer i
