@@ -12,7 +12,7 @@
      *              CSECT,RSECT,XI1,XI2,CNEW,SCR,ICI)
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "SysDef.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "mrci.fh"
 #include "WrkSpc.fh"
       DIMENSION CI(NCONF),SGM(NCONF)
@@ -25,7 +25,8 @@
       DIMENSION IDC(MXVEC),IDS(MXVEC)
       DIMENSION HCOPY(MXVEC,MXVEC),SCOPY(MXVEC,MXVEC)
       DIMENSION PCOPY(MXVEC,MXVEC)
-      DIMENSION EPERT(MXROOT),ELAST(MXROOT),PSEL(MXVEC),RNRM(MXROOT)
+      DIMENSION ELAST(MXROOT),PSEL(MXVEC),RNRM(MXROOT)
+C      DIMENSION EPERT(MXROOT)
 *
       WRITE(6,*)
       WRITE(6,*)('-',I=1,60)
@@ -380,7 +381,7 @@ C        WRITE(6,'(1X,5F15.6)')(SZERO(I,J),J=1,NZ)
 C 392  CONTINUE
       DO 393 I=1,NRROOT
         RNRM(I)=SQRT(SZERO(NRROOT+I,NRROOT+I))
-        EPERT(I)=ESMALL(I)-SZERO(3*NRROOT+I,NRROOT+I)
+C        EPERT(I)=ESMALL(I)-SZERO(3*NRROOT+I,NRROOT+I)
 393   CONTINUE
 C      WRITE(6,*)
 C      WRITE(6,*)' PERTURBATION ESTIMATES TO ENERGY:'
@@ -403,7 +404,6 @@ C      WRITE(6,'(1X,5F15.6)')(ESHIFT+EPERT(I),I=1,NRROOT)
       IF(NRROOT.GT.1) THEN
         DO 1240 I=2,NRROOT
           EDISP=ESMALL(I)+ESHIFT
-          EDIFF=ESMALL(I)-ESMALL(1)
           IF(ITER.EQ.1) THEN
             WRITE(6,1236) EDISP,RNRM(I),PSEL(I)
           ELSE
