@@ -21,7 +21,7 @@
       DIMENSION CSECT(NSECT,MXVEC),RSECT(NSECT,MXVEC)
       DIMENSION XI1(NSECT,NRROOT),XI2(NSECT,NRROOT)
       DIMENSION ARR(NRROOT,NRROOT,11)
-      DIMENSION IDCOPY(MXVEC),IDC(MXVEC),IDS(MXVEC)
+      DIMENSION IDC(MXVEC),IDS(MXVEC)
 C THIS SUBROUTINE LOOPS OVER SECTIONS OF PSI AND SIGMA ARRAYS
 C ON DISK, AND ACCUMULATES OVERLAP MATRICES AND A COUPLE OF
 C HAMILTONIAN MATRICES IN THE BASIS SET PSI, RHO, XI1 AND XI2.
@@ -40,7 +40,6 @@ C LOOP OVER BUFFERS FOR READING PSI, SIGMA AND DBUF:
         IBUF=1+IEND-ISTA
         CALL dDAFILE(LUEIG,2,DBUF,IBUF,IDD)
         DO 20 K=1,NVEC
-          IDCOPY(K)=IDC(K)
           CALL iDAFILE(LUEIG,2,ICI,IBUF,IDC(K))
           CALL UPKVEC(IBUF,ICI,CBUF(1,K))
           CALL dDAFILE(LUEIG,2,SBUF(1,K),IBUF,IDS(K))
