@@ -12,7 +12,7 @@
       SUBROUTINE READIN_MRCI()
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "SysDef.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "mrci.fh"
 #include "WrkSpc.fh"
 #include "niocr.fh"
@@ -49,7 +49,6 @@
       IREST=0
       ICPF=0
       IREFCI=0
-      ISDCI=1
       ITRANS=0
       IGFAC=0
       MXVC=0
@@ -166,13 +165,11 @@
 *---  process ACPF command --------------------------------------------*
 1000  Continue
       ICPF=1
-      ISDCI=0
       Goto 10
 *
 *---  process SDCI command --------------------------------------------*
 1100  Continue
       ICPF=0
-      ISDCI=1
       Goto 10
 *
 *---  process GVAL command --------------------------------------------*
@@ -260,7 +257,7 @@
      &        '*',(' ',i=1,56),'Title:',(' ',i=1,56),'*'
       CALL XFLUSH(6)
       Do i=1,nTit
-         Call Center(Title(i))
+         Call Center_Text(Title(i))
          WRITE(6,'(6X,24A1,A72,24A1)')
      &        '*',(' ',j=1,23),Title(i),(' ',j=1,23),'*'
       CALL XFLUSH(6)
