@@ -12,7 +12,7 @@
       IMPLICIT REAL*8 (A-H,O-Z)
       External COUNT
 #include "SysDef.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "mrci.fh"
       DIMENSION BUFS(NBITM1,NCHN1)
       DIMENSION INDS(NBITM1+2,NCHN1)
@@ -30,9 +30,9 @@ C FIRST CHAIN FOR IJKL
 
       IAD50=0
       CALL iDAFILE(LUTRA,2,iTraToc,nTraToc,IAD50)
-      IBOFF1=RTOI*NBITM1
-      IBBC1=IBOFF1+NBITM1+1
-      IBDA1=IBBC1+1
+*      IBOFF1=RTOI*NBITM1
+*      IBBC1=IBOFF1+NBITM1+1
+*      IBDA1=IBBC1+1
 
       IDISK=0
       ICHK=0
