@@ -12,7 +12,7 @@
       SUBROUTINE SORTB(BUFS,INDS,ACBDS,ACBDT,ISAB,BFACBD,NINTGR)
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "SysDef.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "mrci.fh"
 c      DIMENSION BUFOUT(NBSIZ2,NCHN2)
 *PAM04      DIMENSION BUFOUT(*)
@@ -221,7 +221,6 @@ C EMPTY LAST BUFFERS
             NSAC=MUL(NSM(LN+NA),NSM(LN+NC))
             NSACL=MUL(NSAC,LSYM)
             IF(NSACL.NE.ISYM)GO TO 60
-            ISAC=ISAB(NA+(NC-1)*NVIRT)
             NSC=NSM(LN+NC)
             NDMAX=NVIRP(NSC)+NVIR(NSC)
             IF(NDMAX.GT.NA)NDMAX=NA
