@@ -48,7 +48,7 @@
 C        iAng   = iSD( 1,iS)
          iCmp   = iSD( 2,iS)
          iBas   = iSD( 3,iS)
-         iPrim  = iSD( 5,iS)
+C        iPrim  = iSD( 5,iS)
          iAO    = iSD( 7,iS)
 C        mdci   = iSD(10,iS)
          iShell = iSD(11,iS)
@@ -57,7 +57,7 @@ C        mdci   = iSD(10,iS)
 C           jAng   = iSD( 1,jS)
             jCmp   = iSD( 2,jS)
             jBas   = iSD( 3,jS)
-            jPrim  = iSD( 5,jS)
+C           jPrim  = iSD( 5,jS)
             jAO    = iSD( 7,jS)
 C           mdcj   = iSD(10,jS)
             jShell = iSD(11,jS)
