@@ -27,9 +27,6 @@
       Complex*16 Rnxyz(nZeta*3,0:la,0:lb),
      &           Axyz(nZeta*3,nHer,0:la),
      &           Bxyz(nZeta*3,nHer,0:lb)
-#ifdef _DARWIN_
-      Complex*16 vv1, vv2
-#endif
       Character*80 Label
 *
       iRout = 123
@@ -65,17 +62,10 @@
 *
                Do 30 iHer = 1, nHer
                   Do 10 iZCar = 1, 3*nZeta
-c vv. splitted in order to make GNU compiler on Mac more happy.
-#ifdef _DARWIN_
-                  vv1=Axyz(iZCar,iHer,ia)
-                  vv2=Bxyz(iZCar,iHer,ib)*HerW(iHer)
-                  Rnxyz(iZCar,ia,ib)= Rnxyz(iZCar,ia,ib)+vv1*vv2
-#else
                      Rnxyz(iZCar,ia,ib) = Rnxyz(iZCar,ia,ib) +
      &                             Axyz(iZCar,iHer,ia)*
      &                             Bxyz(iZCar,iHer,ib)*
      &                             HerW(iHer)
-#endif
  10               Continue
  30            Continue
 *
