@@ -11,7 +11,7 @@
 * Copyright (C) 1991, Roland Lindh                                     *
 ************************************************************************
       SubRoutine CCmbnVe(Rnxyz,nZeta,la,lb,Zeta,rKappa,Final,nComp,
-     &                  Vxyz,KVector)
+     &                  Vxyz,KVector,P)
 ************************************************************************
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
@@ -21,9 +21,11 @@
 #include "print.fh"
 #include "real.fh"
       Real*8 Final(nZeta,(la+1)*(la+2)/2,(lb+1)*(lb+2)/2,nComp),
-     &       Zeta(nZeta), rKappa(nZeta), rTemp, Fact, KVector(3)
+     &       Zeta(nZeta), rKappa(nZeta), rTemp, Fact, KVector(3),
+     &       P(nZeta,3), k_dot_P
       Complex*16 Rnxyz(nZeta,3,0:la+1,0:lb+1),
-     &          Vxyz(nZeta,3,0:la,0:lb,2), Temp1, Temp2
+     &          Vxyz(nZeta,3,0:la,0:lb,2), Temp1, Temp2,
+     &          Tempp, Tempm, i
 *
 *     Statement function for Cartesian index
 *
@@ -32,6 +34,7 @@
       iRout = 161
       iPrint = nPrint(iRout)
 *
+      i = (0.0D0,1.0D0)
       Do 10 ixa = 0, la
          iyaMax=la-ixa
       Do 11 ixb = 0, lb
@@ -53,42 +56,45 @@
                rTemp=rTemp/(Four*Zeta(iZeta))
                Fact = rKappa(iZeta) * Zeta(iZeta)**(-Three/Two) *
      &               Exp(-rTemp)
-               Temp1= Fact *
-     &               Vxyz(iZeta,1,ixa,ixb,1)*
+               k_dot_P=kVector(1)*P(iZeta,1)
+     &                +kVector(2)*P(iZeta,2)
+     &                +kVector(3)*P(iZeta,3)
+               Temp1=Vxyz(iZeta,1,ixa,ixb,1)*
      &               Rnxyz(iZeta,2,iya,iyb)*
      &               Rnxyz(iZeta,3,iza,izb)
-               Temp2= Fact *
-     &               Vxyz(iZeta,1,ixa,ixb,2)*
+               Temp2=Vxyz(iZeta,1,ixa,ixb,2)*
      &               Rnxyz(iZeta,2,iya,iyb)*
      &               Rnxyz(iZeta,3,iza,izb)
-               Final(iZeta,ipa,ipb,1) = DBLE((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,4) = DBLE((Temp1-Temp2)*Half)
-               Final(iZeta,ipa,ipb,7) = DIMAG((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,10)= DIMAG((Temp1-Temp2)*Half)
-               Temp1= Fact *
-     &               Rnxyz(iZeta,1,ixa,ixb)*
+               Tempp = Exp(i*k_dot_P) * Fact * (Temp1+Temp2) * Half
+               Tempm = Exp(i*k_dot_P) * Fact * (Temp1-Temp2) * Half
+               Final(iZeta,ipa,ipb,1) = DBLE(Tempp)
+               Final(iZeta,ipa,ipb,4) = DBLE(Tempm)
+               Final(iZeta,ipa,ipb,7) = DIMAG(Tempp)
+               Final(iZeta,ipa,ipb,10)= DIMAG(Tempm)
+               Temp1=Rnxyz(iZeta,1,ixa,ixb)*
      &               Vxyz(iZeta,2,iya,iyb,1)*
      &               Rnxyz(iZeta,3,iza,izb)
-               Temp2= Fact *
-     &               Rnxyz(iZeta,1,ixa,ixb)*
+               Temp2=Rnxyz(iZeta,1,ixa,ixb)*
      &               Vxyz(iZeta,2,iya,iyb,2)*
      &               Rnxyz(iZeta,3,iza,izb)
-               Final(iZeta,ipa,ipb,2) = DBLE((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,5) = DBLE((Temp1-Temp2)*Half)
-               Final(iZeta,ipa,ipb,8) = DIMAG((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,11)= DIMAG((Temp1-Temp2)*Half)
-               Temp1= Fact *
-     &               Rnxyz(iZeta,1,ixa,ixb)*
+               Tempp = Exp(i*k_dot_P) * Fact * (Temp1+Temp2) * Half
+               Tempm = Exp(i*k_dot_P) * Fact * (Temp1-Temp2) * Half
+               Final(iZeta,ipa,ipb,2) = DBLE(Tempp)
+               Final(iZeta,ipa,ipb,5) = DBLE(Tempm)
+               Final(iZeta,ipa,ipb,8) = DIMAG(Tempp)
+               Final(iZeta,ipa,ipb,11)= DIMAG(Tempm)
+               Temp1=Rnxyz(iZeta,1,ixa,ixb)*
      &               Rnxyz(iZeta,2,iya,iyb)*
      &               Vxyz(iZeta,3,iza,izb,1)
-               Temp2= Fact *
-     &               Rnxyz(iZeta,1,ixa,ixb)*
+               Temp2=Rnxyz(iZeta,1,ixa,ixb)*
      &               Rnxyz(iZeta,2,iya,iyb)*
      &               Vxyz(iZeta,3,iza,izb,2)
-               Final(iZeta,ipa,ipb,3) = DBLE((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,6 )= DBLE((Temp1-Temp2)*Half)
-               Final(iZeta,ipa,ipb,9 )= DIMAG((Temp1+Temp2)*Half)
-               Final(iZeta,ipa,ipb,12)= DIMAG((Temp1-Temp2)*Half)
+               Tempp = Exp(i*k_dot_P) * Fact * (Temp1+Temp2) * Half
+               Tempm = Exp(i*k_dot_P) * Fact * (Temp1-Temp2) * Half
+               Final(iZeta,ipa,ipb,3) = DBLE(Tempp)
+               Final(iZeta,ipa,ipb,6 )= DBLE(Tempm)
+               Final(iZeta,ipa,ipb,9 )= DIMAG(Tempp)
+               Final(iZeta,ipa,ipb,12)= DIMAG(Tempm)
  30         Continue
             If (iPrint.ge.99) Then
                Write (6,*) '(',ixa,iya,iza,ixb,iyb,izb,')'
