@@ -37,8 +37,8 @@
 *
       Ind(ixyz,ix,iz) = (ixyz-ix)*(ixyz-ix+1)/2 + iz + 1
 *
-      iRout = 134
-      iPrint = nPrint(iRout)
+*     iRout = 134
+*     iPrint = nPrint(iRout)
 *
       RAB(1)=A(1)-RB(1)
       RAB(2)=A(2)-RB(2)
