@@ -30,9 +30,6 @@
 *     Statement function for Cartesian index
 *
       Ind(ixyz,ix,iz) = (ixyz-ix)*(ixyz-ix+1)/2 + iz + 1
-*
-      iRout = 134
-      iPrint = nPrint(iRout)
 *
       Do 10 ixa = 0, la
          iyaMax=la-ixa
