@@ -51,7 +51,6 @@ c Avoid unused argument warnings
          Call Unused_integer_array(iChO)
          Call Unused_integer_array(iStabM)
          Call Unused_real_array(PtChrg)
-         Call Unused_integer(nGrid)
          Call Unused_integer(iAddPot)
       End If
 *
@@ -173,13 +172,13 @@ c Avoid unused argument warnings
          Call C_F_Pointer(C_Loc(Array(ipVxyz)),zVxyz,
      &                     [nZeta*3*(la+1)*(lb+1)*2])
          Call CCmbnVe(zQxyz,nZeta,la,lb,Zeta,rKappa,
-     &                Array(ipRes),nComp,zVxyz,CCoor)
+     &                Array(ipRes),nComp,zVxyz,CCoor,P)
          Nullify(zQxyz,zVxyz)
       Else
          Call C_F_Pointer(C_Loc(Array(ipQxyz)),zQxyz,
      &                     [nZeta*3*(la+1)*(lb+1)*(nOrdOp+1)])
          Call CCmbnMP(zQxyz,nZeta,la,lb,nOrdOp,Zeta,
-     &                rKappa,Array(ipRes),nComp,CCoor)
+     &                rKappa,Array(ipRes),nComp,CCoor,P)
          Nullify(zQxyz)
       End If
 *
