@@ -8,21 +8,25 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine EMFMem(nHer,MemVe,la,lb,lr)
+      Subroutine EMFMem(
+#define _CALLING_
+#include "mem_interface.fh"
+     &)
+#include "mem_interface.fh"
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *
       nHer=(la+lb+lr+2)/2
-      MemVe = 3*nHer*(la+1+lr) * 2
-     &      + 3*nHer*(lb+1+lr) * 2
-     &      + 3*(la+1+lr)*(lb+1+lr) * 2
+      Mem = 3*nHer*(la+1+lr) * 2
+     &    + 3*nHer*(lb+1+lr) * 2
+     &    + 3*(la+1+lr)*(lb+1+lr) * 2
       If (lr.eq.1) Then
-         MemVe = MemVe
-     &         + 6*(la+1)*(lb+1) * 2 + 2
-     &         + nElem(la)*nElem(lb)*nElem(lr)*12
+         Mem = Mem
+     &       + 6*(la+1)*(lb+1) * 2 + 2
+     &       + nElem(la)*nElem(lb)*nElem(lr)*12
       Else
-         MemVe = MemVe
-     &         + nElem(la)*nElem(lb)*nElem(lr)*2
+         Mem = Mem
+     &       + nElem(la)*nElem(lb)*nElem(lr)*2
       End If
 *
       Return
