@@ -38,9 +38,6 @@
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       nabSz(ixyz) = (ixyz+1)*(ixyz+2)*(ixyz+3)/6  - 1
-*
-      iRout = 201
-      iPrint = nPrint(iRout)
 *
       call dcopy_(nZeta*nElem(la)*nElem(lb)*nIC,[Zero],0,Final,1)
 *
@@ -111,7 +108,6 @@ c Avoid unused argument warnings
          Call Unused_integer(nHer)
          Call Unused_integer(nOrdOp)
          Call Unused_real_array(PtChrg)
-         Call Unused_integer(nGrid)
          Call Unused_integer(iAddPot)
       End If
       End
