@@ -8,7 +8,11 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine MltMem(nHer,MemMlt,la,lb,lr)
+      Subroutine MltMem(
+#define _CALLING_
+#include "mem_interface.fh"
+     &)
+#include "mem_interface.fh"
 *
 #include "rmat_option.fh"
 *
@@ -16,13 +20,13 @@
 *
       nHer=(la+lb+lr+2)/2
       nComp = nElem(lr)
-      MemMlt = 3*nHer*(la+1) +
-     &         3*nHer*(lb+1) +
-     &         3*nHer*(lr+1) +
-     &         3*(la+1)*(lb+1)*(lr+1) +
-     &         nElem(la)*nElem(lb)*nComp
+      Mem = 3*nHer*(la+1) +
+     &      3*nHer*(lb+1) +
+     &      3*nHer*(lr+1) +
+     &      3*(la+1)*(lb+1)*(lr+1) +
+     &      nElem(la)*nElem(lb)*nComp
       If (RMat_type_integrals) Then
-         MemMlt = MemMlt + la+lb+lr+1
+         Mem = Mem + la+lb+lr+1
       End If
 *
       Return
