@@ -38,9 +38,6 @@
 *     Statement function for Cartesian index
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
-*
-      iRout = 210
-      iPrint = nPrint(iRout)
 *
       nip = 1
       ipB = nip
@@ -114,7 +111,6 @@
 c Avoid unused argument warnings
       If (.False.) Then
          Call Unused_real_array(PtChrg)
-         Call Unused_integer(nGrid)
          Call Unused_integer(iAddPot)
       End If
       End
