@@ -10,20 +10,24 @@
 *                                                                      *
 * Copyright (C) 1991, Roland Lindh                                     *
 ************************************************************************
-      Subroutine OAMMem(nHer,MemOAM,la,lb,lr)
+      Subroutine OAMMem(
+#define _CALLING_
+#include "mem_interface.fh"
+     &)
+#include "mem_interface.fh"
 *
 *     Statement function for Cartesian index
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *
-      Call MltMmP(nOrder,MemOAM,la,lb+1,lr-1)
+      Call MltMmP(nOrder,Mem,la,lb+1,lr-1)
       nHer = nOrder
       If (lb.gt.0) Then
          Call MltMmP(nOrder,MmMltP,la,lb-1,lr-1)
-         MemOAM = Max(MemOAM,MmMltP) + nElem(la)*nElem(lb-1)*3
+         Mem = Max(Mem,MmMltP) + nElem(la)*nElem(lb-1)*3
       End If
-      MemOAM = MemOAM + 1 + nElem(la)*nElem(lb+1)*3
-      MemOAM = MemOAM + nElem(la)*nElem(lb)*3
+      Mem = Mem + 1 + nElem(la)*nElem(lb+1)*3
+      Mem = Mem + nElem(la)*nElem(lb)*3
 *
       Return
       End
