@@ -18,12 +18,13 @@
 *     Datasets:
 *       AO_OVERLAP_MATRIX
 
+      use mh5, only: mh5_init_attr, mh5_create_dset_real, mh5_put_dset,
+     &               mh5_close_dset
       implicit none
       integer :: fileid
       integer :: nsym, nbas(*)
 #  include "Molcas.fh"
 #  include "stdalloc.fh"
-#  include "mh5.fh"
 
       integer :: isym
       integer :: nb, nbast, nbast1, nbast2
@@ -50,7 +51,7 @@
 *     atomic orbital overlap matrix
       dsetid = mh5_create_dset_real(fileid,
      $        'AO_OVERLAP_MATRIX', 1, [NBAST2])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Overlap matrix of the atomic orbitals, '//
      $        'arranged as blocks of size [NBAS(i)**2], i=1,#irreps')
 
@@ -89,12 +90,13 @@
 *     Datasets:
 *       AO_FOCKINT_MATRIX
 
+      use mh5, only: mh5_init_attr, mh5_create_dset_real, mh5_put_dset,
+     &               mh5_close_dset
       implicit none
       integer :: fileid
       integer :: nsym, nbas(*)
 #  include "Molcas.fh"
 #  include "stdalloc.fh"
-#  include "mh5.fh"
 
       integer :: isym
       integer :: nb, nbast, nbast1, nbast2
@@ -121,7 +123,7 @@
 *     atomic orbital Fock matrix
       dsetid = mh5_create_dset_real(fileid,
      $        'AO_FOCKINT_MATRIX', 1, [NBAST2])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Fock matrix of the atomic orbitals, '//
      $        'arranged as blocks of size [NBAS(i)**2], i=1,#irreps')
 
@@ -163,12 +165,13 @@
 *       MLTPL_XX, MLTPL_YY, MLTPL_ZZ, MLTPL_XY, MLTPL_YZ, MLTPL_XZ
 *       MLTPL_ORIG
 
+      use mh5, only: mh5_init_attr, mh5_create_dset_real, mh5_put_dset,
+     &               mh5_close_dset
       implicit none
       integer :: fileid
       integer :: nsym, nbas(*)
 #  include "Molcas.fh"
 #  include "stdalloc.fh"
-#  include "mh5.fh"
 
       integer :: isym, jsym, msym
       integer :: nb, nbast, nB1, nB2
@@ -230,7 +233,7 @@
                 jBas = jOff + j
                 Do i=1,nB1
                   iBas = iOff + i
-                  MLTPL(iBas,jBas) = Scratch(1+iScrOff)
+                  MLTPL(jBas,iBas) = Scratch(1+iScrOff)
                   iScrOff = iScrOff + 1
                 End Do
               End Do
@@ -247,10 +250,10 @@
       End Do
       dsetid = mh5_create_dset_real(fileid,
      $        'AO_MLTPL_'//mltpl1_comp(icomp), 2, [NBAST,NBAST])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        '1st-order multipole matrix of the atomic orbitals, '//
      $        'arranged as matrix of size [NBAST,NBAST]')
-      call mh5_put_dset_array_real(dsetid,MLTPL)
+      call mh5_put_dset(dsetid,MLTPL)
       call mh5_close_dset(dsetid)
       end do
 
@@ -287,7 +290,7 @@
                 jBas = jOff + j
                 Do i=1,nB1
                   iBas = iOff + i
-                  MLTPL(iBas,jBas) = Scratch(1+iScrOff)
+                  MLTPL(jBas,iBas) = Scratch(1+iScrOff)
                   iScrOff = iScrOff + 1
                 End Do
               End Do
@@ -304,10 +307,10 @@
       End Do
       dsetid = mh5_create_dset_real(fileid,
      $        'AO_MLTPL_'//mltpl2_comp(icomp), 2, [NBAST,NBAST])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        '2nd-order multipole matrix of the atomic orbitals, '//
      $        'arranged as matrix of size [NBAST,NBAST]')
-      call mh5_put_dset_array_real(dsetid,MLTPL)
+      call mh5_put_dset(dsetid,MLTPL)
       call mh5_close_dset(dsetid)
       end do
 
@@ -318,10 +321,10 @@
 
       dsetid = mh5_create_dset_real(fileid,
      $        'MLTPL_ORIG', 2, [3,3])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Origin used for the multipole moment operators: '//
      $        'arranged as overlap, dipole, quadrupole')
-      call mh5_put_dset_array_real(dsetid,mp_orig,[3,3],[0,0])
+      call mh5_put_dset(dsetid,mp_orig,[3,3],[0,0])
       call mh5_close_dset(dsetid)
 
       end
