@@ -14,13 +14,14 @@
      &                         Tmin, Tmax, chit_exp, eso, w, T, RROT,
      &                         zJ, Xfield, EM, THRS, XT_no_field,
      &                         dipso, s_so, dipexch, s_exch,
-     &                         tinput, smagn, m_paranoid, m_accurate )
+     &                         tinput, smagn, m_paranoid, m_accurate,
+     &                         doplot )
 c this Subroutine computes the XT as M/H as it is observed for most of experiments.
 c The M is averaged over the grid for each temperature point.
 c       chi*t ----------- the units are cgsemu: [ cm^3*k/mol ]
 
       Implicit None
-      Integer, parameter        :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
 #include "mgrid.fh"
 #include "stdalloc.fh"
       Integer, intent(in)          :: exch, nLoc, nCenter, nneq, neqv
@@ -43,7 +44,7 @@ c       chi*t ----------- the units are cgsemu: [ cm^3*k/mol ]
       Complex(kind=8), intent(in) ::  s_so(nneq,3,nLoc,nLoc)
       Complex(kind=8), intent(in) :: dipexch(3,exch,exch)
       Complex(kind=8), intent(in) ::  s_exch(3,exch,exch)
-      Logical, intent(in)          :: tinput, smagn, m_paranoid
+      Logical, intent(in)          :: tinput, smagn, m_paranoid, doplot
 cccc local variables ccc
       Integer                      :: nDirX
       Integer       :: iM,iT,jT,i,j,l,n,isite !,nP
@@ -155,7 +156,7 @@ c standard deviation data:
       Real(kind=8), allocatable :: XTtens_dMdH(:,:,:)
 
       Integer                    :: nTempTotal
-      Real(kind=8)              :: Xfield_1, Xfield_2, dltXF
+      Real(kind=8)              :: Xfield_1, Xfield_2, dltXF, F1, F2
       !Real(kind=8)             :: XTS(nT+nTempMagn)
 c Zeeman energy and M vector
 c      Real(kind=8)             :: dirX(nDir), dirY(nDir), dirZ(nDir)
@@ -164,7 +165,6 @@ c      Real(kind=8)             :: dir_weight(nDirZee,3)
       Real(kind=8)              :: dHX(3)
       Real(kind=8)              :: dHY(3)
       Real(kind=8)              :: dHZ(3)
-      Real(kind=8)              :: dHW(3)
       Integer                    :: RtoB, mem_local
 
       Integer                    :: info, ibuf, ibuf1, ibuf3
@@ -174,6 +174,7 @@ c      Real(kind=8)             :: dir_weight(nDirZee,3)
       External                   :: dev, dnrm2_
       Real(kind=8)              :: cm3tomB
       logical                    :: DBG, m_accurate
+      Character(len=50) :: label
       DBG=.false.
       !m_paranoid=.true.!.false.
       cm3tomB=0.55849389040_wp   !   in cm3 * mol-1 * T
@@ -264,170 +265,161 @@ cccc-------------------------------------------------------cccc
 !=======================================================================
       mem_local=0
       RtoB=8
-      If(nM>=0) Then
-        Call mma_allocate(WEX0,nM,'WEX0')
-        Call mma_allocate(WEX1,nM,'WEX1')
-        Call mma_allocate(WEX2,nM,'WEX2')
-        Call dcopy_(nM,[0.0_wp],0,WEX0,1)
-        Call dcopy_(nM,[0.0_wp],0,WEX1,1)
-        Call dcopy_(nM,[0.0_wp],0,WEX2,1)
-        mem_local=mem_local+3*nM*RtoB
-      End If
-      If((nneq>=0).and.(nLoc>=0)) Then
-        Call mma_allocate(WL0,nneq,nLoc,'WL0')
-        Call mma_allocate(WL1,nneq,nLoc,'WL1')
-        Call mma_allocate(WL2,nneq,nLoc,'WL2')
-        Call mma_allocate(WR0,nneq,nLoc,'WR0')
-        Call mma_allocate(WR1,nneq,nLoc,'WR1')
-        Call mma_allocate(WR2,nneq,nLoc,'WR2')
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WL0,1)
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WL1,1)
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WL2,1)
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WR0,1)
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WR1,1)
-        Call dcopy_(nneq*nLoc,[0.0_wp],0,WR2,1)
-        mem_local=mem_local+6*nneq*nLoc*RtoB
-      End If
+      Call mma_allocate(WEX0,nM,'WEX0')
+      Call mma_allocate(WEX1,nM,'WEX1')
+      Call mma_allocate(WEX2,nM,'WEX2')
+      Call dcopy_(nM,[0.0_wp],0,WEX0,1)
+      Call dcopy_(nM,[0.0_wp],0,WEX1,1)
+      Call dcopy_(nM,[0.0_wp],0,WEX2,1)
+      mem_local=mem_local+3*nM*RtoB
 
-      If((nneq>=0).and.((nT+nTempMagn)>=0)) Then
-        Call mma_allocate(ZL0,nneq,(nT+nTempMagn),'ZL0')
-        Call mma_allocate(ZR0,nneq,(nT+nTempMagn),'ZR0')
-        Call mma_allocate(ZL1,nneq,(nT+nTempMagn),'ZL1')
-        Call mma_allocate(ZR1,nneq,(nT+nTempMagn),'ZR1')
-        Call mma_allocate(ZL2,nneq,(nT+nTempMagn),'ZL2')
-        Call mma_allocate(ZR2,nneq,(nT+nTempMagn),'ZR2')
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL0,1)
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR0,1)
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL1,1)
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR1,1)
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL2,1)
-        Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR2,1)
-        mem_local=mem_local+6*nneq*(nT+nTempMagn)*RtoB
+      Call mma_allocate(WL0,nneq,nLoc,'WL0')
+      Call mma_allocate(WL1,nneq,nLoc,'WL1')
+      Call mma_allocate(WL2,nneq,nLoc,'WL2')
+      Call mma_allocate(WR0,nneq,nLoc,'WR0')
+      Call mma_allocate(WR1,nneq,nLoc,'WR1')
+      Call mma_allocate(WR2,nneq,nLoc,'WR2')
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WL0,1)
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WL1,1)
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WL2,1)
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WR0,1)
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WR1,1)
+      Call dcopy_(nneq*nLoc,[0.0_wp],0,WR2,1)
+      mem_local=mem_local+6*nneq*nLoc*RtoB
 
-        Call mma_allocate(SL0,nneq,3,(nT+nTempMagn),'SL0')
-        Call mma_allocate(SR0,nneq,3,(nT+nTempMagn),'SR0')
-        Call mma_allocate(SL1,nneq,3,(nT+nTempMagn),'SL1')
-        Call mma_allocate(SR1,nneq,3,(nT+nTempMagn),'SR1')
-        Call mma_allocate(SL2,nneq,3,(nT+nTempMagn),'SL2')
-        Call mma_allocate(SR2,nneq,3,(nT+nTempMagn),'SR2')
-        Call mma_allocate(ML0,nneq,3,(nT+nTempMagn),'ML0')
-        Call mma_allocate(MR0,nneq,3,(nT+nTempMagn),'MR0')
-        Call mma_allocate(ML1,nneq,3,(nT+nTempMagn),'ML1')
-        Call mma_allocate(MR1,nneq,3,(nT+nTempMagn),'MR1')
-        Call mma_allocate(ML2,nneq,3,(nT+nTempMagn),'ML2')
-        Call mma_allocate(MR2,nneq,3,(nT+nTempMagn),'MR2')
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL0,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR0,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL1,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR1,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL2,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR2,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML0,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR0,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML1,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR1,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML2,1)
-        Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR2,1)
-        mem_local=mem_local+12*3*nneq*(nT+nTempMagn)*RtoB
-      End If
+      Call mma_allocate(ZL0,nneq,(nT+nTempMagn),'ZL0')
+      Call mma_allocate(ZR0,nneq,(nT+nTempMagn),'ZR0')
+      Call mma_allocate(ZL1,nneq,(nT+nTempMagn),'ZL1')
+      Call mma_allocate(ZR1,nneq,(nT+nTempMagn),'ZR1')
+      Call mma_allocate(ZL2,nneq,(nT+nTempMagn),'ZL2')
+      Call mma_allocate(ZR2,nneq,(nT+nTempMagn),'ZR2')
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL0,1)
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR0,1)
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL1,1)
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR1,1)
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZL2,1)
+      Call dcopy_(nneq*(nT+nTempMagn),[0.0_wp],0,ZR2,1)
+      mem_local=mem_local+6*nneq*(nT+nTempMagn)*RtoB
 
-      If((nT+nTempMagn)>=0) Then
-        Call mma_allocate(ZEX0,(nT+nTempMagn),'ZEX0')
-        Call mma_allocate(ZEX1,(nT+nTempMagn),'ZEX1')
-        Call mma_allocate(ZEX2,(nT+nTempMagn),'ZEX2')
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX0,1)
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX1,1)
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX2,1)
-        mem_local=mem_local+3*(nT+nTempMagn)*RtoB
+      Call mma_allocate(SL0,nneq,3,(nT+nTempMagn),'SL0')
+      Call mma_allocate(SR0,nneq,3,(nT+nTempMagn),'SR0')
+      Call mma_allocate(SL1,nneq,3,(nT+nTempMagn),'SL1')
+      Call mma_allocate(SR1,nneq,3,(nT+nTempMagn),'SR1')
+      Call mma_allocate(SL2,nneq,3,(nT+nTempMagn),'SL2')
+      Call mma_allocate(SR2,nneq,3,(nT+nTempMagn),'SR2')
+      Call mma_allocate(ML0,nneq,3,(nT+nTempMagn),'ML0')
+      Call mma_allocate(MR0,nneq,3,(nT+nTempMagn),'MR0')
+      Call mma_allocate(ML1,nneq,3,(nT+nTempMagn),'ML1')
+      Call mma_allocate(MR1,nneq,3,(nT+nTempMagn),'MR1')
+      Call mma_allocate(ML2,nneq,3,(nT+nTempMagn),'ML2')
+      Call mma_allocate(MR2,nneq,3,(nT+nTempMagn),'MR2')
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL0,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR0,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL1,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR1,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SL2,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,SR2,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML0,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR0,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML1,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR1,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,ML2,1)
+      Call dcopy_(3*nneq*(nT+nTempMagn),[0.0_wp],0,MR2,1)
+      mem_local=mem_local+12*3*nneq*(nT+nTempMagn)*RtoB
 
-        Call mma_allocate(ZT0,(nT+nTempMagn),'ZT0')
-        Call mma_allocate(ZT1,(nT+nTempMagn),'ZT1')
-        Call mma_allocate(ZT2,(nT+nTempMagn),'ZT2')
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX0,1)
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX1,1)
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX2,1)
-        mem_local=mem_local+3*(nT+nTempMagn)*RtoB
+      Call mma_allocate(ZEX0,(nT+nTempMagn),'ZEX0')
+      Call mma_allocate(ZEX1,(nT+nTempMagn),'ZEX1')
+      Call mma_allocate(ZEX2,(nT+nTempMagn),'ZEX2')
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX0,1)
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX1,1)
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX2,1)
+      mem_local=mem_local+3*(nT+nTempMagn)*RtoB
 
-        Call mma_allocate(SEX0,3,(nT+nTempMagn),'SEX0')
-        Call mma_allocate(SEX1,3,(nT+nTempMagn),'SEX1')
-        Call mma_allocate(SEX2,3,(nT+nTempMagn),'SEX2')
-        Call mma_allocate(MEX0,3,(nT+nTempMagn),'MEX0')
-        Call mma_allocate(MEX1,3,(nT+nTempMagn),'MEX1')
-        Call mma_allocate(MEX2,3,(nT+nTempMagn),'MEX2')
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX0,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX1,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX2,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX0,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX1,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX2,1)
-        mem_local=mem_local+6*3*(nT+nTempMagn)*RtoB
+      Call mma_allocate(ZT0,(nT+nTempMagn),'ZT0')
+      Call mma_allocate(ZT1,(nT+nTempMagn),'ZT1')
+      Call mma_allocate(ZT2,(nT+nTempMagn),'ZT2')
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX0,1)
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX1,1)
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,ZEX2,1)
+      mem_local=mem_local+3*(nT+nTempMagn)*RtoB
 
-        Call mma_allocate(ST0,3,(nT+nTempMagn),'ST0')
-        Call mma_allocate(ST1,3,(nT+nTempMagn),'ST1')
-        Call mma_allocate(ST2,3,(nT+nTempMagn),'ST2')
-        Call mma_allocate(MT0,3,(nT+nTempMagn),'MT0')
-        Call mma_allocate(MT1,3,(nT+nTempMagn),'MT1')
-        Call mma_allocate(MT2,3,(nT+nTempMagn),'MT2')
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST0,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST1,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST2,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT0,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT1,1)
-        Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT2,1)
-        mem_local=mem_local+6*3*(nT+nTempMagn)*RtoB
+      Call mma_allocate(SEX0,3,(nT+nTempMagn),'SEX0')
+      Call mma_allocate(SEX1,3,(nT+nTempMagn),'SEX1')
+      Call mma_allocate(SEX2,3,(nT+nTempMagn),'SEX2')
+      Call mma_allocate(MEX0,3,(nT+nTempMagn),'MEX0')
+      Call mma_allocate(MEX1,3,(nT+nTempMagn),'MEX1')
+      Call mma_allocate(MEX2,3,(nT+nTempMagn),'MEX2')
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX0,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX1,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,SEX2,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX0,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX1,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MEX2,1)
+      mem_local=mem_local+6*3*(nT+nTempMagn)*RtoB
 
-        Call mma_allocate(XTM_MH  ,(nT+nTempMagn),'XTM_MH')
-        Call mma_allocate(XTM_dMdH,(nT+nTempMagn),'XTM_dMdH')
-        Call mma_allocate(XTtens_MH  ,3,3,(nT+nTempMagn),'XTtens_MH')
-        Call mma_allocate(XTtens_dMdH,3,3,(nT+nTempMagn),'XTtens_dMdH')
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,XTM_MH,1)
-        Call dcopy_((nT+nTempMagn),[0.0_wp],0,XTM_dMdH,1)
-        Call dcopy_(3*3*(nT+nTempMagn),[0.0_wp],0,XTtens_MH,1)
-        Call dcopy_(3*3*(nT+nTempMagn),[0.0_wp],0,XTtens_dMdH,1)
-        mem_local=mem_local+20*(nT+nTempMagn)*RtoB
-      End If
+      Call mma_allocate(ST0,3,(nT+nTempMagn),'ST0')
+      Call mma_allocate(ST1,3,(nT+nTempMagn),'ST1')
+      Call mma_allocate(ST2,3,(nT+nTempMagn),'ST2')
+      Call mma_allocate(MT0,3,(nT+nTempMagn),'MT0')
+      Call mma_allocate(MT1,3,(nT+nTempMagn),'MT1')
+      Call mma_allocate(MT2,3,(nT+nTempMagn),'MT2')
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST0,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST1,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,ST2,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT0,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT1,1)
+      Call dcopy_(3*(nT+nTempMagn),[0.0_wp],0,MT2,1)
+      mem_local=mem_local+6*3*(nT+nTempMagn)*RtoB
 
-      If((nCenter>=0).and.((nT+nTempMagn)>=0)) Then
-        Call mma_allocate(ZRT0,nCenter,(nT+nTempMagn),'ZRT0')
-        Call mma_allocate(ZLT0,nCenter,(nT+nTempMagn),'ZLT0')
-        Call mma_allocate(ZRT1,nCenter,(nT+nTempMagn),'ZRT1')
-        Call mma_allocate(ZLT1,nCenter,(nT+nTempMagn),'ZLT1')
-        Call mma_allocate(ZRT2,nCenter,(nT+nTempMagn),'ZRT2')
-        Call mma_allocate(ZLT2,nCenter,(nT+nTempMagn),'ZLT2')
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT0,1)
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT0,1)
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT1,1)
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT1,1)
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT2,1)
-        Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT2,1)
-        mem_local=mem_local+6*3*nCenter*(nT+nTempMagn)*RtoB
+      Call mma_allocate(XTM_MH  ,(nT+nTempMagn),'XTM_MH')
+      Call mma_allocate(XTM_dMdH,(nT+nTempMagn),'XTM_dMdH')
+      Call mma_allocate(XTtens_MH  ,3,3,(nT+nTempMagn),'XTtens_MH')
+      Call mma_allocate(XTtens_dMdH,3,3,(nT+nTempMagn),'XTtens_dMdH')
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,XTM_MH,1)
+      Call dcopy_((nT+nTempMagn),[0.0_wp],0,XTM_dMdH,1)
+      Call dcopy_(3*3*(nT+nTempMagn),[0.0_wp],0,XTtens_MH,1)
+      Call dcopy_(3*3*(nT+nTempMagn),[0.0_wp],0,XTtens_dMdH,1)
+      mem_local=mem_local+20*(nT+nTempMagn)*RtoB
 
-        Call mma_allocate(MRT0,nCenter,3,(nT+nTempMagn),'MRT0')
-        Call mma_allocate(MLT0,nCenter,3,(nT+nTempMagn),'MLT0')
-        Call mma_allocate(SRT0,nCenter,3,(nT+nTempMagn),'SRT0')
-        Call mma_allocate(SLT0,nCenter,3,(nT+nTempMagn),'SLT0')
-        Call mma_allocate(MRT1,nCenter,3,(nT+nTempMagn),'MRT1')
-        Call mma_allocate(MLT1,nCenter,3,(nT+nTempMagn),'MLT1')
-        Call mma_allocate(SRT1,nCenter,3,(nT+nTempMagn),'SRT1')
-        Call mma_allocate(SLT1,nCenter,3,(nT+nTempMagn),'SLT1')
-        Call mma_allocate(MRT2,nCenter,3,(nT+nTempMagn),'MRT2')
-        Call mma_allocate(MLT2,nCenter,3,(nT+nTempMagn),'MLT2')
-        Call mma_allocate(SRT2,nCenter,3,(nT+nTempMagn),'SRT2')
-        Call mma_allocate(SLT2,nCenter,3,(nT+nTempMagn),'SLT2')
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT0,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT0,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT0,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT0,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT1,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT1,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT1,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT1,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT2,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT2,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT2,1)
-        Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT2,1)
-        mem_local=mem_local+12*3*nCenter*(nT+nTempMagn)*RtoB
-      End If
+      Call mma_allocate(ZRT0,nCenter,(nT+nTempMagn),'ZRT0')
+      Call mma_allocate(ZLT0,nCenter,(nT+nTempMagn),'ZLT0')
+      Call mma_allocate(ZRT1,nCenter,(nT+nTempMagn),'ZRT1')
+      Call mma_allocate(ZLT1,nCenter,(nT+nTempMagn),'ZLT1')
+      Call mma_allocate(ZRT2,nCenter,(nT+nTempMagn),'ZRT2')
+      Call mma_allocate(ZLT2,nCenter,(nT+nTempMagn),'ZLT2')
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT0,1)
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT0,1)
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT1,1)
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT1,1)
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZRT2,1)
+      Call dcopy_(nCenter*(nT+nTempMagn),[0.0_wp],0,ZLT2,1)
+      mem_local=mem_local+6*3*nCenter*(nT+nTempMagn)*RtoB
+
+      Call mma_allocate(MRT0,nCenter,3,(nT+nTempMagn),'MRT0')
+      Call mma_allocate(MLT0,nCenter,3,(nT+nTempMagn),'MLT0')
+      Call mma_allocate(SRT0,nCenter,3,(nT+nTempMagn),'SRT0')
+      Call mma_allocate(SLT0,nCenter,3,(nT+nTempMagn),'SLT0')
+      Call mma_allocate(MRT1,nCenter,3,(nT+nTempMagn),'MRT1')
+      Call mma_allocate(MLT1,nCenter,3,(nT+nTempMagn),'MLT1')
+      Call mma_allocate(SRT1,nCenter,3,(nT+nTempMagn),'SRT1')
+      Call mma_allocate(SLT1,nCenter,3,(nT+nTempMagn),'SLT1')
+      Call mma_allocate(MRT2,nCenter,3,(nT+nTempMagn),'MRT2')
+      Call mma_allocate(MLT2,nCenter,3,(nT+nTempMagn),'MLT2')
+      Call mma_allocate(SRT2,nCenter,3,(nT+nTempMagn),'SRT2')
+      Call mma_allocate(SLT2,nCenter,3,(nT+nTempMagn),'SLT2')
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT0,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT0,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT0,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT0,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT1,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT1,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT1,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT1,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MRT2,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,MLT2,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SRT2,1)
+      Call dcopy_(3*nCenter*(nT+nTempMagn),[0.0_wp],0,SLT2,1)
+      mem_local=mem_local+12*3*nCenter*(nT+nTempMagn)*RtoB
 
       If(dbg) Write(6,*) 'XT_MH:  memory allocated (local):'
       If(dbg) Write(6,*) 'mem_local=', mem_local
@@ -438,7 +430,6 @@ cccc-------------------------------------------------------cccc
       dHX=0.0_wp
       dHY=0.0_wp
       dHZ=0.0_wp
-      dHW=0.0_wp
 
       nDirX=3
 
@@ -805,19 +796,18 @@ c compute the total magnetizations according to the derived formulas:
          Call Add_Info('dM/dH    MT2', [dnrm2_(ibuf, MT2,1)],1,6)
 c  computing the AVERAGE MOMENTS calculated at dIfferent temperatures (T(i))
          Do iT=1,nTempTotal
+            F1=T(iT)*cm3tomB/dltXF
+            F2=T(iT)*cm3tomB/Xfield
 
             ! dM/dH model
-            XTtens_dMdH(iM,1,iT) = (MT2(1,iT)-MT1(1,iT))*T(iT)
-     &                             * cm3tomB / dltXF
-            XTtens_dMdH(iM,2,iT) = (MT2(2,iT)-MT1(2,iT))*T(iT)
-     &                             * cm3tomB / dltXF
-            XTtens_dMdH(iM,3,iT) = (MT2(3,iT)-MT1(3,iT))*T(iT)
-     &                             * cm3tomB / dltXF
+            XTtens_dMdH(iM,1,iT) = (MT2(1,iT)-MT1(1,iT))*F1
+            XTtens_dMdH(iM,2,iT) = (MT2(2,iT)-MT1(2,iT))*F1
+            XTtens_dMdH(iM,3,iT) = (MT2(3,iT)-MT1(3,iT))*F1
 
             ! M/H model
-            XTtens_MH(iM,1,iT) = MT0(1,iT)*T(iT)*cm3tomB/Xfield
-            XTtens_MH(iM,2,iT) = MT0(2,iT)*T(iT)*cm3tomB/Xfield
-            XTtens_MH(iM,3,iT) = MT0(3,iT)*T(iT)*cm3tomB/Xfield
+            XTtens_MH(iM,1,iT) = MT0(1,iT)*F2
+            XTtens_MH(iM,2,iT) = MT0(2,iT)*F2
+            XTtens_MH(iM,3,iT) = MT0(3,iT)*F2
          End Do
 c ///  closing the loops over field directions
       End Do ! iM (nDirX)
@@ -881,13 +871,45 @@ c  calcualtion of the standard deviation:
      &          dev( nT, XTM_dMdH((1+nTempMagn):(nT+nTempMagn)),
      &                   chit_exp((1+nTempMagn):(nT+nTempMagn))  )
          Write(6,'(a,5x, f20.14)') 'ST.DEV: X=  M/H :',
-     &          dev( nT, XTM_MH((1+nTempMagn):(nT+nTempMagn)),
+     &          dev( nT, XTM_MH(  (1+nTempMagn):(nT+nTempMagn)),
      &                   chit_exp((1+nTempMagn):(nT+nTempMagn))  )
       Write(6,'(A)') '-----|----------------------------------------'//
      &               '----------------------------|'
       End If !tinput
 
 
+!-------------------------  PLOTs -------------------------------------!
+      WRITE(label,'(A)') "with_field_M_over_H"
+      FLUSH(6)
+      IF ( DoPlot ) THEN
+         IF ( tinput ) THEN
+            Call plot_XT_with_Exp(label, nT,
+     &                           T((1+nTempMagn):(nT+nTempMagn) ),
+     &                      XTM_MH((1+nTempMagn):(nT+nTempMagn) ),
+     &                    chit_exp((1+nTempMagn):(nT+nTempMagn) ), zJ )
+         ELSE
+            Call plot_XT_no_Exp(  label, nT,
+     &                           T((1+nTempMagn):(nT+nTempMagn) ),
+     &                      XTM_MH((1+nTempMagn):(nT+nTempMagn) ), zJ )
+         END IF
+      END IF
+
+
+      WRITE(label,'(A)') "with_field_dM_over_dH"
+      FLUSH(6)
+      IF ( DoPlot ) THEN
+         IF ( tinput ) THEN
+            Call plot_XT_with_Exp(label, nT,
+     &                           T((1+nTempMagn):(nT+nTempMagn) ),
+     &                    XTM_dMdH((1+nTempMagn):(nT+nTempMagn) ),
+     &                    chit_exp((1+nTempMagn):(nT+nTempMagn) ), zJ )
+         ELSE
+            Call plot_XT_no_Exp(  label, nT,
+     &                           T((1+nTempMagn):(nT+nTempMagn) ),
+     &                    XTM_dMdH((1+nTempMagn):(nT+nTempMagn) ), zJ )
+         END IF
+      END IF
+!------------------------- END PLOTs -------------------------------------!
 
 
 
@@ -907,7 +929,7 @@ c print out the main VAN VLECK SUSCEPTIBILITY TENSOR, its main values and main a
         info=0
         wt=0.0_wp
         zt=0.0_wp
-        Call DIAG_R2( XTtens_dMdH(:,:,jT) ,3,info,wt,zt)
+        Call DIAG_R2( XTtens_dMdH(1:3,1:3,jT) ,3,info,wt,zt)
         Write(6,'(A)') '------------|---|'//
      &                 '------- x --------- y --------- z ---|'//
      &                 '-----------------|'//
@@ -945,7 +967,7 @@ c print out the main VAN VLECK SUSCEPTIBILITY TENSOR, its main values and main a
         info=0
         wt=0.0_wp
         zt=0.0_wp
-        Call DIAG_R2( XTtens_MH(:,:,jT) ,3,info,wt,zt)
+        Call DIAG_R2( XTtens_MH(1:3,1:3,jT) ,3,info,wt,zt)
         Write(6,'(A)') '------------|---|'//
      &                 '------- x --------- y --------- z ---|'//
      &                 '-----------------|'//
@@ -969,89 +991,77 @@ c print out the main VAN VLECK SUSCEPTIBILITY TENSOR, its main values and main a
 
 
 !=======================================================================
-      If(nM>=0) Then
-        Call mma_deallocate(WEX0)
-        Call mma_deallocate(WEX1)
-        Call mma_deallocate(WEX2)
-      End If
-      If((nneq>=0).and.(nLoc>=0)) Then
-        Call mma_deallocate(WL0)
-        Call mma_deallocate(WL1)
-        Call mma_deallocate(WL2)
-        Call mma_deallocate(WR0)
-        Call mma_deallocate(WR1)
-        Call mma_deallocate(WR2)
-      End If
+      Call mma_deallocate(WEX0)
+      Call mma_deallocate(WEX1)
+      Call mma_deallocate(WEX2)
+      Call mma_deallocate(WL0)
+      Call mma_deallocate(WL1)
+      Call mma_deallocate(WL2)
+      Call mma_deallocate(WR0)
+      Call mma_deallocate(WR1)
+      Call mma_deallocate(WR2)
 
-      If((nneq>=0).and.((nT+nTempMagn)>=0)) Then
-        Call mma_deallocate(ZL0)
-        Call mma_deallocate(ZR0)
-        Call mma_deallocate(ZL1)
-        Call mma_deallocate(ZR1)
-        Call mma_deallocate(ZL2)
-        Call mma_deallocate(ZR2)
-        Call mma_deallocate(SL0)
-        Call mma_deallocate(SR0)
-        Call mma_deallocate(SL1)
-        Call mma_deallocate(SR1)
-        Call mma_deallocate(SL2)
-        Call mma_deallocate(SR2)
-        Call mma_deallocate(ML0)
-        Call mma_deallocate(MR0)
-        Call mma_deallocate(ML1)
-        Call mma_deallocate(MR1)
-        Call mma_deallocate(ML2)
-        Call mma_deallocate(MR2)
-      End If
+      Call mma_deallocate(ZL0)
+      Call mma_deallocate(ZR0)
+      Call mma_deallocate(ZL1)
+      Call mma_deallocate(ZR1)
+      Call mma_deallocate(ZL2)
+      Call mma_deallocate(ZR2)
+      Call mma_deallocate(SL0)
+      Call mma_deallocate(SR0)
+      Call mma_deallocate(SL1)
+      Call mma_deallocate(SR1)
+      Call mma_deallocate(SL2)
+      Call mma_deallocate(SR2)
+      Call mma_deallocate(ML0)
+      Call mma_deallocate(MR0)
+      Call mma_deallocate(ML1)
+      Call mma_deallocate(MR1)
+      Call mma_deallocate(ML2)
+      Call mma_deallocate(MR2)
 
-      If((nT+nTempMagn)>=0) Then
-        Call mma_deallocate(ZEX0)
-        Call mma_deallocate(ZEX1)
-        Call mma_deallocate(ZEX2)
-        Call mma_deallocate(ZT0)
-        Call mma_deallocate(ZT1)
-        Call mma_deallocate(ZT2)
-        Call mma_deallocate(SEX0)
-        Call mma_deallocate(SEX1)
-        Call mma_deallocate(SEX2)
-        Call mma_deallocate(MEX0)
-        Call mma_deallocate(MEX1)
-        Call mma_deallocate(MEX2)
-        Call mma_deallocate(ST0)
-        Call mma_deallocate(ST1)
-        Call mma_deallocate(ST2)
-        Call mma_deallocate(MT0)
-        Call mma_deallocate(MT1)
-        Call mma_deallocate(MT2)
-        Call mma_deallocate(XTM_MH)
-        Call mma_deallocate(XTM_dMdH)
-        Call mma_deallocate(XTtens_MH)
-        Call mma_deallocate(XTtens_dMdH)
-      End If
+      Call mma_deallocate(ZEX0)
+      Call mma_deallocate(ZEX1)
+      Call mma_deallocate(ZEX2)
+      Call mma_deallocate(ZT0)
+      Call mma_deallocate(ZT1)
+      Call mma_deallocate(ZT2)
+      Call mma_deallocate(SEX0)
+      Call mma_deallocate(SEX1)
+      Call mma_deallocate(SEX2)
+      Call mma_deallocate(MEX0)
+      Call mma_deallocate(MEX1)
+      Call mma_deallocate(MEX2)
+      Call mma_deallocate(ST0)
+      Call mma_deallocate(ST1)
+      Call mma_deallocate(ST2)
+      Call mma_deallocate(MT0)
+      Call mma_deallocate(MT1)
+      Call mma_deallocate(MT2)
+      Call mma_deallocate(XTM_MH)
+      Call mma_deallocate(XTM_dMdH)
+      Call mma_deallocate(XTtens_MH)
+      Call mma_deallocate(XTtens_dMdH)
 
-      If((nCenter>=0).and.((nT+nTempMagn)>=0)) Then
-        Call mma_deallocate(ZRT0)
-        Call mma_deallocate(ZLT0)
-        Call mma_deallocate(ZRT1)
-        Call mma_deallocate(ZLT1)
-        Call mma_deallocate(ZRT2)
-        Call mma_deallocate(ZLT2)
-        Call mma_deallocate(MRT0)
-        Call mma_deallocate(MLT0)
-        Call mma_deallocate(SRT0)
-        Call mma_deallocate(SLT0)
-        Call mma_deallocate(MRT1)
-        Call mma_deallocate(MLT1)
-        Call mma_deallocate(SRT1)
-        Call mma_deallocate(SLT1)
-        Call mma_deallocate(MRT2)
-        Call mma_deallocate(MLT2)
-        Call mma_deallocate(SRT2)
-        Call mma_deallocate(SLT2)
-      End If
+      Call mma_deallocate(ZRT0)
+      Call mma_deallocate(ZLT0)
+      Call mma_deallocate(ZRT1)
+      Call mma_deallocate(ZLT1)
+      Call mma_deallocate(ZRT2)
+      Call mma_deallocate(ZLT2)
+      Call mma_deallocate(MRT0)
+      Call mma_deallocate(MLT0)
+      Call mma_deallocate(SRT0)
+      Call mma_deallocate(SLT0)
+      Call mma_deallocate(MRT1)
+      Call mma_deallocate(MLT1)
+      Call mma_deallocate(SRT1)
+      Call mma_deallocate(SLT1)
+      Call mma_deallocate(MRT2)
+      Call mma_deallocate(MLT2)
+      Call mma_deallocate(SRT2)
+      Call mma_deallocate(SLT2)
 
       Return
       End
 
-
-
