@@ -20,7 +20,7 @@
 #include "numbers.fh"
 #include "integral.fh"
 #include "WrkSpc.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "constants.fh"
 
       Parameter (Conver1=1.0d10*CONST_BOHR_RADIUS_IN_SI_)
@@ -91,16 +91,10 @@
       Endif
       DiFac=-(Diel-1.0d0)/(Diel+1.0d0)
       Expran=0.0d0
-      Expre=0.0d0
-      ggsum=0.0d0
-      HighS=0.0d0
       iHowMSampIN=0
       iHowMSampUT=0
-      iD=1
-      Adisp=Disp(1,2)
       nBaseC=nBas_C(1)
       nBaseQ=nBas(1)
-      iTri=(iOrb(1)*(iOrb(1)+1))/2
       iTriBasQ=nBaseQ*(nBaseQ+1)/2
       iTriState=nState*(nState+1)/2
       timeCLAS=0
@@ -149,7 +143,8 @@
         Call DaName(iLuSaUt,SaFilUt)
         iDisk=0 !Put some dummy on the sampfile so we have space for
                 !the real number later.
-        Call iDaFile(iLuSaUt,1,[iHowMSampUT],1,iDisk)
+        iDum(1)=iHowMSampUT
+        Call iDaFile(iLuSaUt,1,iDum,1,iDisk)
         !Below we make a check for extreme cases. Our algorithm to
         !select sampling configurations sets this limit.
         iProdMax=(2**30-1)*2
@@ -261,7 +256,6 @@
 *----------------------------------------------------------------------*
 
       iSnurr=0  !How many steps taken totally.
-      nSiffiB=0  !A number for blocking.
 *
 *---- The Macrosteps.
 *
@@ -635,7 +629,8 @@
 58887 Continue
       If(QmProd.and.iRead.ne.9) then
         iDisk=0
-        Call iDaFile(iLuSaUt,1,[iHowMSampUT],1,iDisk)
+        iDum(1)=iHowMSampUT
+        Call iDaFile(iLuSaUt,1,iDum,1,iDisk)
         Call DaClos(iLuSaUt)
       Endif
 *--------------------------------------------------------------------------*
