@@ -20,7 +20,7 @@
 #include "integral.fh"
 #include "numbers.fh"
 #include "WrkSpc.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "constants.fh"
 
       Parameter (Conver1=1.0d10*CONST_BOHR_RADIUS_IN_SI_)
@@ -87,14 +87,8 @@
       Endif
       DiFac=-(Diel-1)/(Diel+1)
       Expran=0
-      Expre=0
-      ggsum=0
-      HighS=0
-      corr=0
       iHowMSampUT=0
       iHowMSampIN=0
-      iD=1
-      Adisp=Disp(1,2)
       nBaseC=nBas_C(1)
       nBaseQ=nBas(1)
       iTri=(iOrb(1)*(iOrb(1)+1))/2
@@ -138,7 +132,8 @@
         Call DaName(iLuSaUt,SaFilUt)
         iDisk=0 !Put some dummy on the sampfile so we have space for
                 !the real number later.
-        Call iDaFile(iLuSaUt,1,[iHowMSampUT],1,iDisk)
+        iDum(1)=iHowMSampUT
+        Call iDaFile(iLuSaUt,1,iDum,1,iDisk)
         !Below we make a check for extreme cases. Our algorithm to
         !select sampling configurations sets this limit.
         iProdMax=(2**30-1)*2
@@ -228,7 +223,6 @@ c          write(6,*)'ipAOSum',ipAOSum
       ncParm=ncPart-(nCent*icNum)
       nClas=nPart-iCNum
       indma=npart*npol
-      iGG=nPart*nPol
       iCi=(iQ_Atoms*(iQ_Atoms+1))/2
 *----------------------------------------------------------------------*
 * Substitue classical waters for quantum molecule.                     *
@@ -248,7 +242,6 @@ c          write(6,*)'ipAOSum',ipAOSum
 *                                                                      *
 *----------------------------------------------------------------------*
       iSnurr=0  !How many steps taken totally.
-      nSiffiB=0  !A number for blocking.
 *
 *---- The Macrosteps.
 *
@@ -626,7 +619,8 @@ c          write(6,*)'ipAOSum',ipAOSum
 58887 Continue
       If(QmProd.and.iRead.ne.9) then
         iDisk=0
-        Call iDaFile(iLuSaUt,1,[iHowMSampUT],1,iDisk)
+        iDum(1)=iHowMSampUT
+        Call iDaFile(iLuSaUt,1,iDum,1,iDisk)
         Call DaClos(iLuSaUt)
       Endif
 *--------------------------------------------------------------------------*
