@@ -9,7 +9,7 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
 *
-*-- Process input to QMSTAT. All input varibles are stored in
+*-- Process input to QMSTAT. All input variables are stored in
 *   qminp.fh which in turn are initialized in qmstat_init.
 *
       Subroutine Get_Qmstat_Input(iQ_Atoms)
@@ -18,7 +18,7 @@
 #include "maxi.fh"
 #include "qminp.fh"
 #include "files_qmstat.fh"
-#include "warnings.fh"
+#include "warnings.h"
 
       Character*180 Key
       Character*20 Kword
