@@ -17,7 +17,6 @@
 #include "qm2.fh"
 #include "numbers.fh"
 #include "WrkSpc.fh"
-*Removed by Valera or maybe it wasn't in his version #include "MolcasQmStat.fh"
 #include "lenin.fh"
 
       Parameter (ReduceWarning=0.5d0)
@@ -43,7 +42,6 @@
 *--- First we accumulate the different density matrices.
 *
       nSize=nBas(1)*(nBas(1)+1)/2
-      nStri=nState*(nState+1)/2
       weight=ONE/dble(nState)
       Call GetMem('DenM','Allo','Real',iDin,nSize)
       Call GetMem('DenA','Allo','Real',iDav,nSize)
