@@ -59,14 +59,14 @@
 #include "numbers.fh"
 #include "WrkSpc.fh"
 #include "tratoc.fh"
-#include "warnings.fh"
+#include "warnings.h"
 
       Parameter (IndMax=nTraBuf) !nTraBuf definied in tratoc.fh
 
       Dimension Coord(MxAt*3),Chge(MxAt),CoordCC(3*3),ChgeCC(3)
       Dimension Cmo(MxBas**2),Cmo_S(MxBas**2),Occu(MxBas),Dummy(MxBas)
 
-      Dimension nSh(MxAt),nfSh(MxAt,MxAngqNr),nCnC(MxBas),nCnC_C(MxBasC)
+      Dimension nSh(MxAt),nfSh(MxAt,MxAngqNr),nCnC_C(MxBasC)
       Dimension nOcc(MxBas),natyp(MxAt),natypC(MxAt),iDumm(MxBas)
       Dimension nBas(MxSym),nBasCC(1),iCon(MxAt,MxPrCon)
       Dimension iC_icon(MxAt,MxPrCon)
@@ -95,7 +95,7 @@
           If(i.eq.1.or.i.eq.6) Line=StLine
           If(i.eq.3) Line='Project:'
           If(i.eq.4) Write(Line,'(A72)')JobLab
-          Call Center(Line)
+          Call Center_Text(Line)
           Write(6,*)'*'//Line//'*'
 9991    Continue
         Write(6,*)
@@ -211,7 +211,6 @@
       kold=1
       iold=1
       indold=0
-      diff=0
       Do 149, i=1,nntyp
         nOcc(i)=0
 149   Continue
@@ -230,7 +229,6 @@
               ibas=ibas+1
               indold=indold+1
               nOcc(i)=nOcc(i)+2*k-1
-              nCnC(ibas)=nnaa
               ind=ind+1
               iQang(ibas)=k
               icont=Icon(i,ind)
@@ -335,7 +333,6 @@
      &,MxPrCon,MxBas,MxAngqNr,ipACC,nACCSizeC)
       iBas=0
       iAtom=0
-      mbash=0
       kold=1
       iold=1
       indold=0
