@@ -9,12 +9,15 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine Qmstat(ireturn)
+#ifdef _MOLCAS_MPP_
+      Use Para_Info, Only: Is_Real_Par
+#endif
       Implicit Real*8 (a-h,o-z)
 
 #include "maxi.fh"
 #include "qminp.fh"
 #include "WrkSpc.fh"
-#include "warnings.fh"
+#include "warnings.h"
 
       Dimension Coord(MxAt*3)
       Dimension nBas(1),nBas_C(1),nCnC_C(MxBasC)
@@ -25,8 +28,6 @@
       Dimension nOcc(MxBas),natyp(MxAt)
       Character Labjhr*4
 ****************
-      Logical  Is_Real_Par
-      External Is_Real_Par
 
 *
 *-- The journey begins. Set non-zero return code.
