@@ -26,15 +26,16 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
+#ifdef _HDF5_
+      use mh5, only: mh5_close_file
+#endif
       Implicit Real*8 (A-H,O-Z)
       Logical DoCholesky
 #include "rasdim.fh"
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='ClsFls  ')
 
-#include "davctl.fh"
 #include "qnctl.fh"
 #include "raswfn.fh"
 *----------------------------------------------------------------------*
@@ -54,7 +55,10 @@ C Local print level (if any)
         JOBIPH=-1
       End If
 #ifdef _HDF5_
-      call mh5_close_file(wfn_fileid)
+      if (wfn_fileid.ne.0) then
+        call mh5_close_file(wfn_fileid)
+        wfn_fileid=0
+      end if
 #endif
 *---  close the ORDINT file -------------------------------------------*
       CALL DecideOnCholesky(DoCholesky)
