@@ -42,11 +42,12 @@ C
       use fciqmc, only : DoNECI
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "rasrc.fh"
 #include "WrkSpc.fh"
 #include "wadr.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='DAVCRE  ')
       CHARACTER*4 IOUTW,IOUTX
       DIMENSION C((NROOT+NSXS)*NROOT*(ITMAX+1))
