@@ -48,6 +48,7 @@ c     Logical Exist
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='DMRGCTL ')
 #include "WrkSpc.fh"
 #include "SysDef.fh"
@@ -58,7 +59,7 @@ c     Logical Exist
 #include "rasscf_lucia.fh"
 #include "gas.fh"
 #include "pamint.fh"
-      Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
+#include "sxci.fh"
 *PAM05      SymProd(i,j)=1+iEor(i-1,j-1)
 *
 C Local print level (if any)
