@@ -18,7 +18,7 @@ module fcidump_tables
   private
   public :: FockTable, TwoElIntTable, OrbitalTable, mma_allocate, &
     mma_deallocate, length, print, fill_orbitals, fill_fock, fill_2ElInt, &
-    cutoff_default, unused
+    cutoff_default
   save
 
   type :: FockTable
@@ -64,10 +64,6 @@ module fcidump_tables
     module procedure FockTable_print, TwoElIntTable_print, OrbitalTable_print
   end interface
 
-  interface unused
-    module procedure FockTable_unused, TwoElIntTable_unused, OrbitalTable_unused
-  end interface
-
 contains
 
   subroutine OrbitalTable_allocate(orbital_table, n)
@@ -132,14 +128,6 @@ contains
     end do
   end subroutine OrbitalTable_print
 
-  subroutine OrbitalTable_unused(table)
-    type(OrbitalTable), intent(in) :: table
-    integer :: n
-#ifdef _WARNING_WORKAROUND_
-    if (.false.) n = length(table)
-#endif
-  end subroutine OrbitalTable_unused
-
   subroutine FockTable_allocate(fock_table, n)
     implicit none
     integer, intent(in) :: n
@@ -175,8 +163,6 @@ contains
 !>  @param[in] cutoff Optional parameter that is set by default to
 !>    fciqmc_tables::cutoff_default.
   subroutine fill_fock(fock_table, Fock, cutoff)
-    use general_data, only : nActEl, nAsh, ntot, ntot1, ntot2
-    use rasscf_data, only : nAcPar
     implicit none
     real*8, intent(in) :: Fock(:)
     type(FockTable), intent(inout) :: fock_table
@@ -213,14 +199,6 @@ contains
     end do
   end subroutine FockTable_print
 
-  subroutine FockTable_unused(table)
-    type(FockTable), intent(in) :: table
-    integer :: n
-#ifdef _WARNING_WORKAROUND_
-    if (.false.) n = length(table)
-#endif
-  end subroutine FockTable_unused
-
   subroutine TwoElIntTable_allocate(table, n)
     implicit none
     integer, intent(in) :: n
@@ -296,12 +274,4 @@ contains
         table%values(j), (table%index(i, j), i=1, 4)
     end do
   end subroutine TwoElIntTable_print
-
-  subroutine TwoElIntTable_unused(table)
-    type(TwoElIntTable), intent(in) :: table
-    integer :: n
-#ifdef _WARNING_WORKAROUND_
-    if (.false.) n = length(table)
-#endif
-  end subroutine TwoElIntTable_unused
 end module fcidump_tables
