@@ -12,9 +12,7 @@
 !               2019, Oskar Weser                                      *
 !***********************************************************************
 module fcidump_transformations
-  use stdalloc, only : mma_allocate, mma_deallocate
-
-  use general_data, only : nActEl, nAsh, ntot, ntot1, ntot2, nBas, nSym
+  use general_data, only : nActEl, nAsh, ntot1, ntot2, nBas, nSym
   use rasscf_data, only : nAcPar, core_energy => Emy, nAc
   use index_symmetry, only : one_el_idx_flatten
   implicit none
@@ -91,7 +89,8 @@ contains
 !>    \f[\sum_{\sigma\rho} D^I_{\sigma\rho}(g_{\mu\nu\sigma\rho} - \frac{1}{2} g_{\mu\sigma\rho\nu})\f]
 !>    In output FI contains also the core energy added to
 !>    the diagonal elements.
-!>    \f[\sum_{\sigma\rho} D^I_{\sigma\rho}(g_{\mu\nu\sigma\rho} - \frac{1}{2} g_{\mu\sigma\rho\nu}) + \frac{E^{(0)}}{n_el} \delta_{\mu\nu} \f]
+!>    \f[\sum_{\sigma\rho} D^I_{\sigma\rho}(g_{\mu\nu\sigma\rho} -
+!>      \frac{1}{2} g_{\mu\sigma\rho\nu}) + \frac{E^{(0)}}{n_el} \delta_{\mu\nu} \f]
 !>  @param[out] folded_Fock The inactive Fock matrix
 !>    in the basis of the active MOs as obtained from ::SGFCIN.
   subroutine fold_Fock(CMO, D1I_AO, D1A_AO, D1S_MO, F_In, folded_Fock)
