@@ -9,62 +9,80 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
 * Copyright (C) 2014, Giovanni Li Manni                                *
-*               2019, Oskar Weser                                      *
+*               2019-2021, Oskar Weser                                 *
+*               2021, Werner Dobrautz                                  *
 ************************************************************************
+#include "macros.fh"
       module fciqmc
 #ifdef _MOLCAS_MPP_
       use mpi
+      use definitions, only: MPIInt
+      use Para_Info, only: Is_Real_Par
 #endif
-      use definitions, only: wp, MPIInt, int64, real64
-      use filesystem, only: chdir_, getcwd_, get_errno_, strerror_,
-     &    real_path, basename
+      use definitions, only: wp
+      use Para_Info, only: MyRank
+#ifdef _NECI_
+      use filesystem, only: chdir_
+      use stdalloc, only: mxMem
       use fortran_strings, only: str
+#endif
+      use filesystem, only: getcwd_, get_errno_, strerror_,
+     &    real_path, basename
       use linalg_mod, only: abort_
-      use stdalloc, only : mma_allocate, mma_deallocate, mxMem
+      use stdalloc, only: mma_allocate, mma_deallocate
 
-      use rasscf_data, only: iter, lRoots, nRoots, iRoot, EMY,
-     &    S, KSDFT, rotmax, Ener, iAdr15, Weight, nAc, nAcPar, nAcPr2
-      use general_data, only: iSpin, nSym, nConf, JobIPH,
-     &    ntot, ntot1, ntot2, nAsh, nBas
-      use gugx_data, only: IfCAS
-      use gas_data, only: ngssh, iDoGas, nGAS, iGSOCCX
+      use rasscf_data, only: nAcPar, nAcPr2
+      use general_data, only: nSym, nConf
 
       use CI_solver_util, only: wait_and_read, RDM_to_runfile
-      use fciqmc_read_RDM, only: read_neci_RDM
 
       use generic_CI, only: CI_solver_t
 
       implicit none
       save
       private
-      public :: DoNECI, DoEmbdNECI, fciqmc_solver_t
-      logical :: DoEmbdNECI = .false., DoNECI = .false.
-#include "para_info.fh"
+      public :: DoNECI, DoEmbdNECI, fciqmc_solver_t, tGUGA_in
 
+      logical :: DoEmbdNECI = .false., DoNECI = .false.,
+     &  tGUGA_in  = .false.
+
+#ifdef _NECI_
       interface
-          integer function isfreeunit(iseed)
-              integer, intent(in) :: iseed
-          end function
-
-          subroutine NECImain(fcidmp, input_name, MemSize, NECIen)
-            import :: int64, real64
-            character(len=*), intent(in) :: fcidmp, input_name
-            integer(int64), intent(in) :: MemSize
-            real(real64), intent (out) :: NECIen
-          end subroutine
+        subroutine NECImain(fcidmp, input_name, MemSize, NECIen)
+          use, intrinsic :: iso_fortran_env, only: int64, real64
+          character(len=*), intent(in) :: fcidmp, input_name
+          integer(int64), intent(in) :: MemSize
+          real(real64), intent (out) :: NECIen
+        end subroutine
       end interface
+#endif
 
 
       type, extends(CI_solver_t) :: fciqmc_solver_t
+        private
+        logical :: tGUGA
       contains
-        procedure, nopass :: init
-        procedure, nopass :: run => fciqmc_ctl
-        procedure, nopass :: cleanup
+        private
+        procedure, public :: run => fciqmc_ctl
+        procedure, public :: cleanup
       end type
 
+      interface fciqmc_solver_t
+        module procedure construct_FciqmcSolver_t
+      end interface
 
       contains
 
+      function construct_FciqmcSolver_t(tGUGA) result(res)
+        logical, intent(in) :: tGUGA
+        type(fciqmc_solver_t) :: res
+        res%tGUGA = tGUGA
+        write(6,*) ' NECI activated. List of Confs might get lengthy.'
+        write(6,*) ' Number of Configurations computed by GUGA: ', nConf
+        write(6,*) ' nConf variable is set to zero to avoid JOBIPH i/o'
+        nConf= 0
+      end function
+
 !>  @brief
 !>    Start and control FCIQMC.
 !>
@@ -92,11 +110,21 @@
 !>  @paramin[out] DMAT Average 1 body density matrix
 !>  @paramin[out] PSMAT Average symm. 2-dens matrix
 !>  @paramin[out] PAMAT Average antisymm. 2-dens matrix
-      subroutine fciqmc_ctl(actual_iter, CMO, DIAF, D1I_AO, D1A_AO,
-     &                      TUVX, F_IN, D1S_MO, DMAT, PSMAT, PAMAT)
+!>  @paramin[in] fake_run  If true the NECI run is not performed, but
+!>    the RDMs are read from previous runs.
+      subroutine fciqmc_ctl(
+     &      this, actual_iter, CMO, DIAF, D1I_AO, D1A_AO,
+     &      TUVX, F_IN, D1S_MO, DMAT, PSMAT, PAMAT)
+      use general_data, only : iSpin, ntot, ntot1, ntot2, nAsh
+      use rasscf_data, only : iter, lRoots, S, KSDFT, EMY,
+     &    rotmax, Ener, Nac, nAcPar, nAcpr2
+
+      use gas_data, only : ngssh, iDoGas, nGAS, iGSOCCX
+
       use fcidump_reorder, only : get_P_GAS, get_P_inp,ReOrFlag,ReOrInp
       use fcidump, only : make_fcidumps, transform
 #include "rctfld.fh"
+      class(fciqmc_solver_t), intent(in) :: this
       integer, intent(in) :: actual_iter
       real(wp), intent(in) ::
      &    CMO(nTot2), DIAF(nTot),
@@ -104,8 +132,8 @@
       real(wp), intent(inout) :: F_In(nTot1), D1S_MO(nAcPar)
       real(wp), intent(out) :: DMAT(nAcpar),
      &    PSMAT(nAcpr2), PAMAT(nAcpr2)
+
       real(wp) :: NECIen
-      integer :: jRoot
       integer, allocatable :: permutation(:),
      &  GAS_spaces(:, :), GAS_particles(:, :)
       real(wp) :: orbital_E(nTot), folded_Fock(nAcPar)
@@ -155,12 +183,11 @@
      &  GAS_spaces=GAS_spaces, GAS_particles=GAS_particles,
      &  reuse_pops=actual_iter >= 5 .and. abs(rotmax) < 1d-2,
      &  NECIen=NECIen,
-     &  D1S_MO=D1S_MO, DMAT=DMAT, PSMAT=PSMAT, PAMAT=PAMAT)
+     &  D1S_MO=D1S_MO, DMAT=DMAT, PSMAT=PSMAT, PAMAT=PAMAT,
+     &  tGUGA=this%tGUGA)
 ! NECIen so far is only the energy for the GS.
 ! Next step it will be an array containing energies for all the optimized states.
-      do jRoot = 1, lRoots
-        ENER(jRoot, ITER) = NECIen
-      end do
+      ENER(1 : lRoots, iter) = NECIen
 
       if (nAsh(1) /= nac) call dblock(dmat)
 
@@ -175,13 +202,14 @@
       subroutine run_neci(DoEmbdNECI, fake_run,
      &      ascii_fcidmp, h5_fcidmp,
      &      reuse_pops,
-     &      NECIen, D1S_MO, DMAT, PSMAT, PAMAT,
+     &      NECIen, D1S_MO, DMAT, PSMAT, PAMAT, tGUGA,
      &      GAS_spaces, GAS_particles)
         use fciqmc_make_inp, only: make_inp
         logical, intent(in) :: DoEmbdNECI, fake_run, reuse_pops
         character(len=*), intent(in) :: ascii_fcidmp, h5_fcidmp
         real(wp), intent(out) :: NECIen, D1S_MO(nAcPar), DMAT(nAcpar),
      &      PSMAT(nAcpr2), PAMAT(nAcpr2)
+        logical, intent(in) :: tGUGA
         integer, intent(in), optional ::
      &      GAS_spaces(:, :), GAS_particles(:, :)
         real(wp), save :: previous_NECIen = 0.0_wp
@@ -189,18 +217,23 @@
         character(len=*), parameter :: input_name = 'FCINP',
      &    energy_file = 'NEWCYCLE'
 
+#ifdef _WARNING_WORKAROUND_
+        ! there are wrong maybe-unitialized warnings otherwise.
+        ! (unitialized codepaths lead to abortion).
+        NECIen = huge(NECIen)
+#endif
+
         if (fake_run) then
           NECIen = previous_NECIen
-        else
-          if (DoEmbdNECI) then
-            call make_inp(input_name, readpops=reuse_pops,
+        else if (DoEmbdNECI) then
+            call make_inp(input_name, readpops=reuse_pops, tGUGA=tGUGA,
      &          GAS_spaces=GAS_spaces, GAS_particles=GAS_particles)
 #ifdef _NECI_
             write(6,*) 'NECI called automatically within Molcas!'
             if (myrank /= 0) call chdir_('..')
-            call necimain(
-     &        real_path(ascii_fcidmp), real_path(input_name),
-     &                  MxMem, NECIen)
+            call necimain(real_path(ascii_fcidmp),
+     &                    real_path(input_name),
+     &                    MxMem, NECIen)
             if (myrank /= 0) call chdir_('tmp_'//str(myrank))
 #else
             call WarningMessage(2, 'EmbdNECI is given in input, '//
@@ -208,41 +241,32 @@
      &'not compiled with embedded NECI. Please use -DNECI=ON '//
      &'for compiling or use an external NECI.')
 #endif
-          else
-            call make_inp(input_name, basename(real_path(ascii_fcidmp)),
+        else
+            call make_inp(input_name, readpops=.false., tGUGA=tGUGA,
+     &              FCIDUMP_name=basename(real_path(ascii_fcidmp)),
      &              GAS_spaces=GAS_spaces, GAS_particles=GAS_particles)
             if (myrank == 0) then
               call write_ExNECI_message(input_name, ascii_fcidmp,
-     &                                  h5_fcidmp, energy_file)
+     &                                  h5_fcidmp, energy_file, tGUGA)
             end if
             call wait_and_read(energy_file, NECIen)
-          end if
-          previous_NECIen = NECIen
         end if
-        call read_neci_RDM(DMAT, D1S_MO, PSMAT, PAMAT)
+        previous_NECIen = NECIen
+        call get_neci_RDM(D1S_MO, DMAT, PSMAT, PAMAT, tGUGA)
         call RDM_to_runfile(DMAT, D1S_MO, PSMAT, PAMAT)
       end subroutine run_neci
 
-      subroutine cleanup()
+      subroutine cleanup(this)
         use fciqmc_make_inp, only : make_inp_cleanup => cleanup
         use fciqmc_read_RDM, only : read_RDM_cleanup => cleanup
         use fcidump, only : fcidump_cleanup => cleanup
+        class(fciqmc_solver_t), intent(inout) :: this
+        unused_var(this)
         call make_inp_cleanup()
         call read_RDM_cleanup()
         call fcidump_cleanup()
       end subroutine cleanup
 
-      subroutine init()
-! For NECI only orbital related arrays are allowed to be stored.
-! Arrays of nConf size need to be avoided.
-! For this reason set nConf to zero.
-        write(6,*) ' NECI activated. List of Confs might get lengthy.'
-        write(6,*) ' Number of Configurations computed by GUGA: ', nConf
-        write(6,*) ' nConf variable is set to zero to avoid JOBIPH i/o'
-        nConf= 0
-      end subroutine
-
-
       subroutine check_options(lroots, lRf, KSDFT)
         integer, intent(in) :: lroots
         logical, intent(in) :: lRf
@@ -258,16 +282,21 @@
       end subroutine check_options
 
       subroutine write_ExNECI_message(
-     &      input_name, ascii_fcidmp, h5_fcidmp, energy_file)
+     &      input_name, ascii_fcidmp, h5_fcidmp, energy_file, tGUGA)
         character(len=*), intent(in) :: input_name, ascii_fcidmp,
      &          h5_fcidmp, energy_file
+        logical, intent(in) :: tGUGA
         character(len=1024) :: WorkDir
         integer :: err
 
         call getcwd_(WorkDir, err)
         if (err /= 0) write(6, *) strerror_(get_errno_())
 
-        write(6,'(A)')'Run NECI externally.'
+        if (tGUGA) then
+            write(6,'(A)')'Run spin-free GUGA NECI externally.'
+        else
+            write(6,'(A)')'Run NECI externally.'
+        end if
         write(6,'(A)')'Get the (example) NECI input:'
         write(6,'(4x, A, 1x, A, 1x, A)')
      &    'cp', real_path(input_name), '$NECI_RUN_DIR'
@@ -279,12 +308,34 @@
      &    'cp', real_path(h5_fcidmp), '$NECI_RUN_DIR'
         write(6, *)
         write(6,'(A)') "When finished do:"
-        write(6,'(4x, A)')
-     &    'cp TwoRDM_aaaa.1 TwoRDM_abab.1 TwoRDM_abba.1 '//
-     &    'TwoRDM_bbbb.1 TwoRDM_baba.1 TwoRDM_baab.1 '//trim(WorkDir)
+        if (tGUGA) then
+          write(6,'(4x, A)') 'cp PSMAT PAMAT DMAT '//trim(WorkDir)
+        else
+          write(6,'(4x, A)')
+     &      'cp TwoRDM_aaaa.1 TwoRDM_abab.1 TwoRDM_abba.1 '//
+     &      'TwoRDM_bbbb.1 TwoRDM_baba.1 TwoRDM_baab.1 '//trim(WorkDir)
+        end if
         write(6,'(4x, A)')
      &    'echo $your_RDM_Energy > '//real_path(energy_file)
         call xflush(6)
       end subroutine write_ExNECI_message
 
+!> Generate density matrices for Molcas
+!>   Neci density matrices are stored in Files TwoRDM_**** (in spacial orbital basis).
+!>   I will be reading them from those formatted files for the time being.
+!>   Next it will be nice if NECI prints them out already in Molcas format.
+      subroutine get_neci_RDM(D1S_MO, DMAT, PSMAT, PAMAT, tGUGA)
+        use fciqmc_read_RDM, only : read_neci_RDM, read_neci_GUGA_RDM
+        real*8, intent(out) ::
+     &      D1S_MO(nAcPar), DMAT(nAcpar),
+     &      PSMAT(nAcpr2), PAMAT(nAcpr2)
+        logical, intent(in) :: tGUGA
+        if (tGUGA) then
+            ! for GUGA we only need the spin-free 1 and 2-RDM.
+            ! The spin density D1S_MO is set to zero.
+            call read_neci_GUGA_RDM(DMAT, D1S_MO, PSMAT, PAMAT)
+        else
+            call read_neci_RDM(DMAT, D1S_MO, PSMAT, PAMAT)
+        end if
+      end subroutine get_neci_RDM
       end module fciqmc
