@@ -45,14 +45,13 @@ C
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='FOCK    ')
 #include "WrkSpc.fh"
-      Logical DoActive,DoQmat,DoCholesky
-      Integer ALGO
       Dimension P2reo(1)
 
-      COMMON /CHOTODO /DoActive,DoQmat,ipQmat
-      COMMON /CHLCAS  /DoCholesky,ALGO
+#include "chotodo.fh"
+#include "chlcas.fh"
 C
       IPRLEV=IPRLOC(4)
       IF(IPRLEV.ge.DEBUG) THEN
@@ -97,7 +96,6 @@ C
       ISTBM=0
       IX1=0
       ISTZ=0
-      ioffQmat=0
       E2act=0.0d0
 
       DO ISYM=1,NSYM
