@@ -29,7 +29,7 @@
 #ifdef _DMRG_
 !     module dependencies
       use qcmaquis_interface_cfg
-      use qcmaquis_interface_environment, only: print_dmrg_info
+      use qcmaquis_interface_utility_routines, only: print_dmrg_info
 #endif
       use fcidump, only : DumpOnly
       use fciqmc, only: DoNECI
@@ -41,7 +41,6 @@
 #include "general.fh"
 #include "gas.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='INPPRI  ')
 #include "ciinfo.fh"
 #include "rctfld.fh"
 #include "WrkSpc.fh"
@@ -55,13 +54,9 @@
       Character*3 SNAC
 #endif
       Logical DoCholesky
-      Logical DoLocK,Deco, lOPTO, l_casdft
-      Real*8  dmpK
-      Integer nScreen
-      COMMON /CHOLK / DoLocK,Deco,dmpk,Nscreen
-#ifndef _DMRG_
-      logical :: doDMRG = .false.
-#else
+      Logical lOPTO
+#include "cholk.fh"
+#ifdef _DMRG_
       character(len=100) :: dmrg_start_guess
 #endif
 
@@ -86,23 +81,6 @@
       Write(Fmt2,'(A,I3.3,A)') '(',left,'X,'
       IF (IPRLEV.EQ.SILENT) GOTO 900
 *----------------------------------------------------------------------*
-*     Initialize l_casdft global variable for mcpdft                   *
-*----------------------------------------------------------------------*
-      l_casdft = KSDFT(1:5).eq.'TLSDA'   .or.
-     &           KSDFT(1:6).eq.'TLSDA5'  .or.
-     &           KSDFT(1:5).eq.'TBLYP'   .or.
-     &           KSDFT(1:6).eq.'TSSBSW'  .or.
-     &           KSDFT(1:5).eq.'TSSBD'   .or.
-     &           KSDFT(1:5).eq.'TS12G'   .or.
-     &           KSDFT(1:4).eq.'TPBE'    .or.
-     &           KSDFT(1:5).eq.'FTPBE'   .or.
-     &           KSDFT(1:5).eq.'TOPBE'   .or.
-     &           KSDFT(1:6).eq.'FTOPBE'  .or.
-     &           KSDFT(1:7).eq.'TREVPBE' .or.
-     &           KSDFT(1:8).eq.'FTREVPBE'.or.
-     &           KSDFT(1:6).eq.'FTLSDA'  .or.
-     &           KSDFT(1:6).eq.'FTBLYP'
-*----------------------------------------------------------------------*
 *     Print the project title                                          *
 *----------------------------------------------------------------------*
       IF(IPRLEV.GE.USUAL) THEN
@@ -117,7 +95,7 @@
      &     Line='Project:'
            If ( i.ge.4 .and. i.le.nLine-2 )
      &     Write(Line,'(A72)')Title(i-3)
-           Call Center(Line)
+           Call Center_Text(Line)
            Write(LF,Fmt1) '*'//Line//'*'
          End Do
        Write(LF,*)
@@ -132,10 +110,10 @@
        Write(LF,Fmt1) '--------------------------'
        Write(Line,'(36A2)') (Header(i),i=1,36)
        Call LeftAd(Line)
-       Write(LF,Fmt1)  Line(:mylen(Line))
+       Write(LF,Fmt1)  trim(Line)
        Write(Line,'(36A2)') (Header(i),i=37,72)
        Call LeftAd(Line)
-       Write(LF,Fmt1)  Line(:mylen(Line))
+       Write(LF,Fmt1)  trim(Line)
        Write(LF,*)
 *----------------------------------------------------------------------*
 *     Print the status of ORDINT                                       *
@@ -196,7 +174,7 @@ C.. for GAS
       Write(LF,Fmt2//'A,T45,F6.1)')'Spin quantum number',
      &                           (DBLE(ISPIN-1))/2.0d0
       Write(LF,Fmt2//'A,T45,I6)')'State symmetry',
-     &                           LSYM
+     &                           STSYM
       Call CollapseOutput(0,'Wave function specifications:')
 *
       Call Get_cArray('Irreps',lIrrep,24)
@@ -318,19 +296,19 @@ C.. for GAS
 #endif
       else
         Write(LF,Fmt2//'A,T40,I11)')'Number of CSFs',
-     &                           NCSASM(LSYM)
+     &                           NCSASM(STSYM)
         if (N_ELIMINATED_GAS_MOLCAS.gt.0) Then
           Write(LF,Fmt2//'A,T40,I11)')'Number of highly excited CSFs',
      &                           nCSF_HEXS
         EndIf
         Write(LF,Fmt2//'A,T40,I11)')'Number of determinants',
-     &                           NDTASM(LSYM)
+     &                           NDTASM(STSYM)
       end if
         n_Det=2
         n_unpaired_elec=(iSpin-1)
         n_paired_elec=nActEl-n_unpaired_elec
         If(n_unpaired_elec+n_paired_elec/2.eq.nac.or.
-     &     NDTASM(LSYM).eq.1) n_Det = 1
+     &     NDTASM(STSYM).eq.1) n_Det = 1
         If(KSDFT.eq.'DIFF')   n_Det = 1
         If(KSDFT.eq.'ROKS')   n_Det = 1
 
@@ -448,9 +426,9 @@ C.. for GAS
 * Check that the user doesn't try to calculate more roots than it's possible
 * NN.14 FIXME: in DMRG-CASSCF, skip this check for the time
 *              since Block DMRG code will check this internally
-*     If (NROOTS .GT. NCSASM(LSYM)) Then
+*     If (NROOTS .GT. NCSASM(STSYM)) Then
       If (.not. any([DoNECI, Do_CC_CI, DumpOnly, doDMRG, doBlockDMRG])
-     &    .and. NROOTS > NCSASM(LSYM)) Then
+     &    .and. NROOTS > NCSASM(STSYM)) Then
          Write(LF,*) '************ ERROR ***********'
          Write(LF,*) ' You can''t ask for more roots'
          Write(LF,*) ' than there are configurations '
@@ -460,14 +438,14 @@ C.. for GAS
       End If
 * If the calculation will be too big:
       call GetMem('ChkMx','Max','Real',iDum,MaxRem)
-      WillNeedMB=(8.0D0*1.50D0*6.0D0*NDTASM(LSYM)/1.048D6)
+      WillNeedMB=(8.0D0*1.50D0*6.0D0*NDTASM(STSYM)/1.048D6)
       AvailMB=(8.0D0*MaxRem/1.048D6)
       if (WillNeedMB .gt. AvailMB) then
         write(6,*)
         write(6,*)' *************************************************'
         write(6,*)' Sorry, but your calculation will probably be too'
         write(6,*)' large for the available memory.'
-        write(6,*)' The number of determinants is ',NDTASM(LSYM)
+        write(6,*)' The number of determinants is ',NDTASM(STSYM)
         write(6,*)' During CI equation solution, there will be'
         write(6,*)' up to six vectors of this size in memory.'
         write(6,*)' We estimate an additional 50% for other stuff.'
