@@ -53,9 +53,8 @@
       Implicit None
 #include "real.fh"
 #include "stdalloc.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "output_ras.fh"
-      Parameter (ROUTINE='IVOGEN_RASSCF   ')
 *
       Integer  nCMO, nEOrb, nSym
       Integer  nBas(nSym), nFro(nSym), nIsh(nSym), nAsh(nSym)
