@@ -49,6 +49,9 @@ C     Calling arguments:
 
 #ifdef _DMRG_
       use qcmaquis_interface_cfg
+#endif
+#ifdef _HDF5_
+      use mh5, only: mh5_put_dset
 #endif
       IMPLICIT REAL*8 (A-H,O-Z)
 
@@ -57,6 +60,7 @@ C     Calling arguments:
 #include "general.fh"
 #include "gas.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='NEWORB  ')
 #include "SysDef.fh"
 #include "raswfn.fh"
