@@ -10,15 +10,13 @@
 *                                                                      *
 * Copyright (C) 2019, Oskar Weser                                      *
 ************************************************************************
-#include "intent.h"
+#include "intent.fh"
       module orthonormalization
         use definitions, only: wp
-        use stdalloc, only : mma_allocate, mma_deallocate
-        use fortran_strings, only : to_upper, str
-        use blockdiagonal_matrices, only : t_blockdiagonal, new, delete,
+        use stdalloc, only: mma_allocate, mma_deallocate
+        use blockdiagonal_matrices, only: t_blockdiagonal, new, delete,
      &    from_raw, to_raw, from_symm_raw, blocksizes
-        use linalg_mod, only: mult, norm, dot_product_,
-     &      Gram_Schmidt, Lowdin, Canonical
+        use linalg_mod, only: Gram_Schmidt, Lowdin, Canonical
 
         implicit none
         save
@@ -139,7 +137,7 @@
         integer :: i
 
         do i = 1, size(basis)
-          call Lowdin(basis(i)%block, ONB(i)%block, S(i)%block)
+          call Lowdin(basis(i)%blck, ONB(i)%blck, S(i)%blck)
         end do
       end subroutine Lowdin_Blocks
 
@@ -158,8 +156,8 @@
         integer :: i
 
         do i = 1, size(basis)
-          call Canonical(basis(i)%block, n_to_ON(i),
-     &                   ONB(i)%block, n_new(i), S(i)%block)
+          call Canonical(basis(i)%blck, n_to_ON(i),
+     &                   ONB(i)%blck, n_new(i), S(i)%blck)
         end do
       end subroutine Canonical_Blocks
 
@@ -177,8 +175,8 @@
         integer :: i
 
         do i = 1, size(basis)
-          call Gram_Schmidt(basis(i)%block, n_to_ON(i), ONB(i)%block,
-     &                      n_new(i), S(i)%block)
+          call Gram_Schmidt(basis(i)%blck, n_to_ON(i), ONB(i)%blck,
+     &                      n_new(i), S(i)%blck)
         end do
       end subroutine Gram_Schmidt_Blocks
 
@@ -188,12 +186,11 @@
      &    n_to_ON, nNew,
      &    nDel, nSSH, nOrb, nDelt, nSec, nOrbt, nTot3, nTot4)
       use general_data, only : nSym
-#include "warnings.fh"
+#include "warnings.h"
 #include "output_ras.fh"
       integer, intent(in) :: n_to_ON(:), nNew(:)
       integer, intent(inout) :: nDel(:), nSSH(:), nOrb(:),
      &  nDelt, nSec, nOrbt, nTot3, nTot4
-      parameter(ROUTINE='update_orb_numbe')
 
       integer :: iSym, remove(nSym), total_remove
 
@@ -240,7 +237,7 @@
       subroutine read_raw_S(S_buffer)
         real(wp), intent(inout) :: S_buffer(:)
         integer :: i_Rc, i_Opt, i_Component, i_SymLbl
-#include "warnings.fh"
+#include "warnings.h"
 
         i_Rc = 0
         i_Opt = 2
@@ -261,11 +258,10 @@
       subroutine read_S(S)
         use general_data, only : nBas, nSym, nActEl
         use rasscf_data, only : nFr, nIn, Tot_Nuc_Charge
-#include "warnings.fh"
+#include "warnings.h"
 #include "output_ras.fh"
         type(t_blockdiagonal) :: S(nSym)
 
-        parameter(ROUTINE='update_orb_numbe')
         integer :: size_S_buffer
         real(wp) :: Mol_Charge
         real(wp), allocatable :: S_buffer(:)
