@@ -29,7 +29,7 @@
 #ifdef _DMRG_
 !     module dependencies
       use qcmaquis_interface_cfg
-      use qcmaquis_interface_environment, only: print_dmrg_info
+      use qcmaquis_interface_utility_routines, only: print_dmrg_info
 #endif
 
       Implicit Real*8 (A-H,O-Z)
@@ -39,6 +39,7 @@
 #include "general.fh"
 #include "gas.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='OUTCTL  ')
 #include "ciinfo.fh"
 #include "rctfld.fh"
@@ -65,9 +66,7 @@
 
       Integer  Cho_X_GetTol
       External Cho_X_GetTol
-#ifndef _DMRG_
-      logical :: doDMRG = .false.
-#else
+#ifdef _DMRG_
       character(len=100) :: dmrg_start_guess
 #endif
       Dimension Dum(1),iDum(56)
@@ -121,7 +120,7 @@ C Local print level (if any)
       Write(LF,Fmt2//'A,T45,F6.1)')'Spin quantum number',
      &                           (DBLE(ISPIN-1))/2.0d0
       Write(LF,Fmt2//'A,T45,I6)')'State symmetry',
-     &                           LSYM
+     &                           STSYM
       Call CollapseOutput(0,'Wave function specifications:')
 *
       Call Get_cArray('Irreps',lIrrep,24)
@@ -247,9 +246,9 @@ C Local print level (if any)
         Write(LF,Fmt2//'A)')'----------------------------'
         Write(LF,*)
         Write(LF,Fmt2//'A,T40,I11)')'Number of CSFs',
-     &                           NCSASM(LSYM)
+     &                           NCSASM(STSYM)
         Write(LF,Fmt2//'A,T40,I11)')'Number of determinants',
-     &                           NDTASM(LSYM)
+     &                           NDTASM(STSYM)
       end if
       Write(LF,Fmt2//'A,T45,I6)')'Number of root(s) required',
      &                           NROOTS
@@ -655,7 +654,7 @@ C Local print level (if any)
         End Do
         vNentropy = -vNentropy/log(2.0d0)
 *
-        Write(LF,'(6X,A,I2,A,F8.5)')
+        Write(LF,'(6X,A,I3,A,F8.5)')
      *  'Von Neumann Entropy (Root ',KROOT,') = ',vNentropy
         Write(LF,*)
 *
