@@ -50,29 +50,32 @@
 
 #ifdef _DMRG_
 !     module dependencies
-      use qcmaquis_interface_wrapper
       use qcmaquis_interface_cfg
-      use qcmaquis_interface_version
-      use qcmaquis_interface_environment, only:
-     &    finalize_dmrg, dump_dmrg_info
+      use qcmaquis_interface
+      use qcmaquis_interface_mpssi, only: qcmaquis_mpssi_transform
 #endif
       use stdalloc, only: mma_allocate, mma_deallocate
       use write_orbital_files, only : OrbFiles, putOrbFile
-
       use generic_CI, only: CI_solver_t
-      use fciqmc, only: DoNECI, fciqmc_solver_t
+      use fciqmc, only: DoNECI, fciqmc_solver_t, tGUGA_in
       use CC_CI_mod, only: Do_CC_CI, CC_CI_solver_t
       use fcidump, only : make_fcidumps, transform, DumpOnly
-
       use orthonormalization, only : ON_scheme
-      use print_RDMs_NECI_format, only: printRDMs_NECI
+#ifdef _FDE_
+      use Embedding_global, only: Eemb, embInt, embPot, embPotInBasis,
+     &    embPotPath, embWriteEsp
+#endif
+#ifdef _HDF5_
+      use mh5, only: mh5_put_attr, mh5_put_dset
+#endif
+      use OFembed, only: Do_OFemb, FMaux
 
       Implicit Real*8 (A-H,O-Z)
 
 #include "WrkSpc.fh"
 #include "wadr.fh"
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "input_ras.fh"
 #include "rasscf.fh"
 #include "rasrc.fh"
@@ -81,7 +84,6 @@
 #include "splitcas.fh"
 #include "bk_approx.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='RASSCF  ')
 #include "rctfld.fh"
 #include "timers.fh"
 #include "casvb.fh"
@@ -90,53 +92,43 @@
 #include "csfbas.fh"
 #include "gugx.fh"
 #include "pamint.fh"
-#include "davctl.fh"
 #include "qnctl.fh"
 #include "orthonormalize.fh"
 #include "ciinfo.fh"
-#ifdef _FDE_
-#include "embpotdata.fh"
-#endif
 #include "raswfn.fh"
 
       Logical DSCF
       Logical lTemp, lOPTO
+#ifdef _FDE_
       Character*8 label
+#endif
       Character*80 Line
       Character*1 CTHRE, CTHRSX, CTHRTE
-      Logical DoQmat,DoActive, l_casdft
       Logical IfOpened
 #ifdef _DMRG_
       Logical Do_ESPF
+      ! function defined in misc_util/pcm_on.f
+      Logical, External :: PCM_On
 #endif
 
 * --------- Cholesky stuff:
-      Integer ALGO
-      Logical DoCholesky
-      Logical timings,DoLock,Deco
-      Integer Nscreen
-      COMMON /CHOTODO /DoActive,DoQmat,ipQmat
-      COMMON /CHLCAS /DoCholesky,ALGO
-      COMMON /CHOPAR/ ChFracMem
-      COMMON /CHOTIME / timings
-      Common /CHOLK / DoLocK,Deco,dmpk,Nscreen
+#include "chotodo.fh"
+#include "chlcas.fh"
+#include "chopar.fh"
+#include "chotime.fh"
+#include "cholk.fh"
 * --------- End Cholesky stuff
-      Logical Do_OFemb, KEonly, OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_I / ipFMaux, ip_NDSD, l_NDSD
       Character*8 EMILOOP
-* --------- End Orbital-Free Embedding stuff
 * --------- FCIDUMP stuff:
       real*8, allocatable :: orbital_E(:), folded_Fock(:)
 * --------- End FCIDUMP stuff:
-* --------- Procedure pointers for CI-solvers
+* --------- CI-solver class
         class(CI_solver_t), allocatable :: CI_solver
-* --------- End Procedure pointers.
 
 ! actual_iter starts at 0, so iter 1A == 0, 1B == 1, 2 == 2, 3 == 3 and so on
       integer :: actual_iter
 
-      Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
+#include "sxci.fh"
 
       External Get_ProgName
       Character*100 ProgName, Get_ProgName
@@ -144,18 +136,13 @@
       External RasScf_Init
       External Scan_Inp
       External Proc_Inp
-#ifndef _DMRG_
-      logical :: doDMRG = .false.
-#else
+#ifdef _DMRG_
       integer :: maxtrR
       real*8  :: maxtrW
 #include "nevptp.fh"
 #endif
       Dimension Dummy(1)
 
-* Start the traceback utilities
-*
-
 * Set status line for monitor:
       Call StatusLine('RASSCF:',' Just started.')
 
@@ -163,17 +150,24 @@
       ITERM  = 0
       IRETURN=_RC_ALL_IS_WELL_
 
+* Set the HDF5 file id (a proper id will never be 0)
+      wfn_fileid = 0
+
 * Set some Cholesky stuff
       DoActive=.true.
       DoQmat=.false.
       lOPTO=.False.
+* Initialise doDMRG if compiled without QCMaquis
+#ifndef _DMRG_
+      DoDMRG = .false.
+#endif
 
 * Set variable IfVB to check if this is a VB job.
       ProgName=Get_ProgName()
       IfVB=0
       If (ProgName(1:5).eq.'casvb') IfVB=2
 * Default option switches and values, and initial data.
-      EAV1=0.0d0
+      THMAX=0.0d0
       Call RasScf_Init()
       Call Seward_Init()
 * Open the one-olectron integral file:
@@ -263,18 +257,15 @@
 
       Call InpPri(lOpto)
 
-* Note that CI_solver subclasses can provide a final procedure
-* (some people might call it destructor). Hence the deallocation and
+* Note that CI_solver subclasses provide a cleanup procedure
+* (C++ people might call it destructor). Hence the deallocation and
 * cleanup is automatically performed, when it goes out of scope.
       if (DoNECI) then
-        allocate(fciqmc_solver_t :: CI_solver)
+        allocate(CI_solver, source=fciqmc_solver_t(tGUGA_in))
       else if (Do_CC_CI) then
-        allocate(CC_CI_solver_t :: CI_solver)
+        allocate(CI_solver, source=CC_CI_solver_t())
       end if
 
-      if (allocated(CI_solver)) call CI_solver%init()
-
-
 *
 * If this is not CASDFT make sure the DFT flag is unset
 *
@@ -286,27 +277,16 @@
 
 * If the ORBONLY option was chosen, then Proc_Inp just generated
 *  orbitals from the JOBIPH file. Nothing more to do:
-      IF(KeyORBO.or.(MAXIT.eq.0)) GOTO 9989
-*                                                                 *
-*******************************************************************
-* Initialize global variable for mcpdft method                    *
-       l_casdft = KSDFT(1:5).eq.'TLSDA'   .or.
-     &            KSDFT(1:6).eq.'TLSDA5'  .or.
-     &            KSDFT(1:5).eq.'TBLYP'   .or.
-     &            KSDFT(1:6).eq.'TSSBSW'  .or.
-     &            KSDFT(1:5).eq.'TSSBD'   .or.
-     &            KSDFT(1:5).eq.'TS12G'   .or.
-     &            KSDFT(1:4).eq.'TPBE'    .or.
-     &            KSDFT(1:5).eq.'FTPBE'   .or.
-     &            KSDFT(1:5).eq.'TOPBE'   .or.
-     &            KSDFT(1:6).eq.'FTOPBE'  .or.
-     &            KSDFT(1:7).eq.'TREVPBE' .or.
-     &            KSDFT(1:8).eq.'FTREVPBE'.or.
-     &            KSDFT(1:6).eq.'FTLSDA'  .or.
-     &            KSDFT(1:6).eq.'FTBLYP'
-*******************************************************************
+      IF(KeyORBO) GOTO 9989
+      IF(MAXIT.eq.0) GOTO 2009
 #ifdef _DMRG_
-      if(l_casdft .and. doDMRG) domcpdftDMRG = .true.
+      ! delete old checkpoints, unless requested otherwise
+      ! this flag is set in proc_inp
+      if (.not.DoDelChk) then
+        do kroot=1,nroots
+          call qcmaquis_interface_delete_chkp(iroot(kroot))
+        end do
+      end if
 #endif
 *
 * Allocate various matrices
@@ -319,6 +299,15 @@
       Call GetMem('OCCN','Allo','Real',LOCCN,NTOT)
       Call GetMem('LCMO','Allo','Real',LCMO,NTOT2)
       Call GetMem('DIAF','Allo','Real',LDIAF,NTOT)
+#ifdef _DMRG_
+* Allocate RDMs for the reaction field reference root in QCMaquis calculations
+      if (doDMRG.and.PCM_On()) then
+        Call GetMem('D1RF','Allo','Real',LW_RF1,NACPAR)
+        if (twordm_qcm) then
+          Call GetMem('D2RF','Allo','Real',LW_RF2,NACPR2)
+        end if
+      end if
+#endif
       lfi_cvb=lfi
       lfa_cvb=lfa
       ld1i_cvb=ld1i
@@ -351,13 +340,13 @@
          Call GetMem('TUVX','Allo','Real',LTUVX,NACPR2)
          Call FZero(Work(LTUVX),NACPR2)
          ltuvx_cvb=ltuvx
+         Call GetMem('DSPN','Allo','Real',LDSPN,NACPAR)
+         call dcopy_(NACPAR,[0.0d0],0,Work(LDSPN),1)
          if(.not.DumpOnly) then
            Call GetMem('DMAT','Allo','Real',LDMAT,NACPAR)
-           Call GetMem('DSPN','Allo','Real',LDSPN,NACPAR)
            Call GetMem('PMAT','Allo','Real',LPMAT,NACPR2)
            Call GetMem('P2AS','Allo','Real',LPA,NACPR2)
            call dcopy_(NACPAR,[0.0d0],0,Work(LDMAT),1)
-           call dcopy_(NACPAR,[0.0d0],0,Work(LDSPN),1)
            ldmat_cvb=ldmat
            ldspn_cvb=ldspn
            lpmat_cvb=lpmat
@@ -382,7 +371,7 @@
       if (embpot) then
        ! I have no idea why i need memory for x+4 entries
        ! and not just x...
-       Call GetMem('Emb','ALLO','REAL',ipEmb,NTOT1+4)
+       call mma_allocate(embInt,NTOT1+4,label='Emb')
        if (embPotInBasis) then
         ! If the potential is given in basis set representation it
         ! has not been calculated with a OneEl call and is just read
@@ -390,14 +379,14 @@
         iunit = isFreeUnit(1)
         call molcas_open(iunit, embPotPath)
         do iEmb=1, NTOT1
-         read(iunit,*) Work(ipEmb+iEmb-1)
+         read(iunit,*) embInt(iEmb)
         end do
        else
         ! Read in the embedding potential one-electron integrals
         Label='embpot  '
         iRC=-1
         iOpt=0
-        Call RdOne(iRC,iOpt,Label,1,Work(ipEmb),iSyLbl)
+        Call RdOne(iRC,iOpt,Label,1,embInt,iSyLbl)
         If (iRC.ne.0) then
          Call WarningMessage(2,
      &                'Drv1El: Error reading ONEINT;'
@@ -429,16 +418,6 @@
       end if
 * Only now are such variables finally known.
 
-      If ( IPRLEV.ge.DEBUG ) then
-        CALL TRIPRT('Averaged one-body density matrix, D, in RASSCF',
-     &              ' ',Work(LDMAT),NAC)
-        CALL TRIPRT('Averaged one-body spin density matrix DS, RASSCF',
-     &              ' ',Work(LDSPN),NAC)
-        CALL TRIPRT('Averaged two-body density matrix, P',
-     &              ' ',WORK(LPMAT),NACPAR)
-        CALL TRIPRT('Averaged antisym 2-body density matrix PA RASSCF',
-     &              ' ',WORK(LPA),NACPAR)
-      END IF
 *
 * Allocate core space for dynamic storage of data
 *
@@ -529,11 +508,6 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
      &        'S. Keller, M. Dolfi, M. Troyer, M. Reiher,',
      &        'J. Chem. Phys. 143, 244118 (2015)',
      &        '------------------------------------------------'//
-     &        '---------------',
-     &        trim(qcmaquis_interface_v),
-     &        'git reference SHA        : ',
-     &        trim(qcmaquis_interface_g(1:12)),
-     &        '------------------------------------------------'//
      &        '---------------'
        end if
 #endif
@@ -865,11 +839,11 @@ c         write(6,*) (WORK(LTUVX+ind),ind=0,NACPR2-1)
 #ifdef _FDE_
           !Thomas Dresselhaus
           if (embpot) then
-            !Eemb=DDot_(NACPAR,Work(ipEmb),1,Work(LDMAT),1)
-!           Eemb=embPotEne(Work(LD1I), Work(LD1A), Work(ipEmb),
+            !Eemb=DDot_(NACPAR,embInt,1,Work(LDMAT),1)
+!           Eemb=embPotEne(Work(LD1I), Work(LD1A), embInt,
 !    &                   Work(LCMO), nBasFunc, nFrozenOrbs, .true.)
             Eemb=embPotEneMODensities(Work(LD1I), Work(LD1A),
-     &            Work(ipEmb), nBas, nTot2, nFrozenOrbs, nSym)
+     &            embInt, nBas, nTot2, nSym)
             Write(LF,*) "Energy from embedding potential with the"
             Write(LF,*) "initial CI vectors: ", Eemb
           end if
@@ -1176,7 +1150,9 @@ c      call triprt('P-mat 2',' ',WORK(LPMAT),nAc*(nAc+1)/2)
           Call RdOne(iRc,iOpt,'OneHam',iComp,Work(iTmp1),iSyLbl)
           If ( iRc.ne.0 ) then
            Write(LF,*) 'SGFCIN: iRc from Call RdOne not 0'
+#ifdef _FDE_
            Write(LF,*) 'Label = ',Label
+#endif
            Write(LF,*) 'iRc = ',iRc
            Call Abend
           End if
@@ -1231,8 +1207,6 @@ c      call triprt('P-mat 2',' ',WORK(LPMAT),nAc*(nAc+1)/2)
      &                    WORK(LD1A),Work(ipTmpD1S_DFT))
         CALL GETMEM('TmpD1S_DFT','Free','REAL',ipTmpD1S_DFT,NTOT2)
         CALL GETMEM('CASDFT_Fock','FREE','REAL',LFOCK,NACPAR)
-* to fix complains from garble option on borr machines... initialize THMAX to zero.
-        THMAX = 0.0d0
       end if
 
 c        CALL TRIPRT('Averaged one-body density matrix, D, in RASSCF',
@@ -1345,8 +1319,8 @@ cGLM        write(6,*) 'CASDFT energy :', CASDFT_Funct
       CALL DDAFILE(JOBIPH,1,ENER,mxRoot*mxIter,IAD15)
       CALL DDAFILE(JOBIPH,1,CONV,6*mxIter,IAD15)
 #ifdef _HDF5_
-      call mh5_put_attr (wfn_iter, Iter)
-      call mh5_put_dset_array_real(wfn_energy, ENER(1,Iter))
+      call mh5_put_attr(wfn_iter, Iter)
+      call mh5_put_dset(wfn_energy, ENER(1,Iter))
 #endif
 *
 * Print output of energies and convergence parameters
@@ -1407,13 +1381,13 @@ cGLM        write(6,*) 'CASDFT energy :', CASDFT_Funct
               IROT   = MAXLOC(dmrg_energy%num_sweeps,nroots)
               maxtrW = MAXVAL(dmrg_energy%max_truncW)
               maxtrR = MAXLOC(dmrg_energy%max_truncW,nroots)
-#endif
          Write(LF,'(6X,I3,I3,I4,E12.2,I4,I5,F15.8,E12.2,A1,E9.2,A1,'//
      &   '2I4,I2,E10.2,A1,F6.2,F7.2,4X,A2,3X,A3,I7,A1,I2.2,A1,I2.2)')
      &        ITER,ITERCI,IROT,maxtrW,maxtrR,
      &        ITERSX,ECAS-EVAC+CASDFT_Funct,DE,CTHRE,
      &        ROTMAX,CTHRTE,IBLBM,JBLBM,ISYMBB,CBLBM,CTHRSX,
      &        SXSHFT,TMIN,QNSTEP,QNUPDT,ihh,':',imm,':',iss
+#endif
             else
             Write(LF,'(6X,I3,I4,I5,I5,F15.8,E12.2,A1,E10.2,A1,2I4,I2,'//
      &          'E10.2,A1,F6.2,F7.2,4X,A2,3X,A3,I5,A1,I2.2,A1,I2.2)')
@@ -1444,8 +1418,8 @@ cGLM        write(6,*) 'CASDFT energy :', CASDFT_Funct
 #ifdef _FDE_
       ! Embedding
       if (embpot) then
-       Eemb=embPotEneMODensities(Work(LD1I), Work(LD1A), Work(ipEmb),
-     &                nBas, nTot2, nFrozenOrbs, nSym)
+       Eemb=embPotEneMODensities(Work(LD1I), Work(LD1A), embInt,
+     &                nBas, nTot2, nSym)
        Write(LF,*)"E from embedding potential (<Psi|v_emb|Psi>): ",Eemb
       end if
 #endif
@@ -1553,6 +1527,7 @@ cGLM some additional printout for MC-PDFT
         END IF
       end if
 
+
 *
 * Convergence check:
 * check is done on largest BLB matrix
@@ -1809,7 +1784,7 @@ c Clean-close as much as you can the CASDFT stuff...
          Do jRoot=2,lRoots
 *           Read and reorder the left CI vector
             Call DDafile(JOBIPH,2,Work(iTmp),nConf,jDisk)
-            Call Reord2(NAC,NACTEL,LSYM,1,
+            Call Reord2(NAC,NACTEL,STSYM,1,
      &                  iWork(KICONF(1)),iWork(KCFTP),
      &                  Work(iTmp),Work(iVecL),iWork(ivkcnf))
             C_Pointer=iVecL
@@ -1817,16 +1792,16 @@ c Clean-close as much as you can the CASDFT stuff...
             Do kRoot=1,jRoot-1
 *              Read and reorder the right CI vector
                Call DDafile(JOBIPH,2,Work(iTmp),nConf,kDisk)
-               Call Reord2(NAC,NACTEL,LSYM,1,
+               Call Reord2(NAC,NACTEL,STSYM,1,
      &                     iWork(KICONF(1)),iWork(KCFTP),
      &                     Work(iTmp),Work(iVecR),iWork(ivkcnf))
 *              Compute TDM and store in h5 file
                Call Lucia_Util('Densi',iVecR,iDummy,Dummy)
                idx=(jRoot-2)*(jRoot-1)/2+kRoot
-               Call mh5_put_dset_array_real(wfn_transdens, Work(LW6),
+               Call mh5_put_dset(wfn_transdens,Work(LW6:LW6+NAC*NAC-1),
      &              [NAC,NAC,1], [0,0,idx-1])
                If (iSpin.gt.1)
-     &         Call mh5_put_dset_array_real(wfn_transsdens, Work(LW7),
+     &         Call mh5_put_dset(wfn_transsdens,Work(LW7:LW7+NAC*NAC-1),
      &              [NAC,NAC,1], [0,0,idx-1])
             End Do
          End Do
@@ -1886,13 +1861,14 @@ c      write(6,*) 'I am in RASSCF before call to PutRlx!'
 #ifdef _FDE_
       ! Embedding
       if (embpot) then
-       Eemb=embPotEneMODensities(Work(LD1I), Work(LD1A), Work(ipEmb),
-     &                nBas, nTot2, nFrozenOrbs, nSym)
+       Eemb=embPotEneMODensities(Work(LD1I), Work(LD1A), embInt,
+     &                nBas, nTot2, nSym)
        Write(LF,*) "Final energy from embedding potential: ", Eemb
        ! Write out ESP on grid if requested
        if (embWriteEsp) then
         Call Get_iScalar('Unique atoms',nNuc)
-        Call embPotOutputMODensities(nNuc,nSym,LD1I,LD1A,nBas,nTot2)
+        Call embPotOutputMODensities(nNuc,nSym,Work(LD1I),Work(LD1A),
+     &                               nBas,nTot2)
        end if
       end if
 #endif
@@ -1919,14 +1895,8 @@ c  i_root>0 gives natural spin orbitals for that root
       End Do
 
 * Create output orbital files:
-      Call OrbFiles(JOBIPH,IPRLEV)
-*
-************************************************************************
-************ Printing final RDMs in NECI format        *****************
-************************************************************************
-      If ( IPRLEV.ge.DEBUG ) then
-       Call printRDMs_NECI(Work(LDMAT),NAC,Work(LPMAT),Work(LPA),NACPAR)
-      End If
+2009      Call OrbFiles(JOBIPH,IPRLEV)
+
 ************************************************************************
 ******************           Closing up RASSCF       *******************
 ************************************************************************
@@ -1940,11 +1910,11 @@ c  i_root>0 gives natural spin orbitals for that root
 c deallocating TUVX memory...
       IF(NAC.GT.0) THEN
          Call GetMem('TUVX','Free','Real',LTUVX,NACPR2)
+         Call GetMem('DSPN','Free','Real',LDSPN,NACPAR)
          if(.not.DumpOnly) Then
             Call GetMem('P2AS','Free','Real',LPA,NACPR2)
             Call GetMem('PMAT','Free','Real',LPMAT,NACPR2)
             Call GetMem('DMAT','Free','Real',LDMAT,NACPAR)
-            Call GetMem('DSPN','Free','Real',LDSPN,NACPAR)
          endif
       END IF
 *
@@ -1960,7 +1930,7 @@ c deallocating TUVX memory...
             Write(LF,*)' Try to recover. Calculation continues.'
          endif
          If (Do_OFemb) Then
-            Call GetMem('FMaux','Free','Real',ipFMaux,nTot1)
+            Call mma_deallocate(FMaux)
             Call OFE_print(EAV)
          EndIf
       endif
@@ -1979,6 +1949,15 @@ c deallocating TUVX memory...
       Call GetMem('D1tot','Free','Real',lD1tot,NTOT1)
       Call GetMem('OCCN','Free','Real',LOCCN,NTOT)
       Call GetMem('LCMO','Free','Real',LCMO,NTOT2)
+#ifdef _DMRG_
+* Free RDMs for the reaction field reference root in QCMaquis calculations
+      if (doDMRG.and.PCM_On()) then
+        Call GetMem('D1RF','FREE','Real',LW_RF1,NACPAR)
+        if (twordm_qcm) then
+          Call GetMem('D2RF','FREE','Real',LW_RF2,NACPR2)
+        end if
+      end if
+#endif
       If (iClean.eq.1) Call Free_iWork(ipCleanMask)
 
 *
@@ -2034,6 +2013,11 @@ c      End If
         Call MKGUGA_FREE
       end if
 
+      if (DoFaro) then
+         call faroald_free()
+         call citrans_free()
+      end if
+
       if (allocated(CI_solver)) then
           call CI_solver%cleanup()
           deallocate(CI_solver)
@@ -2047,36 +2031,50 @@ c      End If
 #ifdef _DMRG_
         !Leon: Generate 4-RDM evaluation templates for NEVPT2
 
+        !In the new interface the EvRDM keyword will be ignored.
+        !Instead, NEVPT2Prep will always generate the template.
+        !RDM evaluation will now happen in the NEVPT2 module
+        !where NEVPT2 either can attempt to compute it directly
+        !with the new interface or read from QCMaquis HDF5 result
+        !file.
         if (DoNEVPT2Prep) then
+          if (NACTEL.gt.3) then ! Ignore 4-RDM if we have <4 electrons
           do i=1,NROOTS
-            if (DoEvaluateRDM) then
-              Write (6,'(a,i4)') 'Evaluating 4-RDM for state ', i
-            else
-        Write (6,'(a,i4)') 'Writing 4-RDM QCMaquis template'//
-     &   ' for state ', i
-            end if
-            call dmrg_interface_ctl(task='w 4rdmin',state=i-1,
-     &       msproj=MPSCompressM,rdm4=DoEvaluateRDM)
-      !> MPSCompressM is passed to dmrg_interface_ctl via msproj,
-      !> if it is > 0, then MPS compression is triggered there
+              Write (6,'(a)') 'Writing 4-RDM QCMaquis template'//
+     &   ' for state '//trim(str(i))
+              call qcmaquis_interface_prepare_hirdm_template(
+     &        filename="meas-4rdm."//trim(str(i-1))//".in",
+     &        state=i-1,
+     &        tpl=TEMPLATE_4RDM)
+              call qcmaquis_mpssi_transform(
+     &             trim(qcmaquis_param%currdir)//'/'//
+     &             trim(qcmaquis_param%project_name), i)
           end do
+          else
+            write(6,*) "Skipping 4-RDM QCMaquis template generation "//
+     &        "since we have less than 4 electrons."
+          end if
           ! Generate 3-TDM templates
+          if(NACTEL.gt.2) then ! but only if we have more than 3 el.
           do i=1,NROOTS
             do j=i+1,NROOTS
-              if (DoEvaluateRDM) then
-            Write (6,'(a,i4,i4)') 'Evaluating 3-TDM for states ', i,j
-            else
-        Write (6,'(a,i4,i4)') 'Writing 3-TDM QCMaquis'//
-     &   ' template for state ', i,j
-            end if
-
-              call dmrg_interface_ctl(task='w 3tdmin',state=i-1,
-     &         stateL=j-1,rdm3=DoEvaluateRDM)
+              Write (6,'(a)') 'Writing 3-TDM QCMaquis template'//
+     &   ' for states '//trim(str(i))//" and "//trim(str(j))
+              call qcmaquis_interface_prepare_hirdm_template(
+     &        filename="meas-3tdm."//trim(str(i-1))//"."//
+     &         trim(str(j-1))//".in",
+     &        state=i-1,
+     &        state_j=j-1,
+     &        tpl=TEMPLATE_TRANSITION_3RDM)
             end do
           end do
+          else
+            write(6,*) "Skipping 3-RDM QCMaquis template generation "//
+     &        "since we have less than 3 electrons."
+          end if
         end if
-!       call dump_dmrg_info()
-        call finalize_dmrg()
+        ! is it really needed in the times of Fortran 2008?
+        call qcmaquis_interface_deinit
 #endif
       end if
 ! ==========================================================
