@@ -18,16 +18,13 @@
 * Return codes are _RC_ALL_IS_WELL_ or _RC_INPUT_ERROR_
 * ------------------------------------------------------------
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "WrkSpc.fh"
 #include "input_ras.fh"
 #include "output_ras.fh"
-      Parameter(ROUTINE='Scan_Inp')
 *
       Character*4 Command
       Character*180  Line
-      Character*180 Get_LN
-      External Get_LN
 
 #ifdef _DMRG_
       External Get_ProgName
