@@ -38,15 +38,13 @@
 
       use rasscf_data, only : iToc, name, header, title, lRoots, nRoots,
      &  iRoot, LENIN8, mXORB, mxTit, mXroot, iPt2, Weight, iOrbTyp,
-     &  FDiag, E2Act, mxiter, maxorbout
-      use general_data, only : nActel, iSpin, lSym, mXSym,
+     &  FDiag, E2Act, mxiter, maxorbout, doDMRG
+      use general_data, only : nActel, iSpin, stSym, mXSym,
      &  nFro, nIsh, nAsh, nDel, nBas, nRs1, nRs2, nRs3, nHole1, nElec3,
      &  nTot, nTot2, nConf
-      use gugx_data, only : ifCas
       use gas_data, only : nGssh
 
 #include "output_ras.fh"
-      Parameter (ROUTINE='ORBFILES')
 #include "WrkSpc.fh"
       integer, intent(in) :: JobIph, iPrlev
 
@@ -56,9 +54,6 @@
 
       character(len=80) :: VecTyp
       character(len=128) :: Filename
-#ifndef _DMRG_
-      logical :: doDMRG = .false.
-#endif
       interface
         integer function isfreeunit(iseed)
           integer, intent(in) :: iseed
@@ -85,7 +80,7 @@
       Call iDaFile(JobIph,2,iToc,15,iDisk)
       iDisk = iToc(1)
       Call WR_RASSCF_Info(JobIph,2,iDisk,
-     &                    nActEl,iSpin,nSym,lSym,
+     &                    nActEl,iSpin,nSym,stSym,
      &                    nFro,nIsh,nAsh,nDel,
      &                    nBas,mxSym,Name,LENIN8*mxOrb,nConf,
      &                    Header,144,Title,4*18*mxTit,PotNucDummy,
@@ -264,7 +259,7 @@ c     & Work(lCMO), Work(ipOcc), FDIAG, IndType,VecTyp)
 
       subroutine putOrbFile(CMO, orbital_E, iDoGAS)
         use general_data, only : ntot,
-     &    nFro, nIsh, nRs1, nRs2, nRs3, nDel, nAsh, nBas
+     &    nFro, nIsh, nRs1, nRs2, nRs3, nDel, nBas
         use gas_data, only : nGSSH
         real*8, intent(in) :: CMO(:), orbital_E(:)
         logical, intent(in) :: iDoGAS
