@@ -33,7 +33,7 @@
       CHARACTER*8 PRPLST(MXPROP)
       Character*3 lIrrep(8)
       INTEGER ICMPLST(MXPROP)
-      LOGICAL JOBMATCH
+      LOGICAL JOBMATCH,IsAvail(MXPROP),IsAvailSO(MXPROP)
       DIMENSION IDUM(1)
 * Analysing and post-processing the input that was read in readin_rassi.
 
@@ -145,7 +145,6 @@ C (IPUSED will be set later, set it to zero now.)
       IOPT=15
       LABEL='UNDEF'
       CALL iRDONE(IRC,IOPT,LABEL,ICMP,IDUM,ISYLAB)
-      IF(IRC.EQ.0) NSIZ=IDUM(1)
       IF(IRC.NE.0) GOTO 110
       IPRP=1
       CALL UPCASE(LABEL)
@@ -158,7 +157,6 @@ C (IPUSED will be set later, set it to zero now.)
         IRC=-1
         IOPT=23
         CALL iRDONE(IRC,IOPT,LABEL,ICMP,IDUM,ISYLAB)
-        IF(IRC.EQ.0) NSIZ=IDUM(1)
         IF(IRC.NE.0) GOTO 110
         IPRP=IPRP+1
         CALL UPCASE(LABEL)
@@ -166,16 +164,27 @@ C (IPUSED will be set later, set it to zero now.)
         ICMPLST(IPRP)=ICMP
         IPUSED(IPRP)=0
 
-c Copy the EF2 integral label for hyperfine calculations
+c Copy the EF2 integral label for non-rel hyperfine calculations
         IF(LABEL(1:3).EQ.'EF2') THEN
           IF(IPRP.GE.MXPROP) GOTO 110
           IPRP=IPRP+1
           LABEL2=LABEL
-          LABEL2(1:3)='ASD'
+          LABEL2(1:4)='ASDO'
           PRPLST(IPRP)=LABEL2
           ICMPLST(IPRP)=ICMP
           IPUSED(IPRP)=0
+        END IF
 
+c Now the ASD are calculated from X2C
+c magnetic integrals
+        IF(LABEL(1:5).EQ.'MAGXP'.AND.ICMP.LE.6) THEN
+          IF(IPRP.GE.MXPROP) GOTO 110
+          IPRP=IPRP+1
+          LABEL2=LABEL
+          LABEL2(1:5)='ASD  '
+          PRPLST(IPRP)=LABEL2
+          ICMPLST(IPRP)=ICMP
+          IPUSED(IPRP)=0
         END IF
 
         IF(LABEL(1:4).EQ.'PSOI') THEN
@@ -474,12 +483,16 @@ C
        END IF
       END IF
 
+C Make sure we don't check SO properties if no SO requested
+      IF (.NOT. IFSO) NSOPR=0
 C Is everything available that we may need?
       IMiss=0
+      IsAvail(:)=.FALSE.
       DO IPROP=1,NPROP
        DO IPRP=1,NPRPLST
         IF(PNAME(IPROP).EQ.PRPLST(IPRP).AND.
      &        ICOMP(IPROP).EQ.ICMPLST(IPRP)) THEN
+         IsAvail(IPROP)=.TRUE.
          IPUSED(IPRP)=1
          GOTO 120
         END IF
@@ -503,11 +516,13 @@ C Is everything available that we may need?
  120   CONTINUE
       END DO
       IMiss=0
+      IsAvailSO(:)=.FALSE.
       DO ISOPR=1,NSOPR
-       DO IPRP=1,NPRPLST
-        IF(SOPRNM(ISOPR).EQ.PRPLST(IPRP).AND.
+        DO IPRP=1,NPRPLST
+         IF(SOPRNM(ISOPR).EQ.PRPLST(IPRP).AND.
      &        ISOCMP(ISOPR).EQ.ICMPLST(IPRP)) THEN
          IPUSED(IPRP)=1
+         IsAvailSO(ISOPR)=.TRUE.
          GOTO 130
         END IF
        END DO
@@ -551,7 +566,7 @@ cnf
          End If
       End If
 cnf
-C Temporary use IPUSED to mark operators that may be needed:
+C Temporarily use IPUSED to mark operators that may be needed:
       DO IPRP=1,NPRPLST
        DO IPROP=1,NPROP
         IF(PNAME(IPROP).EQ.PRPLST(IPRP).AND.
@@ -673,20 +688,30 @@ C
                PNAME(NPROP)=PRPLST(IPRP)
                PTYPE(NPROP)='UNDEF.  '
                ICOMP(NPROP)=ICMPLST(IPRP)
+               IsAvail(NPROP)=.TRUE.
             END IF
          END IF
       END DO
+      DO IPROP=1,NPROP
+        IF (.NOT.IsAvail(IPROP)) PNAME(IPROP)='REMOVE'
+      END DO
       MPROP=NPROP
       DO IPROP = 1, NPROP
          IF (PNAME(IPROP).EQ.'DONE') EXIT
          IF (PNAME(IPROP).EQ.'REMOVE') THEN
-            DO JPROP = IPROP, MPROP-1
-               PNAME(JPROP)=PNAME(JPROP+1)
-               PTYPE(JPROP)=PTYPE(JPROP+1)
-               ICOMP(JPROP)=ICOMP(JPROP+1)
+            DO N = 1, MPROP-IPROP
+              IF (PNAME(IPROP+N).EQ.'DONE') EXIT
+              IF (PNAME(IPROP+N).NE.'REMOVE') EXIT
             END DO
-            PNAME(MPROP)='DONE'
-            MPROP=MPROP-1
+            DO JPROP = IPROP, MPROP-N
+               PNAME(JPROP)=PNAME(JPROP+N)
+               PTYPE(JPROP)=PTYPE(JPROP+N)
+               ICOMP(JPROP)=ICOMP(JPROP+N)
+            END DO
+            DO JPROP = MPROP-N+1,MPROP
+              PNAME(JPROP)='DONE'
+            END DO
+            MPROP=MPROP-N
          END IF
       END DO
       NPROP=MPROP
@@ -709,23 +734,34 @@ C
                SOPRNM(NSOPR)=PRPLST(IPRP)
                SOPRTP(NSOPR)='UNDEF.  '
                ISOCMP(NSOPR)=ICMPLST(IPRP)
+               IsAvailSO(NSOPR)=.TRUE.
             END IF
          END IF
       END DO
+      DO ISOPR=1,NSOPR
+        IF (.NOT.IsAvailSO(ISOPR)) SOPRNM(ISOPR)='REMOVE'
+      END DO
       MSOPR=NSOPR
       DO ISOPR = 1, NSOPR
          IF (SOPRNM(ISOPR).EQ.'DONE') EXIT
          IF (SOPRNM(ISOPR).EQ.'REMOVE') THEN
-            DO JSOPR = ISOPR, MSOPR-1
-               SOPRNM(JSOPR)=SOPRNM(JSOPR+1)
-               SOPRTP(JSOPR)=SOPRTP(JSOPR+1)
-               ISOCMP(JSOPR)=ISOCMP(JSOPR+1)
+            DO N = 1, MSOPR-ISOPR
+              IF (SOPRNM(ISOPR+N).EQ.'DONE') EXIT
+              IF (SOPRNM(ISOPR+N).NE.'REMOVE') EXIT
             END DO
-            PNAME(MSOPR)='DONE'
-            MSOPR=MSOPR-1
+            DO JSOPR = ISOPR, MSOPR-N
+               SOPRNM(JSOPR)=SOPRNM(JSOPR+N)
+               SOPRTP(JSOPR)=SOPRTP(JSOPR+N)
+               ISOCMP(JSOPR)=ISOCMP(JSOPR+N)
+            END DO
+            DO JSOPR = MSOPR-N+1,MSOPR
+              SOPRNM(JSOPR)='DONE'
+            END DO
+            MSOPR=MSOPR-N
          END IF
       END DO
       NSOPR=MSOPR
+      IF (.NOT. IFSO) NSOPR=0
 
 C IPUSED is used later for other purposes, and should be initialized
 C to zero.
@@ -931,20 +967,25 @@ C Write out various input data:
      &    '(SHIFT keyword).'
           END IF
           IF(NSOPR.GT.0) THEN
+            WRITE(6,*)
             WRITE(6,*)' SO coupling elements will be added.'
-            WRITE(6,*)'      EIGENSTATES OF SPIN-ORBIT HAMILTONIAN'//
-     &            ' WILL BE COMPUTED'
           END IF
         END IF
+      END IF
+      IF(NSOPR.GT.0) THEN
         IF(.NOT.(TRACK.OR.ONLY_OVERLAPS)) THEN
-          IF(NSOPR.GT.0) THEN
+          WRITE(6,*)
           WRITE(6,*) '       MATRIX ELEMENTS OVER SPIN EIGENSTATES FOR:'
           Do i1=1,NSOPR,3
             i2=Min(i1+2,NSOPR)
             WRITE(6,'(3(5X,A8,1X,I3,1X,A1,A8,A1))')
      &           (SOPRNM(i),ISOCMP(i),'(',SOPRTP(i),')',i=i1,i2)
           End Do
-          END IF
+        END IF
+        IF(IFHAM) THEN
+          WRITE(6,*)
+          WRITE(6,*)'      EIGENSTATES OF SPIN-ORBIT HAMILTONIAN'//
+     &            ' WILL BE COMPUTED'
         END IF
       END IF
       IF(IPGLOB.GE.DEBUG) THEN
