@@ -19,8 +19,7 @@
       Dimension iSGStruct(nSGSize)
       CHARACTER*26 CC1,CC2,CTVPT,CBVPT,CSVC
       CHARACTER*20 FRML(7),TEXT
-      COMMON /SEGTAB/ IC1(26),IC2(26),ITVPT(26),IBVPT(26),ISVC(26),
-     *                NIVR,LIVR,NSGMNT,LSGMNT
+#include "segtab.fh"
       DIMENSION IVR(NVERT,2),ISGMNT(NVERT,26),VSGMNT(NVERT,26)
       DIMENSION IDRT(NVERT,5),IDOWN(NVERT,0:3),LTV(-1:NLEV)
       DIMENSION MVL(NMIDV,2),MVR(NMIDV,2)
