@@ -70,7 +70,6 @@ C And MSPROJS which saves their ms projections for later use
       CALL GETMEM('SO2SF','ALLO','INTE',SO2SFNUM,NSS)
       MSPROJS=0
       CALL GETMEM('MSPROJS','ALLO','REAL',MSPROJS,NSS)
-      ISS=0
       SOTOT=0
       SFTOT=0
       DO ISTATE=1,NSTATE
@@ -183,7 +182,6 @@ C SO Dyson orbitals
          ! For each initial state JSTATE up to DYSEXPSFSO we will
          ! gather all the obtained Dysorbs
          ! and export to a shared .molden file
-         IFILE=1
          SODYSCIND=0 ! Orbital coeff. index
          ORBNUM=0 ! Dysorb index for given JSTATE
          SODYSCMOR=0.0D0 ! Real orbital coefficients
@@ -270,9 +268,9 @@ C SO Dyson orbitals
 ! If at least one orbital was found, export it/them
         IF(ORBNUM.GT.0) THEN
          Write(filename,'(A16,I0,A3)') 'Dyson.SO.molden.',JSTATE,'.Re'
-         Call Molden_DysOrb(0,filename,DYSEN,AMPS,SODYSCMOR,ORBNUM,NZ)
+         Call Molden_DysOrb(filename,DYSEN,AMPS,SODYSCMOR,ORBNUM,NZ)
          Write(filename,'(A16,I0,A3)') 'Dyson.SO.molden.',JSTATE,'.Im'
-         Call Molden_DysOrb(0,filename,DYSEN,AMPS,SODYSCMOI,ORBNUM,NZ)
+         Call Molden_DysOrb(filename,DYSEN,AMPS,SODYSCMOI,ORBNUM,NZ)
         END IF
 
        END DO ! JSTATE
