@@ -15,8 +15,10 @@
       use sorting_funcs, only : leq_r
 #ifdef _HDF5_
       use Dens2HDF5
+      use mh5, only: mh5_put_dset
 #endif
 #ifdef _DMRG_
+      use rasscf_data, only: doDMRG
       use qcmaquis_interface_cfg
 #endif
       IMPLICIT NONE
@@ -48,7 +50,6 @@
       INTEGER LHTOTI,LHTOTR
       INTEGER LJ2I,LJ2R,LJXI,LJXR,LJYI,LJYR,LJZI,LJZR,LLXI,LLYI,LLZI
       INTEGER LMAPMS,LMAPSP,LMAPST,LOMGI,LOMGR
-      INTEGER LOWEST
       INTEGER MAGN
       INTEGER MPLET,MPLET1,MPLET2,MSPROJ,MSPROJ1,MSPROJ2
 
@@ -281,8 +282,8 @@ C SPIN-ORBIT HAMILTONIAN MATRIX ELEMENTS:
       call put_darray('HAMSOR_SINGLE',HAMSOR,NSS*NSS)
       call put_darray('HAMSOI_SINGLE',HAMSOI,NSS*NSS)
 #ifdef _HDF5_
-      call mh5_put_dset_array_real(wfn_sos_hsor,HAMSOR)
-      call mh5_put_dset_array_real(wfn_sos_hsoi,HAMSOI)
+      call mh5_put_dset(wfn_sos_hsor,HAMSOR)
+      call mh5_put_dset(wfn_sos_hsoi,HAMSOI)
 #endif
 
       !> use complex matrix diagonalization
@@ -358,8 +359,8 @@ C SPIN-ORBIT HAMILTONIAN MATRIX ELEMENTS:
 
 #ifdef _HDF5_
       call mh5_put_dset(wfn_sos_energy, ENSOR)
-      call mh5_put_dset_array_real(wfn_sos_coefr,USOR)
-      call mh5_put_dset_array_real(wfn_sos_coefi,USOI)
+      call mh5_put_dset(wfn_sos_coefr,USOR)
+      call mh5_put_dset(wfn_sos_coefi,USOI)
 #endif
       !> free memory for H_SO - do not use it below!
       !> eigenvalues are stored in ENSOR!
@@ -488,12 +489,10 @@ C910  CONTINUE
 
 * Find E0=lowest energy, to use for printing table:
       IF(IPGLOB.GE.TERSE) THEN
-       LOWEST=1
        E0=ENSOR(1)
        DO ISS=2,NSS
          E=ENSOR(ISS)
         IF(E.LT.E0) THEN
-         LOWEST=ISS
          E0=E
         END IF
        END DO
@@ -557,6 +556,7 @@ C Added by Ungur Liviu on 04.11.2009
 C Saving the ESO array in the RunFile.
        CALL Put_iscalar('NSS_SINGLE',NSS)
        CALL Put_dArray( 'ESO_SINGLE',ESO,NSS)
+       CALL Put_dArray( 'ESO_LOW'   ,ENSOR+EMIN,NSS)
        CALL MMA_DEALLOCATE(ESO)
       END IF
 
