@@ -21,10 +21,7 @@
       DIMENSION X1(NX1MX),X2(NX2MX),X3(NX3MX),VXPQ(NVXPQ)
       DIMENSION CMO1(NCMO),CMO2(NCMO),TUVX(NGAM2)
 #include "rassi.fh"
-      COMMON/TRNSFRM/ NPQ,NBPQ,NBRS,LADX,NAVX,NAP,NAQ,NAR,NAS,
-     *               NBP,NBQ,NBR,NBS,ISP,ISQ,ISR,ISS,IAPR(8),
-     *               LMOP1,LMOQ1,LMOR1,LMOS1,NX1MX,NX2MX,
-     *               NX3MX,NVXPQ
+#include "trnsfrm.fh"
 C START LOOP OVER ORDERED AO-INTEGRALS: NPQ PQ-PAIRS IN EACH BUFFER.
 C FOR EACH PQ PAIR, THERE IS A MATRIX CONTAINING THE (PQ,RS)
 C INTEGRALS. INDEX S RUNS FASTEST, SO BY FORTRAN RULES, IF REGARDED
