@@ -31,9 +31,6 @@
       Real*8 DM1(nDM,nAuxVec),
      &       Txy(nTxy,nAuxVec),Diag(nDM,nAuxVec),
      &       DMtmp(nDM*(nDM+1)/2)
-      Logical debug
-      debug=.true.
-      debug=.false.
 *
       nCumAct(0)=0
       Do i=1,nIrrep-1
@@ -143,7 +140,7 @@
            Call Cho_DZero(Txy(Txy_sta2,iVec),nkl**2)
            call dcopy_(nkl,[One],0,Txy(Txy_sta2,iVec),nkl+1)
 *
-           Call NIdiag(DMTmp,Txy(Txy_sta2,iVec),nkl,nkl,0)
+           Call NIdiag(DMTmp,Txy(Txy_sta2,iVec),nkl,nkl)
 *
 **       Multiply by Sqrt[eigenvalue]
 *
