@@ -11,8 +11,7 @@
 * Copyright (C) 1990,1991,1993,1998,2005, Roland Lindh                 *
 *               1990, IBM                                              *
 ************************************************************************
-      SubRoutine Drv2El_2Center_RI(Integral_WrOut,ThrAO,ipA_Diag,
-     &                             nSO_Aux,MaxCntr,ipSO2C)
+      SubRoutine Drv2El_2Center_RI(ThrAO,A_Diag,nSO_Aux,MaxCntr,SO2C)
 ************************************************************************
 *                                                                      *
 *  Object: driver for two-electron integrals.                          *
@@ -36,12 +35,11 @@
       use RICD_Info, only: LDF
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
-      External Integral_WrOut
+      External Integral_RI_2
 #include "Molcas.fh"
 #include "setup.fh"
 #include "print.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
 #include "nsd.fh"
 #define _no_nShs_
@@ -49,6 +47,10 @@
       Integer iAddr_AQ(0:7), kCol_Irrep(0:7)
       Logical Verbose, Indexation, FreeK2, DoGrad, DoFock
       Character Name_Q*6
+      Real*8, Allocatable :: A_Diag(:)
+      Integer, Allocatable:: SO2C(:)
+
+      Real*8, Allocatable :: Tmp(:,:), TMax(:), TInt(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -56,15 +58,6 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*----- Statement functions
-*
-      TMax(i)=Work(ipTMax-1+i)
-*                                                                      *
-************************************************************************
-*                                                                      *
-      iRout = 9
-      iPrint = nPrint(iRout)
-*
       Call StatusLine(' Seward:',' Computing 2-center RI integrals')
 *                                                                      *
 ************************************************************************
@@ -88,17 +81,16 @@
 *
        nSO_Aux=nSOs-1
       If (LDF) Then
-         Call GetMem('SO2C','Allo','Inte',ipSO2C,nSO_Aux)
+         Call mma_allocate(SO2C,nSO_Aux,Label='SO2C')
          MaxCntr=0
          Do i = 1, nSO_Aux
             iSh = iSO2Sh(i)
             iCenter=iSD(10,iSh)
             MaxCntr=Max(MaxCntr,iCenter)
-            iWork(ipSO2C+i-1)=iCenter
+            SO2C(i)=iCenter
          End Do
       Else
          MaxCntr=0
-         ipSO2C=ip_Dummy
       End If
 *
       nBfn2 = 0
@@ -112,20 +104,20 @@
          nBfnTot=nBfnTot+lJ
       End Do
       nA_Diag=nBfnTot
-      Call GetMem('A_Diag','Allo','Real',ipA_Diag,nA_Diag)
+      Call mma_allocate(A_Diag,nA_Diag,Label='A_Diag')
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *---  Compute entities for prescreening at shell level
 *
-      Call GetMem('TMax','Allo','Real',ipTMax,nSkal)
-      Call Allocate_Work(ip_Tmp,nSkal**2)
-      Call Shell_MxSchwz(nSkal,Work(ip_Tmp))
+      Call mma_allocate(TMax,nSkal,Label='TMax')
+      Call mma_allocate(Tmp,nSkal,nSkal,Label='Tmp')
+      Call Shell_MxSchwz(nSkal,Tmp)
 
-c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
+c     Call RecPrt('Tmp',' ',Tmp,nSkal,nSkal)
 
-      call dcopy_(nSkal,Work(ip_Tmp+(nSkal-1)*nSkal),1,Work(ipTMax),1)
-      Call Free_Work(ip_Tmp)
+      TMax(:)=Tmp(:,nSkal)
+      Call mma_deallocate(Tmp)
       TMax_all=Zero
       Do iS = 1, nSkal
          TMax_all=Max(TMax_all,TMax(iS))
@@ -135,7 +127,7 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
 *                                                                      *
 *     Preallocate some core for Seward!
 *
-      Call GetMem('MaxMem','Max','Real',iDummy,MemSew)
+      Call mma_maxDBLE(MemSew)
       MemLow=Min(MemSew/2,1024*128)
       MemSew=Max(MemSew/10,MemLow)
       Call xSetMem_Ints(MemSew)
@@ -151,7 +143,7 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
      &                  nMemAm(nShBF,nIrrep,nSkal-1,jS,iOffA,
      &                         .True.) )
       End Do
-      Call GetMem('Am','Allo','Real',ipTInt,nTInt)
+      Call mma_allocate(TInt,nTInt,Label='TInt')
 *                                                                      *
 ************************************************************************
 ************************************************************************
@@ -187,7 +179,7 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
 *        Initialize the buffer
 *
          nTInt_=nMemAm(nShBF,nIrrep,nSkal-1,jS,iOffA,.True.)
-         Call FZero(Work(ipTInt),nTInt_)
+         TInt(1:nTInt_)=Zero
 *                                                                      *
 *----------------------------------------------------------------------*
 *                                                                      *
@@ -197,8 +189,7 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
 *
             Aint=TMax(jS)*TMax(lS)
             If (AInt.lt.CutInt) Go To 14
-            Call Eval_IJKL(iS,jS,kS,lS,Work(ipTInt),nTInt_,
-     &                    Integral_WrOut)
+            Call Eval_IJKL(iS,jS,kS,lS,TInt,nTInt_,Integral_RI_2)
  14         Continue
 *
 *           Use a time slot to save the number of tasks and shell
@@ -216,25 +207,22 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
             mB = iOffA(2,iIrrep)           ! # of bf of shell jS
             If (mB.ne.0) Then
 *
-               ip_A_n=ipTInt + iOffA(1,iIrrep)
+               ip_A_n = 1 + iOffA(1,iIrrep)
                iAddr=iAddr_AQ(iIrrep) ! Disk address
 *
                nB = nBas_Aux(iIrrep)
                If (iIrrep.eq.0) nB = nB - 1 ! subtract dummy af
-               ip_Save = ip_A_n
                Do kCol = 1+kCol_Irrep(iIrrep), mB+kCol_Irrep(iIrrep)
 *
 *                 Write the A-vector to file
 *
-                  Call dDaFile(Lu_A(iIrrep),1,Work(ip_A_n),
-     &                         kCol,iAddr)
+                  Call dDaFile(Lu_A(iIrrep),1,TInt(ip_A_n),kCol,iAddr)
 
-                  ipAs_Diag=ipA_Diag+iOffA(3,iIrrep)+kCol-1
-                  Work(ipAs_Diag)=Work(ip_A_n+kCol-1)
-                  ipAs_Diag=ipAs_Diag+1
+                  ipAs_Diag=1+iOffA(3,iIrrep)+kCol-1
+                  A_Diag(ipAs_Diag)=TInt(ip_A_n+kCol-1)
                   nZero=nB-kCol
                   If (nZero.ne.0) Call dDaFile(Lu_A(iIrrep),0,
-     &                                         Work(ip_A_n),
+     &                                         TInt(ip_A_n),
      &                                         nZero,iAddr)
 *
                   ip_A_n = ip_A_n + kCol
@@ -255,8 +243,8 @@ c      Call RecPrt('ip_Tmp',' ',Work(ip_Tmp),nSkal,nSkal)
 *
       Call Free_iSD()
       Call xRlsMem_Ints
-      Call GetMem('Am', 'Free','Real',ipTInt,nTInt)
-      Call GetMem('TMax','Free','Real',ipTMax,nSkal)
+      Call mma_deallocate(TInt)
+      Call mma_deallocate(TMax)
       Call mma_deallocate(SO2Ind)
 *                                                                      *
 ************************************************************************
