@@ -44,7 +44,6 @@
 #include "print.fh"
 #include "real.fh"
 #include "stdalloc.fh"
-#include "WrkSpc.fh"
 #define _no_nShs_
 #include "iTOffs.fh"
       Real*8, Allocatable :: TInt(:), ADiag(:)
@@ -53,11 +52,6 @@
      &        In_Core, Out_of_Core, Only_DB, Do_RI_Basis, Do_ERIs
 *                                                                      *
 ************************************************************************
-*                                                                      *
-      iRout = 9
-      iPrint = nPrint(iRout)
-*                                                                      *
-************************************************************************
 *                                                                      *
 *     Temporary modifications to facilitate atomic calculations
 *
