@@ -25,18 +25,17 @@
       use pso_stuff
       use RICD_Info, only: Do_RI, Cholesky
       use Symmetry_Info, only: nIrrep
+      use Para_Info, only: myRank, nProcs
+      use Data_Structures, only: Deallocate_DSBA
+      use ExTerm, only: iMP2prpt, LuAVector, LuBVector
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
 #include "disp.fh"
 #include "print.fh"
-#include "para_info.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
 #include "real.fh"
 #include "exterm.fh"
-#include "chomp2g_alaska.fh"
 *#define _CD_TIMING_
 #ifdef _CD_TIMING_
 #include "temptime.fh"
@@ -48,6 +47,39 @@
       Logical Found
       Integer nAct(0:7)
       Real*8, Allocatable:: V_k_new(:,:), U_k_new(:)
+      Integer, Allocatable:: iZk(:), iVk(:), iUk(:)
+
+      Real*8, Allocatable:: DMTmp(:), Tmp(:)
+      Integer, Allocatable :: SO_ab(:), ij2(:,:)
+*                                                                      *
+************************************************************************
+*                                                                      *
+      Interface
+
+      Subroutine Compute_AuxVec(ipVk,ipZpk,myProc,nProc,ipUk)
+      Integer nProc, myProc
+      Integer ipVk(nProc), ipZpk(nProc)
+      Integer, Optional:: ipUk(nProc)
+      End Subroutine Compute_AuxVec
+
+      Subroutine Effective_CD_Pairs(ij2,nij_Eff)
+      Integer, Allocatable:: ij2(:,:)
+      Integer nij_Eff
+      End Subroutine Effective_CD_Pairs
+
+      SubRoutine Drvg1_2Center_RI(Grad,Temp,nGrad,ij2,nij_Eff)
+      Integer nGrad, nij_Eff
+      Real*8  Grad(nGrad), Temp(nGrad)
+      Integer, Allocatable :: ij2(:,:)
+      End SubRoutine Drvg1_2Center_RI
+
+      SubRoutine Drvg1_3Center_RI(Grad,Temp,nGrad,ij3,nij_Eff)
+      Integer nGrad, nij_Eff
+      Real*8  Grad(nGrad), Temp(nGrad)
+      Integer, Allocatable:: ij3(:,:)
+      End SubRoutine Drvg1_3Center_RI
+
+      End Interface
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -65,7 +97,7 @@
 ************************************************************************
 *                                                                      *
       Call FZero(Temp,nGrad)
-      Call Allocate_Work(ipTemp,nGrad)
+      Call mma_allocate(Tmp,nGrad,Label='Tmp')
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -129,7 +161,7 @@
 *                                                                      *
 *-----Prepare handling of two-particle density.
 *
-      Call PrepP
+      Call PrepP()
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -178,12 +210,11 @@
          m_Txy=nAdens
          Call mma_allocate(Txy,n_Txy,nAdens,Label='Txy')
          Call mma_allocate(DMdiag,nG1,nAdens,Label='DMdiag')
-         Call GetMem('Tmp','Allo','Real',ipDMtmp,nG1*(nG1+1)/2)
+         Call mma_allocate(DMtmp,nG1*(nG1+1)/2,Label='DMtmp')
          Call iZero(nnP,nIrrep)
-         Call Compute_txy(G1(1,1),nG1,Txy,
-     &                   n_Txy,nAdens,nIrrep,DMdiag,
-     &                   Work(ipDMtmp),nAct)
-         Call GetMem('Tmp','Free','Real',ipDMtmp,nG1*(nG1+1)/2)
+         Call Compute_txy(G1(1,1),nG1,Txy,n_Txy,nAdens,nIrrep,DMdiag,
+     &                    DMtmp,nAct)
+         Call mma_deallocate(DMtmp)
       Else
          Call mma_allocate(Txy,1,1,Label='Txy')
          Call mma_allocate(DMdiag,1,1,Label='DMdiag')
@@ -195,17 +226,21 @@
       Do i=0,nIrrep-1
          iOff_ij2K(i+1) = n_ij2K
          n_ij2K = n_ij2K + nBas(i)*(nBas(i)+1)/2
-         nZ_p_k = nZ_p_k + nnP(i)*nBas_Aux(i)
-         nZ_p_l = nZ_p_l + nnP(i)*NumCho(i+1)
+         nZ_p_k = nZ_p_k + nnP(i)*nBas_Aux(i)         ! Global size
+         nZ_p_l = nZ_p_l + nnP(i)*NumCho(i+1)         ! Local size
          nZ_p_k_New = nZ_p_k_New + nnP(i)*nBas(i)*(nBas(i)+1)/2
       End Do
       If (Do_RI) nZ_p_k=nZ_p_k-nnP(0)
+
+*     Allocate the "global" Z_p_k array
+
       If (lPSO) Then
-         Call mma_allocate(Z_p_k,nZ_p_k,nAvec,Label='Z_p_k')
-         Z_p_k(:,:)=Zero
+         Call mma_allocate(Z_p_k,nZ_p_k,nAVec,Label='Z_p_k')
       Else
-         Call mma_allocate(Z_p_k,1,1,Label='Z_p_k')
+         nZ_p_k=1
+         Call mma_allocate(Z_p_k,1,nAVec,Label='Z_p_k')
       EndIf
+      Z_p_k(:,:)=Zero
 *
 *     Preprocess the RI and Q vectors as follows
 *
@@ -235,50 +270,58 @@
 *
 *     Note: the above two points apply to Z_p_k as well (active space)
 *
-      Call GetMem('iVk','Allo','Inte',iVk,nProcs)
-      Call GetMem('iZk','Allo','Inte',iZk,nProcs)
-      Call IZero(iWork(iVk),nProcs)
-      Call IZero(iWork(iZk),nProcs)
-      iWork(iVk+myRank) = NumCho(1)*nJdens
-      iWork(iZk+myRank) = nZ_p_l*nAvec
-      Call GAIGOP(iWork(iVk),nProcs,'+')
-      Call GAIGOP(iWork(iZk),nProcs,'+')
+      Call mma_allocate(iVk,[0,nProcs-1],Label='iVk')
+      Call mma_allocate(iZk,[0,nProcs-1],Label='iZk')
+      iVk(:)=0
+      iZk(:)=0
+*     iVk(myRank) = NumCho(1)*nJdens
+      iVk(myRank) = NumCho(1)
+*     iZk(myRank)= nZ_p_l*nAvec           ! store the local size of Zk
+      iZk(myRank)= nZ_p_l                 ! store the local size of Zk
+      Call GAIGOP(iVk,nProcs,'+')
+      Call GAIGOP(iZk,nProcs,'+')           ! distribute to all nodes
+
+!     Compute the starting position in the global sense for each node.
+
       iStart=1
       jStart=1
-      Do j=0,nProcs-1
-         itmp=iWork(iVk+j)
-         iWork(iVk+j)=iStart
+      Do j=0,nProcs-1    !  Loop over all nodes
+         itmp=iVk(j)
+         iVk(j)=iStart
          iStart = iStart + itmp
-         jtmp=iWork(iZk+j)
-         iWork(iZk+j)=jStart
+
+         jtmp=iZk(j)
+         iZk(j)=jStart
          jStart = jStart + jtmp
       End Do
 *
       If(iMp2prpt .eq. 2) Then
-         Call GetMem('iUk','Allo','Inte',iUk,nProcs)
-         Call IZero(iWork(iUk),nProcs)
-         iWork(iUk+myRank) = NumCho(1)
-         Call GAIGOP(iWork(iUk),nProcs,'+')
+         Call mma_allocate(iUk,[0,nProcs-1],Label='iUk')
+         iUk(:)=0
+         iUk(myRank) = NumCho(1)
+         Call GAIGOP(iUk,nProcs,'+')
          kStart=1
          Do j = 0,nProcs-1
-            kTmp=iWork(iUk+j)
-            iWork(iUk+j)=kStart
+            kTmp=iUk(j)
+            iUk(j)=kStart
             kStart = kStart + kTmp
          End Do
-      Else
-         iUk = ip_iDummy
-      End If
 *
-      Call Compute_AuxVec(iWork(iVk),iWork(iUk),iwork(iZk),
-     &                    myRank+1,nProcs)
+         Call Compute_AuxVec(iVk,iZk,myRank+1,nProcs,ipUk=iUk)
+
+      Else
+
+         Call Compute_AuxVec(iVk,iZk,myRank+1,nProcs)
+
+      End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
 
       If (Cholesky.and..Not.Do_RI) Then
 *
-*              Map from Cholesky auxiliary basis to the full
-*              1-center valence product basis.
+*        Map from Cholesky auxiliary basis to the full
+*        1-center valence product basis.
 *
          Call mma_allocate(ij2K,n_ij2K,Label='ij2K')
          ij2K(:)=0
@@ -292,22 +335,20 @@
          End If
 
 *
-         Call GetMem('SO_ab','Allo','INTE',ipSO_ab,2*nAux_Tot)
-         Call IZero(iWork(ipSO_ab),2*nAux_Tot)
-         iOff = 0
+         Call mma_allocate(SO_ab,2*nAux_Tot,Label='SO_ab')
+         SO_ab(:)=0
+         iOff = 1
          Do iSym = 1, nSym
-            ip_List_rs=ip_InfVec+MaxVec*InfVec_N2*(iSym-1)
-            Call CHO_X_GET_PARDIAG(iSym,ip_List_rs,iWork(ipSO_ab+iOff))
+            Call CHO_X_GET_PARDIAG(iSym,SO_ab(iOff))
 
             If((iSym .eq. 1) .and. (iMp2prpt .eq. 2)) Then
-               Call ReMap_U_k(U_k,nV_k,U_k_New,nV_k_New,
-     &                        iWork(ipSO_ab))
+               Call ReMap_U_k(U_k,nV_k,U_k_New,nV_k_New,SO_ab)
             End If
             m_ij2K = nBas(iSym-1)*(nBas(iSym-1)+1)/2
             Do i=0,nJDens-1
               Call ReMap_V_k(iSym,V_k(1,1+i),nV_k,
      &                     V_k_new(1,1+i),nV_k_New,
-     &                     iWork(ipSO_ab+iOff),ij2K(iOff_ij2K(iSym)+1),
+     &                     SO_ab(iOff),ij2K(iOff_ij2K(iSym)+1),
      &                     m_ij2K)
             EndDo
             iOff = iOff + 2*nBas_Aux(iSym-1)
@@ -315,7 +356,7 @@
 *
          nV_k=nV_k_new
 *
-         Call Free_iWork(ipSO_ab)
+         Call mma_deallocate(SO_ab)
          Call mma_deallocate(V_k)
          Call mma_allocate(V_k,nV_k,nJdens,Label='V_k')
          V_k(:,:)=V_k_new(:,:)
@@ -333,9 +374,8 @@
 *                                                                      *
 *        Get the effective list of shell-pairs in case of CD
 *
-         Call Effective_CD_Pairs(ip_ij2,nij_Eff)
+         Call Effective_CD_Pairs(ij2,nij_Eff)
       Else
-         ip_ij2 = ip_iDummy
          nij_Eff = 0
       End If
 *                                                                      *
@@ -380,13 +420,13 @@
 *     Compute contributions due to the "2-center" two-electron integrals
 *
       Case_2C=.True.
-      Call Drvg1_2center_RI(Temp,Work(ipTemp),nGrad,ip_ij2,nij_Eff)
-      Call GADGOP(Work(ipTemp),nGrad,'+')
+      Call Drvg1_2center_RI(Temp,Tmp,nGrad,ij2,nij_Eff)
+      Call GADGOP(Tmp,nGrad,'+')
       If (iPrint.ge.15) Call PrGrad(
      &    ' RI-Two-electron contribution - 2-center term',
-     &    Work(ipTemp),nGrad,ChDisp,iPrint)
+     &    Tmp,nGrad,ChDisp,iPrint)
       Call DaXpY_(nGrad,One,Temp,1,Grad,1) ! Move any 1-el contr.
-      call dcopy_(nGrad,Work(ipTemp),1,Temp,1)
+      call dcopy_(nGrad,Tmp,1,Temp,1)
       Call DScal_(nGrad,-One,Temp,1)
       Case_2C=.False.
 *                                                                      *
@@ -395,16 +435,21 @@
 *     Compute contributions due to the "3-center" two-electron integrals
 *
       Case_3C=.True.
-      Call Drvg1_3center_RI(Temp,Work(ipTemp),nGrad,ip_ij2,nij_Eff)
-      Call GADGOP(Work(ipTemp),nGrad,'+')
+      Call Drvg1_3center_RI(Temp,Tmp,nGrad,ij2,nij_Eff)
+      Call GADGOP(Tmp,nGrad,'+')
       If (iPrint.ge.15) Call PrGrad(
      &    ' RI-Two-electron contribution - 3-center term',
-     &    Work(ipTemp),nGrad,ChDisp,iPrint)
-      Call DaXpY_(nGrad,Two,Work(ipTemp),1,Temp,1)
+     &    Tmp,nGrad,ChDisp,iPrint)
+      Call DaXpY_(nGrad,Two,Tmp,1,Temp,1)
       Case_3C=.False.
       If(Allocated(Txy))  Call mma_deallocate(Txy)
       If(Allocated(DMdiag))  Call mma_deallocate(DMdiag)
-      Call GetMem('AOrb','Free','Real',ipAOrb(0,1),mAO*nADens)
+      If (Allocated(AOrb)) Then
+         Do iADens = 1, nADens
+            Call Deallocate_DSBA(AOrb(iADens))
+         End Do
+         deallocate(AOrb)
+      End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -425,22 +470,24 @@
 
 
       If (Cholesky.and..Not.Do_RI) Then
-         Call Free_iWork(ip_ij2)
+         Call mma_deallocate(ij2)
          Call mma_deallocate(ij2K)
       End If
       Call CloseP
-      Call Free_iWork(iZk)
-      Call Free_iWork(iVk)
-      If(iMp2prpt .eq. 2) Call Free_iWork(iUk)
+      Call mma_deallocate(iZk)
+      Call mma_deallocate(iVk)
+
+      If (Allocated(iUk))   Call mma_deallocate(iUk)
       If (Allocated(Z_p_k)) Call mma_deallocate(Z_p_k)
-      If (Allocated(V_k)) Call mma_deallocate(V_k)
-      If (Allocated(U_k)) Call mma_deallocate(U_k)
+      If (Allocated(V_k))   Call mma_deallocate(V_k)
+      If (Allocated(U_k))   Call mma_deallocate(U_k)
+
       Call Cho_X_Final(irc)
       If (irc.ne.0) Then
          Call WarningMessage(2,' Drvg1_RI: Cho_X_Final failed')
          Call Abend()
       End If
-      Call Free_Work(ipTemp)
+      Call mma_deallocate(Tmp)
       If (iPrint.ge.15)  Call PrGrad(
      &    ' RI-Two-electron contribution - Temp',
      &    Temp,nGrad,ChDisp,iPrint)
