@@ -29,12 +29,10 @@
       use Basis_Info, only: nBas
       use SOAO_Info, only: iAOtSO
       use Symmetry_Info, only: nIrrep
+      use sort_data, only: nSkip
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "print.fh"
-#include "srt0.fh"
-#include "srt1.fh"
-#include "WrkSpc.fh"
 *
       Real*8 SOint(ijkl,nSOint), TInt(nTInt)
       Integer iCmp(4), iShell(4), iAO(4), iOffA(4,0:7),
@@ -53,15 +51,12 @@
       iTri(i,j)=Max(i,j)*(Max(i,j)-1)/2 + Min(i,j)
 *                                                                      *
 ************************************************************************
-*                                                                      *
-      irout = 39
-      iprint = nprint(irout)
-*                                                                      *
-************************************************************************
 *                                                                      *
       k12=0
       k34=0
 #ifdef _DEBUGPRINT_
+      irout = 39
+      iprint = nprint(irout)
       If (iPrint.ge.49) Then
          r1=DDot_(ijkl*nSOInt,SOInt,1,[One],0)
          r2=DDot_(ijkl*nSOInt,SOInt,1,SOInt,1)
