@@ -67,7 +67,7 @@
      &                                   Keep_Shell)
          External Integral_RICD
          Real*8 ThrAO
-         Integer iCnttp, jCnttp, nTInc, Lu_A, ijS_req, Keep_Shell
+         Integer iCnttp, jCnttp, nTInt, Lu_A, ijS_req, Keep_Shell
          Logical In_Core
          Real*8, Allocatable :: TInt(:), ADiag(:)
          End Subroutine
@@ -300,7 +300,7 @@
 *
       Else    ! out-of-core part
 *
-         Call GetMem('Scr','Max','Real',iDum,lScr)
+         Call mma_maxDBLE(lScr)
          lScr=Min(lScr-2*nTInt_c,nTInt_c**2+3*nTInt_c)
          Call mma_Allocate(Scr,lScr,label='Scr')
 *
