@@ -26,15 +26,16 @@
       use Sizes_of_Seward, only: S
       use RICD_Info, only: iRI_Type
       use Logical_Info, only: UnNorm
+      use Gateway_Interfaces, only: GetBS
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
 #include "stdalloc.fh"
-#include "WrkSpc.fh"
 #include "real.fh"
 #include "print.fh"
       Logical Hit, IfTest
       Character*13 DefNm
-      Character*80 Ref(2), BSLbl, BSLB*180
+      Character*180 Ref(2), BSLB
+      Character*80 BSLbl
       Character*80 atom,type,author,basis,CGTO, Aux
       Character*80 atomb
       Character *256 Basis_lib, Fname
@@ -43,20 +44,13 @@
       External Get_Ln
       Integer StrnLn
       External StrnLn
-      Logical Quit_On_Error
-      common /getlnQOE/ Quit_On_Error
+#include "getlnqoe.fh"
       Character*180 Get_Ln_Quit
 
       Integer BasisTypes(4)
       Data DefNm/'basis_library'/
 *                                                                      *
 ************************************************************************
-*                                                                      *
-      Interface
-#include "getbs_interface.fh"
-      End Interface
-*                                                                      *
-************************************************************************
 *                                                                      *
       iRout = 2
       iPrint = nPrint(iRout)
@@ -176,8 +170,8 @@
          If (Show.and.iPrint.ge.6 .and.
      &      Ref(1).ne.'' .and. Ref(2).ne.'') Then
             Write (6,'(1x,a)')  'Basis Set Reference(s):'
-            If (Ref(1).ne.'') Write (6,'(5x,a)') Ref(1)
-            If (Ref(2).ne.'') Write (6,'(5x,a)') Ref(2)
+            If (Ref(1).ne.'') Write (6,'(5x,a)') Trim(Ref(1))
+            If (Ref(2).ne.'') Write (6,'(5x,a)') Trim(Ref(2))
             Write (6,*)
             Write (6,*)
          End If
@@ -371,9 +365,7 @@
                Call mma_allocate(Shells(iShll)%Cff_p,nPrim,nPrim,2,
      &                           Label='Cff_p')
                iEnds= iEnd
-               iEnds= iEnds
-               iEndc = iStrt - 1
-               iEnd  = iStrt - 1
+               iEnd = iStrt - 1
 *              Read contraction coefficients
 *              Observe that the matrix will have nPrim rows and
 *              nCntrc columns
