@@ -35,24 +35,23 @@
       use Basis_Info, only: nBas
       use SOAO_Info, only: iAOtSO
       use pso_stuff, only: nnP, lPSO, lsa, DMdiag, nPos
+      use ExTerm, only: CijK, AMP2, iMP2prpt, nAuxVe, LuAVector, A
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
-#include "print.fh"
-#include "WrkSpc.fh"
 #include "exterm.fh"
-#include "chomp2g_alaska.fh"
       Real*8 PAO(ijkl,nPAO), V_K(mV_K,nSA), U_K(mV_K),
      &       Z_p_K(nnP(0),mV_K,*)
       Integer iAO(4), kOp(4), iAOst(4), iCmp(4)
-      Integer ip_CikJ_(2)
       Logical Shijij,Found
+
+      Real*8, Pointer:: V2(:)=>Null()
+      Real*8, Pointer:: CiKj(:,:)=>Null()
+      Real*8, Pointer:: CiKl(:)=>Null()
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *#define _DEBUGPRINT_
 #ifdef _DEBUGPRINT_
-      iRout = 39
-      iPrint = nPrint(iRout)
       Do i=1,nSA
          Call RecPrt('PGet1_RI2: V_k',' ',V_k(1,i),1,mV_k)
       End Do
@@ -66,8 +65,6 @@
 *
 *
       Call CWTime(Cpu1,Wall1)
-*
-      nMaxBas = Max(lBas,jBas)
 *
       If (Min(lBas,jBas) .eq.0) Return
 *
@@ -75,8 +72,6 @@
       PMax=Zero
       iPAO=0
       iOffA=nBas(0)
-*
-      ip_V2 = 0
 *
       Call Qpg_iScalar('SCF mode',Found)
       If (Found) Then
@@ -141,18 +136,24 @@
          iSym = 1
          lSym = iEor(jSym-1,iSym-1)+1
 *
-         ip_CikJ = ip_CijK
+         nik = nIJ1(iSym,kSym,iSO)
+
+         n = nik*jBas
+         iS = 1
+         iE = n
+         CiKj(1:n,1:1) => CijK(iS:iE)
+         n = nik*lBas
+         iS = iE + 1
+         iE = iE + n
+         CiKl(1:n) => CijK(iS:iE)
 *
          Do i2 = 1, iCmp(2)
             jSO = iAOtSO(iAO(2)+i2,kOp(2))+iAOst(2)
 *
 *           Pick up the MO transformed fitting coefficients, C_ik^J
-            nik = nIJ1(iSym,kSym,iSO)
-            ip_CikL = ip_CikJ + nik*nMaxBas
             jSOj = jSO - iOffA
             iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,1)
-            Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikJ),
-     &                   nik*jBas,iAdrJ)
+            Call dDaFile(LuCVector(jSym,1),2,CikJ(:,1),nik*jBas,iAdrJ)
 
             Do i4 = 1, iCmp(4)
                lSO = iAOtSO(iAO(4)+i4,kOp(4))+iAOst(4)
@@ -163,21 +164,18 @@
                If (lSO.ne.jSO) Then
                   lSOl = lSO - iOffA
                   iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,1)
-                  Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikL),
-     &                         nik*lBas,iAdrL)
+                  Call dDaFile(LuCVector(jSym,1),2,CiKl,nik*lBas,iAdrL)
 
-                  ip_V2 = ip_CikL
+                  V2(1:)=>CiKl(1:)
                Else
-                  ip_V2 = ip_CikJ
+                  V2(1:)=>CiKj(1:,1)
                EndIf
 
-               Call FZero(Work(ip_A),jBas*lBas)
+               A(1:jBas*lBas)=Zero
                CALL DGEMM_('T','N',jBas,lBas,nik,
-     &                    1.0d0,Work(ip_CikJ),nik,
-     &                    Work(ip_V2),nik,
-     &                    0.0d0,Work(ip_A),jBas)
-*              Call RecPrt('A_JK',' ',Work(ip_A),
-*    &                     jBas,lBas)
+     &                    1.0d0,CiKj,nik,
+     &                          V2,nik,
+     &                    0.0d0,A,jBas)
 
                Do lAOl = 0, lBas-1
                   lSOl = lSO + lAOl - iOffA
@@ -186,7 +184,7 @@
                      nijkl = nijkl + 1
 
                      temp = CoulFac*V_K(jSOj,1)*V_K(lSOl,1)
-                     temp = temp - ExFac*Work(ip_A+nijkl-1)
+                     temp = temp - ExFac*A(nijkl)
 *
                      PMax = Max(PMax,Abs(temp))
                      PAO(nijkl,iPAO) = Fac*temp
@@ -207,59 +205,62 @@
          kSym = jSym
          iSym = 1
          lSym = iEor(jSym-1,iSym-1)+1
+         nik1= nIJ1(iSym,kSym,1)
+         nik2= nIJ1(iSym,kSym,2)
+         nik = Max(nik1,nik2)
 *
-         ip_CikJ_(1) = ip_CijK
+         n = nik * jBas
+         iS = 1
+         iE = n * 2
+         CiKj(1:n,1:2) => CijK(iS:iE)
 *
          Do i2 = 1, iCmp(2)
             jSO = iAOtSO(iAO(2)+i2,kOp(2))+iAOst(2)
             jSOj = jSO - iOffA
 *
 *           Pick up the MO transformed fitting coefficients, C_ik^J
-            nik = nIJ1(iSym,kSym,1)
-            If (nik.ne.0) Then
-              iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,1)
-              Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikJ_(1)),
-     &                     nik*jBas,iAdrJ)
+            If (nik1.ne.0) Then
+              iAdrJ = nik1*(jSOj-1) + iAdrCVec(jSym,iSym,1)
+              Call dDaFile(LuCVector(jSym,1),2,CiKj(:,1),nik1*jBas,
+     &                     iAdrJ)
             EndIf
 *
-            ip_CikJ_(2)=ip_CikJ_(1)+nik*nMaxBas
-            nik = nIJ1(iSym,kSym,2)
-            If (nik.ne.0) Then
-              iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,2)
-*
-              Call dDaFile(LuCVector(jSym,2),2,Work(ip_CikJ_(2)),
-     &                  nik*jBas,iAdrJ)
+            If (nik2.ne.0) Then
+              iAdrJ = nik2*(jSOj-1) + iAdrCVec(jSym,iSym,2)
+              Call dDaFile(LuCVector(jSym,2),2,CikJ(:,2),nik2*jBas,
+     &                     iAdrJ)
             EndIf
 *
-            ip_CikL = ip_CikJ_(nKVec) + nik*nMaxBas
-
             Do i4 = 1, iCmp(4)
                lSO = iAOtSO(iAO(4)+i4,kOp(4))+iAOst(4)
 *
                iPAO = iPAO + 1
                nijkl = 0
 
-               Factor=0.0d0
-               Call FZero(Work(ip_A),jBas*lBas)
+               Factor=Zero
+               A(1:jBas*lBas)=Zero
                Do iSO=1,nKVec
                  nik = nIJ1(iSym,kSym,iSO)
-                 If (nik.ne.0) Then
-                   If (lSO.ne.jSO) Then
-                      lSOl = lSO - iOffA
-                      iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,iSO)
-                      Call dDaFile(LuCVector(jSym,iSO),2,Work(ip_CikL),
-     &                             nik*lBas,iAdrL)
-                      ip_V2 = ip_CikL
-                   Else
-                      ip_V2 = ip_CikJ_(iSO)
-                   EndIf
-*
-                   CALL DGEMM_('T','N',jBas,lBas,nik,
-     &                         1.0d0,Work(ip_CikJ_(iSO)),nik,
-     &                         Work(ip_V2),nik,
-     &                         Factor,Work(ip_A),jBas)
-                    Factor=1.0d0
+
+                 CiKl(1:nik*lBas) => CijK(iE+1:iE+nik*lBas)
+
+                 If (nik==0) Cycle
+
+                 If (lSO.ne.jSO) Then
+                    lSOl = lSO - iOffA
+                    iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,iSO)
+                    Call dDaFile(LuCVector(jSym,iSO),2,CiKl,nik*lBas,
+     &                           iAdrL)
+                    V2(1:) => CiKl(1:)
+                 Else
+                    V2(1:) => CiKj(1:,iSO)
                  EndIf
+*
+                 CALL DGEMM_('T','N',jBas,lBas,nik,
+     &                       1.0d0,CikJ(:,iSO),nik,
+     &                             V2,nik,
+     &                       Factor,A,jBas)
+                 Factor=1.0d0
                End Do
 
                Do lAOl = 0, lBas-1
@@ -269,7 +270,7 @@
                      nijkl = nijkl + 1
 
                      temp = CoulFac*V_K(jSOj,1)*V_K(lSOl,1)
-                     temp = temp - 2.0d0*ExFac*Work(ip_A+nijkl-1)
+                     temp = temp - 2.0d0*ExFac*A(nijkl)
 *
                      PMax = Max(PMax,Abs(temp))
                      PAO(nijkl,iPAO) = Fac*temp
@@ -293,18 +294,21 @@
          iSym = 1
          lSym = iEor(jSym-1,iSym-1)+1
 *
-         ip_CikJ = ip_CijK
+         nik = nIJ1(iSym,kSym,iSO)
+         iS = 1
+         iE = nik*jBas
+         CiKj(1:nik*jBas,1:1) => CijK(iS:iE)
+         iS = iE + 1
+         iE = iE + nik*lBas
+         CiKl(1:nik*lBas) => CijK(iS:iE)
 *
          Do i2 = 1, iCmp(2)
             jSO = iAOtSO(iAO(2)+i2,kOp(2))+iAOst(2)
 *
 *           Pick up the MO transformed fitting coefficients, C_ik^J
-            nik = nIJ1(iSym,kSym,iSO)
-            ip_CikL = ip_CikJ + nik*nMaxBas
             jSOj = jSO - iOffA
             iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,1)
-            Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikJ),
-     &                   nik*jBas,iAdrJ)
+            Call dDaFile(LuCVector(jSym,1),2,CiKj(:,1),nik*jBas,iAdrJ)
 
             Do i4 = 1, iCmp(4)
                lSO = iAOtSO(iAO(4)+i4,kOp(4))+iAOst(4)
@@ -315,19 +319,18 @@
                If (lSO.ne.jSO) Then
                   lSOl = lSO - iOffA
                   iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,1)
-                  Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikL),
-     &                         nik*lBas,iAdrL)
+                  Call dDaFile(LuCVector(jSym,1),2,CiKl,nik*lBas,iAdrL)
 
-                  ip_V2 = ip_CikL
+                  V2(1:) => CiKl(1:)
                Else
-                  ip_V2 = ip_CikJ
+                  V2(1:) => CiKj(1:,1)
                EndIf
 
-               Call FZero(Work(ip_A),jBas*lBas)
+               A(1:jBas*lBas)=Zero
                CALL DGEMM_('T','N',jBas,lBas,nik,
-     &                    1.0d0,Work(ip_CikJ),nik,
-     &                    Work(ip_V2),nik,
-     &                    0.0d0,Work(ip_A),jBas)
+     &                    1.0d0,CiKj(:,1),nik,
+     &                          V2,nik,
+     &                    0.0d0,A,jBas)
 
                Do lAOl = 0, lBas-1
                   lSOl = lSO + lAOl - iOffA
@@ -336,7 +339,7 @@
                      nijkl = nijkl + 1
 
                      temp = CoulFac*V_K(jSOj,1)*V_K(lSOl,1)
-                     temp = temp - ExFac*Work(ip_A+nijkl-1)
+                     temp = temp - ExFac*A(nijkl)
 *
 *----- Active space contribution
                      temp2=0.0d0
@@ -367,78 +370,87 @@
          iSym = 1
          lSym = iEor(jSym-1,iSym-1)+1
 *
-         ip_CikJ_(1) = ip_CijK
+         nik1= nIJ1(iSym,kSym,1)
+         nik2= nIJ1(iSym,kSym,2)
+         nik = Max(nik1,nik2)
+
+         iS = 1
+         iE = 2 * nik * jBas
+         CiKj(1:nik*jBas,1:2) => CijK(iS:iE)
 *
          Do i2 = 1, iCmp(2)
             jSO = iAOtSO(iAO(2)+i2,kOp(2))+iAOst(2)
             jSOj = jSO - iOffA
 *
 *           Pick up the MO transformed fitting coefficients, C_ik^J
-            nik = nIJ1(iSym,kSym,1)
-            If (nik.ne.0) Then
-              iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,1)
-              Call dDaFile(LuCVector(jSym,1),2,Work(ip_CikJ_(1)),
-     &                     nik*jBas,iAdrJ)
+            If (nik1.ne.0) Then
+              iAdrJ = nik1*(jSOj-1) + iAdrCVec(jSym,iSym,1)
+              Call dDaFile(LuCVector(jSym,1),2,CikJ(:,1),nik1*jBas,
+     &                     iAdrJ)
             EndIf
 *
-            ip_CikJ_(2)=ip_CikJ_(1)+nik*nMaxBas
-            nik = nIJ1(iSym,kSym,2)
-            If (nik.ne.0) Then
-              iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,2)
+            If (nik2.ne.0) Then
+              iAdrJ = nik2*(jSOj-1) + iAdrCVec(jSym,iSym,2)
 *
-              Call dDaFile(LuCVector(jSym,2),2,Work(ip_CikJ_(2)),
-     &                  nik*jBas,iAdrJ)
+              Call dDaFile(LuCVector(jSym,2),2,CikJ(:,2),nik2*jBas,
+     &                     iAdrJ)
             EndIf
 *
-            ip_CikL = ip_CikJ_(nKVec) + nik*nMaxBas
-
             Do i4 = 1, iCmp(4)
                lSO = iAOtSO(iAO(4)+i4,kOp(4))+iAOst(4)
 *
                iPAO = iPAO + 1
                nijkl = 0
 
-               Factor=0.0d0
-               Call FZero(Work(ip_A),jBas*lBas)
+               Factor=Zero
+               A(1:jBas*lBas)=Zero
 
                Do iSO=1,nKVec
                  nik = nIJ1(iSym,kSym,iSO)
-                 If (nik.ne.0) Then
-                   If (lSO.ne.jSO) Then
-                      lSOl = lSO - iOffA
-                      iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,iSO)
-                      Call dDaFile(LuCVector(jSym,iSO),2,Work(ip_CikL),
-     &                             nik*lBas,iAdrL)
-                      ip_V2 = ip_CikL
-                   Else
-                      ip_V2 = ip_CikJ_(iSO)
-                   EndIf
+
+                 CiKl(1:nik*lBas) => CijK(iE+1:iE+nik*lBas)
+
+                 If (nik==0) Cycle
+
+                 If (lSO.ne.jSO) Then
+                    lSOl = lSO - iOffA
+                    iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,iSO)
+                    Call dDaFile(LuCVector(jSym,iSO),2,CikL,nik*lBas,
+     &                           iAdrL)
+                    V2(1:) => CiKl(1:)
+                 Else
+                    V2(1:) => CiKj(1:,iSO)
+                 EndIf
 *
 ** Here one should keep track of negative eigenvalues of the densities
 *
-                   iSO2=iSO+2
+                 iSO2=iSO+2
 *
-                   Do l=0,lBas-1
-                     Do k=0,jBas-1
-                       tmp=0.0d0
-                       Do i=0,nChOrb(0,iSO)-1
-                          Do j=0,npos(0,iSO)-1
-                             tmp=tmp+
-     &                 Work(ip_CikJ_(iSO)+i*nChOrb(0,iSO2)+j+k*nik)*
-     &                 Work(ip_V2+i*nChOrb(0,iSO2)+j+l*nik)
-                          End Do
-                          Do j=npos(0,iSO),nChOrb(0,iSO2)-1
-                             tmp=tmp-
-     &                 Work(ip_CikJ_(iSO)+i*nChOrb(0,iSO2)+j+k*nik)*
-     &                 Work(ip_V2+i*nChOrb(0,iSO2)+j+l*nik)
-                          End Do
-                       End Do
-                       Work(ip_A+l*jBas+k)=
-     &                   Factor*Work(ip_A+l*jBas+k)+tmp
+                 Do l=1,lBas
+                   Do k=1,jBas
+
+                     tmp=0.0d0
+
+                     Do i=1,nChOrb(0,iSO)
+                        Do j=1,nChOrb(0,iSO2)
+
+                           jik = j + nChOrb(0,iSO2)*(i-1) + nik*(k-1)
+                           jil = j + nChOrb(0,iSO2)*(i-1) + nik*(l-1)
+                           If (j<=npos(0,iSO)) Then
+                              tmp = tmp + CiKj(jik,iSO)* V2(jil)
+                           Else
+                              tmp = tmp - CiKj(jik,iSO)* V2(jil)
+                           End If
+                        End Do
                      End Do
+
+                     kl = k + jBas*(l-1)
+                     A(kl)= Factor*A(kl)+tmp
+
                    End Do
-                   Factor=1.0d0
-                 EndIf
+                 End Do
+                 Factor=1.0d0
+
                End Do
 
                Do lAOl = 0, lBas-1
@@ -453,7 +465,7 @@
      &                             V_K(lSOl,4)*V_K(jSOj,3)+
      &                             V_K(lSOl,1)*V_K(jSOj,5)+
      &                             V_K(lSOl,5)*V_K(jSOj,1))
-                     temp = temp - ExFac*Work(ip_A+nijkl-1)
+                     temp = temp - ExFac*A(nijkl)
 *
 *----- Active space contribution
                      temp2=0.0d0
@@ -491,14 +503,16 @@
 
          nik = nIJ1(iSym,lSym,iSO)
 
-         ip_CijK2 = ip_CijK + nik*nMaxBas
+         iS = 1
+         iE = nik * Max(jBas,lBas) * 2
+         CiKj(1:nik * Max(jBas,lBas),1:2) => CijK(iS:iE)
+
          Do i2 = 1, iCmp(2)
             jSO = iAOtSO(iAO(2)+i2,kOp(2))+iAOst(2)
 
             jSOj = jSO - iOffA
             iAdrJ = nik*(jSOj-1) + iAdrCVec(jSym,iSym,1)
-            Call dDaFile(LuCVector(jSym,1),2,Work(ip_CijK),
-     &                   nik*jBas,iAdrJ)
+            Call dDaFile(LuCVector(jSym,1),2,CiKj(:,1),nik*jBas,iAdrJ)
 
             Do i4 = 1, iCmp(4)
                lSO = iAOtSO(iAO(4)+i4,kOp(4))+iAOst(4)
@@ -508,21 +522,19 @@
                If (lSO.ne.jSO) Then
                   lSOl = lSO - iOffA
                   iAdrL = nik*(lSOl-1) + iAdrCVec(jSym,iSym,1)
-                  Call dDaFile(LuCVector(jSym,1),2,Work(ip_CijK2),
-     &                         nik*lBas,iAdrL)
+                  Call dDaFile(LuCVector(jSym,1),2,CiKj(:,2),nik*lBas,
+     &                         iAdrL)
 
-                  ip_V2 = ip_CijK2
+                  V2(1:) => CiKj(1:,2)
                Else
-                  ip_V2=ip_CijK
+                  V2(1:) => CiKj(1:,1)
                EndIf
 
-               Call FZero(Work(ip_A),jBas*lBas)
+               A(1:jBas*lBas)=Zero
                CALL DGEMM_('T','N',jBas,lBas,nik,
-     &                    1.0d0,Work(ip_CijK),nik,
-     &                    Work(ip_V2),nik,
-     &                    0.0d0,Work(ip_A),jBas)
-*              Call RecPrt('A_JK',' ',Work(ip_A),
-*    &                     jBas,lBas)
+     &                    1.0d0,CiKj(:,1),nik,
+     &                          V2,nik,
+     &                    0.0d0,A,jBas)
 *
                Do lAOl = 0, lBas-1
                   lSOl = lSO + lAOl - iOffA
@@ -534,11 +546,9 @@
 *
                   lTot = jBas
                   iAdrA = nAuxVe*(lSOl-1) + (jSO - iOffA)
-                  Call dDaFile(LuAVector(1),2,Work(ip_A_MP2(1)),
-     &                         lTot,iAdrA)
+                  Call dDaFile(LuAVector(1),2,AMP2(:,1),lTot,iAdrA)
                   iAdrA = nAuxVe*(lSOl-1) + (jSO - iOffA)
-                  Call dDaFile(LuAVector(2),2,Work(ip_A_MP2(2)),
-     &                         lTot,iAdrA)
+                  Call dDaFile(LuAVector(2),2,AMP2(:,2),lTot,iAdrA)
 *
                   Do jAOj = 0, jBas-1
                      jSOj = jSO + jAOj - iOffA
@@ -547,12 +557,12 @@
                      temp = CoulFac*V_K(jSOj,1)*V_K(lSOl,1)
      &                    + CoulFac*V_K(jSOj,1)*U_K(lSOl)
      &                    + CoulFac*U_K(jSOj)*V_K(lSOl,1)
-     &                    - ExFac*Work(ip_A+nijkl-1)
+     &                    - ExFac*A(nijkl)
 *
-                     tempJ_mp2=Work(ip_A_MP2(2)+jAOj)
+                     tempJ_mp2=AMP2(1+jAOj,2)
                      temp = temp + tempJ_mp2*CoulFac
 *
-                     tempK_mp2=Work(ip_A_MP2(1)+jAOj)
+                     tempK_mp2=AMP2(1+jAOj,1)
                      temp = temp - ExFac*half*tempK_mp2
 *
                      PMax = Max(PMax,Abs(temp))
@@ -565,6 +575,10 @@
 ************************************************************************
 *                                                                      *
       End If
+
+      CiKj => Null()
+      CiKl => Null()
+      V2   => Null()
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -575,7 +589,6 @@
 *
 #ifdef _DEBUGPRINT_
       Call RecPrt(' In PGet1_RI2:PAO ',' ',PAO,ijkl,nPAO)
-      Call GetMem(' Exit PGet1_RI2','CHECK','REAL',iDum,iDum)
 #endif
       Call CWTime(Cpu2,Wall2)
       Cpu = Cpu2 - Cpu1
