@@ -29,13 +29,14 @@
 *             Modified for 3-center RI gradients, March 2007           *
 ************************************************************************
       use SOAO_Info, only: iAOtSO
-      use pso_stuff, only: lPSO, nnp, Thpkl, ipAorb
+      use pso_stuff, only: lPSO, nnp, Thpkl, AOrb
       use Basis_Info, only: nBas, nBas_Aux
       use Symmetry_Info, only: nIrrep
+      use ExTerm, only: CijK, CilK, BklK
+      use ExTerm, only: Ymnij, ipYmnij, nYmnij, iOff_Ymnij
+      use ExTerm, only: Yij, CMOi
       Implicit Real*8 (A-H,O-Z)
-#include "WrkSpc.fh"
 #include "real.fh"
-#include "print.fh"
 #include "exterm.fh"
       Real*8 PSO(nijkl,nPSO), DSO(nDSO,nSA), DSSO(nDSO), V_k(mV_k,nSA),
      &       Zpk(*)
@@ -43,38 +44,34 @@
       Logical Shijij
 *     Local Array
       Integer jSym(0:7), kSym(0:7), lSym(0:7), nAct(0:7)
-      Integer iTwoj(0:7),nCumnnP(0:7),nCumnnP2(0:7)
-      Data iTwoj/1,2,4,8,16,32,64,128/
-#include "ymnij.fh"
+      Integer nCumnnP(0:7),nCumnnP2(0:7)
+
+      Real*8, Pointer :: Xki(:)=>Null()
+      Real*8, Pointer :: Xli(:)=>Null()
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *     Statement function
 *
-      kYmnij(l)=iWork(ipYmnij(1)-1+l)
+      kYmnij(l)=Ymnij(ipYmnij(1)-1+l)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      iRout = 39
-      iPrint = nPrint(iRout)
 #ifdef _DEBUGPRINT_
-      iPrint=99
-      If (iPrint.ge.99) Then
-         iComp = 1
-         Call PrMtrx(' In PGET_RI3:DSO ',[iD0Lbl],iComp,1,D0)
-         Call RecPrt('V_K',' ',V_K,1,mV_K)
-         Write (6,*)
-         Write (6,*) 'Distribution of Ymnij'
-         Do iSym = 1, nIrrep
-           If (nYmnij(iSym,1).gt.0) Then
-           Write (6,*) 'iSym=',iSym
-           Do i= iOff_Ymnij(iSym,1)+1,iOff_Ymnij(iSym,1)+nYmnij(iSym,1)
-              Write (6,*) 'kYmnij=',kYmnij(i)
-           End Do
-           End If
-         End Do
-         Write (6,*) 'jbas,kbas,lbas=',jBas,kBas,lBas
-      End If
+      iComp = 1
+      Call PrMtrx(' In PGET_RI3:DSO ',[iD0Lbl],iComp,1,D0)
+      Call RecPrt('V_K',' ',V_K,1,mV_K)
+      Write (6,*)
+      Write (6,*) 'Distribution of Ymnij'
+      Do iSym = 1, nIrrep
+        If (nYmnij(iSym,1).gt.0) Then
+        Write (6,*) 'iSym=',iSym
+        Do i= iOff_Ymnij(iSym,1)+1,iOff_Ymnij(iSym,1)+nYmnij(iSym,1)
+           Write (6,*) 'kYmnij=',kYmnij(i)
+        End Do
+        End If
+      End Do
+      Write (6,*) 'jbas,kbas,lbas=',jBas,kBas,lBas
 #endif
 *                                                                      *
 ************************************************************************
@@ -129,10 +126,6 @@
                      nlSym = nlSym + 1
                   End If
  401           Continue
-*              Write (*,*)
-*              Write (*,*) 'i2,i3,i4=',i2,i3,i4
-*              Write (*,*) '=================='
-*              Write (*,*)
 *
 *------Loop over irreps which are spanned by the basis function.
 *
@@ -172,89 +165,76 @@
 *
 *                  Offset to where the block starts (jbas,kbas,i3)
 *
-                   jp_Xki=ip_CMOi(1) + iOff_CMOi(j3+1,1)
-     &                   + nChOrb(j3,iSO)*(kSO-1)-1
+                   lda = SIZE(CMOi(1)%SB(j3+1)%A2,1)
+                   ik  = 1 + lda*(kSO-1)
+                   Xki(1:) => CMOi(1)%SB(j3+1)%A1(ik:)
 *
 *                  Loop over the auxiliary basis functions which has
 *                  significant contributions to the k shell.
 *
-                   imo=0
+                   imo=1
                    Do k = 1, nk
                       kmo=kYmnij(k+iOff_Ymnij(j3+1,1))
 *
-                      jCMOk=jp_Xki+kmo
-                      jr   =jr_Xki(1)+imo
-                      call dcopy_(kBas,Work(jCMOk),nChOrb(j3,iSO),
-     &                                 Work(jr),  nk)
+                      call dcopy_(kBas,Xki(kmo:),nChOrb(j3,iSO),
+     &                                 Yij(imo,1,1),  nk)
 *
                       imo = imo +1
                    End Do
 *                  Reset pointers
-                   jp_Xki=jr_Xki(1)
-*                  Write (*,*) 'i3,j3=',i3,j3
-*                  Call RecPrt('X(i,mu)C',' ',Work(jp_Xki),nk,kBas)
+                   Xki(1:nk*kBas) => Yij(1:nk*kBas,1,1)
+*                  Call RecPrt('X(i,mu)C',' ',Xki,nk,kBas)
                 Else If (ExFac.ne.Zero.and.nk.gt.0) Then
-                   jp_Xki=ip_CMOi(1) + iOff_CMOi(j3+1,1)
-     &                   + nChOrb(j3,iSO)*(kSO-1)
-*                  Write (*,*) 'i3,j3=',i3,j3
-*                  Call RecPrt('X(i,mu)R',' ',Work(jp_Xki),nk,kBas)
+                   lda = SIZE(CMOi(1)%SB(j3+1)%A2,1)
+                   ik  = 1 + lda*(kSO-1)
+                   Xki(1:) => CMOi(1)%SB(j3+1)%A1(ik:)
+*                  Call RecPrt('X(i,mu)R',' ',Xki,nk,kBas)
                 Else
-                   jp_Xki=ip_Dummy
+                   Xki=>Null()
                 End If
 *
                 Do 410 ls = 0, nlSym-1
                    j4 = lSym(ls)
-*                  Write (*,*)
-*                  Write (*,*) 'j2,j3,j4=',j2,j3,j4
-*                  Write (*,*)
                    If (j23.ne.j4) Go To 410
-*                  Write (*,*) 'Pass symmetry check'
-*                  Write (*,*) 'j2,j3,j4=',j2,j3,j4
                    nl = nYmnij(j4+1,1)
-*                  Write (*,*) 'j4,nl=',j4,nl
                    lSO = iAOtSO(iAO(4)+i4,j4)+iAOst(4)
 *
 *                  Pointers to the full list of the X_mu,i elements
 *
                    If (nl.lt.nChOrb(j4,iSO).and.ExFac.ne.Zero.and.
      &                 nl.gt.0) Then
-                      jp_Xli=ip_CMOi(1) + iOff_CMOi(j4+1,1)
-     &                      + nChOrb(j4,iSO)*(lSO-1)-1
-                      imo=0
+
+                      lda = SIZE(CMOi(1)%SB(j4+1)%A2,1)
+                      il  = 1 + lda*(lSO-1)
+                      Xli(1:) => CMOi(1)%SB(j4+1)%A1(il:)
+                      imo=1
                       Do l = 1, nl
                          lmo=kYmnij(l+iOff_Ymnij(j4+1,1))
 *
-                         jCMOl=jp_Xli+lmo
-                         jr   =jr_Xli(1)+imo
-                         call dcopy_(lBas,Work(jCMOl),nChOrb(j4,iSO),
-     &                                    Work(jr),   nl)
+                         call dcopy_(lBas,Xli(lmo:),nChOrb(j4,iSO),
+     &                                    Yij(imo,2,1),   nl)
 *
                          imo = imo +1
                       End Do
 *                     Reset pointers
-                      jp_Xli=jr_Xli(1)
-*                     Write (*,*) 'i4,j4=',i4,j4
-*                     Call RecPrt('X(j,nu)C',' ',Work(jp_Xli),nl,lBas)
+                      Xli(1:nl*lBas) => Yij(1:nl*lBas,2,1)
+*                     Call RecPrt('X(j,nu)C',' ',Xli,nl,lBas)
                    Else If (ExFac.ne.Zero.and.nl.gt.0) Then
-                      jp_Xli=ip_CMOi(1) + iOff_CMOi(j4+1,1)
-     &                      + nChOrb(j4,iSO)*(lSO-1)
-*                     Write (*,*) 'i4,j4=',i4,j4
-*                     Call RecPrt('X(j,nu)R',' ',Work(jp_Xli),nl,lBas)
+                      lda = SIZE(CMOi(1)%SB(j4+1)%A2,1)
+                      il  = 1 + lda*(lSO-1)
+                      Xli(1:) => CMOi(1)%SB(j4+1)%A1(il:)
+*                     Call RecPrt('X(j,nu)R',' ',Xli,nl,lBas)
                    Else
-                      jp_Xli=ip_Dummy
+                      Xli=>Null()
                    End If
 *
                    MemSO2 = MemSO2 + 1
-*                  Write (6,*) 'MemSO2=',MemSO2
 *
                    jSO = iAOtSO(iAO(2)+i2,j2)+iAOst(2)
                    jSO_off = jSO - nBas(j2)
 *
                    ExFac_ = ExFac
                    If (nJ*nk*nl.eq.0) ExFac=Zero
-*                  Write (6,*) 'i2,i3,i4=',i2,i3,i4
-*                  Write (6,*) 'nJ,nk,nl=',nJ,nk,nl
-*                  Write (6,*) 'ExFac=',ExFac
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -268,40 +248,38 @@
                    lCVec = nIJR(j3+1,j4+1,iSO)*jBas
                    iAdr =  iAdrCVec(j2+1,j3+1,1)
      &                  +  nIJR(j3+1,j4+1,iSO)*(jSO_Off-1)
-                   Call dDaFile(LuCVector(j2+1,1),2,Work(ip_Cijk),
-     &                          lCVec,iAdr)
-*                  Call RecPrt('C(ij,K)',' ',Work(ip_CijK),
+                   Call dDaFile(LuCVector(j2+1,1),2,Cijk,lCVec,iAdr)
+*                  Call RecPrt('C(ij,K)',' ',CijK,
 *    &                         nIJR(j3+1,j4+1,iSO),jBas)
 *
 *                  Extract only those C_kl^Js for which we deem k and l
 *                  to belong to the shell-pair and to be of
 *                  significance. Use temporary memory location at
-*                  ip_CilK.
+*                  CilK.
 *
                    If (nk*nl.lt.nChOrb(j3,iSO)*nChOrb(j4,iSO)) Then
-                      ij=0
+                      ij=1
                       Do j=1,nl
                          jmo=kYmnij(j+iOff_Ymnij(j4+1,1))
                          Do i=1,nk
                             imo=kYmnij(i+iOff_Ymnij(j3+1,1))
 *
-                            jC=ip_Cijk-1+nChOrb(j3,iSO)*(jmo-1)+imo
-                            jr=ip_CilK+ij
+                            jC=imo+nChOrb(j3,iSO)*(jmo-1)
 *
 *                           For this particular ij combination pick
 *                           the whole row.
 *
-                            call dcopy_(jBas,Work(jC),nChOrb(j3,iSO)*
+                            call dcopy_(jBas,CijK(jC),nChOrb(j3,iSO)*
      &                                               nChOrb(j4,iSO),
-     &                                      Work(jr),nk*nl)
+     &                                      CilK(ij),nk*nl)
                             ij=ij+1
                          End Do
                       End Do
 *
 *                     Copy back to original memory position.
 *
-                      call dcopy_(nk*nl*jBas,Work(ip_CilK),1,
-     &                                      Work(ip_CijK),1)
+                      n2j=nk*nl*jBas
+                      CijK(1:n2j)=CilK(1:n2j)
                    End If
 *
 *                  Transform according to Eq. 16 (step 4) and
@@ -310,31 +288,19 @@
 *
 *                  E(jK,m) = Sum_i C(i,jK)' * X(i,m)
 *
-*                  Call RecPrt('C(ij,K)',' ',Work(ip_CijK),
-*    &                         nk*nl,jBas)
-*                  Call RecPrt('X(i,mu)',' ',Work(jp_Xki),
-*    &                          nk,kBas)
                    Call dGEMM_('T','N',nl*jBas,kBas,nk,
-     &                        1.0D0,Work(ip_CijK),nk,
-     &                              Work(jp_Xki),nk,
-     &                        0.0D0,Work(ip_CilK),nl*jBas)
+     &                        1.0D0,CijK,nk,
+     &                              Xki,nk,
+     &                        0.0D0,CilK,nl*jBas)
 *
 *                  B(Km,n) = Sum_j E(j, Km)' * X(j,n)
 *
                    Call dGEMM_('T','N',jBas*kBas,lBas,nl,
-     &                         1.0D0,Work(ip_CilK),nl,
-     &                               Work(jp_Xli),nl,
-     &                         0.0D0,Work(ip_BklK),jBas*kBas)
-*                  Write (*,*) 'i2,i3,i4=',i2,i3,i4
-*                  Write (*,*) 'MemSO2=',MemSO2
-*                  Call RecPrt('B_kl^K',' ',Work(ip_BklK),
-*    &                         jBas,kBas*lBas)
+     &                         1.0D0,CilK,nl,
+     &                               Xli,nl,
+     &                         0.0D0,BklK,jBas*kBas)
 
                    End If
-*
-*                  Write (6,*)
-*                  Write (6,*) 'j2,j3,j4=',j2,j3,j4
-*                  Write (6,*)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -346,13 +312,9 @@
                      Do iVec=1,nAVec
                        iMO1=1
                        iMO2=1
-                       iVec_=iVec
-                       fact=1.0d0
                        If (iVec.eq.2) iMO2=2
-                       If (iVec.eq.3) fact=2.0d0
                        If (iVec.eq.4) Then
                          iMO1=2
-                         iVec_=2
                        EndIf
 *
                        Do jAOj = 0, jBas-1
@@ -360,36 +322,36 @@
                          jp=nCumnnP(j2)+(jSOj-1)*nnP(j2)+nCumnnP2(j3)
                          Do lAOl = 0, lBas-1
                            lSOl = lSO + lAOl
-                           lp=(lSOl-1)*nAct(j4)+ipAOrb(j4,iMO1)
 
                            If (j3.eq.j4) Then
                              Do kAct=1,nAct(j3)
 *Zpk(*,iVec)
                                tmp=ddot_(kAct,Zpk(jp+kAct*(kAct-1)/2+1),
-     &                             1,Work(lp),1)
+     &                             1,AOrb(iMO1)%SB(j4+1)%A2(:,lSOl),1)
                                Do lAct=kAct+1,nAct(j4)
                                  tmp=tmp+Zpk(jp+lAct*(lAct-1)/2+kAct)*
-     &                               Work(lp+lAct-1)
+     &                               AOrb(iMO1)%SB(j4+1)%A2(lAct,lSOl)
                                End Do
-                               Work(ip_Cilk+kAct-1)=tmp
+                               Cilk(kAct)=tmp
                              End Do
                            Else
                              If (j3.lt.j4) Then
                                Call dGeMV_('N',nAct(j3),nAct(j4),1.0d0,
-     &                                    Zpk(jp+1),nAct(j3),Work(lp),1,
-     &                                    0.0d0,Work(ip_CilK),1)
+     &                                    Zpk(jp+1),nAct(j3),
+     &                                 AOrb(iMO1)%SB(j4+1)%A2(:,lSOl),1,
+     &                                    0.0d0,CilK,1)
                              Else
                                Call dGeMV_('T',nAct(j4),nAct(j3),1.0d0,
-     &                                    Zpk(jp+1),nAct(j4),Work(lp),1,
-     &                                    0.0d0,Work(ip_CilK),1)
+     &                                    Zpk(jp+1),nAct(j4),
+     &                                 AOrb(iMO1)%SB(j4+1)%A2(:,lSOl),1,
+     &                                    0.0d0,CilK,1)
                              EndIf
                            EndIf
 *
                            iThpkl= jAOj+ lAOl*kBas*jBas+1
-                           kp=ipAOrb(j3,iMO2)+(kSO-1)*nAct(j3)
                            Call dGeMV_('T',nAct(j3),kBas,1.0d0,
-     &                         Work(kp),
-     &                         nAct(j3),Work(ip_Cilk),1,1.0d0,
+     &                         AOrb(iMO2)%SB(j3+1)%A2(:,kSO),
+     &                         nAct(j3),Cilk,1,1.0d0,
      &                         Thpkl(iThpkl),jBas)
 
                          End Do
@@ -461,6 +423,8 @@
                    ExFac = ExFac_
 *
  410            Continue
+                Xki=>Null()
+                Xli=>Null()
  310         Continue
           End Do
 *
@@ -474,10 +438,7 @@
       End If
 *
 #ifdef _DEBUGPRINT_
-      If (iPrint.ge.99) Then
-         Call RecPrt(' In PGET_RI3:PSO ',' ',PSO,nijkl,nPSO)
-      End If
-      Call GetMem(' Exit PGET_RI3','CHECK','REAL',iDum,iDum)
+      Call RecPrt(' In PGET_RI3:PSO ',' ',PSO,nijkl,nPSO)
 #endif
 
       Call CWTime(Cpu2,Wall2)
