@@ -31,14 +31,11 @@
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "print.fh"
-#include "srt0.fh"
-#include "srt1.fh"
-#include "WrkSpc.fh"
 *
       Real*8 AOint(ijkl,iCmp,jCmp,kCmp,lCmp), TInt(nTInt,mTInt)
       Integer iShell(4), iAO(4), kOp(4), iAOst(4), iSOs(4)
       Logical Shijij
-      Common /ibas_ricd/ jbas_, lbas_
+#include "ibas_ricd.fh"
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -46,8 +43,6 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      irout = 109
-      iprint = nprint(irout)
 *define _DEBUGPRINT_
 #ifdef _DEBUGPRINT_
       r1=DDot_(ijkl*iCmp*jCmp*kCmp*lCmp,AOInt,1,[One],0)
