@@ -11,7 +11,7 @@
 * Copyright (C) 1990,1991,1993,1998,2005, Roland Lindh                 *
 *               1990, IBM                                              *
 ************************************************************************
-      SubRoutine Post_2Center_RI(ipA_Diag)
+      SubRoutine Post_2Center_RI(A_Diag)
 ************************************************************************
 *                                                                      *
 *  Object: driver for two-electron integrals.                          *
@@ -35,10 +35,38 @@
 #include "setup.fh"
 #include "print.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
+      Real*8, Allocatable:: A_Diag(:)
       Integer  nDmA(0:7),  nDmB(0:7)
       Logical Out_of_Core
       Character Name_Q*6
+
+      Real*8, Allocatable :: Scr(:), X(:), Z(:)
+      Integer, Allocatable :: iDiag(:)
+      Real*8, Allocatable, Target :: Am(:), Qm(:), A_k(:), Q_k(:)
+      Real*8, Pointer :: A_l(:)=>Null(), Q_l(:)=>Null()
+*                                                                      *
+************************************************************************
+*                                                                      *
+      INTERFACE
+      SUBROUTINE SORT_mat(irc,nDim,nVec,iD_A,nSym,lu_A0,mode,lScr,Scr,
+     &                    Diag)
+      Integer irc
+      Integer nSym
+      Integer nDim(nSym)
+      Integer nVec(nSym)
+      Integer iD_A(*)
+      Integer lu_A0(nSym)
+      Character(LEN=7) mode
+      Integer lScr
+      Real*8  Scr(lScr)
+      Real*8, Optional ::  Diag(*)
+      END SUBROUTINE SORT_mat
+      END INTERFACE
+*                                                                      *
+************************************************************************
+*                                                                      *
+
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -61,7 +89,7 @@
       End Do
       nA_Diag=nBfnTot
 *
-      Call GetMem('MemMax','Max','Real',iDummy,MaxMem)
+      Call mma_maxDBLE(MaxMem)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -77,16 +105,16 @@
 *                                                                      *
 *     Pivoting of the A matrix
 *
-      Call GetMem('iD_Diag','Allo','Inte',ip_iDiag,nA_Diag)
-      Call GetMem('MemMax','Max','Real',iDummy,MaxMem2)
+      Call mma_allocate(iDiag,nA_Diag,Label='iDiag')
+      Call mma_maxDBLE(MaxMem2)
 *
       If (Force_Out_of_Core) MaxMem2=3*nBfnTot
 *     lScr=Min(MaxMem2,nScr)
-      lScr=Max(MaxMem2,nScr)
-      Call GetMem('Scr','Allo','Real',ip_Scr,lScr)
+      lScr=Max(MaxMem2-(nScr/3),nScr)
+      Call mma_allocate(Scr,lScr,Label='Scr')
 *
-      Call SORT_mat(irc,Work(ipA_Diag),nDmA,nDmB,iWork(ip_iDiag),nIrrep,
-     &                  LU_A,'GePivot',lScr,Work(ip_Scr))
+      Call SORT_mat(irc,nDmA,nDmB,iDiag,nIrrep,
+     &              LU_A,'GePivot',lScr,Scr,Diag=A_Diag)
       ichk=0
       Do iIrrep = 0, nIrrep-1
          nChV(iIrrep)=nDmB(iIrrep)
@@ -103,15 +131,14 @@
          write(6,*)
       EndIf
 *
-      Call SORT_mat(irc,Work(ipA_Diag),nDmA,nDmB,iWork(ip_iDiag),nIrrep,
-     &                  LU_A,'DoPivot',lScr,Work(ip_Scr))
+      Call SORT_mat(irc,nDmA,nDmB,iDiag,nIrrep,
+     &                  LU_A,'DoPivot',lScr,Scr)
 *
 *     Note: after the 'DoPivot' call to Sort_mat, the A-matrix is
 *           no longer stored as squared but as upper-triangular
 *
-      Call GetMem('Scr','Free','Real',ip_Scr,lScr)
-      Call GetMem('A_Diag','Free','Real',ipA_Diag,nA_Diag)
-      ipA_Diag=ip_Dummy  ! Dummy memory pointer.
+      Call mma_deallocate(Scr)
+      Call mma_deallocate(A_Diag)
 *
 ************************************************************************
 *     A-vectors are now on disk. Go ahead and compute the Q-vectors!
@@ -163,18 +190,17 @@ c         If (iIrrep.eq.0) nB = nB - 1
 *        Some of memory for scratch arrays for Inv_Cho_Factor
 *        Allocate memory for the A- and Q-vectors and initialize.
 *
-         Call GetMem('ICF','Allo','Real',ip_ICF,lAm+lQm+5*nXZ)
-         ipZ    = ip_ICF
-         ipX    = ip_ICF + 1*nXZ
-         ip_Q_k = ip_ICF + 2*nXZ
-         ip_A_k = ip_ICF + 3*nXZ
-         ip_Scr = ip_ICF + 4*nXZ
          lScr=nXZ
-         ip_Am  = ip_ICF + 5*nXZ
-         ip_Qm  = ip_ICF + 5*nXZ + lAm
+         Call mma_allocate(Scr,lScr,Label='Scr')
+         Call mma_allocate(Z,nXZ,Label='Z')
+         Call mma_allocate(X,nXZ,Label='X')
+         Call mma_allocate(Am,lAm,Label='Am')
+         Call mma_allocate(Qm,lQm,Label='Qm')
+         Call mma_allocate(A_k,nXZ,Label='A_k')
+         Call mma_allocate(Q_k,nXZ,Label='Q_k')
 *
-         Call FZero(Work(ip_Am),lAm)
-         Call FZero(Work(ip_Qm),lQm)
+         Am(:)=Zero
+         Qm(:)=Zero
 *                                                                      *
 *----------------------------------------------------------------------*
 *                                                                      *
@@ -193,29 +219,28 @@ c         If (iIrrep.eq.0) nB = nB - 1
             If (kCol.le.nMem) Then
 *              Point to A_k in Am
                iOff = (kCol-1)*kCol/2
-               ip_A_l=ip_Am+iOff
+               A_l(1:kCol) => Am(iOff+1:iOff+kCol)
                If (kCol.eq.1) Then
                   nAm=nMem*(nMem+1)/2
-                  Call dDaFile(Lu_A(iIrrep),2,Work(ip_Am),nAm,iAddr_)
+                  Call dDaFile(Lu_A(iIrrep),2,Am,nAm,iAddr_)
                End If
 *              Point to Q_k in Qm
-               iOff = (kCol-1)*kCol/2
-               ip_Q_l=ip_Qm+iOff
+               Q_l(1:kCol) => Qm(iOff+1:iOff+kCol)
             Else If (kCol.gt.nMem) Then
 *              Use special scratch for A_k
-               ip_A_l=ip_A_k
-               Call dDaFile(Lu_A(iIrrep),2,Work(ip_A_l),kCol,iAddr_)
+               A_l(1:kCol) => A_k(1:kCol)
+               Call dDaFile(Lu_A(iIrrep),2,A_l,kCol,iAddr_)
 *              Use special scratch for Q_k
-               ip_Q_l=ip_Q_k
+               Q_l(1:kCol) => Q_k(1:kCol)
             End If
 *
             LinDep=2
-            Call Inv_Cho_Factor(Work(ip_A_l),kCol,
-     &                          Work(ip_Am),Work(ip_Qm),nMem,
+            Call Inv_Cho_Factor(A_l,kCol,
+     &                          Am,Qm,nMem,
      &                          Lu_A(iIrrep),Lu_Q(iIrrep),
-     &                          Work(ip_Scr),lScr,
-     &                          Work(ipZ),Work(ipX),ThrQ,
-     &                          Work(ip_Q_l),LinDep)
+     &                          Scr,lScr,
+     &                          Z,X,ThrQ,
+     &                          Q_l,LinDep)
 
             If (LinDep.ne.0) Then
                Call WarningMessage(2,'Error in Post_2Center_RI')
@@ -228,16 +253,24 @@ c         If (iIrrep.eq.0) nB = nB - 1
             iAddr_=iAddr
             If (kCol.eq.nMem) Then
                nQm=kCol*(kCol+1)/2
-               Call dDaFile(Lu_Q(iIrrep),1,Work(ip_Qm),nQm,iAddr )
-               Call dDaFile(Lu_A(iIrrep),1,Work(ip_Am),nQm,iAddr_)
+               Call dDaFile(Lu_Q(iIrrep),1,Qm,nQm,iAddr )
+               Call dDaFile(Lu_A(iIrrep),1,Am,nQm,iAddr_)
             Else If (kCol.gt.nMem) Then
-               Call dDaFile(Lu_Q(iIrrep),1,Work(ip_Q_k),kCol,iAddr )
-               Call dDaFile(Lu_A(iIrrep),1,Work(ip_A_l),kCol,iAddr_)
+               Call dDaFile(Lu_Q(iIrrep),1,Q_l,kCol,iAddr )
+               Call dDaFile(Lu_A(iIrrep),1,A_l,kCol,iAddr_)
             End If
 *
          End Do
 *
-         Call GetMem('ICF','Free','Real',ip_ICF,lAm+lQm+5*nXZ)
+         Q_l=>Null()
+         A_l=>Null()
+         Call mma_deallocate(Q_k)
+         Call mma_deallocate(A_k)
+         Call mma_deallocate(Qm)
+         Call mma_deallocate(Am)
+         Call mma_deallocate(X)
+         Call mma_deallocate(Z)
+         Call mma_deallocate(Scr)
          Call DaClos(Lu_A(iIrrep))
  777     Continue
       End Do ! iIrrep
@@ -246,21 +279,21 @@ c         If (iIrrep.eq.0) nB = nB - 1
 *                                                                      *
 *     Sort the Q-matrix back to the original order.
 *
-      Call GetMem('MemMax','Max','Real',iDummy,MaxMem2)
+      Call mma_maxDBLE(MaxMem2)
 *
       If (Force_Out_of_Core) MaxMem2=2*nBfnTot
       lScr=Min(MaxMem2,Max(nBfn2,2*nBfnTot))
-      Call GetMem('Scr','Allo','Real',ip_Scr,lScr)
+      Call mma_allocate(Scr,lScr,Label='Scr')
 *
-      Call SORT_mat(irc,Work(ipA_Diag),nDmA,nDmB,iWork(ip_iDiag),nIrrep,
-     &                  LU_Q,'Restore',lScr,Work(ip_Scr))
+      Call SORT_mat(irc,nDmA,nDmB,iDiag,nIrrep,
+     &                  LU_Q,'Restore',lScr,Scr)
 *
 *     Note: after the 'Restore' call to Sort_mat, the Q-matrix is
 *           no longer stored as upper-triangular but as RECTANGULAR
 *           (nDmA,nDmB). The column index is still pivoted.
 *
-      Call GetMem('Scr','Free','Real',ip_Scr,lScr)
-      Call GetMem('iD_Diag','Free','Inte',ip_iDiag,nA_Diag)
+      Call mma_deallocate(Scr)
+      Call mma_deallocate(iDiag)
 *                                                                      *
 ************************************************************************
 ************************************************************************
