@@ -23,11 +23,13 @@
 *       DESYM_CENTER_COORDINATES, DESYM_BASIS_FUNCTION_IDS,
 *       DESYM_MATRIX, PRIMITIVE_IDS, PRIMITIVES
 
+      use mh5, only: mh5_init_attr, mh5_create_dset_str,
+     &               mh5_create_dset_int, mh5_create_dset_real,
+     &               mh5_put_dset, mh5_close_dset
       implicit none
       integer :: fileid
 #  include "Molcas.fh"
 #  include "stdalloc.fh"
-#  include "mh5.fh"
 
       integer :: natoms
       real*8, allocatable :: charges(:), coord(:,:)
@@ -90,7 +92,7 @@
 *     atom labels
       dsetid = mh5_create_dset_str(fileid,
      $        'CENTER_LABELS', 1, [nAtoms], LENIN)
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Unique center labels '//
      $          'arranged as one [NATOMS_UNIQUE] block')
       call mma_allocate(atomlbl,nAtoms)
@@ -102,8 +104,8 @@
 *     atom numbers
       dsetid = mh5_create_dset_int(fileid,
      $        'CENTER_ATNUMS', 1, [nAtoms])
-      call mh5_init_attr(dsetid, 'description',
-     $        'Atomic numbers, storead as '//
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
+     $        'Atomic numbers, stored as '//
      $        'array of size [NATOMS_UNIQUE]')
       call mma_allocate(atnums,nAtoms)
       Call Get_iArray('Un_cen Charge',atnums,nAtoms)
@@ -114,8 +116,8 @@
 *     atom charges
       dsetid = mh5_create_dset_real(fileid,
      $        'CENTER_CHARGES', 1, [nAtoms])
-      call mh5_init_attr(dsetid, 'description',
-     $        'Nuclear charges, storead as '//
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
+     $        'Nuclear charges, stored as '//
      $        'array of size [NATOMS_UNIQUE]')
       call mma_allocate(charges,nAtoms)
       Call Get_dArray('Un_cen Effective Charge',charges,nAtoms)
@@ -126,24 +128,24 @@
 *     atom coordinates
       dsetid = mh5_create_dset_real(fileid,
      $        'CENTER_COORDINATES', 2, [3,nAtoms])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Atom coordinates, matrix of size [NATOMS_UNIQUE,3], '//
      $        'stored with atom index varying slowest')
       call mma_allocate(coord,3,nAtoms)
       Call Get_dArray('Un_cen Coordinates',coord,3*nAtoms)
-      call mh5_put_dset_array_real(dsetid,coord)
+      call mh5_put_dset(dsetid,coord)
       call mma_deallocate(coord)
       call mh5_close_dset(dsetid)
 
 *     unique basis names
       dsetid = mh5_create_dset_int(fileid,
      $        'BASIS_FUNCTION_IDS', 2, [4,nbast])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Unique basis function IDs (c,n,l,m) '//
      $        'arranged as blocks of size [4*NBAS(i)], i=1,#irreps')
       call mma_allocate(basis_ids,4,nbast)
       Call Get_iArray('Basis IDs',basis_ids,4*nbast)
-      call mh5_put_dset_array_int(dsetid,basis_ids)
+      call mh5_put_dset(dsetid,basis_ids)
       call mma_deallocate(basis_ids)
       call mh5_close_dset(dsetid)
 
@@ -156,7 +158,7 @@
 *     desymmetrized atom labels
         dsetid = mh5_create_dset_str(fileid,
      $          'DESYM_CENTER_LABELS', 1, [mcentr], LENIN4)
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Desymmetrized center labels '//
      $          'arranged as one [NATOMS_ALL] block')
         call mma_allocate(desym_atomlbl,mcentr)
@@ -168,7 +170,7 @@
 *     desymmetrized atom numbers
         dsetid = mh5_create_dset_int(fileid,
      $          'DESYM_CENTER_ATNUMS', 1, [MCENTR])
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Desymmetrized atomic numbers, '//
      $          'stored as array of size [NATOMS_ALL]')
         call mma_allocate(atnums,mcentr)
@@ -180,7 +182,7 @@
 *     desymmetrized atom charges
         dsetid = mh5_create_dset_real(fileid,
      $          'DESYM_CENTER_CHARGES', 1, [MCENTR])
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Desymmetrized center charges, '//
      $          'stored as array of size [NATOMS_ALL]')
         call mma_allocate(charges,mcentr)
@@ -192,34 +194,34 @@
 *     desymmetrized atom coordinates
         dsetid = mh5_create_dset_real(fileid,
      $          'DESYM_CENTER_COORDINATES', 2, [3,MCENTR])
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Desymmetrized coordinates, size [NATOMS_ALL,3], '//
      $          'stored with atom index varying slowest')
         call mma_allocate(coord,3,MCENTR)
         call get_dArray('LP_Coor',coord,3*mcentr)
-        call mh5_put_dset_array_real(dsetid,coord)
+        call mh5_put_dset(dsetid,coord)
         call mma_deallocate(coord)
         call mh5_close_dset(dsetid)
 
         dsetid = mh5_create_dset_int(fileid,
      $          'DESYM_BASIS_FUNCTION_IDS', 2, [4,nBast])
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Basis function IDs (desymmetrized) (c,n,l,m) '//
      $          'arranged as one [4*NBAST] block, NBAST=sum(NBAS)')
-        call mma_allocate(desym_basis_ids, 4, nbast)
+        call mma_allocate(desym_basis_ids,4,nbast)
         Call get_iArray('Desym Basis IDs',desym_basis_ids,4*nbast)
-        call mh5_put_dset_array_int(dsetid,desym_basis_ids)
+        call mh5_put_dset(dsetid,desym_basis_ids)
         call mma_deallocate(desym_basis_ids)
         call mh5_close_dset(dsetid)
 
 *     basis function conversion matrix
         dsetid = mh5_create_dset_real(fileid,
      $          'DESYM_MATRIX', 1, [nbast**2])
-        call mh5_init_attr(dsetid, 'description',
+        call mh5_init_attr(dsetid, 'DESCRIPTION',
      $          'Symmetrization matrix for the basis functions '//
      $          'arranged as a [NBAST,NBAST] block, NBAST=sum(NBAS), '//
      $          'fast index corresponds to desymmetrized basis.')
-        call mma_allocate(desym_matrix, nbast**2)
+        call mma_allocate(desym_matrix,nbast**2)
         Call get_dArray('SM',desym_matrix,nbast**2)
         call mh5_put_dset(dsetid,desym_matrix)
         call mma_deallocate(desym_matrix)
@@ -233,7 +235,7 @@
 *     radial primitive identifications
       dsetid = mh5_create_dset_int(fileid,
      $        'PRIMITIVE_IDS', 2, [3,nPrim])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Primitive IDs, arranged as an '//
      $        'array of size [3*NPRIM], with consecutive '//
      $        'center_id, angmom, shell_id (C1 2s <-> 1,0,2)')
@@ -256,20 +258,20 @@
         end do
       end if
       call mma_deallocate(QMMap)
-      call mh5_put_dset_array_int(dsetid,PrimIDs)
+      call mh5_put_dset(dsetid,PrimIDs)
       call mma_deallocate(PrimIDs)
       call mh5_close_dset(dsetid)
 
 *     atom maximum angular momenta
       dsetid = mh5_create_dset_real(fileid,
      $        'PRIMITIVES', 2, [2,nPrim])
-      call mh5_init_attr(dsetid, 'description',
+      call mh5_init_attr(dsetid, 'DESCRIPTION',
      $        'Primitives, arranged as an '//
      $        'array of size [2*NPRIM], with consecutive '//
      $        'exponent, contraction coefficient')
       call mma_allocate(Primitives,2,nPrim)
       call get_dArray('primitives', Primitives, 2*nPrim)
-      call mh5_put_dset_array_real(dsetid,Primitives)
+      call mh5_put_dset(dsetid,Primitives)
       call mma_deallocate(Primitives)
       call mh5_close_dset(dsetid)
 
