@@ -37,9 +37,6 @@
 *     Statement functions
 *
       nElem(i) = (i+1)*(i+2)/2
-*
-      iRout = 248
-      iPrint = nPrint(iRout)
 *
       call dcopy_(9,[Zero],0,Temp,1)
 *
@@ -73,7 +70,6 @@
 *
          ixcd = ixc + ixd
          iycd = iyc + iyd
-         izcd = izc + izd
 *
       Do 300 ipb = 1, nElem(lb)
          ixb = ixyz(1,jj+ipb)
@@ -82,7 +78,6 @@
 *
          ixbcd = ixcd + ixb
          iybcd = iycd + iyb
-         izbcd = izcd + izb
 *
       Do 400 ipa = 1, nElem(la)
          ixa = ixyz(1,ii+ipa)
@@ -91,7 +86,6 @@
 *
          ixabcd = ixbcd + ixa
          iyabcd = iybcd + iya
-         izabcd = izbcd + iza
 *
 *
 *        Compute all desired gradients with respect to an x-component.
