@@ -26,9 +26,6 @@
       Real*8 Arr1(nTR,3*nArr1), Arr2(nTR,3*nArr2),
      &       A(3), B(3), C(3), D(3)
       Logical IfGrad(3,4)
-*
-      iRout = 233
-      iPrint = nPrint(iRout)
 *
       Call Hrr2Da(Arr1,nTR,nabMax,ncdMax,Arr2,A,B,la,lb,lc,ld,IfGrad)
 *
