@@ -42,11 +42,6 @@
 #endif
 *                                                                      *
 ************************************************************************
-*                                                                      *
-      iRout = 16
-      iPrint = nPrint(iRout)
-*                                                                      *
-************************************************************************
 *                                                                      *
       ne = (neMax+1)*(neMax+2)/2
       nf = (nfMax+1)*(nfMax+2)/2
