@@ -35,9 +35,6 @@
 *
       iCan(ixyz,ix,iz) = ixyz*(ixyz+1)*(ixyz+2)/6 +
      &   (ixyz-ix)*(ixyz-ix+1)/2 + iz
-*
-      iRout = 17
-      iPrint = nPrint(iRout)
 *
       izf=nzfMax
       ize=nzeMax
