@@ -36,13 +36,12 @@
      &       CR2(nMax,2), CR1(nMax,2), CR0(nMax,2),
      &       HerW(2), HerR2(2)
       Integer iPntr(nPntr)
-      Logical ABeqCD, EQ
+      Logical EQ
 *
 *
       xdInv=One/ddx
       dddx = ddx/10d0 + ddx
 *
-      ABeqCD = EQ(A,B) .and. EQ(A,C) .and. EQ(A,D)
       If (     EQ(A,B).and..Not.EQ(C,D)) Go To 200
       If (.Not.EQ(A,B).and.     EQ(C,D)) Go To 300
       If (     EQ(A,B).and.     EQ(C,D)) Go To 400
