@@ -34,8 +34,10 @@
 *                                                                      *
 ************************************************************************
 #ifdef _FDE_
-      Use SCF_Arrays, Only: Emb
+      use Embedding_Global, only: Eemb, embInt, embPot
 #endif
+      use OFembed, only: Do_OFemb
+      use OFembed, only: Rep_EN
       Implicit Real*8 (a-h,o-z)
 *
 * Declaration of procedure parameters
@@ -47,13 +49,6 @@
 
 #include "mxdm.fh"
 #include "infscf.fh"
-#ifdef _FDE_
-#include "embpotdata.fh"
-#endif
-      Logical Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_R / Rep_EN,Func_AB,Func_A,Func_B,Energy_NAD,
-     &                      V_Nuc_AB,V_Nuc_BA,V_emb
 *----------------------------------------------------------------------*
 * Start                                                                *
 *----------------------------------------------------------------------*
@@ -77,7 +72,7 @@ c set to Zero for RHF
 *
 #ifdef _FDE_
       ! Embedding
-      if (embPot) Eemb = DDot_(nBT*nD,Emb,1,Dens(1,1,iPsLst),1)
+      if (embPot) Eemb = DDot_(nBT*nD,embInt,1,Dens(1,1,iPsLst),1)
 #endif
 *
 *     If just one electron make sure that the two-electron energy
