@@ -12,25 +12,21 @@
      &                       DLT,DSQ,FLT,nFLT,
      &                       ExFac,nBSQT,nBMX,iUHF,DLT_ab,
      &                       DSQ_ab,FLT_ab,nOcc,nOcc_ab,iDummy_run)
+      use OFembed, only: Do_OFemb,OFE_first,FMaux
+      use OFembed, only: Rep_EN
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
       Integer nSym,nBas(8), nAux(8), Keep(8)
       Integer nOcc(nSym),nOcc_ab(nSym)
       Logical DoCholesky,GenInt,DoLDF
-      Integer ALGO,nSCREEn
-      Logical REORD,DECO,timings
-      Real*8 DLT(*),DSQ(*),FLT(nFLT),dmpk,dFKmat
+      Real*8 DLT(*),DSQ(*),FLT(nFLT)
       Real*8 DLT_ab(*),DSQ_ab(*),FLT_ab(*)
       Character*50 CFmt
 
-      Common /CHOSCF / REORD,DECO,dmpk,dFKmat,ALGO,nSCREEN
-      Common /CHOTIME / timings
-      Logical Do_OFemb, KEonly, OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_R / Rep_EN,Func_AB,Func_A,Func_B,Energy_NAD,
-     &                      V_Nuc_Ab,V_Nuc_BA,V_emb
-      COMMON  / OFembed_I / ipFMaux, ip_NDSD, l_NDSD
+#include "choscf.fh"
+#include "chotime.fh"
 *
 
       GenInt=.false.
@@ -49,9 +45,8 @@ c      write(6,*)'ExFac= ',ExFac
       If (Do_OFemb) Then ! Coul. potential from subsys B
          nFM=1
          If (iUHF.eq.1) nFM=2
-         If (OFE_first) Call GetMem('FMaux','Allo','Real',ipFMaux,nFlt)
-         Call Coul_DMB(OFE_first,nFM,Rep_EN,Work(ipFMaux),
-     &                 DLT,DLT_ab,nFlt)
+         If (OFE_first) Call mma_allocate(FMaux,nFlt,Label='FMaux')
+         Call Coul_DMB(OFE_first,nFM,Rep_EN,FMaux,DLT,DLT_ab,nFlt)
          OFE_first=.false.
       End If
 *
@@ -192,13 +187,13 @@ C zeroing the elements
 
            CALL CHOscf_drv(iUHF,nSym,nBas,DSQ,DLT,DSQ_ab,DLT_ab,
      &                 Work(ipTemp),Work(ipTemp_ab),nFLT,ExFac,
-     &                 LWFSQ,LWFSQ_ab,nOcc,nOcc_ab)
+     &                 Work(LWFSQ),Work(LWFSQ_ab),nOcc,nOcc_ab)
         Else
 *
            CALL CHOscf_drv(iUHF,nSym,nBas,DSQ,DLT,
      &                 Work(ip_Dummy),Work(ip_Dummy),
      &                 Work(ipTemp),Work(ip_Dummy),nFLT,ExFac,
-     &                 LWFSQ,ip_Dummy,nOcc,iWork(ip_iDummy))
+     &                 Work(LWFSQ),Work(ip_Dummy),nOcc,iWork(ip_iDummy))
         EndIf
 
       ENDIF
@@ -214,8 +209,8 @@ C zeroing the elements
       endif
 *
       If (Do_OFemb) Then ! add FM from subsystem B
-        Call DaXpY_(nFlt,One,Work(ipFMaux),1,FLT,1)
-        If (iUHF.eq.1) Call DaXpY_(nFlt,One,Work(ipFMaux),1,FLT_ab,1)
+        Call DaXpY_(nFlt,One,FMaux,1,FLT,1)
+        If (iUHF.eq.1) Call DaXpY_(nFlt,One,FMaux,1,FLT_ab,1)
       EndIf
 *
       IF ((.not.DoCholesky).or.(GenInt)) THEN
