@@ -19,7 +19,7 @@
       Real*8 FSQ(*),FLT(nFlt),DSQ(*),DLT(*),X1(*),X2(*)
       Real*8 DLT_ab(*),DSQ_ab(*),FLT_ab(*),FSQ_ab(*)
       Integer ISTLT(8),ISTSQ(8),KEEP(8),NBAS(8),NFRO(8)
-      Logical Debug,myDebug
+      Logical myDebug
 c
 c This routine has been nicked from the MOTRA package. It was
 c originally written by Marcus Fuelscher, and has been slightly
@@ -44,11 +44,8 @@ c
        myDebug=.false.
        Factor=0.5D0
         if(iUHF.eq.1) Factor=1.0D0
-#ifdef _DEBUGPRINT_
-      Debug=.true.
+#ifdef _BUGPRINT_
 c      myDebug=.true. ! very extensive print out
-#else
-      Debug=.false.
 #endif
       ISTSQ(1)=0
       ISTLT(1)=0
