@@ -9,17 +9,15 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine Get_Enondyn_dft(nh1,Grad,nGrad,DFTFOCK)
+      use SCF_Arrays, only: CMO
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "mxdm.fh"
-#include "addr.fh"
 #include "WrkSpc.fh"
 #include "infscf.fh"
       Real*8  Grad(nGrad)
       Character*4 DFTFOCK
-      Real*8 Erest_xc
-      COMMON /dCSCF_xc/ Erest_xc
-
+#include "dcscf.fh"
 *
       Erest_xc=0.0d0
       Call GetMem('F-DS','Allo','Real',ipF_DFT,2*nBT)
@@ -27,20 +25,18 @@
       ip_Da=ip_D_DS
       ip_Db=ip_D_DS+nBT
 *
-      iOff=0
+      iOff=1
       jOff=0
       Do iSym=1,nSym
          ipDaa=ip_Da+jOff
-         mAdCMOO=mAdCMO+iOff
          Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nOcc(iSym,1),
-     &                    1.0d0,Work(mAdCMOO),nBas(iSym),
-     &                          Work(mAdCMOO),nBas(iSym),
+     &                    1.0d0,CMO(iOff,1),nBas(iSym),
+     &                          CMO(iOff,1),nBas(iSym),
      &                    0.0d0,Work(ipDaa),nBas(iSym))
          ipDbb=ip_Db+jOff
-         mAdCMOO=mAdCMO_ab+iOff
          Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nOcc(iSym,2),
-     &                    1.0d0,Work(mAdCMOO),nBas(iSym),
-     &                          Work(mAdCMOO),nBas(iSym),
+     &                    1.0d0,CMO(iOff,2),nBas(iSym),
+     &                          CMO(iOff,2),nBas(iSym),
      &                    0.0d0,Work(ipDbb),nBas(iSym))
          Do j=1,nBas(iSym)
             Do i=1,j-1
@@ -87,8 +83,7 @@
       Logical Do_MO,Do_TwoEl,Do_Grad
       Character*4 DFTFOCK
       Character*16  KSDFT
-      Real*8 Erest_xc
-      COMMON /dCSCF_xc/ Erest_xc
+#include "dcscf.fh"
 *
       lKSDFT=LEN(KSDFT)
       Debug=.False.
@@ -115,7 +110,7 @@
        If (KSDFT.eq.'LSDA ' .or.
      &     KSDFT.eq.'LDA '  .or.
      &     KSDFT.eq.'SVWN ') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=LDA_type
          Call DrvNQ(LSDA   ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -130,7 +125,7 @@
        Else If (KSDFT.eq.'LSDA5' .or.
      &          KSDFT.eq.'LDA5'  .or.
      &          KSDFT.eq.'SVWN5') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=LDA_type
          Call DrvNQ(LSDA5  ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -143,7 +138,7 @@
 *     HFB
 *
        Else If (KSDFT.eq.'HFB') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(HFB    ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -156,7 +151,7 @@
 *      HFS
 *
        Else If (KSDFT.eq.'HFS') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=LDA_type
          Call DrvNQ(HFS    ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -169,7 +164,7 @@
 *      XALPHA
 *
        Else If (KSDFT.eq.'XALPHA') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=LDA_type
          Call DrvNQ(XAlpha ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -182,7 +177,7 @@
 *     Overlap
 *
       Else If (KSDFT.eq.'Overlap') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=LDA_type
          Call DrvNQ(Overlap,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -195,7 +190,7 @@
 *     NucAtt
 *
       Else If (KSDFT.eq.'NucAtt') Then
-         ExFac=One
+c        ExFac=One
          Functional_type=LDA_type
          Call DrvNQ(NucAtt,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -208,7 +203,7 @@
 *     BLYP
 *
       Else If (KSDFT.eq.'BLYP') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(BLYP   ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -221,7 +216,7 @@
 *     TLYP
 *
       Else If (KSDFT.eq.'TLYP') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(TLYP   ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -234,7 +229,7 @@
 *     NLYP
 *
       Else If (KSDFT.eq.'NLYP') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(NLYP   ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -247,7 +242,7 @@
 *     B3LYP
 *
       Else If (KSDFT.eq.'B3LYP ') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(B3LYP  ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -260,7 +255,7 @@
 *     B3LYP5
 *
       Else If (KSDFT.eq.'B3LYP5') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(B3LYP5 ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -273,7 +268,7 @@
 *     PBE
 *
       Else If (KSDFT.eq.'PBE') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(PBE   ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -286,7 +281,7 @@
 *     PBE0
 *
       Else If (KSDFT.eq.'PBE0') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=GGA_type
          Call DrvNQ(PBE0  ,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -299,7 +294,7 @@
 *     M06-L
 *
       Else If (KSDFT.eq.'M06L') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=meta_GGA_type1
          Call DrvNQ(M06L,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -311,7 +306,7 @@
 *                                                                      *
 *     M06
       Else If (KSDFT.eq.'M06 ') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=meta_GGA_type1
          Call DrvNQ(M06,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -323,7 +318,7 @@
 *                                                                      *
 *     M06-2X
       Else If (KSDFT.eq.'M062X') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=meta_GGA_type1
          Call DrvNQ(M062X,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -335,7 +330,7 @@
 *                                                                      *
 *     M06-HF
       Else If (KSDFT.eq.'M06HF') Then
-         ExFac=Get_ExFac(KSDFT)
+c        ExFac=Get_ExFac(KSDFT)
          Functional_type=meta_GGA_type1
          Call DrvNQ(M06HF,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
@@ -348,7 +343,7 @@
 *     Checker
 *
       Else If (KSDFT.eq.'CHECKER') Then
-         ExFac=Zero
+c        ExFac=Zero
          Functional_type=meta_GGA_type2
          Call DrvNQ(Checker,Work(ipF_DFT),nFckDim,Func,
      &              Work(ip_D_DS),nh1,nD,
