@@ -11,7 +11,7 @@
 * Copyright (C) 2010, Thomas Bondo Pedersen                            *
 ************************************************************************
       Subroutine LDFSCF_Drv(iUHF,nSym,nBas,DSQ,DLT,DSQ_ab,DLT_ab,
-     &                      FLT,FLT_ab,nFLT,ExFac,LWFSQ,LWFSQ_ab,
+     &                      FLT,FLT_ab,nFLT,ExFac,FSQ,FSQ_ab,
      &                      nOcc,nOcc_ab)
 C
 C     Thomas Bondo Pedersen, September 2010.
@@ -20,11 +20,12 @@ C     Purpose: compute two-electron contributions to the SCF Fock matrix
 C              using Local Density Fitting (LDF) coefficients.
 C
       Implicit None
-      Integer iUHF, nSym, nFLT, LWFSQ, LWFSQ_ab
+      Integer iUHF, nSym, nFLT
       Integer nBas(nSym), nOcc(nSym), nOcc_ab(nSym)
       Real*8  DSQ(*), DLT(*)
       Real*8  DSQ_ab(*), DLT_ab(*)
       Real*8  FLT(*), FLT_ab(*)
+      Real*8  FSQ(*), FSQ_ab(*)
       Real*8  ExFac
 #include "WrkSpc.fh"
 #include "ldfscf.fh"
@@ -59,7 +60,6 @@ C
 
       Real*8  ThrPS(2)
       Real*8  FactC(nDen_Max)
-      Real*8  FactX(nDen_Max)
       Integer ip_D(nDen_Max)
       Integer ip_F(nDen_Max)
 
@@ -69,7 +69,6 @@ C
       Integer irc
       Integer ip_UBFNorm, l_UBFNorm
       Integer ipF, lF, ipF2
-      Integer ip_myF, l_myF
       Integer iDen
       Integer AB_MAE, AB_MRNrm
       Integer lMode
@@ -99,8 +98,7 @@ C
 #if defined (_DEBUGPRINT_)
       ! Enter
 #endif
-      Call ThisIsRestrictedCode('Thomas Bondo Pedersen','LDF-SCF',
-     &                          .false.)
+      Call Untested('LDF-SCF')
 
       ! Get print level
 #if defined (_DEBUGPRINT_)
@@ -334,7 +332,6 @@ C--------------------------------------------------------------
       If (ExFac.ne.0.0d0) Then ! Coulomb-and-exchange
          Write(6,'(//,A,A)') SecNam,': Exchange not implemented yet!'
          Call LDF_NotImplemented()
-         FactX(1)=ExFac ! avoid compiler warning
       Else ! Coulomb-only
          ! Set number of density matrices
          nDen=1
@@ -409,56 +406,44 @@ C--------------------------------------------------------------
             Call LDF_Fock_CoulombOnly(IntegralOption,
      &                                Timing,Mode,ThrPS,
      &                                Add,PackedD,PackedF,
-     &                                nDen,FactC,ip_D,ip_F)
+     &                                nDen,FactC,ip_D,FLT)
             ! Debug: check Coulomb error
             If (LDF_CoulombCheck) Then
                Call WarningMessage(0,
      &                            SecNam//': Analysis of Coulomb error')
                Call xFlush(6)
-               l_myF=nDen
-               Call GetMem('DrvmyF','Allo','Inte',ip_myF,l_myF)
                If (PackedF) Then
                   lF=nBas(1)*(nBas(1)+1)/2
                Else
                   lF=nBas(1)**2
                End If
+               Call GetMem('DrvF','Allo','Real',ipF,nDen*lF)
                Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
-                  Call dCopy_(lF,Work(ip_F(iDen)),1,Work(ipF),1)
-                  iWork(ip_myF-1+iDen)=ipF
+                  Call dCopy_(lF,Work(ip_F(iDen)),1,
+     &                           Work(ipF+(iDen-1)*lF),1)
                End Do
                ComputeF=.False.
                Call LDF_Fock_CoulombErrorAnalysis(ComputeF,Mode,
      &                                            PackedD,PackedF,
      &                                            nDen,FactC,ip_D,
-     &                                            iWork(ip_myF))
-               Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  Call GetMem('DrvF','Free','Real',ipF,lF)
-               End Do
-               Call GetMem('DrvmyF','Free','Inte',ip_myF,l_myF)
+     &                                            Work(ipF))
+               Call GetMem('DrvF','Free','Real',ipF,nDen*lF)
             End If
             ! Debug: check mode consistency
             If (LDF_ModeCheck) Then
                LDF_ModeCheck=.False. ! check only once
                Call WarningMessage(0,SecNam//': Mode Check')
                Call xFlush(6)
-               l_myF=nDen*2
-               Call GetMem('DrvmyF','Allo','Inte',ip_myF,l_myF)
                If (PackedF) Then
                   lF=nBas(1)*(nBas(1)+1)/2
                Else
                   lF=nBas(1)**2
                End If
+               Call GetMem('DrvF','Allo','Real',ipF,nDen*2*lF)
                Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
-                  iWork(ip_myF-1+iDen)=ipF
-               End Do
-               Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
                   ipF2=ip_F(iDen)
-                  Call dCopy_(lF,Work(ipF2),1,Work(ipF),1)
-                  iWork(ip_myF-1+nDen+iDen)=ipF
+                  Call dCopy_(lF,Work(ipF2),1,
+     &                           Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                If (Mode.eq.1) Then
                   lMode=3
@@ -468,8 +453,7 @@ C--------------------------------------------------------------
                   factor=-2.0d0
                Else If (Mode.eq.3) Then
                   Do iDen=1,nDen
-                     ipF=iWork(ip_myF-1+nDen+iDen)
-                     Call dScal_(lF,2.0d0,Work(ipF),1)
+                     Call dScal_(lF,2.0d0,Work(ipF+(nDen+iDen-1)*lF),1)
                   End Do
                   lMode=1
                   factor=-1.0d0
@@ -483,12 +467,10 @@ C--------------------------------------------------------------
      &                                   Timing,lMode,ThrPS,
      &                                   Add,PackedD,PackedF,
      &                                   nDen,FactC,ip_D,
-     &                                   iWork(ip_myF))
+     &                                   Work(ipF))
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  ipF2=iWork(ip_myF-1+nDen+iDen)
-                  Call dAXPY_(lF,factor,Work(ipF),1,
-     &                                 Work(ipF2),1)
+                  Call dAXPY_(lF,factor,Work(ipF+(iDen-1)*lF),1,
+     &                                  Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                If (Mode.eq.1) Then
                   lMode=2
@@ -509,18 +491,16 @@ C--------------------------------------------------------------
      &                                   Timing,lMode,ThrPS,
      &                                   Add,PackedD,PackedF,
      &                                   nDen,FactC,ip_D,
-     &                                   iWork(ip_myF))
+     &                                   Work(ipF))
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  ipF2=iWork(ip_myF-1+nDen+iDen)
-                  Call dAXPY_(lF,factor,Work(ipF),1,
-     &                                 Work(ipF2),1)
+                  Call dAXPY_(lF,factor,Work(ipF+(iDen-1)*lF),1,
+     &                                  Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                Call Cho_Head(SecNam//': Mode Check','=',80,6)
                n=0
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+nDen+iDen)
-                  FNorm=sqrt(dDot_(lF,Work(ipF),1,Work(ipF),1))
+                  FNorm=sqrt(dDot_(lF,Work(ipF+(nDen+iDen-1)*lF),1,
+     &                                Work(ipF+(nDen+iDen-1)*lF),1))
                   If (FNorm.gt.Tol_ModeCheck) Then
                      Write(6,'(3X,A,I3,A,1P,D20.10,A)')
      &               'Density no.',iDen,' Check norm=',Fnorm,
@@ -537,11 +517,7 @@ C--------------------------------------------------------------
                   Call LDF_Quit(1)
                End If
                Call xFlush(6)
-               Do iDen=1,nDen*2
-                  ipF=iWork(ip_myF-1+iDen)
-                  Call GetMem('DrvF','Free','Real',ipF,lF)
-               End Do
-               Call GetMem('DrvmyF','Free','Inte',ip_myF,l_myF)
+               Call GetMem('DrvF','Free','Real',ipF,nDen*2*lF)
             End If
          Else ! spin-unrestricted Coulomb-only
             ! Add alpha and beta parts of density matrix
@@ -608,56 +584,44 @@ C--------------------------------------------------------------
             Call LDF_Fock_CoulombOnly(IntegralOption,
      &                                Timing,Mode,ThrPS,
      &                                Add,PackedD,PackedF,
-     &                                nDen,FactC,ip_D,ip_F)
+     &                                nDen,FactC,ip_D,FLT)
             ! Debug: check Coulomb error
             If (LDF_CoulombCheck) Then
                Call WarningMessage(2,
      &                            SecNam//': Analysis of Coulomb error')
                Call xFlush(6)
-               l_myF=nDen
-               Call GetMem('DrvmyF','Allo','Inte',ip_myF,l_myF)
                If (PackedF) Then
                   lF=nBas(1)*(nBas(1)+1)/2
                Else
                   lF=nBas(1)**2
                End If
+               Call GetMem('DrvF','Allo','Real',ipF,nDen*lF)
                Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
-                  Call dCopy_(lF,Work(ip_F(iDen)),1,Work(ipF),1)
-                  iWork(ip_myF-1+iDen)=ipF
+                  Call dCopy_(lF,Work(ip_F(iDen)),1,
+     &                           Work(ipF+(iDen-1)*lF),1)
                End Do
                ComputeF=.False.
                Call LDF_Fock_CoulombErrorAnalysis(ComputeF,Mode,
      &                                            PackedD,PackedF,
      &                                            nDen,FactC,ip_D,
-     &                                            iWork(ip_myF))
-               Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  Call GetMem('DrvF','Free','Real',ipF,lF)
-               End Do
-               Call GetMem('DrvmyF','Free','Inte',ip_myF,l_myF)
+     &                                            Work(ipF))
+               Call GetMem('DrvF','Free','Real',ipF,nDen*lF)
             End If
             ! Debug: check mode consistency
             If (LDF_ModeCheck) Then
                LDF_ModeCheck=.False. ! check only once
                Call WarningMessage(0,SecNam//': Mode Check')
                Call xFlush(6)
-               l_myF=nDen*2
-               Call GetMem('DrvmyF','Allo','Inte',ip_myF,l_myF)
                If (PackedF) Then
                   lF=nBas(1)*(nBas(1)+1)/2
                Else
                   lF=nBas(1)**2
                End If
+               Call GetMem('DrvF','Allo','Real',ipF,nDen*2*lF)
                Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
-                  iWork(ip_myF-1+iDen)=ipF
-               End Do
-               Do iDen=1,nDen
-                  Call GetMem('DrvF','Allo','Real',ipF,lF)
                   ipF2=ip_F(iDen)
-                  Call dCopy_(lF,Work(ipF2),1,Work(ipF),1)
-                  iWork(ip_myF-1+nDen+iDen)=ipF
+                  Call dCopy_(lF,Work(ipF2),1,
+     &                           Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                If (Mode.eq.1) Then
                   lMode=3
@@ -667,8 +631,7 @@ C--------------------------------------------------------------
                   factor=-2.0d0
                Else If (Mode.eq.3) Then
                   Do iDen=1,nDen
-                     ipF=iWork(ip_myF-1+nDen+iDen)
-                     Call dScal_(lF,2.0d0,Work(ipF),1)
+                     Call dScal_(lF,2.0d0,Work(ipF+(nDen+iDen-1)*lF),1)
                   End Do
                   lMode=1
                   factor=-1.0d0
@@ -682,12 +645,10 @@ C--------------------------------------------------------------
      &                                   Timing,lMode,ThrPS,
      &                                   Add,PackedD,PackedF,
      &                                   nDen,FactC,ip_D,
-     &                                   iWork(ip_myF))
+     &                                   Work(ipF))
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  ipF2=iWork(ip_myF-1+nDen+iDen)
-                  Call dAXPY_(lF,factor,Work(ipF),1,
-     &                                 Work(ipF2),1)
+                  Call dAXPY_(lF,factor,Work(ipF+(iDen-1)*lF),1,
+     &                                  Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                If (Mode.eq.1) Then
                   lMode=2
@@ -708,18 +669,16 @@ C--------------------------------------------------------------
      &                                   Timing,lMode,ThrPS,
      &                                   Add,PackedD,PackedF,
      &                                   nDen,FactC,ip_D,
-     &                                   iWork(ip_myF))
+     &                                   Work(ipF))
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+iDen)
-                  ipF2=iWork(ip_myF-1+nDen+iDen)
-                  Call dAXPY_(lF,factor,Work(ipF),1,
-     &                                 Work(ipF2),1)
+                  Call dAXPY_(lF,factor,Work(ipF+(iDen-1)*lF),1,
+     &                                  Work(ipF+(nDen+iDen-1)*lF),1)
                End Do
                Call Cho_Head(SecNam//': Mode Check','=',80,6)
                n=0
                Do iDen=1,nDen
-                  ipF=iWork(ip_myF-1+nDen+iDen)
-                  FNorm=sqrt(dDot_(lF,Work(ipF),1,Work(ipF),1))
+                  FNorm=sqrt(dDot_(lF,Work(ipF+(nDen+iDen-1)*lF),1,
+     &                                Work(ipF+(nDen+iDen-1)*lF),1))
                   If (FNorm.gt.Tol_ModeCheck) Then
                      Write(6,'(3X,A,I3,A,1P,D20.10,A)')
      &               'Density no.',iDen,' Check norm=',Fnorm,
@@ -736,11 +695,7 @@ C--------------------------------------------------------------
                   Call LDF_Quit(1)
                End If
                Call xFlush(6)
-               Do iDen=1,nDen*2
-                  ipF=iWork(ip_myF-1+iDen)
-                  Call GetMem('DrvF','Free','Real',ipF,lF)
-               End Do
-               Call GetMem('DrvmyF','Free','Inte',ip_myF,l_myF)
+               Call GetMem('DrvF','Free','Real',ipF,nDen*2*lF)
             End If
             ! Copy result to FLT_ab
             Call dCopy_(nFLT,FLT,1,FLT_ab,1)
@@ -775,8 +730,8 @@ C--------------------------------------------------------------
 c Avoid unused argument warnings
       If (.False.) Then
          Call Unused_real_array(DLT_ab)
-         Call Unused_integer(LWFSQ)
-         Call Unused_integer(LWFSQ_ab)
+         Call Unused_real_array(FSQ)
+         Call Unused_real_array(FSQ_ab)
          Call Unused_integer_array(nOcc)
          Call Unused_integer_array(nOcc_ab)
       End If
