@@ -61,8 +61,7 @@
       Logical AllowFlip
       Logical Scram, em_On
 *
-      Logical Do_SpinAV
-      COMMON  / SPAVE_L  / Do_SpinAV
+#include "spave.fh"
       Real*8 Ovlp(nFO)
       Save iSeed
       Data iSeed/13/
@@ -156,7 +155,7 @@
 *    &                    '(20F10.4)',TraF,nOccmF)
 #endif
               nOccmF=nOccmF-nConstr(iSym)
-              Call NIdiag(TraF,CMO(iCMO,iD),nOccmF,nBas(iSym),0)
+              Call NIdiag(TraF,CMO(iCMO,iD),nOccmF,nBas(iSym))
               nOccmF=nOccmF+nConstr(iSym)
 #ifdef _DEBUGPRINT_
 *             Call Triprt('Occupied Fock matrix in MO basis',
@@ -189,7 +188,7 @@
 *             Call Triprt('Virtual Fock matrix in MO basis',
 *    &                    '(20F10.4)',TraF,nVrt)
 #endif
-              Call NIdiag(TraF,CMO(iCMO,iD),nVrt,nBas(iSym),0)
+              Call NIdiag(TraF,CMO(iCMO,iD),nVrt,nBas(iSym))
 #ifdef _DEBUGPRINT_
 *             Call Triprt('Virtual Fock matrix in MO basis',
 *    &                    '(20F10.4)',TraF,nVrt)
@@ -414,10 +413,10 @@ c    &                 '(20F10.4)',TraF,nOrbmF)
      &                       nBas(iSym),0,-1,
      &                       'J',nFound,iErr)
 *
-*           Fix standard phase pf the orbitals
+*           Fix standard phase of the orbitals
 *
             Do i = 1, nBas(iSym)
-               tmp = OrbPhase(CMO(iCMO+(i-1)*nBas(iSym),iD),nBas(iSym))
+               call VecPhase(CMO(iCMO+(i-1)*nBas(iSym),iD),nBas(iSym))
             End Do
 *define _DEBUGPRINT_
 #ifdef _DEBUGPRINT_
