@@ -43,6 +43,7 @@
 *     history: UHF - V.Veryazov, 2003                                  *
 *                                                                      *
 ************************************************************************
+      use OFembed, only: Do_OFemb
       Implicit Real*8 (a-h,o-z)
       External EFP_On
 #include "real.fh"
@@ -59,13 +60,9 @@
       Real*8 Fock(nDT,nD)
       Logical FstItr, NoCoul
 *
-      Integer ALGO,NSCREEN
-      Logical REORD,DECO
-      Real*8  dmpk,dFKmat
-      Common /CHOSCF / REORD,DECO,dmpk,dFKmat,ALGO,NSCREEN
+#include "choscf.fh"
 *
-      Logical Do_OFemb, KEonly, OFE_first, Found, EFP_On
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
+      Logical Found, EFP_On
 *
 *---- Define local variables
       Logical First, NonEq, ltmp1, ltmp2, Do_DFT
@@ -87,7 +84,7 @@
         Integer nDens, nDisc
         Real*8, Target:: Dens(nDens), TwoHam(nDens)
         Real*8 Thize, ExFac
-        Logical NoCoul,NoExch
+        Logical NoCoul
         Logical FstItr, PreSch
         End Subroutine Drv2El_dscf
       End Interface
