@@ -34,7 +34,11 @@
 *                                                                      *
 ************************************************************************
       use OccSets
-      use IOBUF
+      use OFembed
+      use IOBuf, only: lDaRec,nSect!,DiskMx_MByte
+#ifdef _HDF5_
+      use mh5, only: mh5_is_hdf5, mh5_open_file_r
+#endif
 *
       Implicit Real*8 (a-h,o-z)
       External Allocdisk
@@ -50,47 +54,29 @@
 #include "file.fh"
 #include "iprlv.fh"
 #include "ksdft.fh"
-#ifdef _HDF5_
-#  include "mh5.fh"
-#endif
+#include "hfc_logical.fh"
 *
 *---- Define local variables
-      Character*180  Key, Line, BLIne
+      Character*180  Key, Line
       Character*180 Get_Ln
       External Get_Ln
       Integer nLev,iArray(32)
       Logical lTtl, IfAufChg,OccSet,FermSet,CharSet,UHFSet,SpinSet
-      Logical Cholesky,REORD,DECO,timings,DensityCheck
-      Integer ALGO,NSCREEN
-      Real*8  dmpk,dFKmat
+      Logical Cholesky
       Real*8  ThrRd(1)
       Integer Mode(1)
 *     character ww*128
       character Method*8
-      Logical Cho_Aufb,Estimate,Update
       Logical TDen_UsrDef
 
-      Common /CHOSCF / REORD,DECO,dmpk,dFKmat,ALGO,NSCREEN
-      COMMON /CHOTIME / timings
-      COMMON /CHODENSITY/ DensityCheck
-      COMMON /CHOSCREEN/ Estimate,Update
-      Common /CHOAUF / Cho_Aufb
-      Logical Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
-      Character*16  OFE_KSDFT
-      COMMON  / OFembed_C / OFE_KSDFT
-      COMMON  / OFembed_I / ipFMaux, ip_NDSD, l_NDSD
-      COMMON  / OFembed_T / ThrFThaw
-      COMMON  / OFembed_R1/ Xsigma
-      COMMON  / OFembed_R2/ dFMD
-      Logical Do_Tw
-      COMMON  / Tw_corr_L   / Do_Tw
-      Character*16  ADDC_KSDFT
-      COMMON  / ADDcorr_C   / ADDC_KSDFT
-      Logical Do_Addc
-      COMMON  / ADDcorr_L   / Do_Addc
-      Logical Do_SpinAV
-      COMMON  / SPAVE_L  / Do_SpinAV
+#include "choscf.fh"
+#include "chotime.fh"
+#include "chodensity.fh"
+#include "choscreen.fh"
+#include "choauf.fh"
+
+#include "addcorr.fh"
+#include "spave.fh"
 
 *
 *     copy input from standard input to a local scratch file
@@ -99,7 +85,6 @@
 *
       Call ICopy(2*MxPrLv,[0],0,iPrLV,1)
 *
-      BLine=' '
       OccSet=.false.
       FermSet=.false.
       CharSet=.false.
@@ -136,16 +121,6 @@
       Do_Addc=.false.
       Do_SpinAV=.false.
       iTer2run=2
-* Orbital-free embedding
-      Do_OFemb=.false.
-      KEonly  =.false.
-      OFE_first  =.true.
-      ThrFThaw = 0.0d0
-      dFMD = 0.0d0
-      Xsigma = 1.0d4
-      ipFMaux = -666666
-      ip_NDSD = -696969
-      l_NDSD = 0
 * KSDFT exch. and corr. scaling factors
       CoefX = 1.0D0
       CoefR = 1.0D0
@@ -318,6 +293,7 @@
       If (Line(1:4).eq.'MCCN') Go To 2510
       If (Line(1:4).eq.'IVO ') Go To 2600
       If (Line(1:4).eq.'UHF ') Go To 2700
+      If (Line(1:4).eq.'HFC ') Go To 2701
       If (Line(1:4).eq.'ROHF') Go To 2800
       If (Line(1:4).eq.'NODA') Go To 2900
       If (Line(1:4).eq.'CONV') Go To 3000
@@ -822,6 +798,11 @@ c      End If
       nD       = 2
       GoTo 1000
 *
+*>>>>>>>>>>>>> HFC  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+ 2701 Continue
+      UHF_HFC     = .True.
+      GoTo 1000
+*
 *>>>>>>>>>>>>> ROHF <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  2800 Continue
       iROHF = 1
@@ -1618,6 +1599,11 @@ c         Write (6,*)
      &   'inappropriate value for Invec')
          Call Abend
       End If
+*
+      If(iUHF.eq.0 .and. UHF_HFC) Then
+      call sysAbendMsg('rdinp','incorrect input',
+     &                 'HFC keyword should be used with UHF')
+      End If
 *
 *---- Print out warning informations (if any)
 *
