@@ -39,7 +39,6 @@
 *     Local variables
       Real*8, Dimension(:), Allocatable:: Tmp, Val, Vec
       Logical Iterate, Restart
-      Real*8 Lambda
 *
       UpMeth='RS-RFO'
       Step_Trunc=' '
@@ -137,7 +136,6 @@
 *        Compute lambda_i according to Eq. (8a)
 *
          EigVal=-DDot_(nInter,dq,1,g,1) ! note sign
-         Lambda = EigVal
 *
 *        Compute R^2 according to Eq. (8c)
 *
