@@ -33,7 +33,9 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
-      use SCF_Arrays
+      Use SCF_Arrays
+      Use Interfaces_SCF, Only: OccDef
+      use OFembed, only: Do_OFemb
       Implicit Real*8 (a-h,o-z)
 *
 #include "mxdm.fh"
@@ -43,14 +45,11 @@
 #include "twoswi.fh"
 #include "file.fh"
 #include "hflda.fh"
-#include "warnings.fh"
-      Logical Do_OFemb,KEonly,OFE_first
-      COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
+#include "warnings.h"
 *
       Character*8 EMILOOP
       Logical FstItr, Semi_Direct
       Real*8 SIntTh
-#include "interfaces_scf.fh"
 *
 *----------------------------------------------------------------------*
 *     Start                                                            *
@@ -97,7 +96,7 @@
 *                                                                      *
       Call WrInp_SCF(SIntTh)
 
-      Call Cre_SCFWfn
+      Call Cre_SCFWfn()
 
       FstItr=.True.
 
@@ -108,14 +107,14 @@
 *     so that iPsLst is right in case of nIter==0
       If (nIter(nIterP).eq.0) iter0=-1
       Call Final()
-      If (DSCF) Call Free_TLists
+      If (DSCF) Call Free_TLists()
 *
       Call CWTime(TCPU2,TWall2)
       Call SavTim(4,TCPU2-TCPU1,TWall2-TWall1)
 *
       Call GMFree()
-      Call ClsFls_SCF
-      If (Semi_Direct) Call xRlsMem_Ints
+      Call ClsFls_SCF()
+      If (Semi_Direct) Call xRlsMem_Ints()
 *
 *     Call MolDen Interface
 *
@@ -282,25 +281,6 @@ c     MemRsv=6*nBT
        Write (6,*)
       Return
       End
-#ifdef _NOTUSED_
-*----------------------------------------------------------------------*
-      Subroutine Init_TLists
-      Implicit Real*8 (a-h,o-z)
-*     Include 'mxdm.fh'
-#include <mxdm.fh>
-
-      Logical Triangular
-*
-      If (DSCF) Then
-         Triangular=.True.
-         Call Init_TList(Triangular)
-         Call Init_PPList
-         Call Init_GTList
-      End If
-*
-      Return
-      End
-#endif
 *----------------------------------------------------------------------*
       Subroutine Free_TLists
       Implicit Real*8 (a-h,o-z)
@@ -308,10 +288,11 @@ c     MemRsv=6*nBT
 #include "mxdm.fh"
 #include "infscf.fh"
 *
+      Write (6,*) 'Free_TLists:',DSCF
       If (DSCF) Then
-         Call Free_TList
-         Call Free_PPList
-         Call Free_GTList
+         Call Free_TList()
+         Call Free_PPList()
+         Call Free_GTList()
       End If
 *
       Return
@@ -324,8 +305,7 @@ c     MemRsv=6*nBT
 #include "mxdm.fh"
 #include "infscf.fh"
 #include "infso.fh"
-      Common /Save/ SIntTh_old, EThr_old, DThr_old, DltNTh_old,
-     &              FThr_old, ThrInt_Old
+#include "save.fh"
 *
       Write (6,*)
       Write (6,*) 'Temporary increase of thresholds...'
@@ -361,13 +341,11 @@ c     MemRsv=6*nBT
 #include "mxdm.fh"
 #include "infscf.fh"
 #include "infso.fh"
-      Common /Save/ SIntTh_old, EThr_old, DThr_old, DltNTh_old,
-     &              FThr_old, ThrInt_Old
+#include "save.fh"
 *
       Write (6,*)
       Write (6,*) 'Restore thresholds...'
       Write (6,*)
-      SIntTh=SIntTh_old
       EThr=EThr_old
       DThr=DThr_old
       DltNTh=DltNTh_old
