@@ -58,6 +58,9 @@
 *                                                                      *
 ************************************************************************
 *
+#ifdef _HDF5_
+      Use mh5, Only: mh5_close_file
+#endif
       Implicit Real*8 (a-h,o-z)
 *
 #include "real.fh"
@@ -65,9 +68,6 @@
 #include "infscf.fh"
 #include "infso.fh"
 #include "file.fh"
-#ifdef _HDF5_
-#  include "mh5.fh"
-#endif
       Real*8 CMO(mBB,nD), TrM(mBB,nD), OneHam(mBT), Fock(mBT,nD),
      &       Ovrlp(mBT), EOrb(mmB,nD), OccNo(mmB,nD)
       Character FName*512, KSDFT_save*16
