@@ -57,17 +57,13 @@
 #include "WrkSpc.fh"
       Real*8 DeTW, CMOI(*), EOcc(*), EVir(*)
 C
-      Logical DoDens_
-      Integer ChoAlg_
       Integer nExt(8)
 #include "mxdm.fh"
 #include "infscf.fh"
 #include "chomp2_cfg.fh"
       Dimension Grad(1)
 
-      DoDens_= DoDens
       DoDens = .false.
-      ChoAlg_= ChoAlg
       ChoAlg = 2
 *
       CALL GETMEM('DMAT','ALLO','REAL',ip_DM0,2*nBT)
@@ -133,9 +129,7 @@ C
       Integer nBas(nSym),nFro(nSym),nIsh(nSym),nSsh(nSym),
      &        nDel(nSym)
       Real*8  CMOI(*), EOcc(*), EVir(*), DM0(*), DM(*)
-      Real*8  DeMP2
-      Logical MP2_small
-      Common / ChFNOPT/ DeMP2, MP2_small
+#include "chfnopt.fh"
 *
       Integer lnOrb(8), lnOcc(8), lnFro(8), lnDel(8), lnVir(8)
 *
