@@ -85,6 +85,10 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
+#ifdef _MSYM_
+      Use, Intrinsic :: iso_c_binding, only: c_ptr
+#endif
+      Use Interfaces_SCF, Only: TraClc_i
       Implicit Real*8 (a-h,o-z)
       External Seconds
       Real*8 Seconds
@@ -103,7 +107,7 @@
 #include "llists.fh"
 #include "twoswi.fh"
 #include "ldfscf.fh"
-#include "warnings.fh"
+#include "warnings.h"
       Real*8, Dimension(:),   Allocatable:: D1Sao
       Real*8, Dimension(:,:), Allocatable:: Grd1, Disp, Xnp1
 
@@ -120,10 +124,10 @@
       Integer iAufOK, Ind(MxOptm)
       Character*128 OrbName
 #ifdef _MSYM_
-      Real*8 msym_ctx
+      Type(c_ptr) msym_ctx
 #endif
-#include "interfaces_scf.fh"
       Dimension Dummy(1),iDummy(7,8)
+      External DNRM2_
 *
 *----------------------------------------------------------------------*
 *     Start                                                            *
@@ -223,7 +227,6 @@
 *---  Print header to iterations
 *
       If(KSDFT.eq.'SCF'.or.One_Grid) Call PrBeg(Meth)
-      Temsav=RTemp
       AufBau_Done=.False.
 *                                                                      *
 *======================================================================*
@@ -300,7 +303,8 @@
 *                                                                      *
 *======================================================================*
 *                                                                      *
-      Do 100 iter = iterSt+1, iterSt+nIter(nIterP)
+      Do 100 iter_ = iterSt+1, iterSt+nIter(nIterP)
+         iter = iter_
          IterX=IterX+1
          WarnCfg=.false.
 *
@@ -583,7 +587,7 @@
 *
 *           compute Norm of dX(n)
 *
-            DltNrm=DBLE(nD)*DNORM2(nOV*nD,Disp,1)
+            DltNrm=DBLE(nD)*DNRM2_(nOV*nD,Disp,1)
 
 *           Generate the CMOs, rotate MOs accordingly to new point
 *
@@ -736,11 +740,6 @@
          If(iUHF.eq.0) Then
             OrbName='SCFORB'
             Note='*  intermediate SCF orbitals'
-            If(KSDFT.eq.'SCF') Then
-               iWFtype=2
-            Else
-               iWFtype=3
-            End If
 
             Call WrVec_(OrbName,LuOut,'CO',iUHF,nSym,nBas,nBas,
      &                  TrM(1,1), Dummy,OccNo(1,1), Dummy,
@@ -753,11 +752,6 @@
          Else
             OrbName='UHFORB'
             Note='*  intermediate UHF orbitals'
-            If(KSDFT.eq.'SCF') Then
-               iWFtype=4
-            Else
-               iWFtype=5
-            End If
             Call WrVec_(OrbName,LuOut,'CO',iUHF,nSym,nBas,nBas,
      &                  TrM(1,1), TrM(1,2),OccNo(1,1),OccNo(1,2),
      &                  Dummy,Dummy, iDummy,Note,3)
@@ -1039,7 +1033,7 @@
 *                                                                      *
 *     End of iteration loop
 *
- 100  Continue ! iter
+ 100  Continue ! iter_
 *                                                                      *
 *======================================================================*
 *                                                                      *
