@@ -166,14 +166,16 @@
       Subroutine fetch_data_RunFile_all( nss, nstate,
      &                                   multiplicity, eso, esfs,
      &                                   U, MM, MS, ML, DM, angmom,
-     &                                   eDmom, amfi, HSO )
+     &                                   eDmom, amfi, HSO,
+     &                                   eso_au, esfs_au )
       Implicit None
-      Integer, Parameter :: wp=selected_real_kind(p=15,r=307)
+      Integer, Parameter            :: wp=kind(0.d0)
 #include "stdalloc.fh"
       Integer :: nss, nstate
       Integer :: multiplicity(nstate)
       Real(kind=8) :: eso(nss), esfs(nstate), angmom(3,nstate,nstate),
-     &                 eDmom(3,nstate,nstate), amfi(3,nstate,nstate)
+     &                 eDmom(3,nstate,nstate), amfi(3,nstate,nstate),
+     &                 eso_au(nss), esfs_au(nstate)
       Complex(kind=8) :: MM(3,nss,nss), MS(3,nss,nss), ML(3,nss,nss)
       Complex(kind=8) :: DM(3,nss,nss)
       Complex(kind=8) :: U(nss,nss), HSO(nss,nss)
@@ -181,12 +183,12 @@
       Integer              :: njob, mxjob, iss, ibas(nstate,-50:50)
       Integer              :: i, j, i1, j1, ist, jst, mult, multI, multJ
       Integer              :: l, ipar, info
-      Real(kind=8)        :: g_e, au2cm, thr_deg, diff
+      Real(kind=8)         :: g_e, au2cm, thr_deg, diff
       ! allocatable local arrays:
-      Integer, allocatable :: mltplt(:), jbnum(:) !,lroot(:)
+      Integer, allocatable :: mltplt(:), jbnum(:), nstat(:) !,lroot(:)
       Real(kind=8), allocatable :: tmpR(:,:), tmpI(:,:), W(:)
       Complex(kind=8), allocatable :: tmp(:,:)
-      Complex(kind=8) :: Spin
+      Complex(kind=8)  :: Spin
       External         :: Spin
       Logical          :: found_edmom, found_amfi, found_hsor,
      &                    found_hsoi
@@ -201,11 +203,14 @@
       ! allocate temporary memory:
       Call mma_allocate(jbnum,nstate,'jbnum')
       Call mma_allocate(mltplt,mxjob,'mltplt')
+      Call mma_allocate(nstat,mxjob,'nstat')
       ! get the information from RUNFILE:
       mltplt=0
       jbnum=0
+      nstat=0
       Call get_iArray('MLTP_SINGLE',MLTPLT,MXJOB)
       Call get_iArray('JBNUM_SINGLE',JBNUM,NSTATE)
+      Call get_iArray('NSTAT_SINGLE',NSTAT,MXJOB)
       ! computing the multiplicity of each state:
       multiplicity=0
       Do i=1,nstate
@@ -213,14 +218,19 @@
       End Do
       Call mma_deallocate(jbnum)
       Call mma_deallocate(mltplt)
+      Call mma_deallocate(nstat)
 
       ! fetch the spin-orbit energies:
       eso=0.0_wp
+      eso_au=0.0_wp
       Call get_dArray('ESO_SINGLE',eso,nss)
+      Call get_dArray('ESO_LOW',eso_au,nss)
 
       ! fetch the spin-free energies:
       esfs=0.0_wp
+      esfs_au=0.0_wp
       Call get_dArray('ESFS_SINGLE',esfs,nstate)
+      Call get_dArray('ESFS_SINGLEAU',esfs_au,nstate)
 
       ! fetch the U matrix:
       Call mma_allocate(tmpR,nss,nss,'tmpR')
@@ -239,12 +249,10 @@
       End Do
 
 
-
       ! fetch the angular momentum integrals:
       angmom=0.0_wp
       Call get_dArray('ANGM_SINGLE',angmom,3*nstate*nstate)
 
-
       ! fetch the electric dipole moment integrals:
       edmom=0.0_wp
       found_EDMOM=.false.
@@ -260,7 +268,6 @@
       If (found_amfi)
      &  Call get_dArray('AMFI_SINGLE',amfi,3*nstate*nstate)
 
-
       ! fetch the spin-orbit hamiltonian
       FOUND_HSOR=.FALSE.
       FOUND_HSOI=.FALSE.
@@ -299,6 +306,7 @@
          Do i=1,nss
             ESO(i) = (W(i)-W(1))*au2cm
          End Do
+
          Call mma_deallocate(W)
 !-----------------------------------------------------------------------
       End If
@@ -367,6 +375,7 @@ c----- expand the spin free basis to the spin-orbit basis:
          End Do   ! Jst
       End Do   ! Ist
 
+
       ! calculate the matrix elements of the spin and magnetic moment
       ! in the spin-orbit basis:
       Call mma_allocate(tmp,nss,nss,'tmp')
@@ -418,5 +427,8 @@ c----- expand the spin free basis to the spin-orbit basis:
       Call mma_deallocate(tmp)
 
 
+      ! check the commutation rules of spin:
+      Call check_commutation(nss, MS(1:3,1:nss,1:nss), .false.)
+
       Return
       End Subroutine fetch_data_RunFile_all
